/* shotwell-video-thumbnailer.c generated by valac 0.36.6, the Vala compiler
 * generated from shotwell-video-thumbnailer.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 * 
 * This is a Vala-rewrite of GStreamer snapshot example. Adapted from earlier 
 * work from Wim Taymans.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */
/* Shotwell Thumbnailer takes in a video file and returns a thumbnail to stdout.  This is*/
/* a replacement for totem-video-thumbnailer*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gst/gst.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdio.h>
#include <gobject/gvaluecollector.h>


#define TYPE_SHOTWELL_THUMBNAILER (shotwell_thumbnailer_get_type ())
#define SHOTWELL_THUMBNAILER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SHOTWELL_THUMBNAILER, ShotwellThumbnailer))
#define SHOTWELL_THUMBNAILER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SHOTWELL_THUMBNAILER, ShotwellThumbnailerClass))
#define IS_SHOTWELL_THUMBNAILER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SHOTWELL_THUMBNAILER))
#define IS_SHOTWELL_THUMBNAILER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SHOTWELL_THUMBNAILER))
#define SHOTWELL_THUMBNAILER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SHOTWELL_THUMBNAILER, ShotwellThumbnailerClass))

typedef struct _ShotwellThumbnailer ShotwellThumbnailer;
typedef struct _ShotwellThumbnailerClass ShotwellThumbnailerClass;
typedef struct _ShotwellThumbnailerPrivate ShotwellThumbnailerPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _ParamSpecShotwellThumbnailer ParamSpecShotwellThumbnailer;

struct _ShotwellThumbnailer {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ShotwellThumbnailerPrivate * priv;
};

struct _ShotwellThumbnailerClass {
	GTypeClass parent_class;
	void (*finalize) (ShotwellThumbnailer *self);
};

struct _ParamSpecShotwellThumbnailer {
	GParamSpec parent_instance;
};


static gpointer shotwell_thumbnailer_parent_class = NULL;

gpointer shotwell_thumbnailer_ref (gpointer instance);
void shotwell_thumbnailer_unref (gpointer instance);
GParamSpec* param_spec_shotwell_thumbnailer (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_shotwell_thumbnailer (GValue* value, gpointer v_object);
void value_take_shotwell_thumbnailer (GValue* value, gpointer v_object);
gpointer value_get_shotwell_thumbnailer (const GValue* value);
GType shotwell_thumbnailer_get_type (void) G_GNUC_CONST;
enum  {
	SHOTWELL_THUMBNAILER_DUMMY_PROPERTY
};
#define SHOTWELL_THUMBNAILER_caps_string "video/x-raw,format=RGB,pixel-aspect-ratio=1/1"
gint shotwell_thumbnailer_main (gchar** args, int args_length1);
ShotwellThumbnailer* shotwell_thumbnailer_new (void);
ShotwellThumbnailer* shotwell_thumbnailer_construct (GType object_type);
static void shotwell_thumbnailer_finalize (ShotwellThumbnailer * obj);


static gpointer _g_object_ref0 (gpointer self) {
#line 25 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	return self ? g_object_ref (self) : NULL;
#line 79 "shotwell-video-thumbnailer.c"
}


gint shotwell_thumbnailer_main (gchar** args, int args_length1) {
	gint result = 0;
	GstElement* pipeline = NULL;
	GstElement* sink = NULL;
	gchar* descr = NULL;
	GdkPixbuf* pixbuf = NULL;
	guint8* pngdata = NULL;
	gint pngdata_length1 = 0;
	gint _pngdata_size_ = 0;
	gint64 duration = 0LL;
	gint64 position = 0LL;
	GstStateChangeReturn ret = 0;
	GstRegistry* registry = NULL;
	GstRegistry* _tmp0_;
	GstRegistry* _tmp1_;
	GstPluginFeature* feature = NULL;
	GstRegistry* _tmp2_;
	GstPluginFeature* _tmp3_;
	GstPluginFeature* _tmp4_;
	GstRegistry* _tmp7_;
	GstPluginFeature* _tmp8_;
	GstPluginFeature* _tmp9_;
	gchar** _tmp12_;
	gint _tmp12__length1;
	gchar** _tmp16_;
	gint _tmp16__length1;
	const gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	GError * _inner_error_ = NULL;
#line 23 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	gst_init (&args_length1, &args);
#line 25 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp0_ = gst_registry_get ();
#line 25 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 25 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	registry = _tmp1_;
#line 27 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp2_ = registry;
#line 27 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp3_ = gst_registry_find_feature (_tmp2_, "vaapidecodebin", gst_element_factory_get_type ());
#line 27 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	feature = _tmp3_;
#line 29 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp4_ = feature;
#line 29 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (_tmp4_ != NULL) {
#line 134 "shotwell-video-thumbnailer.c"
		GstRegistry* _tmp5_;
		GstPluginFeature* _tmp6_;
#line 30 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp5_ = registry;
#line 30 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp6_ = feature;
#line 30 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		gst_registry_remove_feature (_tmp5_, _tmp6_);
#line 143 "shotwell-video-thumbnailer.c"
	}
#line 33 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp7_ = registry;
#line 33 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp8_ = gst_registry_find_feature (_tmp7_, "vaapidecode", gst_element_factory_get_type ());
#line 33 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_g_object_unref0 (feature);
#line 33 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	feature = _tmp8_;
#line 35 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp9_ = feature;
#line 35 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (_tmp9_ != NULL) {
#line 157 "shotwell-video-thumbnailer.c"
		GstRegistry* _tmp10_;
		GstPluginFeature* _tmp11_;
#line 36 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp10_ = registry;
#line 36 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp11_ = feature;
#line 36 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		gst_registry_remove_feature (_tmp10_, _tmp11_);
#line 166 "shotwell-video-thumbnailer.c"
	}
#line 39 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp12_ = args;
#line 39 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp12__length1 = args_length1;
#line 39 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (_tmp12__length1 != 2) {
#line 174 "shotwell-video-thumbnailer.c"
		FILE* _tmp13_;
		gchar** _tmp14_;
		gint _tmp14__length1;
		const gchar* _tmp15_;
#line 40 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp13_ = stdout;
#line 40 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp14_ = args;
#line 40 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp14__length1 = args_length1;
#line 40 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp15_ = _tmp14_[0];
#line 40 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		fprintf (_tmp13_, "usage: %s [filename]\n Writes video thumbnail to stdout\n", _tmp15_);
#line 41 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		result = 1;
#line 41 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (feature);
#line 41 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (registry);
#line 41 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		pngdata = (g_free (pngdata), NULL);
#line 41 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (pixbuf);
#line 41 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_free0 (descr);
#line 41 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (sink);
#line 41 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (pipeline);
#line 41 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		return result;
#line 207 "shotwell-video-thumbnailer.c"
	}
#line 44 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp16_ = args;
#line 44 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp16__length1 = args_length1;
#line 44 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp17_ = _tmp16_[1];
#line 44 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp18_ = g_strdup_printf ("filesrc location=\"%s\" ! decodebin ! videoconvert ! videoscale ! ", _tmp17_);
#line 44 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp19_ = _tmp18_;
#line 44 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp20_ = g_strdup_printf ("%s ! gdkpixbufsink name=sink", SHOTWELL_THUMBNAILER_caps_string);
#line 44 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp21_ = _tmp20_;
#line 44 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_tmp22_ = g_strconcat (_tmp19_, _tmp21_, NULL);
#line 44 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_g_free0 (descr);
#line 44 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	descr = _tmp22_;
#line 44 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_g_free0 (_tmp21_);
#line 44 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_g_free0 (_tmp19_);
#line 233 "shotwell-video-thumbnailer.c"
	{
		GstElement* _tmp23_ = NULL;
		const gchar* _tmp24_;
		GstElement* _tmp25_;
		GstElement* _tmp26_;
		GstElement* _tmp27_;
		GstElement* _tmp28_;
		GstElement* _tmp29_;
		GstStateChangeReturn _tmp30_;
		GstStateChangeReturn _tmp31_;
		GstElement* _tmp35_;
		GstStateChangeReturn _tmp36_;
		GstStateChangeReturn _tmp37_;
		GstElement* _tmp39_;
		gint64 _tmp40_ = 0LL;
		gboolean _tmp41_;
		GstElement* _tmp43_;
		gint64 _tmp44_;
		GstElement* _tmp45_;
		GstStateChangeReturn _tmp46_;
		GstStateChangeReturn _tmp47_;
		GstElement* _tmp49_;
		GdkPixbuf* _tmp50_;
		guint8* _tmp51_ = NULL;
		gsize _tmp52_;
		FILE* _tmp53_;
		guint8* _tmp54_;
		gint _tmp54__length1;
		GstElement* _tmp55_;
#line 49 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp24_ = descr;
#line 49 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp25_ = gst_parse_launch_full (_tmp24_, NULL, GST_PARSE_FLAG_NONE, &_inner_error_);
#line 49 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		g_object_ref_sink (_tmp25_);
#line 49 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp23_ = _tmp25_;
#line 49 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 273 "shotwell-video-thumbnailer.c"
			goto __catch0_g_error;
		}
#line 49 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp26_ = _tmp23_;
#line 49 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp23_ = NULL;
#line 49 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		g_object_ref_sink (_tmp26_);
#line 49 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (pipeline);
#line 49 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		pipeline = _tmp26_;
#line 52 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp27_ = pipeline;
#line 52 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp28_ = gst_bin_get_by_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gst_bin_get_type (), GstBin), "sink");
#line 52 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (sink);
#line 52 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		sink = _tmp28_;
#line 55 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp29_ = pipeline;
#line 55 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp30_ = gst_element_set_state (_tmp29_, GST_STATE_PAUSED);
#line 55 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		ret = _tmp30_;
#line 56 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp31_ = ret;
#line 56 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		if (_tmp31_ == GST_STATE_CHANGE_FAILURE) {
#line 304 "shotwell-video-thumbnailer.c"
			FILE* _tmp32_;
#line 57 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_tmp32_ = stderr;
#line 57 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			fprintf (_tmp32_, "Failed to play the file: couldn't set state\n");
#line 58 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			result = 3;
#line 58 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (_tmp23_);
#line 58 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (feature);
#line 58 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (registry);
#line 58 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			pngdata = (g_free (pngdata), NULL);
#line 58 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (pixbuf);
#line 58 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_free0 (descr);
#line 58 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (sink);
#line 58 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (pipeline);
#line 58 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			return result;
#line 330 "shotwell-video-thumbnailer.c"
		} else {
			GstStateChangeReturn _tmp33_;
#line 59 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_tmp33_ = ret;
#line 59 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			if (_tmp33_ == GST_STATE_CHANGE_NO_PREROLL) {
#line 337 "shotwell-video-thumbnailer.c"
				FILE* _tmp34_;
#line 60 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
				_tmp34_ = stderr;
#line 60 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
				fprintf (_tmp34_, "Live sources not supported yet.\n");
#line 61 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
				result = 4;
#line 61 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
				_g_object_unref0 (_tmp23_);
#line 61 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
				_g_object_unref0 (feature);
#line 61 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
				_g_object_unref0 (registry);
#line 61 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
				pngdata = (g_free (pngdata), NULL);
#line 61 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
				_g_object_unref0 (pixbuf);
#line 61 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
				_g_free0 (descr);
#line 61 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
				_g_object_unref0 (sink);
#line 61 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
				_g_object_unref0 (pipeline);
#line 61 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
				return result;
#line 363 "shotwell-video-thumbnailer.c"
			}
		}
#line 67 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp35_ = pipeline;
#line 67 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp36_ = gst_element_get_state (_tmp35_, NULL, NULL, (GstClockTime) (5 * GST_SECOND));
#line 67 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		ret = _tmp36_;
#line 68 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp37_ = ret;
#line 68 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		if (_tmp37_ == GST_STATE_CHANGE_FAILURE) {
#line 376 "shotwell-video-thumbnailer.c"
			FILE* _tmp38_;
#line 69 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_tmp38_ = stderr;
#line 69 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			fprintf (_tmp38_, "Failed to play the file: couldn't get state.\n");
#line 70 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			result = 3;
#line 70 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (_tmp23_);
#line 70 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (feature);
#line 70 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (registry);
#line 70 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			pngdata = (g_free (pngdata), NULL);
#line 70 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (pixbuf);
#line 70 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_free0 (descr);
#line 70 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (sink);
#line 70 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (pipeline);
#line 70 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			return result;
#line 402 "shotwell-video-thumbnailer.c"
		}
#line 74 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp39_ = pipeline;
#line 74 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp41_ = gst_element_query_duration (_tmp39_, GST_FORMAT_TIME, &_tmp40_);
#line 74 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		duration = _tmp40_;
#line 74 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		if (!_tmp41_) {
#line 412 "shotwell-video-thumbnailer.c"
			FILE* _tmp42_;
#line 75 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_tmp42_ = stderr;
#line 75 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			fprintf (_tmp42_, "Failed to query file for duration\n");
#line 76 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			result = 3;
#line 76 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (_tmp23_);
#line 76 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (feature);
#line 76 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (registry);
#line 76 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			pngdata = (g_free (pngdata), NULL);
#line 76 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (pixbuf);
#line 76 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_free0 (descr);
#line 76 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (sink);
#line 76 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (pipeline);
#line 76 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			return result;
#line 438 "shotwell-video-thumbnailer.c"
		}
#line 79 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		position = (gint64) (1 * GST_SECOND);
#line 85 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp43_ = pipeline;
#line 85 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp44_ = position;
#line 85 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		gst_element_seek_simple (_tmp43_, GST_FORMAT_TIME, GST_SEEK_FLAG_KEY_UNIT | GST_SEEK_FLAG_FLUSH, _tmp44_);
#line 87 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp45_ = pipeline;
#line 87 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp46_ = gst_element_get_state (_tmp45_, NULL, NULL, (GstClockTime) (5 * GST_SECOND));
#line 87 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		ret = _tmp46_;
#line 88 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp47_ = ret;
#line 88 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		if (_tmp47_ == GST_STATE_CHANGE_FAILURE) {
#line 458 "shotwell-video-thumbnailer.c"
			FILE* _tmp48_;
#line 89 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_tmp48_ = stderr;
#line 89 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			fprintf (_tmp48_, "Failed to play the file: couldn't get state.\n");
#line 90 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			result = 3;
#line 90 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (_tmp23_);
#line 90 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (feature);
#line 90 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (registry);
#line 90 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			pngdata = (g_free (pngdata), NULL);
#line 90 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (pixbuf);
#line 90 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_free0 (descr);
#line 90 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (sink);
#line 90 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (pipeline);
#line 90 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			return result;
#line 484 "shotwell-video-thumbnailer.c"
		}
#line 93 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp49_ = sink;
#line 93 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, G_TYPE_OBJECT, GObject), "last-pixbuf", &pixbuf, NULL);
#line 96 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp50_ = pixbuf;
#line 96 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		gdk_pixbuf_save_to_buffer (_tmp50_, &_tmp51_, &_tmp52_, "png", &_inner_error_, NULL);
#line 96 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		pngdata = (g_free (pngdata), NULL);
#line 96 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		pngdata = _tmp51_;
#line 96 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		pngdata_length1 = _tmp52_;
#line 96 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_pngdata_size_ = pngdata_length1;
#line 96 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 96 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			_g_object_unref0 (_tmp23_);
#line 506 "shotwell-video-thumbnailer.c"
			goto __catch0_g_error;
		}
#line 97 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp53_ = stdout;
#line 97 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp54_ = pngdata;
#line 97 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp54__length1 = pngdata_length1;
#line 97 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		fwrite (_tmp54_, (gsize) 1, _tmp54__length1, _tmp53_);
#line 100 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp55_ = pipeline;
#line 100 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		gst_element_set_state (_tmp55_, GST_STATE_NULL);
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (_tmp23_);
#line 523 "shotwell-video-thumbnailer.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		FILE* _tmp56_;
		GError* _tmp57_;
		const gchar* _tmp58_;
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		e = _inner_error_;
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_inner_error_ = NULL;
#line 103 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp56_ = stderr;
#line 103 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp57_ = e;
#line 103 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_tmp58_ = _tmp57_->message;
#line 103 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		fprintf (_tmp56_, "%s", _tmp58_);
#line 104 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		result = 2;
#line 104 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_error_free0 (e);
#line 104 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (feature);
#line 104 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (registry);
#line 104 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		pngdata = (g_free (pngdata), NULL);
#line 104 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (pixbuf);
#line 104 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_free0 (descr);
#line 104 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (sink);
#line 104 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (pipeline);
#line 104 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		return result;
#line 564 "shotwell-video-thumbnailer.c"
	}
	__finally0:
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 569 "shotwell-video-thumbnailer.c"
		gint _tmp59_ = 0;
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (feature);
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (registry);
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		pngdata = (g_free (pngdata), NULL);
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (pixbuf);
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_free0 (descr);
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (sink);
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		_g_object_unref0 (pipeline);
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		g_clear_error (&_inner_error_);
#line 47 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		return _tmp59_;
#line 591 "shotwell-video-thumbnailer.c"
	}
#line 107 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	result = 0;
#line 107 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_g_object_unref0 (feature);
#line 107 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_g_object_unref0 (registry);
#line 107 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	pngdata = (g_free (pngdata), NULL);
#line 107 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_g_object_unref0 (pixbuf);
#line 107 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_g_free0 (descr);
#line 107 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_g_object_unref0 (sink);
#line 107 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	_g_object_unref0 (pipeline);
#line 107 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	return result;
#line 611 "shotwell-video-thumbnailer.c"
}


int main (int argc, char ** argv) {
#if !GLIB_CHECK_VERSION (2,35,0)
	g_type_init ();
#endif
#line 15 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	return shotwell_thumbnailer_main (argv, argc);
#line 621 "shotwell-video-thumbnailer.c"
}


ShotwellThumbnailer* shotwell_thumbnailer_construct (GType object_type) {
	ShotwellThumbnailer* self = NULL;
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	self = (ShotwellThumbnailer*) g_type_create_instance (object_type);
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	return self;
#line 631 "shotwell-video-thumbnailer.c"
}


ShotwellThumbnailer* shotwell_thumbnailer_new (void) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	return shotwell_thumbnailer_construct (TYPE_SHOTWELL_THUMBNAILER);
#line 638 "shotwell-video-thumbnailer.c"
}


static void value_shotwell_thumbnailer_init (GValue* value) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	value->data[0].v_pointer = NULL;
#line 645 "shotwell-video-thumbnailer.c"
}


static void value_shotwell_thumbnailer_free_value (GValue* value) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (value->data[0].v_pointer) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		shotwell_thumbnailer_unref (value->data[0].v_pointer);
#line 654 "shotwell-video-thumbnailer.c"
	}
}


static void value_shotwell_thumbnailer_copy_value (const GValue* src_value, GValue* dest_value) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (src_value->data[0].v_pointer) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		dest_value->data[0].v_pointer = shotwell_thumbnailer_ref (src_value->data[0].v_pointer);
#line 664 "shotwell-video-thumbnailer.c"
	} else {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		dest_value->data[0].v_pointer = NULL;
#line 668 "shotwell-video-thumbnailer.c"
	}
}


static gpointer value_shotwell_thumbnailer_peek_pointer (const GValue* value) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	return value->data[0].v_pointer;
#line 676 "shotwell-video-thumbnailer.c"
}


static gchar* value_shotwell_thumbnailer_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (collect_values[0].v_pointer) {
#line 683 "shotwell-video-thumbnailer.c"
		ShotwellThumbnailer * object;
		object = collect_values[0].v_pointer;
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		if (object->parent_instance.g_class == NULL) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 690 "shotwell-video-thumbnailer.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 694 "shotwell-video-thumbnailer.c"
		}
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		value->data[0].v_pointer = shotwell_thumbnailer_ref (object);
#line 698 "shotwell-video-thumbnailer.c"
	} else {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		value->data[0].v_pointer = NULL;
#line 702 "shotwell-video-thumbnailer.c"
	}
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	return NULL;
#line 706 "shotwell-video-thumbnailer.c"
}


static gchar* value_shotwell_thumbnailer_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	ShotwellThumbnailer ** object_p;
	object_p = collect_values[0].v_pointer;
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (!object_p) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 717 "shotwell-video-thumbnailer.c"
	}
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (!value->data[0].v_pointer) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		*object_p = NULL;
#line 723 "shotwell-video-thumbnailer.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		*object_p = value->data[0].v_pointer;
#line 727 "shotwell-video-thumbnailer.c"
	} else {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		*object_p = shotwell_thumbnailer_ref (value->data[0].v_pointer);
#line 731 "shotwell-video-thumbnailer.c"
	}
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	return NULL;
#line 735 "shotwell-video-thumbnailer.c"
}


GParamSpec* param_spec_shotwell_thumbnailer (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecShotwellThumbnailer* spec;
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_SHOTWELL_THUMBNAILER), NULL);
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	return G_PARAM_SPEC (spec);
#line 749 "shotwell-video-thumbnailer.c"
}


gpointer value_get_shotwell_thumbnailer (const GValue* value) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_SHOTWELL_THUMBNAILER), NULL);
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	return value->data[0].v_pointer;
#line 758 "shotwell-video-thumbnailer.c"
}


void value_set_shotwell_thumbnailer (GValue* value, gpointer v_object) {
	ShotwellThumbnailer * old;
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_SHOTWELL_THUMBNAILER));
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	old = value->data[0].v_pointer;
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (v_object) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_SHOTWELL_THUMBNAILER));
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		value->data[0].v_pointer = v_object;
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		shotwell_thumbnailer_ref (value->data[0].v_pointer);
#line 778 "shotwell-video-thumbnailer.c"
	} else {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		value->data[0].v_pointer = NULL;
#line 782 "shotwell-video-thumbnailer.c"
	}
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (old) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		shotwell_thumbnailer_unref (old);
#line 788 "shotwell-video-thumbnailer.c"
	}
}


void value_take_shotwell_thumbnailer (GValue* value, gpointer v_object) {
	ShotwellThumbnailer * old;
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_SHOTWELL_THUMBNAILER));
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	old = value->data[0].v_pointer;
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (v_object) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_SHOTWELL_THUMBNAILER));
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		value->data[0].v_pointer = v_object;
#line 807 "shotwell-video-thumbnailer.c"
	} else {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		value->data[0].v_pointer = NULL;
#line 811 "shotwell-video-thumbnailer.c"
	}
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (old) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		shotwell_thumbnailer_unref (old);
#line 817 "shotwell-video-thumbnailer.c"
	}
}


static void shotwell_thumbnailer_class_init (ShotwellThumbnailerClass * klass) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	shotwell_thumbnailer_parent_class = g_type_class_peek_parent (klass);
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	((ShotwellThumbnailerClass *) klass)->finalize = shotwell_thumbnailer_finalize;
#line 827 "shotwell-video-thumbnailer.c"
}


static void shotwell_thumbnailer_instance_init (ShotwellThumbnailer * self) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	self->ref_count = 1;
#line 834 "shotwell-video-thumbnailer.c"
}


static void shotwell_thumbnailer_finalize (ShotwellThumbnailer * obj) {
	ShotwellThumbnailer * self;
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SHOTWELL_THUMBNAILER, ShotwellThumbnailer);
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	g_signal_handlers_destroy (self);
#line 844 "shotwell-video-thumbnailer.c"
}


GType shotwell_thumbnailer_get_type (void) {
	static volatile gsize shotwell_thumbnailer_type_id__volatile = 0;
	if (g_once_init_enter (&shotwell_thumbnailer_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_shotwell_thumbnailer_init, value_shotwell_thumbnailer_free_value, value_shotwell_thumbnailer_copy_value, value_shotwell_thumbnailer_peek_pointer, "p", value_shotwell_thumbnailer_collect_value, "p", value_shotwell_thumbnailer_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (ShotwellThumbnailerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) shotwell_thumbnailer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ShotwellThumbnailer), 0, (GInstanceInitFunc) shotwell_thumbnailer_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType shotwell_thumbnailer_type_id;
		shotwell_thumbnailer_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ShotwellThumbnailer", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&shotwell_thumbnailer_type_id__volatile, shotwell_thumbnailer_type_id);
	}
	return shotwell_thumbnailer_type_id__volatile;
}


gpointer shotwell_thumbnailer_ref (gpointer instance) {
	ShotwellThumbnailer * self;
	self = instance;
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	g_atomic_int_inc (&self->ref_count);
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	return instance;
#line 869 "shotwell-video-thumbnailer.c"
}


void shotwell_thumbnailer_unref (gpointer instance) {
	ShotwellThumbnailer * self;
	self = instance;
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		SHOTWELL_THUMBNAILER_GET_CLASS (self)->finalize (self);
#line 12 "/home/jens/Source/shotwell/thumbnailer/shotwell-video-thumbnailer.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 882 "shotwell-video-thumbnailer.c"
	}
}



