/* FSpotMetaTable.c generated by valac 0.36.6, the Vala compiler
 * generated from FSpotMetaTable.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <sqlite3.h>


#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_ROW (data_imports_fspot_db_fspot_meta_row_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_META_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_ROW, DataImportsFSpotDbFSpotMetaRow))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_META_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_ROW, DataImportsFSpotDbFSpotMetaRowClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_META_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_ROW))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_META_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_ROW))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_META_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_ROW, DataImportsFSpotDbFSpotMetaRowClass))

typedef struct _DataImportsFSpotDbFSpotMetaRow DataImportsFSpotDbFSpotMetaRow;
typedef struct _DataImportsFSpotDbFSpotMetaRowClass DataImportsFSpotDbFSpotMetaRowClass;
typedef struct _DataImportsFSpotDbFSpotMetaRowPrivate DataImportsFSpotDbFSpotMetaRowPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_IMPORTABLE_DATABASE_TABLE (importable_database_table_get_type ())
#define IMPORTABLE_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORTABLE_DATABASE_TABLE, ImportableDatabaseTable))
#define IMPORTABLE_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORTABLE_DATABASE_TABLE, ImportableDatabaseTableClass))
#define IS_IMPORTABLE_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORTABLE_DATABASE_TABLE))
#define IS_IMPORTABLE_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORTABLE_DATABASE_TABLE))
#define IMPORTABLE_DATABASE_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORTABLE_DATABASE_TABLE, ImportableDatabaseTableClass))

typedef struct _ImportableDatabaseTable ImportableDatabaseTable;
typedef struct _ImportableDatabaseTableClass ImportableDatabaseTableClass;
typedef struct _ImportableDatabaseTablePrivate ImportableDatabaseTablePrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE (data_imports_fspot_db_fspot_database_table_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTableClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_DATABASE_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTableClass))

typedef struct _DataImportsFSpotDbFSpotDatabaseTable DataImportsFSpotDbFSpotDatabaseTable;
typedef struct _DataImportsFSpotDbFSpotDatabaseTableClass DataImportsFSpotDbFSpotDatabaseTableClass;
typedef struct _DataImportsFSpotDbFSpotDatabaseTablePrivate DataImportsFSpotDbFSpotDatabaseTablePrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR (data_imports_fspot_db_fspot_table_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TABLE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_TABLE_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_TABLE_BEHAVIOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehaviorIface))

typedef struct _DataImportsFSpotDbFSpotTableBehavior DataImportsFSpotDbFSpotTableBehavior;
typedef struct _DataImportsFSpotDbFSpotTableBehaviorIface DataImportsFSpotDbFSpotTableBehaviorIface;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_TABLE (data_imports_fspot_db_fspot_meta_table_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_META_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_TABLE, DataImportsFSpotDbFSpotMetaTable))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_META_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_TABLE, DataImportsFSpotDbFSpotMetaTableClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_META_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_TABLE))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_META_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_TABLE))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_META_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_TABLE, DataImportsFSpotDbFSpotMetaTableClass))

typedef struct _DataImportsFSpotDbFSpotMetaTable DataImportsFSpotDbFSpotMetaTable;
typedef struct _DataImportsFSpotDbFSpotMetaTableClass DataImportsFSpotDbFSpotMetaTableClass;
typedef struct _DataImportsFSpotDbFSpotMetaTablePrivate DataImportsFSpotDbFSpotMetaTablePrivate;

#define DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_BEHAVIOR (data_imports_fspot_db_fspot_meta_behavior_get_type ())
#define DATA_IMPORTS_FSPOT_DB_FSPOT_META_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_BEHAVIOR, DataImportsFSpotDbFSpotMetaBehavior))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_META_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_BEHAVIOR, DataImportsFSpotDbFSpotMetaBehaviorClass))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_META_BEHAVIOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_IS_FSPOT_META_BEHAVIOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_BEHAVIOR))
#define DATA_IMPORTS_FSPOT_DB_FSPOT_META_BEHAVIOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_BEHAVIOR, DataImportsFSpotDbFSpotMetaBehaviorClass))

typedef struct _DataImportsFSpotDbFSpotMetaBehavior DataImportsFSpotDbFSpotMetaBehavior;
typedef struct _DataImportsFSpotDbFSpotMetaBehaviorClass DataImportsFSpotDbFSpotMetaBehaviorClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _sqlite3_finalize0(var) ((var == NULL) ? NULL : (var = (sqlite3_finalize (var), NULL)))
typedef struct _DataImportsFSpotDbFSpotMetaBehaviorPrivate DataImportsFSpotDbFSpotMetaBehaviorPrivate;

struct _DataImportsFSpotDbFSpotMetaRow {
	GObject parent_instance;
	DataImportsFSpotDbFSpotMetaRowPrivate * priv;
	gchar* name;
	gchar* data;
};

struct _DataImportsFSpotDbFSpotMetaRowClass {
	GObjectClass parent_class;
};

struct _ImportableDatabaseTable {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportableDatabaseTablePrivate * priv;
	gchar* table_name;
};

struct _ImportableDatabaseTableClass {
	GTypeClass parent_class;
	void (*finalize) (ImportableDatabaseTable *self);
};

struct _DataImportsFSpotDbFSpotTableBehaviorIface {
	GTypeInterface parent_iface;
	gchar* (*get_table_name) (DataImportsFSpotDbFSpotTableBehavior* self);
	gchar** (*list_columns) (DataImportsFSpotDbFSpotTableBehavior* self, int* result_length1);
	void (*build_row) (DataImportsFSpotDbFSpotTableBehavior* self, sqlite3_stmt* stmt, gpointer* row, gint offset);
};

struct _DataImportsFSpotDbFSpotDatabaseTable {
	ImportableDatabaseTable parent_instance;
	DataImportsFSpotDbFSpotDatabaseTablePrivate * priv;
	sqlite3* fspot_db;
	DataImportsFSpotDbFSpotTableBehavior* behavior;
};

struct _DataImportsFSpotDbFSpotDatabaseTableClass {
	ImportableDatabaseTableClass parent_class;
};

struct _DataImportsFSpotDbFSpotMetaTable {
	DataImportsFSpotDbFSpotDatabaseTable parent_instance;
	DataImportsFSpotDbFSpotMetaTablePrivate * priv;
};

struct _DataImportsFSpotDbFSpotMetaTableClass {
	DataImportsFSpotDbFSpotDatabaseTableClass parent_class;
};

typedef enum  {
	DATABASE_ERROR_ERROR,
	DATABASE_ERROR_BACKING,
	DATABASE_ERROR_MEMORY,
	DATABASE_ERROR_ABORT,
	DATABASE_ERROR_LIMITS,
	DATABASE_ERROR_TYPESPEC
} DatabaseError;
#define DATABASE_ERROR database_error_quark ()
struct _DataImportsFSpotDbFSpotMetaBehavior {
	GObject parent_instance;
	DataImportsFSpotDbFSpotMetaBehaviorPrivate * priv;
};

struct _DataImportsFSpotDbFSpotMetaBehaviorClass {
	GObjectClass parent_class;
};


static gpointer data_imports_fspot_db_fspot_meta_row_parent_class = NULL;
static gpointer data_imports_fspot_db_fspot_meta_table_parent_class = NULL;
static gpointer data_imports_fspot_db_fspot_meta_behavior_parent_class = NULL;
static DataImportsFSpotDbFSpotMetaBehavior* data_imports_fspot_db_fspot_meta_behavior_instance;
static DataImportsFSpotDbFSpotMetaBehavior* data_imports_fspot_db_fspot_meta_behavior_instance = NULL;
static DataImportsFSpotDbFSpotTableBehaviorIface * data_imports_fspot_db_fspot_meta_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = NULL;

GType data_imports_fspot_db_fspot_meta_row_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_META_ROW_DUMMY_PROPERTY
};
DataImportsFSpotDbFSpotMetaRow* data_imports_fspot_db_fspot_meta_row_new (void);
DataImportsFSpotDbFSpotMetaRow* data_imports_fspot_db_fspot_meta_row_construct (GType object_type);
static void data_imports_fspot_db_fspot_meta_row_finalize (GObject * obj);
gpointer importable_database_table_ref (gpointer instance);
void importable_database_table_unref (gpointer instance);
GParamSpec* param_spec_importable_database_table (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_importable_database_table (GValue* value, gpointer v_object);
void value_take_importable_database_table (GValue* value, gpointer v_object);
gpointer value_get_importable_database_table (const GValue* value);
GType importable_database_table_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_database_table_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_table_behavior_get_type (void) G_GNUC_CONST;
GType data_imports_fspot_db_fspot_meta_table_get_type (void) G_GNUC_CONST;
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_META_TABLE_DUMMY_PROPERTY
};
DataImportsFSpotDbFSpotMetaTable* data_imports_fspot_db_fspot_meta_table_new (sqlite3* db);
DataImportsFSpotDbFSpotMetaTable* data_imports_fspot_db_fspot_meta_table_construct (GType object_type, sqlite3* db);
DataImportsFSpotDbFSpotDatabaseTable* data_imports_fspot_db_fspot_database_table_construct (GType object_type, GType t_type, GBoxedCopyFunc t_dup_func, GDestroyNotify t_destroy_func, sqlite3* db);
void data_imports_fspot_db_fspot_database_table_set_behavior (DataImportsFSpotDbFSpotDatabaseTable* self, DataImportsFSpotDbFSpotTableBehavior* behavior);
GType data_imports_fspot_db_fspot_meta_behavior_get_type (void) G_GNUC_CONST;
DataImportsFSpotDbFSpotMetaBehavior* data_imports_fspot_db_fspot_meta_behavior_get_instance (void);
GQuark database_error_quark (void);
gchar* data_imports_fspot_db_fspot_meta_table_get_data (DataImportsFSpotDbFSpotMetaTable* self, const gchar* name, GError** error);
gchar** data_imports_fspot_db_fspot_table_behavior_list_columns (DataImportsFSpotDbFSpotTableBehavior* self, int* result_length1);
void importable_database_table_throw_error (const gchar* method, gint res, GError** error);
void data_imports_fspot_db_fspot_table_behavior_build_row (DataImportsFSpotDbFSpotTableBehavior* self, sqlite3_stmt* stmt, gpointer* row, gint offset);
gchar* data_imports_fspot_db_fspot_meta_table_get_app_version (DataImportsFSpotDbFSpotMetaTable* self, GError** error);
gchar* data_imports_fspot_db_fspot_meta_table_get_db_version (DataImportsFSpotDbFSpotMetaTable* self, GError** error);
gint64 data_imports_fspot_db_fspot_meta_table_get_hidden_tag_id (DataImportsFSpotDbFSpotMetaTable* self, GError** error);
enum  {
	DATA_IMPORTS_FSPOT_DB_FSPOT_META_BEHAVIOR_DUMMY_PROPERTY
};
#define DATA_IMPORTS_FSPOT_DB_FSPOT_META_BEHAVIOR_TABLE_NAME "Meta"
static DataImportsFSpotDbFSpotMetaBehavior* data_imports_fspot_db_fspot_meta_behavior_new (void);
static DataImportsFSpotDbFSpotMetaBehavior* data_imports_fspot_db_fspot_meta_behavior_construct (GType object_type);
static gchar* data_imports_fspot_db_fspot_meta_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base);
static gchar** data_imports_fspot_db_fspot_meta_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1);
static void data_imports_fspot_db_fspot_meta_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotMetaRow* * row, gint offset);
static void data_imports_fspot_db_fspot_meta_behavior_finalize (GObject * obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


DataImportsFSpotDbFSpotMetaRow* data_imports_fspot_db_fspot_meta_row_construct (GType object_type) {
	DataImportsFSpotDbFSpotMetaRow * self = NULL;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	self = (DataImportsFSpotDbFSpotMetaRow*) g_object_new (object_type, NULL);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	return self;
#line 214 "FSpotMetaTable.c"
}


DataImportsFSpotDbFSpotMetaRow* data_imports_fspot_db_fspot_meta_row_new (void) {
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	return data_imports_fspot_db_fspot_meta_row_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_ROW);
#line 221 "FSpotMetaTable.c"
}


static void data_imports_fspot_db_fspot_meta_row_class_init (DataImportsFSpotDbFSpotMetaRowClass * klass) {
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	data_imports_fspot_db_fspot_meta_row_parent_class = g_type_class_peek_parent (klass);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_meta_row_finalize;
#line 230 "FSpotMetaTable.c"
}


static void data_imports_fspot_db_fspot_meta_row_instance_init (DataImportsFSpotDbFSpotMetaRow * self) {
}


static void data_imports_fspot_db_fspot_meta_row_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotMetaRow * self;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_ROW, DataImportsFSpotDbFSpotMetaRow);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_g_free0 (self->name);
#line 15 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_g_free0 (self->data);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_meta_row_parent_class)->finalize (obj);
#line 248 "FSpotMetaTable.c"
}


/**
 * The value object for the "meta" table, representing a single database row.
 */
GType data_imports_fspot_db_fspot_meta_row_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_meta_row_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_meta_row_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotMetaRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_meta_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotMetaRow), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_meta_row_instance_init, NULL };
		GType data_imports_fspot_db_fspot_meta_row_type_id;
		data_imports_fspot_db_fspot_meta_row_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotMetaRow", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_fspot_db_fspot_meta_row_type_id__volatile, data_imports_fspot_db_fspot_meta_row_type_id);
	}
	return data_imports_fspot_db_fspot_meta_row_type_id__volatile;
}


DataImportsFSpotDbFSpotMetaTable* data_imports_fspot_db_fspot_meta_table_construct (GType object_type, sqlite3* db) {
	DataImportsFSpotDbFSpotMetaTable* self = NULL;
	sqlite3* _tmp0_;
	DataImportsFSpotDbFSpotMetaBehavior* _tmp1_;
	DataImportsFSpotDbFSpotMetaBehavior* _tmp2_;
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	g_return_val_if_fail (db != NULL, NULL);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp0_ = db;
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	self = (DataImportsFSpotDbFSpotMetaTable*) data_imports_fspot_db_fspot_database_table_construct (object_type, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_ROW, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp0_);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp1_ = data_imports_fspot_db_fspot_meta_behavior_get_instance ();
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp2_ = _tmp1_;
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	data_imports_fspot_db_fspot_database_table_set_behavior (G_TYPE_CHECK_INSTANCE_CAST (self, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable), G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, DataImportsFSpotDbFSpotTableBehavior));
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_g_object_unref0 (_tmp2_);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	return self;
#line 288 "FSpotMetaTable.c"
}


DataImportsFSpotDbFSpotMetaTable* data_imports_fspot_db_fspot_meta_table_new (sqlite3* db) {
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	return data_imports_fspot_db_fspot_meta_table_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_TABLE, db);
#line 295 "FSpotMetaTable.c"
}


static gchar* _vala_g_strjoinv (const gchar* separator, gchar** str_array, int str_array_length1) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gchar** _tmp3_;
	gint _tmp3__length1;
#line 1078 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = separator;
#line 1078 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp0_ == NULL) {
#line 1079 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		separator = "";
#line 312 "FSpotMetaTable.c"
	}
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = str_array;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3__length1 = str_array_length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp2_ = TRUE;
#line 322 "FSpotMetaTable.c"
	} else {
		gchar** _tmp4_;
		gint _tmp4__length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = str_array;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4__length1 = str_array_length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp4__length1 > 0;
#line 332 "FSpotMetaTable.c"
	}
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp2_) {
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 338 "FSpotMetaTable.c"
	} else {
		gboolean _tmp5_ = FALSE;
		gchar** _tmp6_;
		gint _tmp6__length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6_ = str_array;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6__length1 = str_array_length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		if (_tmp6__length1 == -1) {
#line 349 "FSpotMetaTable.c"
			gchar** _tmp7_;
			gint _tmp7__length1;
			const gchar* _tmp8_;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp7_ = str_array;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp7__length1 = str_array_length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp8_ = _tmp7_[0];
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp5_ = _tmp8_ != NULL;
#line 361 "FSpotMetaTable.c"
		} else {
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp5_ = FALSE;
#line 365 "FSpotMetaTable.c"
		}
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp1_ = _tmp5_;
#line 369 "FSpotMetaTable.c"
	}
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 373 "FSpotMetaTable.c"
		gint i = 0;
		gsize len = 0UL;
		gint _tmp31_;
		gint _tmp33_;
		gint _tmp34_;
		gsize _tmp35_;
		const gchar* _tmp36_;
		gint _tmp37_;
		gint _tmp38_;
		gint _tmp39_;
		const gchar* res = NULL;
		gsize _tmp40_;
		void* _tmp41_;
		void* ptr = NULL;
		const gchar* _tmp42_;
		gchar** _tmp43_;
		gint _tmp43__length1;
		const gchar* _tmp44_;
		void* _tmp45_;
		const gchar* _tmp62_;
#line 1083 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		len = (gsize) 1;
#line 396 "FSpotMetaTable.c"
		{
			gboolean _tmp9_ = FALSE;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			i = 0;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp9_ = TRUE;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 405 "FSpotMetaTable.c"
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				gchar** _tmp13_;
				gint _tmp13__length1;
				gint _tmp21_ = 0;
				gchar** _tmp22_;
				gint _tmp22__length1;
				gint _tmp23_;
				const gchar* _tmp24_;
				gsize _tmp30_;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (!_tmp9_) {
#line 418 "FSpotMetaTable.c"
					gint _tmp10_;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp10_ = i;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					i = _tmp10_ + 1;
#line 424 "FSpotMetaTable.c"
				}
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp9_ = FALSE;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp13_ = str_array;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp13__length1 = str_array_length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (_tmp13__length1 != -1) {
#line 434 "FSpotMetaTable.c"
					gint _tmp14_;
					gchar** _tmp15_;
					gint _tmp15__length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp14_ = i;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp15_ = str_array;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp15__length1 = str_array_length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp12_ = _tmp14_ < _tmp15__length1;
#line 446 "FSpotMetaTable.c"
				} else {
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp12_ = FALSE;
#line 450 "FSpotMetaTable.c"
				}
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (_tmp12_) {
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp11_ = TRUE;
#line 456 "FSpotMetaTable.c"
				} else {
					gboolean _tmp16_ = FALSE;
					gchar** _tmp17_;
					gint _tmp17__length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp17_ = str_array;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp17__length1 = str_array_length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					if (_tmp17__length1 == -1) {
#line 467 "FSpotMetaTable.c"
						gchar** _tmp18_;
						gint _tmp18__length1;
						gint _tmp19_;
						const gchar* _tmp20_;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp18_ = str_array;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp18__length1 = str_array_length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp19_ = i;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp20_ = _tmp18_[_tmp19_];
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp16_ = _tmp20_ != NULL;
#line 482 "FSpotMetaTable.c"
					} else {
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp16_ = FALSE;
#line 486 "FSpotMetaTable.c"
					}
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp11_ = _tmp16_;
#line 490 "FSpotMetaTable.c"
				}
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (!_tmp11_) {
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					break;
#line 496 "FSpotMetaTable.c"
				}
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp22_ = str_array;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp22__length1 = str_array_length1;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp23_ = i;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp24_ = _tmp22_[_tmp23_];
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (_tmp24_ != NULL) {
#line 508 "FSpotMetaTable.c"
					gchar** _tmp25_;
					gint _tmp25__length1;
					gint _tmp26_;
					const gchar* _tmp27_;
					gint _tmp28_;
					gint _tmp29_;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp25_ = str_array;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp25__length1 = str_array_length1;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp26_ = i;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp27_ = _tmp25_[_tmp26_];
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp28_ = strlen ((const gchar*) _tmp27_);
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp29_ = _tmp28_;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp21_ = _tmp29_;
#line 529 "FSpotMetaTable.c"
				} else {
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp21_ = 0;
#line 533 "FSpotMetaTable.c"
				}
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp30_ = len;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				len = _tmp30_ + _tmp21_;
#line 539 "FSpotMetaTable.c"
			}
		}
#line 1087 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp31_ = i;
#line 1087 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		if (_tmp31_ == 0) {
#line 546 "FSpotMetaTable.c"
			gchar* _tmp32_;
#line 1088 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp32_ = g_strdup ("");
#line 1088 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			result = _tmp32_;
#line 1088 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			return result;
#line 554 "FSpotMetaTable.c"
		}
#line 1090 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp33_ = i;
#line 1090 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		str_array_length1 = _tmp33_;
#line 1090 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp34_ = str_array_length1;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp35_ = len;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp36_ = separator;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp37_ = strlen ((const gchar*) _tmp36_);
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp38_ = _tmp37_;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp39_ = i;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		len = _tmp35_ + (_tmp38_ * (_tmp39_ - 1));
#line 1093 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp40_ = len;
#line 1093 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp41_ = g_malloc (_tmp40_);
#line 1093 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		res = _tmp41_;
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp42_ = res;
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp43_ = str_array;
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp43__length1 = str_array_length1;
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp44_ = _tmp43_[0];
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp45_ = g_stpcpy ((void*) _tmp42_, (const gchar*) _tmp44_);
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		ptr = _tmp45_;
#line 592 "FSpotMetaTable.c"
		{
			gboolean _tmp46_ = FALSE;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			i = 1;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp46_ = TRUE;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 601 "FSpotMetaTable.c"
				gint _tmp48_;
				gchar** _tmp49_;
				gint _tmp49__length1;
				void* _tmp50_;
				const gchar* _tmp51_;
				void* _tmp52_;
				const gchar* _tmp53_ = NULL;
				gchar** _tmp54_;
				gint _tmp54__length1;
				gint _tmp55_;
				const gchar* _tmp56_;
				void* _tmp60_;
				void* _tmp61_;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (!_tmp46_) {
#line 617 "FSpotMetaTable.c"
					gint _tmp47_;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp47_ = i;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					i = _tmp47_ + 1;
#line 623 "FSpotMetaTable.c"
				}
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp46_ = FALSE;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp48_ = i;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp49_ = str_array;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp49__length1 = str_array_length1;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (!(_tmp48_ < _tmp49__length1)) {
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					break;
#line 637 "FSpotMetaTable.c"
				}
#line 1096 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp50_ = ptr;
#line 1096 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp51_ = separator;
#line 1096 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp52_ = g_stpcpy (_tmp50_, (const gchar*) _tmp51_);
#line 1096 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				ptr = _tmp52_;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp54_ = str_array;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp54__length1 = str_array_length1;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp55_ = i;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp56_ = _tmp54_[_tmp55_];
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (_tmp56_ != NULL) {
#line 657 "FSpotMetaTable.c"
					gchar** _tmp57_;
					gint _tmp57__length1;
					gint _tmp58_;
					const gchar* _tmp59_;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp57_ = str_array;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp57__length1 = str_array_length1;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp58_ = i;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp59_ = _tmp57_[_tmp58_];
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp53_ = (const gchar*) _tmp59_;
#line 672 "FSpotMetaTable.c"
				} else {
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp53_ = "";
#line 676 "FSpotMetaTable.c"
				}
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp60_ = ptr;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp61_ = g_stpcpy (_tmp60_, _tmp53_);
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				ptr = _tmp61_;
#line 684 "FSpotMetaTable.c"
			}
		}
#line 1100 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp62_ = res;
#line 1100 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		res = NULL;
#line 1100 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = (gchar*) _tmp62_;
#line 1100 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 695 "FSpotMetaTable.c"
	} else {
		gchar* _tmp63_;
#line 1102 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp63_ = g_strdup ("");
#line 1102 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = _tmp63_;
#line 1102 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 704 "FSpotMetaTable.c"
	}
}


gchar* data_imports_fspot_db_fspot_meta_table_get_data (DataImportsFSpotDbFSpotMetaTable* self, const gchar* name, GError** error) {
	gchar* result = NULL;
	gchar** columns = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp0_;
	gint _tmp1_;
	gchar** _tmp2_;
	gint columns_length1;
	gint _columns_size_;
	gchar* column_list = NULL;
	gchar** _tmp3_;
	gint _tmp3__length1;
	gchar* _tmp4_;
	gchar* sql = NULL;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp8_;
	const gchar* _tmp9_;
	sqlite3_stmt* _tmp10_ = NULL;
	gint _tmp11_;
	gint _tmp12_;
	sqlite3_stmt* _tmp17_;
	const gchar* _tmp18_;
	gchar* _tmp19_;
	GDestroyNotify _tmp20_;
	gint _tmp21_;
	gint _tmp22_;
	sqlite3_stmt* _tmp27_;
	gint _tmp28_;
	gint _tmp29_;
	DataImportsFSpotDbFSpotMetaRow* row = NULL;
	DataImportsFSpotDbFSpotTableBehavior* _tmp32_;
	sqlite3_stmt* _tmp33_;
	gpointer _tmp34_ = NULL;
	DataImportsFSpotDbFSpotMetaRow* _tmp35_;
	const gchar* _tmp36_;
	gchar* _tmp37_;
	GError * _inner_error_ = NULL;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_META_TABLE (self), NULL);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (self, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable)->behavior;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_table_behavior_list_columns (_tmp0_, &_tmp1_);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	columns = _tmp2_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	columns_length1 = _tmp1_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_columns_size_ = columns_length1;
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp3_ = columns;
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp3__length1 = columns_length1;
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp4_ = _vala_g_strjoinv (", ", _tmp3_, _tmp3__length1);
#line 41 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	column_list = _tmp4_;
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp5_ = column_list;
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp6_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_IMPORTABLE_DATABASE_TABLE, ImportableDatabaseTable)->table_name;
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp7_ = g_strdup_printf ("SELECT %s FROM %s WHERE name=?", _tmp5_, _tmp6_);
#line 42 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	sql = _tmp7_;
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp8_ = G_TYPE_CHECK_INSTANCE_CAST (self, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable)->fspot_db;
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp9_ = sql;
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp11_ = sqlite3_prepare_v2 (_tmp8_, _tmp9_, -1, &_tmp10_, NULL);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_sqlite3_finalize0 (stmt);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	stmt = _tmp10_;
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	res = _tmp11_;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp12_ = res;
#line 45 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	if (_tmp12_ != SQLITE_OK) {
#line 795 "FSpotMetaTable.c"
		const gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gint _tmp16_;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_tmp13_ = sql;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_tmp14_ = g_strdup_printf ("Statement failed: %s", _tmp13_);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_tmp15_ = _tmp14_;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_tmp16_ = res;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		importable_database_table_throw_error (_tmp15_, _tmp16_, &_inner_error_);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_g_free0 (_tmp15_);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				g_propagate_error (error, _inner_error_);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				_sqlite3_finalize0 (stmt);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				_g_free0 (sql);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				_g_free0 (column_list);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				columns = (_vala_array_free (columns, columns_length1, (GDestroyNotify) g_free), NULL);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				return NULL;
#line 828 "FSpotMetaTable.c"
			} else {
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				_sqlite3_finalize0 (stmt);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				_g_free0 (sql);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				_g_free0 (column_list);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				columns = (_vala_array_free (columns, columns_length1, (GDestroyNotify) g_free), NULL);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				g_clear_error (&_inner_error_);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				return NULL;
#line 844 "FSpotMetaTable.c"
			}
		}
	}
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp17_ = stmt;
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp18_ = name;
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp19_ = g_strdup (_tmp18_);
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp20_ = g_free;
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp21_ = sqlite3_bind_text (_tmp17_, 1, _tmp19_, -1, _tmp20_);
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	res = _tmp21_;
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp22_ = res;
#line 49 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	if (_tmp22_ != SQLITE_OK) {
#line 864 "FSpotMetaTable.c"
		const gchar* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gint _tmp26_;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_tmp23_ = name;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_tmp24_ = g_strdup_printf ("Bind failed for name %s", _tmp23_);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_tmp25_ = _tmp24_;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_tmp26_ = res;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		importable_database_table_throw_error (_tmp25_, _tmp26_, &_inner_error_);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_g_free0 (_tmp25_);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				g_propagate_error (error, _inner_error_);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				_sqlite3_finalize0 (stmt);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				_g_free0 (sql);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				_g_free0 (column_list);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				columns = (_vala_array_free (columns, columns_length1, (GDestroyNotify) g_free), NULL);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				return NULL;
#line 897 "FSpotMetaTable.c"
			} else {
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				_sqlite3_finalize0 (stmt);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				_g_free0 (sql);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				_g_free0 (column_list);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				columns = (_vala_array_free (columns, columns_length1, (GDestroyNotify) g_free), NULL);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				g_clear_error (&_inner_error_);
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				return NULL;
#line 913 "FSpotMetaTable.c"
			}
		}
	}
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp27_ = stmt;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp28_ = sqlite3_step (_tmp27_);
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	res = _tmp28_;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp29_ = res;
#line 53 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	if (_tmp29_ != SQLITE_ROW) {
#line 927 "FSpotMetaTable.c"
		gint _tmp30_;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_tmp30_ = res;
#line 54 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		if (_tmp30_ != SQLITE_DONE) {
#line 933 "FSpotMetaTable.c"
			gint _tmp31_;
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			_tmp31_ = res;
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			importable_database_table_throw_error ("FSpotMetaTable.get_data", _tmp31_, &_inner_error_);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
				if (_inner_error_->domain == DATABASE_ERROR) {
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
					g_propagate_error (error, _inner_error_);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
					_sqlite3_finalize0 (stmt);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
					_g_free0 (sql);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
					_g_free0 (column_list);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
					columns = (_vala_array_free (columns, columns_length1, (GDestroyNotify) g_free), NULL);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
					return NULL;
#line 955 "FSpotMetaTable.c"
				} else {
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
					_sqlite3_finalize0 (stmt);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
					_g_free0 (sql);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
					_g_free0 (column_list);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
					columns = (_vala_array_free (columns, columns_length1, (GDestroyNotify) g_free), NULL);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
					g_clear_error (&_inner_error_);
#line 55 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
					return NULL;
#line 971 "FSpotMetaTable.c"
				}
			}
		}
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		result = NULL;
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_sqlite3_finalize0 (stmt);
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_g_free0 (sql);
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_g_free0 (column_list);
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		columns = (_vala_array_free (columns, columns_length1, (GDestroyNotify) g_free), NULL);
#line 57 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		return result;
#line 987 "FSpotMetaTable.c"
	}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp32_ = G_TYPE_CHECK_INSTANCE_CAST (self, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, DataImportsFSpotDbFSpotDatabaseTable)->behavior;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp33_ = stmt;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	data_imports_fspot_db_fspot_table_behavior_build_row (_tmp32_, _tmp33_, &_tmp34_, 0);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_g_object_unref0 (row);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	row = _tmp34_;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp35_ = row;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp36_ = _tmp35_->data;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp37_ = g_strdup (_tmp36_);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	result = _tmp37_;
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_g_object_unref0 (row);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_sqlite3_finalize0 (stmt);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_g_free0 (sql);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_g_free0 (column_list);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	columns = (_vala_array_free (columns, columns_length1, (GDestroyNotify) g_free), NULL);
#line 62 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	return result;
#line 1019 "FSpotMetaTable.c"
}


gchar* data_imports_fspot_db_fspot_meta_table_get_app_version (DataImportsFSpotDbFSpotMetaTable* self, GError** error) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_;
	gchar* _tmp2_;
	GError * _inner_error_ = NULL;
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_META_TABLE (self), NULL);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp1_ = data_imports_fspot_db_fspot_meta_table_get_data (self, "F-Spot Version", &_inner_error_);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp0_ = _tmp1_;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			g_propagate_error (error, _inner_error_);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			return NULL;
#line 1043 "FSpotMetaTable.c"
		} else {
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			g_clear_error (&_inner_error_);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			return NULL;
#line 1051 "FSpotMetaTable.c"
		}
	}
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp2_ = _tmp0_;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp0_ = NULL;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	result = _tmp2_;
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_g_free0 (_tmp0_);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	return result;
#line 1064 "FSpotMetaTable.c"
}


gchar* data_imports_fspot_db_fspot_meta_table_get_db_version (DataImportsFSpotDbFSpotMetaTable* self, GError** error) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_;
	gchar* _tmp2_;
	GError * _inner_error_ = NULL;
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_META_TABLE (self), NULL);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp1_ = data_imports_fspot_db_fspot_meta_table_get_data (self, "F-Spot Database Version", &_inner_error_);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp0_ = _tmp1_;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			g_propagate_error (error, _inner_error_);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			return NULL;
#line 1088 "FSpotMetaTable.c"
		} else {
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			g_clear_error (&_inner_error_);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			return NULL;
#line 1096 "FSpotMetaTable.c"
		}
	}
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp2_ = _tmp0_;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp0_ = NULL;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	result = _tmp2_;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_g_free0 (_tmp0_);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	return result;
#line 1109 "FSpotMetaTable.c"
}


static gint64 int64_parse (const gchar* str) {
	gint64 result = 0LL;
	const gchar* _tmp0_;
	gint64 _tmp1_;
#line 687 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (str != NULL, 0LL);
#line 688 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = str;
#line 688 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = g_ascii_strtoll (_tmp0_, NULL, (guint) 0);
#line 688 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 688 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 1127 "FSpotMetaTable.c"
}


gint64 data_imports_fspot_db_fspot_meta_table_get_hidden_tag_id (DataImportsFSpotDbFSpotMetaTable* self, GError** error) {
	gint64 result = 0LL;
	gchar* id_str = NULL;
	gchar* _tmp0_;
	GError * _inner_error_ = NULL;
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	g_return_val_if_fail (DATA_IMPORTS_FSPOT_DB_IS_FSPOT_META_TABLE (self), 0LL);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_meta_table_get_data (self, "Hidden Tag Id", &_inner_error_);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	id_str = _tmp0_;
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 1146 "FSpotMetaTable.c"
			gint64 _tmp1_ = 0LL;
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			g_propagate_error (error, _inner_error_);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			return _tmp1_;
#line 1152 "FSpotMetaTable.c"
		} else {
			gint64 _tmp2_ = 0LL;
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			g_clear_error (&_inner_error_);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
			return _tmp2_;
#line 1161 "FSpotMetaTable.c"
		}
	}
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	if (id_str != NULL) {
#line 1166 "FSpotMetaTable.c"
		gint64 _tmp3_;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_tmp3_ = int64_parse (id_str);
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		result = _tmp3_;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_g_free0 (id_str);
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		return result;
#line 1176 "FSpotMetaTable.c"
	} else {
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		result = (gint64) -1;
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_g_free0 (id_str);
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		return result;
#line 1184 "FSpotMetaTable.c"
	}
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_g_free0 (id_str);
#line 1188 "FSpotMetaTable.c"
}


static void data_imports_fspot_db_fspot_meta_table_class_init (DataImportsFSpotDbFSpotMetaTableClass * klass) {
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	data_imports_fspot_db_fspot_meta_table_parent_class = g_type_class_peek_parent (klass);
#line 1195 "FSpotMetaTable.c"
}


static void data_imports_fspot_db_fspot_meta_table_instance_init (DataImportsFSpotDbFSpotMetaTable * self) {
}


/**
 * This class represents the F-Spot meta table, which stores some essential
 * meta-data for the whole database. It is implemented as a simple dictionary
 * where each row in the table is a key/value pair.
 *
 * The meta table implementation is the only one that throws a database error
 * if something goes wrong because:
 *  * it is essential to read the content of that table in order to identify
 *    the version of the database and select the correct behavior,
 *  * this table is read at the very beginning of the process so any failure
 *    will occur immediately,
 *  * failing to read this table means that there is no point in reading the
 *    attempting to read the rest of the database so we might as well abort.
 */
GType data_imports_fspot_db_fspot_meta_table_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_meta_table_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_meta_table_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotMetaTableClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_meta_table_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotMetaTable), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_meta_table_instance_init, NULL };
		GType data_imports_fspot_db_fspot_meta_table_type_id;
		data_imports_fspot_db_fspot_meta_table_type_id = g_type_register_static (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_DATABASE_TABLE, "DataImportsFSpotDbFSpotMetaTable", &g_define_type_info, 0);
		g_once_init_leave (&data_imports_fspot_db_fspot_meta_table_type_id__volatile, data_imports_fspot_db_fspot_meta_table_type_id);
	}
	return data_imports_fspot_db_fspot_meta_table_type_id__volatile;
}


static DataImportsFSpotDbFSpotMetaBehavior* data_imports_fspot_db_fspot_meta_behavior_construct (GType object_type) {
	DataImportsFSpotDbFSpotMetaBehavior * self = NULL;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	self = (DataImportsFSpotDbFSpotMetaBehavior*) g_object_new (object_type, NULL);
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	return self;
#line 1235 "FSpotMetaTable.c"
}


static DataImportsFSpotDbFSpotMetaBehavior* data_imports_fspot_db_fspot_meta_behavior_new (void) {
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	return data_imports_fspot_db_fspot_meta_behavior_construct (DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_BEHAVIOR);
#line 1242 "FSpotMetaTable.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	return self ? g_object_ref (self) : NULL;
#line 1249 "FSpotMetaTable.c"
}


DataImportsFSpotDbFSpotMetaBehavior* data_imports_fspot_db_fspot_meta_behavior_get_instance (void) {
	DataImportsFSpotDbFSpotMetaBehavior* result = NULL;
	DataImportsFSpotDbFSpotMetaBehavior* _tmp0_;
	DataImportsFSpotDbFSpotMetaBehavior* _tmp2_;
	DataImportsFSpotDbFSpotMetaBehavior* _tmp3_;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_meta_behavior_instance;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	if (_tmp0_ == NULL) {
#line 1262 "FSpotMetaTable.c"
		DataImportsFSpotDbFSpotMetaBehavior* _tmp1_;
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_tmp1_ = data_imports_fspot_db_fspot_meta_behavior_new ();
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_g_object_unref0 (data_imports_fspot_db_fspot_meta_behavior_instance);
#line 93 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		data_imports_fspot_db_fspot_meta_behavior_instance = _tmp1_;
#line 1270 "FSpotMetaTable.c"
	}
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp2_ = data_imports_fspot_db_fspot_meta_behavior_instance;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	result = _tmp3_;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	return result;
#line 1280 "FSpotMetaTable.c"
}


static gchar* data_imports_fspot_db_fspot_meta_behavior_real_get_table_name (DataImportsFSpotDbFSpotTableBehavior* base) {
	DataImportsFSpotDbFSpotMetaBehavior * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 97 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_BEHAVIOR, DataImportsFSpotDbFSpotMetaBehavior);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp0_ = g_strdup (DATA_IMPORTS_FSPOT_DB_FSPOT_META_BEHAVIOR_TABLE_NAME);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	result = _tmp0_;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	return result;
#line 1296 "FSpotMetaTable.c"
}


static gchar** data_imports_fspot_db_fspot_meta_behavior_real_list_columns (DataImportsFSpotDbFSpotTableBehavior* base, int* result_length1) {
	DataImportsFSpotDbFSpotMetaBehavior * self;
	gchar** result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar** _tmp2_;
	gchar** _tmp3_;
	gint _tmp3__length1;
#line 101 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_BEHAVIOR, DataImportsFSpotDbFSpotMetaBehavior);
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp0_ = g_strdup ("name");
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp1_ = g_strdup ("data");
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp2_ = g_new0 (gchar*, 2 + 1);
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp2_[0] = _tmp0_;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp2_[1] = _tmp1_;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp3_ = _tmp2_;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp3__length1 = 2;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	if (result_length1) {
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		*result_length1 = _tmp3__length1;
#line 1328 "FSpotMetaTable.c"
	}
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	result = _tmp3_;
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	return result;
#line 1334 "FSpotMetaTable.c"
}


static void data_imports_fspot_db_fspot_meta_behavior_real_build_row (DataImportsFSpotDbFSpotTableBehavior* base, sqlite3_stmt* stmt, DataImportsFSpotDbFSpotMetaRow* * row, gint offset) {
	DataImportsFSpotDbFSpotMetaBehavior * self;
	DataImportsFSpotDbFSpotMetaRow* _vala_row = NULL;
	DataImportsFSpotDbFSpotMetaRow* _tmp0_;
	sqlite3_stmt* _tmp1_;
	gint _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	sqlite3_stmt* _tmp5_;
	gint _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_BEHAVIOR, DataImportsFSpotDbFSpotMetaBehavior);
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	g_return_if_fail (stmt != NULL);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp0_ = data_imports_fspot_db_fspot_meta_row_new ();
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_g_object_unref0 (_vala_row);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_vala_row = _tmp0_;
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp1_ = stmt;
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp2_ = offset;
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp3_ = sqlite3_column_text (_tmp1_, _tmp2_ + 0);
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_g_free0 (_vala_row->name);
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_vala_row->name = _tmp4_;
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp5_ = stmt;
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp6_ = offset;
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp7_ = sqlite3_column_text (_tmp5_, _tmp6_ + 1);
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_tmp8_ = g_strdup (_tmp7_);
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_g_free0 (_vala_row->data);
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	_vala_row->data = _tmp8_;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	if (row) {
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		*row = _vala_row;
#line 1388 "FSpotMetaTable.c"
	} else {
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
		_g_object_unref0 (_vala_row);
#line 1392 "FSpotMetaTable.c"
	}
}


static void data_imports_fspot_db_fspot_meta_behavior_class_init (DataImportsFSpotDbFSpotMetaBehaviorClass * klass) {
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	data_imports_fspot_db_fspot_meta_behavior_parent_class = g_type_class_peek_parent (klass);
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	G_OBJECT_CLASS (klass)->finalize = data_imports_fspot_db_fspot_meta_behavior_finalize;
#line 1402 "FSpotMetaTable.c"
}


static void data_imports_fspot_db_fspot_meta_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init (DataImportsFSpotDbFSpotTableBehaviorIface * iface) {
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	data_imports_fspot_db_fspot_meta_behavior_data_imports_fspot_db_fspot_table_behavior_parent_iface = g_type_interface_peek_parent (iface);
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	iface->get_table_name = (gchar* (*) (DataImportsFSpotDbFSpotTableBehavior *)) data_imports_fspot_db_fspot_meta_behavior_real_get_table_name;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	iface->list_columns = (gchar** (*) (DataImportsFSpotDbFSpotTableBehavior *, int*)) data_imports_fspot_db_fspot_meta_behavior_real_list_columns;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	iface->build_row = (void (*) (DataImportsFSpotDbFSpotTableBehavior *, sqlite3_stmt*, gpointer*, gint)) data_imports_fspot_db_fspot_meta_behavior_real_build_row;
#line 1415 "FSpotMetaTable.c"
}


static void data_imports_fspot_db_fspot_meta_behavior_instance_init (DataImportsFSpotDbFSpotMetaBehavior * self) {
}


static void data_imports_fspot_db_fspot_meta_behavior_finalize (GObject * obj) {
	DataImportsFSpotDbFSpotMetaBehavior * self;
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_META_BEHAVIOR, DataImportsFSpotDbFSpotMetaBehavior);
#line 83 "/home/jens/Source/shotwell/plugins/shotwell-data-imports/FSpotMetaTable.vala"
	G_OBJECT_CLASS (data_imports_fspot_db_fspot_meta_behavior_parent_class)->finalize (obj);
#line 1429 "FSpotMetaTable.c"
}


GType data_imports_fspot_db_fspot_meta_behavior_get_type (void) {
	static volatile gsize data_imports_fspot_db_fspot_meta_behavior_type_id__volatile = 0;
	if (g_once_init_enter (&data_imports_fspot_db_fspot_meta_behavior_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DataImportsFSpotDbFSpotMetaBehaviorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) data_imports_fspot_db_fspot_meta_behavior_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DataImportsFSpotDbFSpotMetaBehavior), 0, (GInstanceInitFunc) data_imports_fspot_db_fspot_meta_behavior_instance_init, NULL };
		static const GInterfaceInfo data_imports_fspot_db_fspot_table_behavior_info = { (GInterfaceInitFunc) data_imports_fspot_db_fspot_meta_behavior_data_imports_fspot_db_fspot_table_behavior_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType data_imports_fspot_db_fspot_meta_behavior_type_id;
		data_imports_fspot_db_fspot_meta_behavior_type_id = g_type_register_static (G_TYPE_OBJECT, "DataImportsFSpotDbFSpotMetaBehavior", &g_define_type_info, 0);
		g_type_add_interface_static (data_imports_fspot_db_fspot_meta_behavior_type_id, DATA_IMPORTS_FSPOT_DB_TYPE_FSPOT_TABLE_BEHAVIOR, &data_imports_fspot_db_fspot_table_behavior_info);
		g_once_init_leave (&data_imports_fspot_db_fspot_meta_behavior_type_id__volatile, data_imports_fspot_db_fspot_meta_behavior_type_id);
	}
	return data_imports_fspot_db_fspot_meta_behavior_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



