/* ShotwellAuthenticatorFactory.c generated by valac 0.36.6, the Vala compiler
 * generated from ShotwellAuthenticatorFactory.vala, do not modify */


#include <glib.h>
#include <glib-object.h>
#include "shotwell-plugin-dev-1.0.h"
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>


#define PUBLISHING_AUTHENTICATOR_TYPE_FACTORY (publishing_authenticator_factory_get_type ())
#define PUBLISHING_AUTHENTICATOR_FACTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_AUTHENTICATOR_TYPE_FACTORY, PublishingAuthenticatorFactory))
#define PUBLISHING_AUTHENTICATOR_FACTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_AUTHENTICATOR_TYPE_FACTORY, PublishingAuthenticatorFactoryClass))
#define PUBLISHING_AUTHENTICATOR_IS_FACTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_AUTHENTICATOR_TYPE_FACTORY))
#define PUBLISHING_AUTHENTICATOR_IS_FACTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_AUTHENTICATOR_TYPE_FACTORY))
#define PUBLISHING_AUTHENTICATOR_FACTORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_AUTHENTICATOR_TYPE_FACTORY, PublishingAuthenticatorFactoryClass))

typedef struct _PublishingAuthenticatorFactory PublishingAuthenticatorFactory;
typedef struct _PublishingAuthenticatorFactoryClass PublishingAuthenticatorFactoryClass;
typedef struct _PublishingAuthenticatorFactoryPrivate PublishingAuthenticatorFactoryPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_TYPE_FLICKR (publishing_authenticator_shotwell_flickr_flickr_get_type ())
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_FLICKR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_TYPE_FLICKR, PublishingAuthenticatorShotwellFlickrFlickr))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_FLICKR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_TYPE_FLICKR, PublishingAuthenticatorShotwellFlickrFlickrClass))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_IS_FLICKR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_TYPE_FLICKR))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_IS_FLICKR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_TYPE_FLICKR))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_FLICKR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FLICKR_TYPE_FLICKR, PublishingAuthenticatorShotwellFlickrFlickrClass))

typedef struct _PublishingAuthenticatorShotwellFlickrFlickr PublishingAuthenticatorShotwellFlickrFlickr;
typedef struct _PublishingAuthenticatorShotwellFlickrFlickrClass PublishingAuthenticatorShotwellFlickrFlickrClass;

#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK (publishing_authenticator_shotwell_facebook_facebook_get_type ())
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, PublishingAuthenticatorShotwellFacebookFacebook))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, PublishingAuthenticatorShotwellFacebookFacebookClass))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_IS_FACEBOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_FACEBOOK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_FACEBOOK_TYPE_FACEBOOK, PublishingAuthenticatorShotwellFacebookFacebookClass))

typedef struct _PublishingAuthenticatorShotwellFacebookFacebook PublishingAuthenticatorShotwellFacebookFacebook;
typedef struct _PublishingAuthenticatorShotwellFacebookFacebookClass PublishingAuthenticatorShotwellFacebookFacebookClass;

#define PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_TYPE_GOOGLE (publishing_authenticator_shotwell_google_google_get_type ())
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_GOOGLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_TYPE_GOOGLE, PublishingAuthenticatorShotwellGoogleGoogle))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_GOOGLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_TYPE_GOOGLE, PublishingAuthenticatorShotwellGoogleGoogleClass))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_IS_GOOGLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_TYPE_GOOGLE))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_IS_GOOGLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_TYPE_GOOGLE))
#define PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_GOOGLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_AUTHENTICATOR_SHOTWELL_GOOGLE_TYPE_GOOGLE, PublishingAuthenticatorShotwellGoogleGoogleClass))

typedef struct _PublishingAuthenticatorShotwellGoogleGoogle PublishingAuthenticatorShotwellGoogleGoogle;
typedef struct _PublishingAuthenticatorShotwellGoogleGoogleClass PublishingAuthenticatorShotwellGoogleGoogleClass;

struct _PublishingAuthenticatorFactory {
	GObject parent_instance;
	PublishingAuthenticatorFactoryPrivate * priv;
};

struct _PublishingAuthenticatorFactoryClass {
	GObjectClass parent_class;
};


static gpointer publishing_authenticator_factory_parent_class = NULL;
static PublishingAuthenticatorFactory* publishing_authenticator_factory_instance;
static PublishingAuthenticatorFactory* publishing_authenticator_factory_instance = NULL;
static SpitPublishingAuthenticatorFactoryIface * publishing_authenticator_factory_spit_publishing_authenticator_factory_parent_iface = NULL;

GType publishing_authenticator_factory_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_AUTHENTICATOR_FACTORY_DUMMY_PROPERTY
};
PublishingAuthenticatorFactory* publishing_authenticator_factory_get_instance (void);
PublishingAuthenticatorFactory* publishing_authenticator_factory_new (void);
PublishingAuthenticatorFactory* publishing_authenticator_factory_construct (GType object_type);
static GeeList* publishing_authenticator_factory_real_get_available_authenticators (SpitPublishingAuthenticatorFactory* base);
static SpitPublishingAuthenticator* publishing_authenticator_factory_real_create (SpitPublishingAuthenticatorFactory* base, const gchar* provider, SpitPublishingPluginHost* host);
PublishingAuthenticatorShotwellFlickrFlickr* publishing_authenticator_shotwell_flickr_flickr_new (SpitPublishingPluginHost* host);
PublishingAuthenticatorShotwellFlickrFlickr* publishing_authenticator_shotwell_flickr_flickr_construct (GType object_type, SpitPublishingPluginHost* host);
GType publishing_authenticator_shotwell_flickr_flickr_get_type (void) G_GNUC_CONST;
PublishingAuthenticatorShotwellFacebookFacebook* publishing_authenticator_shotwell_facebook_facebook_new (SpitPublishingPluginHost* host);
PublishingAuthenticatorShotwellFacebookFacebook* publishing_authenticator_shotwell_facebook_facebook_construct (GType object_type, SpitPublishingPluginHost* host);
GType publishing_authenticator_shotwell_facebook_facebook_get_type (void) G_GNUC_CONST;
PublishingAuthenticatorShotwellGoogleGoogle* publishing_authenticator_shotwell_google_google_new (const gchar* scope, const gchar* welcome_message, SpitPublishingPluginHost* host);
PublishingAuthenticatorShotwellGoogleGoogle* publishing_authenticator_shotwell_google_google_construct (GType object_type, const gchar* scope, const gchar* welcome_message, SpitPublishingPluginHost* host);
GType publishing_authenticator_shotwell_google_google_get_type (void) G_GNUC_CONST;
static void publishing_authenticator_factory_finalize (GObject * obj);


static gpointer _g_object_ref0 (gpointer self) {
#line 10 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	return self ? g_object_ref (self) : NULL;
#line 96 "ShotwellAuthenticatorFactory.c"
}


PublishingAuthenticatorFactory* publishing_authenticator_factory_get_instance (void) {
	PublishingAuthenticatorFactory* result = NULL;
	PublishingAuthenticatorFactory* _tmp0_;
	PublishingAuthenticatorFactory* _tmp2_;
	PublishingAuthenticatorFactory* _tmp3_;
#line 6 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	_tmp0_ = publishing_authenticator_factory_instance;
#line 6 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	if (_tmp0_ == NULL) {
#line 109 "ShotwellAuthenticatorFactory.c"
		PublishingAuthenticatorFactory* _tmp1_;
#line 7 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
		_tmp1_ = publishing_authenticator_factory_new ();
#line 7 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
		_g_object_unref0 (publishing_authenticator_factory_instance);
#line 7 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
		publishing_authenticator_factory_instance = _tmp1_;
#line 117 "ShotwellAuthenticatorFactory.c"
	}
#line 10 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	_tmp2_ = publishing_authenticator_factory_instance;
#line 10 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 10 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	result = _tmp3_;
#line 10 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	return result;
#line 127 "ShotwellAuthenticatorFactory.c"
}


static GeeList* publishing_authenticator_factory_real_get_available_authenticators (SpitPublishingAuthenticatorFactory* base) {
	PublishingAuthenticatorFactory * self;
	GeeList* result = NULL;
	GeeArrayList* list = NULL;
	GeeArrayList* _tmp0_;
#line 13 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_AUTHENTICATOR_TYPE_FACTORY, PublishingAuthenticatorFactory);
#line 14 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	_tmp0_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL);
#line 14 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	list = _tmp0_;
#line 15 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (list, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), "flickr");
#line 16 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (list, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), "facebook");
#line 17 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (list, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), "picasa");
#line 18 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (list, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), "youtube");
#line 20 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (list, GEE_TYPE_LIST, GeeList);
#line 20 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	return result;
#line 154 "ShotwellAuthenticatorFactory.c"
}


static SpitPublishingAuthenticator* publishing_authenticator_factory_real_create (SpitPublishingAuthenticatorFactory* base, const gchar* provider, SpitPublishingPluginHost* host) {
	PublishingAuthenticatorFactory * self;
	SpitPublishingAuthenticator* result = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GQuark _tmp3_ = 0U;
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	static GQuark _tmp2_label0 = 0;
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	static GQuark _tmp2_label1 = 0;
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	static GQuark _tmp2_label2 = 0;
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	static GQuark _tmp2_label3 = 0;
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_AUTHENTICATOR_TYPE_FACTORY, PublishingAuthenticatorFactory);
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	g_return_val_if_fail (provider != NULL, NULL);
#line 23 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	_tmp0_ = provider;
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	_tmp1_ = _tmp0_;
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	_tmp3_ = (NULL == _tmp1_) ? 0 : g_quark_from_string (_tmp1_);
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	if (_tmp3_ == ((0 != _tmp2_label0) ? _tmp2_label0 : (_tmp2_label0 = g_quark_from_static_string ("flickr")))) {
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
		switch (0) {
#line 188 "ShotwellAuthenticatorFactory.c"
			default:
			{
				SpitPublishingPluginHost* _tmp4_;
				PublishingAuthenticatorShotwellFlickrFlickr* _tmp5_;
#line 27 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				_tmp4_ = host;
#line 27 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				_tmp5_ = publishing_authenticator_shotwell_flickr_flickr_new (_tmp4_);
#line 27 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				result = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, SPIT_PUBLISHING_TYPE_AUTHENTICATOR, SpitPublishingAuthenticator);
#line 27 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				return result;
#line 201 "ShotwellAuthenticatorFactory.c"
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label1) ? _tmp2_label1 : (_tmp2_label1 = g_quark_from_static_string ("facebook")))) {
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
		switch (0) {
#line 207 "ShotwellAuthenticatorFactory.c"
			default:
			{
				SpitPublishingPluginHost* _tmp6_;
				PublishingAuthenticatorShotwellFacebookFacebook* _tmp7_;
#line 29 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				_tmp6_ = host;
#line 29 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				_tmp7_ = publishing_authenticator_shotwell_facebook_facebook_new (_tmp6_);
#line 29 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				result = G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, SPIT_PUBLISHING_TYPE_AUTHENTICATOR, SpitPublishingAuthenticator);
#line 29 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				return result;
#line 220 "ShotwellAuthenticatorFactory.c"
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label2) ? _tmp2_label2 : (_tmp2_label2 = g_quark_from_static_string ("picasa")))) {
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
		switch (0) {
#line 226 "ShotwellAuthenticatorFactory.c"
			default:
			{
				SpitPublishingPluginHost* _tmp8_;
				PublishingAuthenticatorShotwellGoogleGoogle* _tmp9_;
#line 31 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				_tmp8_ = host;
#line 31 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				_tmp9_ = publishing_authenticator_shotwell_google_google_new ("https://picasaweb.google.com/data/", _ ("You are not currently logged into Picasa Web Albums.\n" \
"\n" \
"Click Log in to log into Picasa Web Albums in your Web browser. You wi" \
"ll have to authorize Shotwell Connect to link to your Picasa Web Album" \
"s account."), _tmp8_);
#line 31 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				result = G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, SPIT_PUBLISHING_TYPE_AUTHENTICATOR, SpitPublishingAuthenticator);
#line 31 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				return result;
#line 239 "ShotwellAuthenticatorFactory.c"
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label3) ? _tmp2_label3 : (_tmp2_label3 = g_quark_from_static_string ("youtube")))) {
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
		switch (0) {
#line 245 "ShotwellAuthenticatorFactory.c"
			default:
			{
				SpitPublishingPluginHost* _tmp10_;
				PublishingAuthenticatorShotwellGoogleGoogle* _tmp11_;
#line 34 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				_tmp10_ = host;
#line 34 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				_tmp11_ = publishing_authenticator_shotwell_google_google_new ("https://gdata.youtube.com/", _ ("You are not currently logged into YouTube.\n" \
"\n" \
"You must have already signed up for a Google account and set it up for" \
" use with YouTube to continue. You can set up most accounts by using y" \
"our browser to log into the YouTube site at least once."), _tmp10_);
#line 34 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				result = G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, SPIT_PUBLISHING_TYPE_AUTHENTICATOR, SpitPublishingAuthenticator);
#line 34 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				return result;
#line 258 "ShotwellAuthenticatorFactory.c"
			}
		}
	} else {
#line 25 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
		switch (0) {
#line 264 "ShotwellAuthenticatorFactory.c"
			default:
			{
#line 36 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				result = NULL;
#line 36 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
				return result;
#line 271 "ShotwellAuthenticatorFactory.c"
			}
		}
	}
}


PublishingAuthenticatorFactory* publishing_authenticator_factory_construct (GType object_type) {
	PublishingAuthenticatorFactory * self = NULL;
#line 2 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	self = (PublishingAuthenticatorFactory*) g_object_new (object_type, NULL);
#line 2 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	return self;
#line 284 "ShotwellAuthenticatorFactory.c"
}


PublishingAuthenticatorFactory* publishing_authenticator_factory_new (void) {
#line 2 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	return publishing_authenticator_factory_construct (PUBLISHING_AUTHENTICATOR_TYPE_FACTORY);
#line 291 "ShotwellAuthenticatorFactory.c"
}


static void publishing_authenticator_factory_class_init (PublishingAuthenticatorFactoryClass * klass) {
#line 2 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	publishing_authenticator_factory_parent_class = g_type_class_peek_parent (klass);
#line 2 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_authenticator_factory_finalize;
#line 300 "ShotwellAuthenticatorFactory.c"
}


static void publishing_authenticator_factory_spit_publishing_authenticator_factory_interface_init (SpitPublishingAuthenticatorFactoryIface * iface) {
#line 2 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	publishing_authenticator_factory_spit_publishing_authenticator_factory_parent_iface = g_type_interface_peek_parent (iface);
#line 2 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	iface->get_available_authenticators = (GeeList* (*) (SpitPublishingAuthenticatorFactory *)) publishing_authenticator_factory_real_get_available_authenticators;
#line 2 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	iface->create = (SpitPublishingAuthenticator* (*) (SpitPublishingAuthenticatorFactory *, const gchar*, SpitPublishingPluginHost*)) publishing_authenticator_factory_real_create;
#line 311 "ShotwellAuthenticatorFactory.c"
}


static void publishing_authenticator_factory_instance_init (PublishingAuthenticatorFactory * self) {
}


static void publishing_authenticator_factory_finalize (GObject * obj) {
	PublishingAuthenticatorFactory * self;
#line 2 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_AUTHENTICATOR_TYPE_FACTORY, PublishingAuthenticatorFactory);
#line 2 "/home/jens/Source/shotwell/plugins/authenticator/shotwell/ShotwellAuthenticatorFactory.vala"
	G_OBJECT_CLASS (publishing_authenticator_factory_parent_class)->finalize (obj);
#line 325 "ShotwellAuthenticatorFactory.c"
}


GType publishing_authenticator_factory_get_type (void) {
	static volatile gsize publishing_authenticator_factory_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_authenticator_factory_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingAuthenticatorFactoryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_authenticator_factory_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingAuthenticatorFactory), 0, (GInstanceInitFunc) publishing_authenticator_factory_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_authenticator_factory_info = { (GInterfaceInitFunc) publishing_authenticator_factory_spit_publishing_authenticator_factory_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_authenticator_factory_type_id;
		publishing_authenticator_factory_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingAuthenticatorFactory", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_authenticator_factory_type_id, SPIT_PUBLISHING_TYPE_AUTHENTICATOR_FACTORY, &spit_publishing_authenticator_factory_info);
		g_once_init_leave (&publishing_authenticator_factory_type_id__volatile, publishing_authenticator_factory_type_id);
	}
	return publishing_authenticator_factory_type_id__volatile;
}



