/* StandardHostInterface.c generated by valac 0.36.6, the Vala compiler
 * generated from StandardHostInterface.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include "shotwell-plugin-dev-1.0.h"
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <float.h>
#include <math.h>


#define PLUGINS_TYPE_STANDARD_HOST_INTERFACE (plugins_standard_host_interface_get_type ())
#define PLUGINS_STANDARD_HOST_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface))
#define PLUGINS_STANDARD_HOST_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterfaceClass))
#define PLUGINS_IS_STANDARD_HOST_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE))
#define PLUGINS_IS_STANDARD_HOST_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PLUGINS_TYPE_STANDARD_HOST_INTERFACE))
#define PLUGINS_STANDARD_HOST_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterfaceClass))

typedef struct _PluginsStandardHostInterface PluginsStandardHostInterface;
typedef struct _PluginsStandardHostInterfaceClass PluginsStandardHostInterfaceClass;
typedef struct _PluginsStandardHostInterfacePrivate PluginsStandardHostInterfacePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;

struct _PluginsStandardHostInterface {
	GObject parent_instance;
	PluginsStandardHostInterfacePrivate * priv;
};

struct _PluginsStandardHostInterfaceClass {
	GObjectClass parent_class;
};

struct _PluginsStandardHostInterfacePrivate {
	gchar* config_domain;
	gchar* config_id;
	GFile* module_file;
	SpitPluggableInfo info;
};


static gpointer plugins_standard_host_interface_parent_class = NULL;
static SpitHostInterfaceIface * plugins_standard_host_interface_spit_host_interface_parent_iface = NULL;

GType plugins_standard_host_interface_get_type (void) G_GNUC_CONST;
#define PLUGINS_STANDARD_HOST_INTERFACE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterfacePrivate))
enum  {
	PLUGINS_STANDARD_HOST_INTERFACE_DUMMY_PROPERTY
};
PluginsStandardHostInterface* plugins_standard_host_interface_new (SpitPluggable* pluggable, const gchar* config_domain);
PluginsStandardHostInterface* plugins_standard_host_interface_construct (GType object_type, SpitPluggable* pluggable, const gchar* config_domain);
static gchar* plugins_standard_host_interface_parse_key (const gchar* id);
GFile* plugins_get_pluggable_module_file (SpitPluggable* pluggable);
static GFile* plugins_standard_host_interface_real_get_module_file (SpitHostInterface* base);
static gboolean plugins_standard_host_interface_real_get_config_bool (SpitHostInterface* base, const gchar* key, gboolean def);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
gboolean configuration_facade_get_plugin_bool (ConfigurationFacade* self, const gchar* domain, const gchar* id, const gchar* key, gboolean def);
static void plugins_standard_host_interface_real_set_config_bool (SpitHostInterface* base, const gchar* key, gboolean val);
void configuration_facade_set_plugin_bool (ConfigurationFacade* self, const gchar* domain, const gchar* id, const gchar* key, gboolean val);
static gint plugins_standard_host_interface_real_get_config_int (SpitHostInterface* base, const gchar* key, gint def);
gint configuration_facade_get_plugin_int (ConfigurationFacade* self, const gchar* domain, const gchar* id, const gchar* key, gint def);
static void plugins_standard_host_interface_real_set_config_int (SpitHostInterface* base, const gchar* key, gint val);
void configuration_facade_set_plugin_int (ConfigurationFacade* self, const gchar* domain, const gchar* id, const gchar* key, gint val);
static gchar* plugins_standard_host_interface_real_get_config_string (SpitHostInterface* base, const gchar* key, const gchar* def);
gchar* configuration_facade_get_plugin_string (ConfigurationFacade* self, const gchar* domain, const gchar* id, const gchar* key, const gchar* def);
static void plugins_standard_host_interface_real_set_config_string (SpitHostInterface* base, const gchar* key, const gchar* val);
void configuration_facade_set_plugin_string (ConfigurationFacade* self, const gchar* domain, const gchar* id, const gchar* key, const gchar* val);
static gdouble plugins_standard_host_interface_real_get_config_double (SpitHostInterface* base, const gchar* key, gdouble def);
gdouble configuration_facade_get_plugin_double (ConfigurationFacade* self, const gchar* domain, const gchar* id, const gchar* key, gdouble def);
static void plugins_standard_host_interface_real_set_config_double (SpitHostInterface* base, const gchar* key, gdouble val);
void configuration_facade_set_plugin_double (ConfigurationFacade* self, const gchar* domain, const gchar* id, const gchar* key, gdouble val);
static void plugins_standard_host_interface_real_unset_config_key (SpitHostInterface* base, const gchar* key);
void configuration_facade_unset_plugin_key (ConfigurationFacade* self, const gchar* domain, const gchar* id, const gchar* key);
static void plugins_standard_host_interface_finalize (GObject * obj);


PluginsStandardHostInterface* plugins_standard_host_interface_construct (GType object_type, SpitPluggable* pluggable, const gchar* config_domain) {
	PluginsStandardHostInterface * self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	SpitPluggable* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	SpitPluggable* _tmp5_;
	GFile* _tmp6_;
	SpitPluggable* _tmp7_;
#line 15 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	g_return_val_if_fail (SPIT_IS_PLUGGABLE (pluggable), NULL);
#line 15 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	g_return_val_if_fail (config_domain != NULL, NULL);
#line 15 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self = (PluginsStandardHostInterface*) g_object_new (object_type, NULL);
#line 16 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp0_ = config_domain;
#line 16 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 16 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_free0 (self->priv->config_domain);
#line 16 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self->priv->config_domain = _tmp1_;
#line 17 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp2_ = pluggable;
#line 17 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp3_ = spit_pluggable_get_id (_tmp2_);
#line 17 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp4_ = plugins_standard_host_interface_parse_key (_tmp3_);
#line 17 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_free0 (self->priv->config_id);
#line 17 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self->priv->config_id = _tmp4_;
#line 18 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp5_ = pluggable;
#line 18 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp6_ = plugins_get_pluggable_module_file (_tmp5_);
#line 18 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_object_unref0 (self->priv->module_file);
#line 18 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self->priv->module_file = _tmp6_;
#line 19 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp7_ = pluggable;
#line 19 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	spit_pluggable_get_info (_tmp7_, &self->priv->info);
#line 15 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	return self;
#line 156 "StandardHostInterface.c"
}


PluginsStandardHostInterface* plugins_standard_host_interface_new (SpitPluggable* pluggable, const gchar* config_domain) {
#line 15 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	return plugins_standard_host_interface_construct (PLUGINS_TYPE_STANDARD_HOST_INTERFACE, pluggable, config_domain);
#line 163 "StandardHostInterface.c"
}


static gchar* plugins_standard_host_interface_parse_key (const gchar* id) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GQuark _tmp3_ = 0U;
#line 25 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	static GQuark _tmp2_label0 = 0;
#line 25 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	static GQuark _tmp2_label1 = 0;
#line 25 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	static GQuark _tmp2_label2 = 0;
#line 25 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	static GQuark _tmp2_label3 = 0;
#line 22 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	g_return_val_if_fail (id != NULL, NULL);
#line 25 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp0_ = id;
#line 25 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp1_ = _tmp0_;
#line 25 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp3_ = (NULL == _tmp1_) ? 0 : g_quark_from_string (_tmp1_);
#line 25 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	if (_tmp3_ == ((0 != _tmp2_label0) ? _tmp2_label0 : (_tmp2_label0 = g_quark_from_static_string ("org.yorba.shotwell.publishing.facebook")))) {
#line 25 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
		switch (0) {
#line 192 "StandardHostInterface.c"
			default:
			{
				gchar* _tmp4_;
#line 27 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				_tmp4_ = g_strdup ("facebook");
#line 27 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				result = _tmp4_;
#line 27 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				return result;
#line 202 "StandardHostInterface.c"
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label1) ? _tmp2_label1 : (_tmp2_label1 = g_quark_from_static_string ("org.yorba.shotwell.publishing.picasa")))) {
#line 25 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
		switch (0) {
#line 208 "StandardHostInterface.c"
			default:
			{
				gchar* _tmp5_;
#line 30 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				_tmp5_ = g_strdup ("picasa");
#line 30 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				result = _tmp5_;
#line 30 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				return result;
#line 218 "StandardHostInterface.c"
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label2) ? _tmp2_label2 : (_tmp2_label2 = g_quark_from_static_string ("org.yorba.shotwell.publishing.flickr")))) {
#line 25 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
		switch (0) {
#line 224 "StandardHostInterface.c"
			default:
			{
				gchar* _tmp6_;
#line 33 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				_tmp6_ = g_strdup ("flickr");
#line 33 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				result = _tmp6_;
#line 33 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				return result;
#line 234 "StandardHostInterface.c"
			}
		}
	} else if (_tmp3_ == ((0 != _tmp2_label3) ? _tmp2_label3 : (_tmp2_label3 = g_quark_from_static_string ("org.yorba.shotwell.publishing.youtube")))) {
#line 25 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
		switch (0) {
#line 240 "StandardHostInterface.c"
			default:
			{
				gchar* _tmp7_;
#line 36 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				_tmp7_ = g_strdup ("youtube");
#line 36 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				result = _tmp7_;
#line 36 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				return result;
#line 250 "StandardHostInterface.c"
			}
		}
	} else {
#line 25 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
		switch (0) {
#line 256 "StandardHostInterface.c"
			default:
			{
				const gchar* _tmp8_;
				gchar* _tmp9_;
#line 39 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				_tmp8_ = id;
#line 39 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				_tmp9_ = g_strdup (_tmp8_);
#line 39 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				result = _tmp9_;
#line 39 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
				return result;
#line 269 "StandardHostInterface.c"
			}
		}
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 44 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	return self ? g_object_ref (self) : NULL;
#line 279 "StandardHostInterface.c"
}


static GFile* plugins_standard_host_interface_real_get_module_file (SpitHostInterface* base) {
	PluginsStandardHostInterface * self;
	GFile* result = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
#line 43 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface);
#line 44 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp0_ = self->priv->module_file;
#line 44 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 44 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	result = _tmp1_;
#line 44 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	return result;
#line 298 "StandardHostInterface.c"
}


static gboolean plugins_standard_host_interface_real_get_config_bool (SpitHostInterface* base, const gchar* key, gboolean def) {
	PluginsStandardHostInterface * self;
	gboolean result = FALSE;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
	gboolean _tmp7_;
#line 47 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface);
#line 47 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	g_return_val_if_fail (key != NULL, FALSE);
#line 48 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp0_ = config_facade_get_instance ();
#line 48 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp1_ = _tmp0_;
#line 48 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp2_ = self->priv->config_domain;
#line 48 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp3_ = self->priv->config_id;
#line 48 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp4_ = key;
#line 48 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp5_ = def;
#line 48 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp6_ = configuration_facade_get_plugin_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_, _tmp3_, _tmp4_, _tmp5_);
#line 48 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp7_ = _tmp6_;
#line 48 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_object_unref0 (_tmp1_);
#line 48 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	result = _tmp7_;
#line 48 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	return result;
#line 339 "StandardHostInterface.c"
}


static void plugins_standard_host_interface_real_set_config_bool (SpitHostInterface* base, const gchar* key, gboolean val) {
	PluginsStandardHostInterface * self;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gboolean _tmp5_;
#line 51 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface);
#line 51 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	g_return_if_fail (key != NULL);
#line 52 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp0_ = config_facade_get_instance ();
#line 52 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp1_ = _tmp0_;
#line 52 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp2_ = self->priv->config_domain;
#line 52 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp3_ = self->priv->config_id;
#line 52 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp4_ = key;
#line 52 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp5_ = val;
#line 52 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	configuration_facade_set_plugin_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_, _tmp3_, _tmp4_, _tmp5_);
#line 52 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_object_unref0 (_tmp1_);
#line 371 "StandardHostInterface.c"
}


static gint plugins_standard_host_interface_real_get_config_int (SpitHostInterface* base, const gchar* key, gint def) {
	PluginsStandardHostInterface * self;
	gint result = 0;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	gint _tmp7_;
#line 55 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface);
#line 55 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	g_return_val_if_fail (key != NULL, 0);
#line 56 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp0_ = config_facade_get_instance ();
#line 56 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp1_ = _tmp0_;
#line 56 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp2_ = self->priv->config_domain;
#line 56 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp3_ = self->priv->config_id;
#line 56 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp4_ = key;
#line 56 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp5_ = def;
#line 56 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp6_ = configuration_facade_get_plugin_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_, _tmp3_, _tmp4_, _tmp5_);
#line 56 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp7_ = _tmp6_;
#line 56 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_object_unref0 (_tmp1_);
#line 56 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	result = _tmp7_;
#line 56 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	return result;
#line 412 "StandardHostInterface.c"
}


static void plugins_standard_host_interface_real_set_config_int (SpitHostInterface* base, const gchar* key, gint val) {
	PluginsStandardHostInterface * self;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gint _tmp5_;
#line 59 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface);
#line 59 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	g_return_if_fail (key != NULL);
#line 60 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp0_ = config_facade_get_instance ();
#line 60 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp1_ = _tmp0_;
#line 60 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp2_ = self->priv->config_domain;
#line 60 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp3_ = self->priv->config_id;
#line 60 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp4_ = key;
#line 60 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp5_ = val;
#line 60 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	configuration_facade_set_plugin_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_, _tmp3_, _tmp4_, _tmp5_);
#line 60 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_object_unref0 (_tmp1_);
#line 444 "StandardHostInterface.c"
}


static gchar* plugins_standard_host_interface_real_get_config_string (SpitHostInterface* base, const gchar* key, const gchar* def) {
	PluginsStandardHostInterface * self;
	gchar* result = NULL;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
#line 63 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface);
#line 63 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	g_return_val_if_fail (key != NULL, NULL);
#line 64 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp0_ = config_facade_get_instance ();
#line 64 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp1_ = _tmp0_;
#line 64 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp2_ = self->priv->config_domain;
#line 64 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp3_ = self->priv->config_id;
#line 64 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp4_ = key;
#line 64 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp5_ = def;
#line 64 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp6_ = configuration_facade_get_plugin_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_, _tmp3_, _tmp4_, _tmp5_);
#line 64 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp7_ = _tmp6_;
#line 64 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_object_unref0 (_tmp1_);
#line 64 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	result = _tmp7_;
#line 64 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	return result;
#line 485 "StandardHostInterface.c"
}


static void plugins_standard_host_interface_real_set_config_string (SpitHostInterface* base, const gchar* key, const gchar* val) {
	PluginsStandardHostInterface * self;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
#line 67 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface);
#line 67 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	g_return_if_fail (key != NULL);
#line 68 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp0_ = config_facade_get_instance ();
#line 68 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp1_ = _tmp0_;
#line 68 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp2_ = self->priv->config_domain;
#line 68 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp3_ = self->priv->config_id;
#line 68 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp4_ = key;
#line 68 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp5_ = val;
#line 68 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	configuration_facade_set_plugin_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_, _tmp3_, _tmp4_, _tmp5_);
#line 68 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_object_unref0 (_tmp1_);
#line 517 "StandardHostInterface.c"
}


static gdouble plugins_standard_host_interface_real_get_config_double (SpitHostInterface* base, const gchar* key, gdouble def) {
	PluginsStandardHostInterface * self;
	gdouble result = 0.0;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gdouble _tmp5_;
	gdouble _tmp6_;
	gdouble _tmp7_;
#line 71 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface);
#line 71 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	g_return_val_if_fail (key != NULL, 0.0);
#line 72 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp0_ = config_facade_get_instance ();
#line 72 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp1_ = _tmp0_;
#line 72 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp2_ = self->priv->config_domain;
#line 72 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp3_ = self->priv->config_id;
#line 72 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp4_ = key;
#line 72 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp5_ = def;
#line 72 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp6_ = configuration_facade_get_plugin_double (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_, _tmp3_, _tmp4_, _tmp5_);
#line 72 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp7_ = _tmp6_;
#line 72 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_object_unref0 (_tmp1_);
#line 72 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	result = _tmp7_;
#line 72 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	return result;
#line 558 "StandardHostInterface.c"
}


static void plugins_standard_host_interface_real_set_config_double (SpitHostInterface* base, const gchar* key, gdouble val) {
	PluginsStandardHostInterface * self;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gdouble _tmp5_;
#line 75 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface);
#line 75 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	g_return_if_fail (key != NULL);
#line 76 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp0_ = config_facade_get_instance ();
#line 76 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp1_ = _tmp0_;
#line 76 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp2_ = self->priv->config_domain;
#line 76 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp3_ = self->priv->config_id;
#line 76 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp4_ = key;
#line 76 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp5_ = val;
#line 76 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	configuration_facade_set_plugin_double (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_, _tmp3_, _tmp4_, _tmp5_);
#line 76 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_object_unref0 (_tmp1_);
#line 590 "StandardHostInterface.c"
}


static void plugins_standard_host_interface_real_unset_config_key (SpitHostInterface* base, const gchar* key) {
	PluginsStandardHostInterface * self;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
#line 79 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface);
#line 79 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	g_return_if_fail (key != NULL);
#line 80 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp0_ = config_facade_get_instance ();
#line 80 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp1_ = _tmp0_;
#line 80 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp2_ = self->priv->config_domain;
#line 80 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp3_ = self->priv->config_id;
#line 80 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_tmp4_ = key;
#line 80 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	configuration_facade_unset_plugin_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_, _tmp3_, _tmp4_);
#line 80 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_object_unref0 (_tmp1_);
#line 619 "StandardHostInterface.c"
}


static void plugins_standard_host_interface_class_init (PluginsStandardHostInterfaceClass * klass) {
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	plugins_standard_host_interface_parent_class = g_type_class_peek_parent (klass);
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	g_type_class_add_private (klass, sizeof (PluginsStandardHostInterfacePrivate));
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	G_OBJECT_CLASS (klass)->finalize = plugins_standard_host_interface_finalize;
#line 630 "StandardHostInterface.c"
}


static void plugins_standard_host_interface_spit_host_interface_interface_init (SpitHostInterfaceIface * iface) {
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	plugins_standard_host_interface_spit_host_interface_parent_iface = g_type_interface_peek_parent (iface);
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	iface->get_module_file = (GFile* (*) (SpitHostInterface *)) plugins_standard_host_interface_real_get_module_file;
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	iface->get_config_bool = (gboolean (*) (SpitHostInterface *, const gchar*, gboolean)) plugins_standard_host_interface_real_get_config_bool;
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	iface->set_config_bool = (void (*) (SpitHostInterface *, const gchar*, gboolean)) plugins_standard_host_interface_real_set_config_bool;
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	iface->get_config_int = (gint (*) (SpitHostInterface *, const gchar*, gint)) plugins_standard_host_interface_real_get_config_int;
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	iface->set_config_int = (void (*) (SpitHostInterface *, const gchar*, gint)) plugins_standard_host_interface_real_set_config_int;
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	iface->get_config_string = (gchar* (*) (SpitHostInterface *, const gchar*, const gchar*)) plugins_standard_host_interface_real_get_config_string;
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	iface->set_config_string = (void (*) (SpitHostInterface *, const gchar*, const gchar*)) plugins_standard_host_interface_real_set_config_string;
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	iface->get_config_double = (gdouble (*) (SpitHostInterface *, const gchar*, gdouble)) plugins_standard_host_interface_real_get_config_double;
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	iface->set_config_double = (void (*) (SpitHostInterface *, const gchar*, gdouble)) plugins_standard_host_interface_real_set_config_double;
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	iface->unset_config_key = (void (*) (SpitHostInterface *, const gchar*)) plugins_standard_host_interface_real_unset_config_key;
#line 657 "StandardHostInterface.c"
}


static void plugins_standard_host_interface_instance_init (PluginsStandardHostInterface * self) {
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self->priv = PLUGINS_STANDARD_HOST_INTERFACE_GET_PRIVATE (self);
#line 664 "StandardHostInterface.c"
}


static void plugins_standard_host_interface_finalize (GObject * obj) {
	PluginsStandardHostInterface * self;
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface);
#line 10 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_free0 (self->priv->config_domain);
#line 11 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_free0 (self->priv->config_id);
#line 12 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	_g_object_unref0 (self->priv->module_file);
#line 13 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	spit_pluggable_info_destroy (&self->priv->info);
#line 9 "/home/jens/Source/shotwell/src/plugins/StandardHostInterface.vala"
	G_OBJECT_CLASS (plugins_standard_host_interface_parent_class)->finalize (obj);
#line 682 "StandardHostInterface.c"
}


GType plugins_standard_host_interface_get_type (void) {
	static volatile gsize plugins_standard_host_interface_type_id__volatile = 0;
	if (g_once_init_enter (&plugins_standard_host_interface_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PluginsStandardHostInterfaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) plugins_standard_host_interface_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PluginsStandardHostInterface), 0, (GInstanceInitFunc) plugins_standard_host_interface_instance_init, NULL };
		static const GInterfaceInfo spit_host_interface_info = { (GInterfaceInitFunc) plugins_standard_host_interface_spit_host_interface_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType plugins_standard_host_interface_type_id;
		plugins_standard_host_interface_type_id = g_type_register_static (G_TYPE_OBJECT, "PluginsStandardHostInterface", &g_define_type_info, 0);
		g_type_add_interface_static (plugins_standard_host_interface_type_id, SPIT_TYPE_HOST_INTERFACE, &spit_host_interface_info);
		g_once_init_leave (&plugins_standard_host_interface_type_id__volatile, plugins_standard_host_interface_type_id);
	}
	return plugins_standard_host_interface_type_id__volatile;
}



