/* TrashSidebarEntry.c generated by valac 0.36.6, the Vala compiler
 * generated from TrashSidebarEntry.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <gee.h>
#include <glib/gi18n-lib.h>


#define SIDEBAR_TYPE_ENTRY (sidebar_entry_get_type ())
#define SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntry))
#define SIDEBAR_IS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_ENTRY))
#define SIDEBAR_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntryIface))

typedef struct _SidebarEntry SidebarEntry;
typedef struct _SidebarEntryIface SidebarEntryIface;

#define SIDEBAR_TYPE_TREE (sidebar_tree_get_type ())
#define SIDEBAR_TREE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_TREE, SidebarTree))
#define SIDEBAR_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_TREE, SidebarTreeClass))
#define SIDEBAR_IS_TREE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_TREE))
#define SIDEBAR_IS_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_TREE))
#define SIDEBAR_TREE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_TREE, SidebarTreeClass))

typedef struct _SidebarTree SidebarTree;
typedef struct _SidebarTreeClass SidebarTreeClass;

#define SIDEBAR_TYPE_SELECTABLE_ENTRY (sidebar_selectable_entry_get_type ())
#define SIDEBAR_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntry))
#define SIDEBAR_IS_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY))
#define SIDEBAR_SELECTABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntryIface))

typedef struct _SidebarSelectableEntry SidebarSelectableEntry;
typedef struct _SidebarSelectableEntryIface SidebarSelectableEntryIface;

#define SIDEBAR_TYPE_PAGE_REPRESENTATIVE (sidebar_page_representative_get_type ())
#define SIDEBAR_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative))
#define SIDEBAR_IS_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE))
#define SIDEBAR_PAGE_REPRESENTATIVE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentativeIface))

typedef struct _SidebarPageRepresentative SidebarPageRepresentative;
typedef struct _SidebarPageRepresentativeIface SidebarPageRepresentativeIface;

#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;

#define SIDEBAR_TYPE_CONTEXTABLE (sidebar_contextable_get_type ())
#define SIDEBAR_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextable))
#define SIDEBAR_IS_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_CONTEXTABLE))
#define SIDEBAR_CONTEXTABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextableIface))

typedef struct _SidebarContextable SidebarContextable;
typedef struct _SidebarContextableIface SidebarContextableIface;

#define SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY (sidebar_simple_page_entry_get_type ())
#define SIDEBAR_SIMPLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntry))
#define SIDEBAR_SIMPLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntryClass))
#define SIDEBAR_IS_SIMPLE_PAGE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY))
#define SIDEBAR_IS_SIMPLE_PAGE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY))
#define SIDEBAR_SIMPLE_PAGE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, SidebarSimplePageEntryClass))

typedef struct _SidebarSimplePageEntry SidebarSimplePageEntry;
typedef struct _SidebarSimplePageEntryClass SidebarSimplePageEntryClass;
typedef struct _SidebarSimplePageEntryPrivate SidebarSimplePageEntryPrivate;

#define SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY (sidebar_internal_drop_target_entry_get_type ())
#define SIDEBAR_INTERNAL_DROP_TARGET_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY, SidebarInternalDropTargetEntry))
#define SIDEBAR_IS_INTERNAL_DROP_TARGET_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY))
#define SIDEBAR_INTERNAL_DROP_TARGET_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY, SidebarInternalDropTargetEntryIface))

typedef struct _SidebarInternalDropTargetEntry SidebarInternalDropTargetEntry;
typedef struct _SidebarInternalDropTargetEntryIface SidebarInternalDropTargetEntryIface;

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY (library_trash_sidebar_entry_get_type ())
#define LIBRARY_TRASH_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY, LibraryTrashSidebarEntry))
#define LIBRARY_TRASH_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY, LibraryTrashSidebarEntryClass))
#define LIBRARY_IS_TRASH_SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY))
#define LIBRARY_IS_TRASH_SIDEBAR_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY))
#define LIBRARY_TRASH_SIDEBAR_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY, LibraryTrashSidebarEntryClass))

typedef struct _LibraryTrashSidebarEntry LibraryTrashSidebarEntry;
typedef struct _LibraryTrashSidebarEntryClass LibraryTrashSidebarEntryClass;
typedef struct _LibraryTrashSidebarEntryPrivate LibraryTrashSidebarEntryPrivate;

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;

#define TYPE_MEDIA_SOURCE_COLLECTION (media_source_collection_get_type ())
#define MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection))
#define MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))
#define IS_MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_COLLECTION))
#define IS_MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_COLLECTION))
#define MEDIA_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))

typedef struct _MediaSourceCollection MediaSourceCollection;
typedef struct _MediaSourceCollectionClass MediaSourceCollectionClass;

#define TYPE_MEDIA_COLLECTION_REGISTRY (media_collection_registry_get_type ())
#define MEDIA_COLLECTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistry))
#define MEDIA_COLLECTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistryClass))
#define IS_MEDIA_COLLECTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_COLLECTION_REGISTRY))
#define IS_MEDIA_COLLECTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_COLLECTION_REGISTRY))
#define MEDIA_COLLECTION_REGISTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistryClass))

typedef struct _MediaCollectionRegistry MediaCollectionRegistry;
typedef struct _MediaCollectionRegistryClass MediaCollectionRegistryClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _media_collection_registry_unref0(var) ((var == NULL) ? NULL : (var = (media_collection_registry_unref (var), NULL)))
#define _data_collection_unref0(var) ((var == NULL) ? NULL : (var = (data_collection_unref (var), NULL)))

#define TYPE_COMMAND_MANAGER (command_manager_get_type ())
#define COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND_MANAGER, CommandManager))
#define COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND_MANAGER, CommandManagerClass))
#define IS_COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND_MANAGER))
#define IS_COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND_MANAGER))
#define COMMAND_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND_MANAGER, CommandManagerClass))

typedef struct _CommandManager CommandManager;
typedef struct _CommandManagerClass CommandManagerClass;

#define TYPE_COMMAND (command_get_type ())
#define COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND, Command))
#define COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND, CommandClass))
#define IS_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND))
#define IS_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND))
#define COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND, CommandClass))

typedef struct _Command Command;
typedef struct _CommandClass CommandClass;

#define TYPE_PAGE_COMMAND (page_command_get_type ())
#define PAGE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_COMMAND, PageCommand))
#define PAGE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_COMMAND, PageCommandClass))
#define IS_PAGE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_COMMAND))
#define IS_PAGE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_COMMAND))
#define PAGE_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_COMMAND, PageCommandClass))

typedef struct _PageCommand PageCommand;
typedef struct _PageCommandClass PageCommandClass;

#define TYPE_TRASH_UNTRASH_PHOTOS_COMMAND (trash_untrash_photos_command_get_type ())
#define TRASH_UNTRASH_PHOTOS_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TRASH_UNTRASH_PHOTOS_COMMAND, TrashUntrashPhotosCommand))
#define TRASH_UNTRASH_PHOTOS_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TRASH_UNTRASH_PHOTOS_COMMAND, TrashUntrashPhotosCommandClass))
#define IS_TRASH_UNTRASH_PHOTOS_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TRASH_UNTRASH_PHOTOS_COMMAND))
#define IS_TRASH_UNTRASH_PHOTOS_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TRASH_UNTRASH_PHOTOS_COMMAND))
#define TRASH_UNTRASH_PHOTOS_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TRASH_UNTRASH_PHOTOS_COMMAND, TrashUntrashPhotosCommandClass))

typedef struct _TrashUntrashPhotosCommand TrashUntrashPhotosCommand;
typedef struct _TrashUntrashPhotosCommandClass TrashUntrashPhotosCommandClass;
#define _command_manager_unref0(var) ((var == NULL) ? NULL : (var = (command_manager_unref (var), NULL)))

#define TYPE_CHECKERBOARD_PAGE (checkerboard_page_get_type ())
#define CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPage))
#define CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))
#define IS_CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_PAGE))
#define IS_CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_PAGE))
#define CHECKERBOARD_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))

typedef struct _CheckerboardPage CheckerboardPage;
typedef struct _CheckerboardPageClass CheckerboardPageClass;

#define TYPE_TRASH_PAGE (trash_page_get_type ())
#define TRASH_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TRASH_PAGE, TrashPage))
#define TRASH_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TRASH_PAGE, TrashPageClass))
#define IS_TRASH_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TRASH_PAGE))
#define IS_TRASH_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TRASH_PAGE))
#define TRASH_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TRASH_PAGE, TrashPageClass))

typedef struct _TrashPage TrashPage;
typedef struct _TrashPageClass TrashPageClass;
#define _g_free0(var) (var = (g_free (var), NULL))

struct _SidebarEntryIface {
	GTypeInterface parent_iface;
	gchar* (*get_sidebar_name) (SidebarEntry* self);
	gchar* (*get_sidebar_tooltip) (SidebarEntry* self);
	gchar* (*get_sidebar_icon) (SidebarEntry* self);
	gchar* (*to_string) (SidebarEntry* self);
	void (*grafted) (SidebarEntry* self, SidebarTree* tree);
	void (*pruned) (SidebarEntry* self, SidebarTree* tree);
};

struct _SidebarSelectableEntryIface {
	GTypeInterface parent_iface;
};

struct _SidebarPageRepresentativeIface {
	GTypeInterface parent_iface;
	gboolean (*has_page) (SidebarPageRepresentative* self);
	Page* (*get_page) (SidebarPageRepresentative* self);
};

struct _SidebarContextableIface {
	GTypeInterface parent_iface;
	GtkMenu* (*get_sidebar_context_menu) (SidebarContextable* self, GdkEventButton* event);
};

struct _SidebarSimplePageEntry {
	GObject parent_instance;
	SidebarSimplePageEntryPrivate * priv;
};

struct _SidebarSimplePageEntryClass {
	GObjectClass parent_class;
	gchar* (*get_sidebar_name) (SidebarSimplePageEntry* self);
	gchar* (*get_sidebar_tooltip) (SidebarSimplePageEntry* self);
	gchar* (*get_sidebar_icon) (SidebarSimplePageEntry* self);
	gchar* (*to_string) (SidebarSimplePageEntry* self);
	Page* (*create_page) (SidebarSimplePageEntry* self);
};

struct _SidebarInternalDropTargetEntryIface {
	GTypeInterface parent_iface;
	gboolean (*internal_drop_received) (SidebarInternalDropTargetEntry* self, GeeList* sources);
	gboolean (*internal_drop_received_arbitrary) (SidebarInternalDropTargetEntry* self, GtkSelectionData* data);
};

struct _LibraryTrashSidebarEntry {
	SidebarSimplePageEntry parent_instance;
	LibraryTrashSidebarEntryPrivate * priv;
};

struct _LibraryTrashSidebarEntryClass {
	SidebarSimplePageEntryClass parent_class;
};


static gpointer library_trash_sidebar_entry_parent_class = NULL;
static SidebarInternalDropTargetEntryIface * library_trash_sidebar_entry_sidebar_internal_drop_target_entry_parent_iface = NULL;

GType sidebar_tree_get_type (void) G_GNUC_CONST;
GType sidebar_entry_get_type (void) G_GNUC_CONST;
GType sidebar_selectable_entry_get_type (void) G_GNUC_CONST;
GType page_get_type (void) G_GNUC_CONST;
GType sidebar_page_representative_get_type (void) G_GNUC_CONST;
GType sidebar_contextable_get_type (void) G_GNUC_CONST;
GType sidebar_simple_page_entry_get_type (void) G_GNUC_CONST;
GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
GType sidebar_internal_drop_target_entry_get_type (void) G_GNUC_CONST;
GType library_trash_sidebar_entry_get_type (void) G_GNUC_CONST;
enum  {
	LIBRARY_TRASH_SIDEBAR_ENTRY_DUMMY_PROPERTY
};
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_data_collection (GValue* value, gpointer v_object);
void value_take_data_collection (GValue* value, gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType source_collection_get_type (void) G_GNUC_CONST;
GType database_source_collection_get_type (void) G_GNUC_CONST;
GType media_source_collection_get_type (void) G_GNUC_CONST;
gpointer media_collection_registry_ref (gpointer instance);
void media_collection_registry_unref (gpointer instance);
GParamSpec* param_spec_media_collection_registry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_media_collection_registry (GValue* value, gpointer v_object);
void value_take_media_collection_registry (GValue* value, gpointer v_object);
gpointer value_get_media_collection_registry (const GValue* value);
GType media_collection_registry_get_type (void) G_GNUC_CONST;
MediaCollectionRegistry* media_collection_registry_get_instance (void);
GeeCollection* media_collection_registry_get_all (MediaCollectionRegistry* self);
static void library_trash_sidebar_entry_on_trashcan_contents_altered (LibraryTrashSidebarEntry* self);
static void _library_trash_sidebar_entry_on_trashcan_contents_altered_media_source_collection_trashcan_contents_altered (MediaSourceCollection* _sender, GeeCollection* added, GeeCollection* removed, gpointer self);
LibraryTrashSidebarEntry* library_trash_sidebar_entry_new (void);
LibraryTrashSidebarEntry* library_trash_sidebar_entry_construct (GType object_type);
SidebarSimplePageEntry* sidebar_simple_page_entry_construct (GType object_type);
void library_trash_sidebar_entry_init (void);
void library_trash_sidebar_entry_terminate (void);
static gchar* library_trash_sidebar_entry_real_get_sidebar_name (SidebarSimplePageEntry* base);
#define TRASH_PAGE_NAME _ ("Trash")
static gchar* library_trash_sidebar_entry_real_get_sidebar_icon (SidebarSimplePageEntry* base);
static gchar* library_trash_sidebar_entry_get_current_icon (void);
gint media_source_collection_get_trashcan_count (MediaSourceCollection* self);
#define RESOURCES_ICON_TRASH_FULL "user-trash-full"
#define RESOURCES_ICON_TRASH_EMPTY "user-trash"
static gboolean library_trash_sidebar_entry_real_internal_drop_received (SidebarInternalDropTargetEntry* base, GeeList* media);
gpointer command_manager_ref (gpointer instance);
void command_manager_unref (gpointer instance);
GParamSpec* param_spec_command_manager (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_command_manager (GValue* value, gpointer v_object);
void value_take_command_manager (GValue* value, gpointer v_object);
gpointer value_get_command_manager (const GValue* value);
GType command_manager_get_type (void) G_GNUC_CONST;
CommandManager* app_window_get_command_manager (void);
GType command_get_type (void) G_GNUC_CONST;
void command_manager_execute (CommandManager* self, Command* command);
TrashUntrashPhotosCommand* trash_untrash_photos_command_new (GeeCollection* sources, gboolean to_trash);
TrashUntrashPhotosCommand* trash_untrash_photos_command_construct (GType object_type, GeeCollection* sources, gboolean to_trash);
GType page_command_get_type (void) G_GNUC_CONST;
GType trash_untrash_photos_command_get_type (void) G_GNUC_CONST;
static gboolean library_trash_sidebar_entry_real_internal_drop_received_arbitrary (SidebarInternalDropTargetEntry* base, GtkSelectionData* data);
static Page* library_trash_sidebar_entry_real_create_page (SidebarSimplePageEntry* base);
TrashPage* trash_page_new (void);
TrashPage* trash_page_construct (GType object_type);
GType checkerboard_page_get_type (void) G_GNUC_CONST;
GType trash_page_get_type (void) G_GNUC_CONST;
static void library_trash_sidebar_entry_finalize (GObject * obj);


static void _library_trash_sidebar_entry_on_trashcan_contents_altered_media_source_collection_trashcan_contents_altered (MediaSourceCollection* _sender, GeeCollection* added, GeeCollection* removed, gpointer self) {
#line 16 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	library_trash_sidebar_entry_on_trashcan_contents_altered ((LibraryTrashSidebarEntry*) self);
#line 392 "TrashSidebarEntry.c"
}


LibraryTrashSidebarEntry* library_trash_sidebar_entry_construct (GType object_type) {
	LibraryTrashSidebarEntry * self = NULL;
#line 9 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	self = (LibraryTrashSidebarEntry*) sidebar_simple_page_entry_construct (object_type);
#line 400 "TrashSidebarEntry.c"
	{
		GeeIterator* _media_sources_it = NULL;
		MediaCollectionRegistry* _tmp0_;
		MediaCollectionRegistry* _tmp1_;
		GeeCollection* _tmp2_;
		GeeCollection* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp0_ = media_collection_registry_get_instance ();
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp1_ = _tmp0_;
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp2_ = media_collection_registry_get_all (_tmp1_);
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp3_ = _tmp2_;
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp4_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp5_ = _tmp4_;
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_g_object_unref0 (_tmp3_);
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_media_collection_registry_unref0 (_tmp1_);
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_media_sources_it = _tmp5_;
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		while (TRUE) {
#line 429 "TrashSidebarEntry.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_;
			MediaSourceCollection* media_sources = NULL;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			MediaSourceCollection* _tmp10_;
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp6_ = _media_sources_it;
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			if (!_tmp7_) {
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
				break;
#line 444 "TrashSidebarEntry.c"
			}
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp8_ = _media_sources_it;
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			media_sources = (MediaSourceCollection*) _tmp9_;
#line 11 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp10_ = media_sources;
#line 11 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			g_signal_connect_object (_tmp10_, "trashcan-contents-altered", (GCallback) _library_trash_sidebar_entry_on_trashcan_contents_altered_media_source_collection_trashcan_contents_altered, self, 0);
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_data_collection_unref0 (media_sources);
#line 458 "TrashSidebarEntry.c"
		}
#line 10 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_g_object_unref0 (_media_sources_it);
#line 462 "TrashSidebarEntry.c"
	}
#line 9 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	return self;
#line 466 "TrashSidebarEntry.c"
}


LibraryTrashSidebarEntry* library_trash_sidebar_entry_new (void) {
#line 9 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	return library_trash_sidebar_entry_construct (LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY);
#line 473 "TrashSidebarEntry.c"
}


void library_trash_sidebar_entry_init (void) {
}


void library_trash_sidebar_entry_terminate (void) {
}


static gchar* library_trash_sidebar_entry_real_get_sidebar_name (SidebarSimplePageEntry* base) {
	LibraryTrashSidebarEntry * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 25 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY, LibraryTrashSidebarEntry);
#line 26 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_tmp0_ = g_strdup (TRASH_PAGE_NAME);
#line 26 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	result = _tmp0_;
#line 26 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	return result;
#line 497 "TrashSidebarEntry.c"
}


static gchar* library_trash_sidebar_entry_real_get_sidebar_icon (SidebarSimplePageEntry* base) {
	LibraryTrashSidebarEntry * self;
	gchar* result = NULL;
	gchar* _tmp0_;
#line 29 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY, LibraryTrashSidebarEntry);
#line 30 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_tmp0_ = library_trash_sidebar_entry_get_current_icon ();
#line 30 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	result = _tmp0_;
#line 30 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	return result;
#line 513 "TrashSidebarEntry.c"
}


static gchar* library_trash_sidebar_entry_get_current_icon (void) {
	gchar* result = NULL;
	gchar* _tmp13_;
	{
		GeeIterator* _media_sources_it = NULL;
		MediaCollectionRegistry* _tmp0_;
		MediaCollectionRegistry* _tmp1_;
		GeeCollection* _tmp2_;
		GeeCollection* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp0_ = media_collection_registry_get_instance ();
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp1_ = _tmp0_;
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp2_ = media_collection_registry_get_all (_tmp1_);
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp3_ = _tmp2_;
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp4_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp5_ = _tmp4_;
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_g_object_unref0 (_tmp3_);
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_media_collection_registry_unref0 (_tmp1_);
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_media_sources_it = _tmp5_;
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		while (TRUE) {
#line 548 "TrashSidebarEntry.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_;
			MediaSourceCollection* media_sources = NULL;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			MediaSourceCollection* _tmp10_;
			gint _tmp11_;
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp6_ = _media_sources_it;
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			if (!_tmp7_) {
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
				break;
#line 564 "TrashSidebarEntry.c"
			}
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp8_ = _media_sources_it;
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			media_sources = (MediaSourceCollection*) _tmp9_;
#line 35 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp10_ = media_sources;
#line 35 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp11_ = media_source_collection_get_trashcan_count (_tmp10_);
#line 35 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			if (_tmp11_ > 0) {
#line 578 "TrashSidebarEntry.c"
				gchar* _tmp12_;
#line 36 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
				_tmp12_ = g_strdup (RESOURCES_ICON_TRASH_FULL);
#line 36 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
				result = _tmp12_;
#line 36 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
				_data_collection_unref0 (media_sources);
#line 36 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
				_g_object_unref0 (_media_sources_it);
#line 36 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
				return result;
#line 590 "TrashSidebarEntry.c"
			}
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_data_collection_unref0 (media_sources);
#line 594 "TrashSidebarEntry.c"
		}
#line 34 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_g_object_unref0 (_media_sources_it);
#line 598 "TrashSidebarEntry.c"
	}
#line 39 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_tmp13_ = g_strdup (RESOURCES_ICON_TRASH_EMPTY);
#line 39 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	result = _tmp13_;
#line 39 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	return result;
#line 606 "TrashSidebarEntry.c"
}


static gboolean library_trash_sidebar_entry_real_internal_drop_received (SidebarInternalDropTargetEntry* base, GeeList* media) {
	LibraryTrashSidebarEntry * self;
	gboolean result = FALSE;
	CommandManager* _tmp0_;
	CommandManager* _tmp1_;
	GeeList* _tmp2_;
	TrashUntrashPhotosCommand* _tmp3_;
	TrashUntrashPhotosCommand* _tmp4_;
#line 42 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY, LibraryTrashSidebarEntry);
#line 42 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	g_return_val_if_fail (GEE_IS_LIST (media), FALSE);
#line 43 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_tmp0_ = app_window_get_command_manager ();
#line 43 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_tmp1_ = _tmp0_;
#line 43 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_tmp2_ = media;
#line 43 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_tmp3_ = trash_untrash_photos_command_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection), TRUE);
#line 43 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_tmp4_ = _tmp3_;
#line 43 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	command_manager_execute (_tmp1_, G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_COMMAND, Command));
#line 43 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_g_object_unref0 (_tmp4_);
#line 43 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_command_manager_unref0 (_tmp1_);
#line 45 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	result = TRUE;
#line 45 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	return result;
#line 642 "TrashSidebarEntry.c"
}


static gboolean library_trash_sidebar_entry_real_internal_drop_received_arbitrary (SidebarInternalDropTargetEntry* base, GtkSelectionData* data) {
	LibraryTrashSidebarEntry * self;
	gboolean result = FALSE;
#line 48 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY, LibraryTrashSidebarEntry);
#line 48 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	g_return_val_if_fail (data != NULL, FALSE);
#line 49 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	result = FALSE;
#line 49 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	return result;
#line 657 "TrashSidebarEntry.c"
}


static Page* library_trash_sidebar_entry_real_create_page (SidebarSimplePageEntry* base) {
	LibraryTrashSidebarEntry * self;
	Page* result = NULL;
	TrashPage* _tmp0_;
#line 52 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY, LibraryTrashSidebarEntry);
#line 53 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_tmp0_ = trash_page_new ();
#line 53 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	g_object_ref_sink (_tmp0_);
#line 53 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_PAGE, Page);
#line 53 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	return result;
#line 675 "TrashSidebarEntry.c"
}


static void library_trash_sidebar_entry_on_trashcan_contents_altered (LibraryTrashSidebarEntry* self) {
	gchar* _tmp0_;
	gchar* _tmp1_;
#line 56 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	g_return_if_fail (LIBRARY_IS_TRASH_SIDEBAR_ENTRY (self));
#line 57 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_tmp0_ = library_trash_sidebar_entry_get_current_icon ();
#line 57 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_tmp1_ = _tmp0_;
#line 57 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, SIDEBAR_TYPE_ENTRY, SidebarEntry), "sidebar-icon-changed", _tmp1_);
#line 57 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	_g_free0 (_tmp1_);
#line 692 "TrashSidebarEntry.c"
}


static void library_trash_sidebar_entry_class_init (LibraryTrashSidebarEntryClass * klass) {
#line 7 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	library_trash_sidebar_entry_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	((SidebarSimplePageEntryClass *) klass)->get_sidebar_name = (gchar* (*) (SidebarSimplePageEntry *)) library_trash_sidebar_entry_real_get_sidebar_name;
#line 7 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	((SidebarSimplePageEntryClass *) klass)->get_sidebar_icon = (gchar* (*) (SidebarSimplePageEntry *)) library_trash_sidebar_entry_real_get_sidebar_icon;
#line 7 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	((SidebarSimplePageEntryClass *) klass)->create_page = (Page* (*) (SidebarSimplePageEntry *)) library_trash_sidebar_entry_real_create_page;
#line 7 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	G_OBJECT_CLASS (klass)->finalize = library_trash_sidebar_entry_finalize;
#line 707 "TrashSidebarEntry.c"
}


static void library_trash_sidebar_entry_sidebar_internal_drop_target_entry_interface_init (SidebarInternalDropTargetEntryIface * iface) {
#line 7 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	library_trash_sidebar_entry_sidebar_internal_drop_target_entry_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	iface->internal_drop_received = (gboolean (*) (SidebarInternalDropTargetEntry *, GeeList*)) library_trash_sidebar_entry_real_internal_drop_received;
#line 7 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	iface->internal_drop_received_arbitrary = (gboolean (*) (SidebarInternalDropTargetEntry *, GtkSelectionData*)) library_trash_sidebar_entry_real_internal_drop_received_arbitrary;
#line 718 "TrashSidebarEntry.c"
}


static void library_trash_sidebar_entry_instance_init (LibraryTrashSidebarEntry * self) {
}


static void library_trash_sidebar_entry_finalize (GObject * obj) {
	LibraryTrashSidebarEntry * self;
#line 7 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LIBRARY_TYPE_TRASH_SIDEBAR_ENTRY, LibraryTrashSidebarEntry);
#line 730 "TrashSidebarEntry.c"
	{
		GeeIterator* _media_sources_it = NULL;
		MediaCollectionRegistry* _tmp0_;
		MediaCollectionRegistry* _tmp1_;
		GeeCollection* _tmp2_;
		GeeCollection* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp0_ = media_collection_registry_get_instance ();
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp1_ = _tmp0_;
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp2_ = media_collection_registry_get_all (_tmp1_);
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp3_ = _tmp2_;
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp4_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_tmp5_ = _tmp4_;
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_g_object_unref0 (_tmp3_);
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_media_collection_registry_unref0 (_tmp1_);
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_media_sources_it = _tmp5_;
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		while (TRUE) {
#line 759 "TrashSidebarEntry.c"
			GeeIterator* _tmp6_;
			gboolean _tmp7_;
			MediaSourceCollection* media_sources = NULL;
			GeeIterator* _tmp8_;
			gpointer _tmp9_;
			MediaSourceCollection* _tmp10_;
			guint _tmp11_;
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp6_ = _media_sources_it;
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			if (!_tmp7_) {
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
				break;
#line 775 "TrashSidebarEntry.c"
			}
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp8_ = _media_sources_it;
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			media_sources = (MediaSourceCollection*) _tmp9_;
#line 16 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_tmp10_ = media_sources;
#line 16 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			g_signal_parse_name ("trashcan-contents-altered", TYPE_MEDIA_SOURCE_COLLECTION, &_tmp11_, NULL, FALSE);
#line 16 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			g_signal_handlers_disconnect_matched (_tmp10_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp11_, 0, NULL, (GCallback) _library_trash_sidebar_entry_on_trashcan_contents_altered_media_source_collection_trashcan_contents_altered, self);
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
			_data_collection_unref0 (media_sources);
#line 791 "TrashSidebarEntry.c"
		}
#line 15 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
		_g_object_unref0 (_media_sources_it);
#line 795 "TrashSidebarEntry.c"
	}
#line 7 "/home/jens/Source/shotwell/src/library/TrashSidebarEntry.vala"
	G_OBJECT_CLASS (library_trash_sidebar_entry_parent_class)->finalize (obj);
#line 799 "TrashSidebarEntry.c"
}


GType library_trash_sidebar_entry_get_type (void) {
	static volatile gsize library_trash_sidebar_entry_type_id__volatile = 0;
	if (g_once_init_enter (&library_trash_sidebar_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (LibraryTrashSidebarEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_trash_sidebar_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryTrashSidebarEntry), 0, (GInstanceInitFunc) library_trash_sidebar_entry_instance_init, NULL };
		static const GInterfaceInfo sidebar_internal_drop_target_entry_info = { (GInterfaceInitFunc) library_trash_sidebar_entry_sidebar_internal_drop_target_entry_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType library_trash_sidebar_entry_type_id;
		library_trash_sidebar_entry_type_id = g_type_register_static (SIDEBAR_TYPE_SIMPLE_PAGE_ENTRY, "LibraryTrashSidebarEntry", &g_define_type_info, 0);
		g_type_add_interface_static (library_trash_sidebar_entry_type_id, SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY, &sidebar_internal_drop_target_entry_info);
		g_once_init_leave (&library_trash_sidebar_entry_type_id__volatile, library_trash_sidebar_entry_type_id);
	}
	return library_trash_sidebar_entry_type_id__volatile;
}



