/* PhotoTable.c generated by valac 0.36.6, the Vala compiler
 * generated from PhotoTable.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <string.h>
#include <stdlib.h>
#include <time.h>
#include <gee.h>
#include <sqlite3.h>
#include <gio/gio.h>
#include <gobject/gvaluecollector.h>


#define TYPE_PHOTO_ID (photo_id_get_type ())
typedef struct _PhotoID PhotoID;

#define TYPE_IMPORT_ID (import_id_get_type ())
typedef struct _ImportID ImportID;

#define TYPE_PHOTO_ROW (photo_row_get_type ())
#define PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_ROW, PhotoRow))
#define PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_ROW, PhotoRowClass))
#define IS_PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_ROW))
#define IS_PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_ROW))
#define PHOTO_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_ROW, PhotoRowClass))

typedef struct _PhotoRow PhotoRow;
typedef struct _PhotoRowClass PhotoRowClass;
typedef struct _PhotoRowPrivate PhotoRowPrivate;

#define TYPE_BACKING_PHOTO_ROW (backing_photo_row_get_type ())
#define BACKING_PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BACKING_PHOTO_ROW, BackingPhotoRow))
#define BACKING_PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BACKING_PHOTO_ROW, BackingPhotoRowClass))
#define IS_BACKING_PHOTO_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BACKING_PHOTO_ROW))
#define IS_BACKING_PHOTO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BACKING_PHOTO_ROW))
#define BACKING_PHOTO_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BACKING_PHOTO_ROW, BackingPhotoRowClass))

typedef struct _BackingPhotoRow BackingPhotoRow;
typedef struct _BackingPhotoRowClass BackingPhotoRowClass;

#define TYPE_EVENT_ID (event_id_get_type ())
typedef struct _EventID EventID;

#define TYPE_ORIENTATION (orientation_get_type ())

#define TYPE_KEY_VALUE_MAP (key_value_map_get_type ())
#define KEY_VALUE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_KEY_VALUE_MAP, KeyValueMap))
#define KEY_VALUE_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_KEY_VALUE_MAP, KeyValueMapClass))
#define IS_KEY_VALUE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_KEY_VALUE_MAP))
#define IS_KEY_VALUE_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_KEY_VALUE_MAP))
#define KEY_VALUE_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_KEY_VALUE_MAP, KeyValueMapClass))

typedef struct _KeyValueMap KeyValueMap;
typedef struct _KeyValueMapClass KeyValueMapClass;

#define TYPE_RATING (rating_get_type ())

#define TYPE_BACKING_PHOTO_ID (backing_photo_id_get_type ())
typedef struct _BackingPhotoID BackingPhotoID;

#define TYPE_RAW_DEVELOPER (raw_developer_get_type ())
#define _backing_photo_row_unref0(var) ((var == NULL) ? NULL : (var = (backing_photo_row_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _ParamSpecPhotoRow ParamSpecPhotoRow;

#define TYPE_DATABASE_TABLE (database_table_get_type ())
#define DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_TABLE, DatabaseTable))
#define DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_TABLE, DatabaseTableClass))
#define IS_DATABASE_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_TABLE))
#define IS_DATABASE_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_TABLE))
#define DATABASE_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_TABLE, DatabaseTableClass))

typedef struct _DatabaseTable DatabaseTable;
typedef struct _DatabaseTableClass DatabaseTableClass;
typedef struct _DatabaseTablePrivate DatabaseTablePrivate;

#define TYPE_PHOTO_TABLE (photo_table_get_type ())
#define PHOTO_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_TABLE, PhotoTable))
#define PHOTO_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_TABLE, PhotoTableClass))
#define IS_PHOTO_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_TABLE))
#define IS_PHOTO_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_TABLE))
#define PHOTO_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_TABLE, PhotoTableClass))

typedef struct _PhotoTable PhotoTable;
typedef struct _PhotoTableClass PhotoTableClass;
typedef struct _PhotoTablePrivate PhotoTablePrivate;
#define _sqlite3_finalize0(var) ((var == NULL) ? NULL : (var = (sqlite3_finalize (var), NULL)))
#define _database_table_unref0(var) ((var == NULL) ? NULL : (var = (database_table_unref (var), NULL)))
typedef struct _BackingPhotoRowPrivate BackingPhotoRowPrivate;

#define TYPE_PHOTO_FILE_FORMAT (photo_file_format_get_type ())

#define TYPE_DIMENSIONS (dimensions_get_type ())
typedef struct _Dimensions Dimensions;
#define _photo_row_unref0(var) ((var == NULL) ? NULL : (var = (photo_row_unref (var), NULL)))
#define _g_key_file_unref0(var) ((var == NULL) ? NULL : (var = (g_key_file_unref (var), NULL)))
#define _key_value_map_unref0(var) ((var == NULL) ? NULL : (var = (key_value_map_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _ParamSpecBackingPhotoRow ParamSpecBackingPhotoRow;

#define TYPE_BACKING_PHOTO_TABLE (backing_photo_table_get_type ())
#define BACKING_PHOTO_TABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BACKING_PHOTO_TABLE, BackingPhotoTable))
#define BACKING_PHOTO_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BACKING_PHOTO_TABLE, BackingPhotoTableClass))
#define IS_BACKING_PHOTO_TABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BACKING_PHOTO_TABLE))
#define IS_BACKING_PHOTO_TABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BACKING_PHOTO_TABLE))
#define BACKING_PHOTO_TABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BACKING_PHOTO_TABLE, BackingPhotoTableClass))

typedef struct _BackingPhotoTable BackingPhotoTable;
typedef struct _BackingPhotoTableClass BackingPhotoTableClass;
typedef struct _BackingPhotoTablePrivate BackingPhotoTablePrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PhotoID {
	gint64 id;
};

struct _ImportID {
	gint64 id;
};

struct _EventID {
	gint64 id;
};

typedef enum  {
	ORIENTATION_MIN = 1,
	ORIENTATION_TOP_LEFT = 1,
	ORIENTATION_TOP_RIGHT = 2,
	ORIENTATION_BOTTOM_RIGHT = 3,
	ORIENTATION_BOTTOM_LEFT = 4,
	ORIENTATION_LEFT_TOP = 5,
	ORIENTATION_RIGHT_TOP = 6,
	ORIENTATION_RIGHT_BOTTOM = 7,
	ORIENTATION_LEFT_BOTTOM = 8,
	ORIENTATION_MAX = 8
} Orientation;

typedef enum  {
	RATING_REJECTED = -1,
	RATING_UNRATED = 0,
	RATING_ONE = 1,
	RATING_TWO = 2,
	RATING_THREE = 3,
	RATING_FOUR = 4,
	RATING_FIVE = 5
} Rating;

struct _BackingPhotoID {
	gint64 id;
};

typedef enum  {
	RAW_DEVELOPER_SHOTWELL = 0,
	RAW_DEVELOPER_CAMERA,
	RAW_DEVELOPER_EMBEDDED
} RawDeveloper;

struct _PhotoRow {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PhotoRowPrivate * priv;
	PhotoID photo_id;
	BackingPhotoRow* master;
	time_t exposure_time;
	ImportID import_id;
	EventID event_id;
	Orientation orientation;
	GeeHashMap* transformations;
	gchar* md5;
	gchar* thumbnail_md5;
	gchar* exif_md5;
	time_t time_created;
	guint64 flags;
	Rating rating;
	gchar* title;
	gchar* comment;
	gchar* backlinks;
	time_t time_reimported;
	BackingPhotoID editable_id;
	gboolean metadata_dirty;
	RawDeveloper developer;
	BackingPhotoID* development_ids;
	gint development_ids_length1;
};

struct _PhotoRowClass {
	GTypeClass parent_class;
	void (*finalize) (PhotoRow *self);
};

struct _ParamSpecPhotoRow {
	GParamSpec parent_instance;
};

struct _DatabaseTable {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DatabaseTablePrivate * priv;
	gchar* table_name;
};

struct _DatabaseTableClass {
	GTypeClass parent_class;
	void (*finalize) (DatabaseTable *self);
};

struct _PhotoTable {
	DatabaseTable parent_instance;
	PhotoTablePrivate * priv;
};

struct _PhotoTableClass {
	DatabaseTableClass parent_class;
};

typedef enum  {
	PHOTO_FILE_FORMAT_JFIF,
	PHOTO_FILE_FORMAT_RAW,
	PHOTO_FILE_FORMAT_PNG,
	PHOTO_FILE_FORMAT_TIFF,
	PHOTO_FILE_FORMAT_BMP,
	PHOTO_FILE_FORMAT_UNKNOWN
} PhotoFileFormat;

struct _Dimensions {
	gint width;
	gint height;
};

struct _BackingPhotoRow {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BackingPhotoRowPrivate * priv;
	BackingPhotoID id;
	time_t time_created;
	gchar* filepath;
	gint64 filesize;
	time_t timestamp;
	PhotoFileFormat file_format;
	Dimensions dim;
	Orientation original_orientation;
};

struct _BackingPhotoRowClass {
	GTypeClass parent_class;
	void (*finalize) (BackingPhotoRow *self);
};

typedef enum  {
	DATABASE_ERROR_ERROR,
	DATABASE_ERROR_BACKING,
	DATABASE_ERROR_MEMORY,
	DATABASE_ERROR_ABORT,
	DATABASE_ERROR_LIMITS,
	DATABASE_ERROR_TYPESPEC
} DatabaseError;
#define DATABASE_ERROR database_error_quark ()
struct _ParamSpecBackingPhotoRow {
	GParamSpec parent_instance;
};

struct _BackingPhotoTable {
	DatabaseTable parent_instance;
	BackingPhotoTablePrivate * priv;
};

struct _BackingPhotoTableClass {
	DatabaseTableClass parent_class;
};


static gpointer photo_row_parent_class = NULL;
static gpointer photo_table_parent_class = NULL;
static PhotoTable* photo_table_instance;
static PhotoTable* photo_table_instance = NULL;
extern sqlite3* database_table_db;
static gpointer backing_photo_row_parent_class = NULL;
static gpointer backing_photo_table_parent_class = NULL;
static BackingPhotoTable* backing_photo_table_instance;
static BackingPhotoTable* backing_photo_table_instance = NULL;

GType photo_id_get_type (void) G_GNUC_CONST;
PhotoID* photo_id_dup (const PhotoID* self);
void photo_id_free (PhotoID* self);
#define PHOTO_ID_INVALID ((gint64) -1)
void photo_id_init (PhotoID *self, gint64 id);
gboolean photo_id_is_invalid (PhotoID *self);
gboolean photo_id_is_valid (PhotoID *self);
guint photo_id_hash (PhotoID *self);
guint int64_hash (gint64* n);
gboolean photo_id_equal (void* a, void* b);
gchar* photo_id_upgrade_photo_id_to_source_id (PhotoID* photo_id);
#define PHOTO_TYPENAME "thumb"
GType import_id_get_type (void) G_GNUC_CONST;
ImportID* import_id_dup (const ImportID* self);
void import_id_free (ImportID* self);
#define IMPORT_ID_INVALID ((gint64) 0)
void import_id_init (ImportID *self, gint64 id);
void import_id_generate (ImportID* result);
gboolean import_id_is_invalid (ImportID *self);
gboolean import_id_is_valid (ImportID *self);
gint import_id_compare_func (ImportID* a, ImportID* b);
gint64 import_id_comparator (void* a, void* b);
gpointer photo_row_ref (gpointer instance);
void photo_row_unref (gpointer instance);
GParamSpec* param_spec_photo_row (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_photo_row (GValue* value, gpointer v_object);
void value_take_photo_row (GValue* value, gpointer v_object);
gpointer value_get_photo_row (const GValue* value);
GType photo_row_get_type (void) G_GNUC_CONST;
gpointer backing_photo_row_ref (gpointer instance);
void backing_photo_row_unref (gpointer instance);
GParamSpec* param_spec_backing_photo_row (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_backing_photo_row (GValue* value, gpointer v_object);
void value_take_backing_photo_row (GValue* value, gpointer v_object);
gpointer value_get_backing_photo_row (const GValue* value);
GType backing_photo_row_get_type (void) G_GNUC_CONST;
GType event_id_get_type (void) G_GNUC_CONST;
EventID* event_id_dup (const EventID* self);
void event_id_free (EventID* self);
GType orientation_get_type (void) G_GNUC_CONST;
gpointer key_value_map_ref (gpointer instance);
void key_value_map_unref (gpointer instance);
GParamSpec* param_spec_key_value_map (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_key_value_map (GValue* value, gpointer v_object);
void value_take_key_value_map (GValue* value, gpointer v_object);
gpointer value_get_key_value_map (const GValue* value);
GType key_value_map_get_type (void) G_GNUC_CONST;
GType rating_get_type (void) G_GNUC_CONST;
GType backing_photo_id_get_type (void) G_GNUC_CONST;
BackingPhotoID* backing_photo_id_dup (const BackingPhotoID* self);
void backing_photo_id_free (BackingPhotoID* self);
GType raw_developer_get_type (void) G_GNUC_CONST;
enum  {
	PHOTO_ROW_DUMMY_PROPERTY
};
PhotoRow* photo_row_new (void);
PhotoRow* photo_row_construct (GType object_type);
BackingPhotoRow* backing_photo_row_new (void);
BackingPhotoRow* backing_photo_row_construct (GType object_type);
#define BACKING_PHOTO_ID_INVALID ((gint64) -1)
void backing_photo_id_init (BackingPhotoID *self, gint64 id);
RawDeveloper* raw_developer_as_array (int* result_length1);
static void photo_row_finalize (PhotoRow * obj);
gpointer database_table_ref (gpointer instance);
void database_table_unref (gpointer instance);
GParamSpec* param_spec_database_table (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_database_table (GValue* value, gpointer v_object);
void value_take_database_table (GValue* value, gpointer v_object);
gpointer value_get_database_table (const GValue* value);
GType database_table_get_type (void) G_GNUC_CONST;
GType photo_table_get_type (void) G_GNUC_CONST;
enum  {
	PHOTO_TABLE_DUMMY_PROPERTY
};
static PhotoTable* photo_table_new (void);
static PhotoTable* photo_table_construct (GType object_type);
DatabaseTable* database_table_construct (GType object_type);
void database_table_fatal (const gchar* op, gint res);
void database_table_warning (const gchar* op, gint res);
void database_table_set_table_name (DatabaseTable* self, const gchar* table_name);
PhotoTable* photo_table_get_instance (void);
void photo_table_add (PhotoTable* self, PhotoRow* photo_row, PhotoID* result);
gulong now_sec (void);
GType photo_file_format_get_type (void) G_GNUC_CONST;
GType dimensions_get_type (void) G_GNUC_CONST;
Dimensions* dimensions_dup (const Dimensions* self);
void dimensions_free (Dimensions* self);
#define EVENT_ID_INVALID ((gint64) -1)
gint photo_file_format_serialize (PhotoFileFormat self);
gint rating_serialize (Rating self);
gchar* raw_developer_to_string (RawDeveloper self);
void event_id_init (EventID *self, gint64 id);
GQuark database_error_quark (void);
void photo_table_reimport (PhotoTable* self, PhotoRow* row, GError** error);
void database_table_throw_error (const gchar* method, gint res, GError** error);
gboolean photo_table_master_exif_updated (PhotoTable* self, PhotoID* photoID, gint64 filesize, glong timestamp, const gchar* md5, const gchar* exif_md5, const gchar* thumbnail_md5, PhotoRow* row);
static void photo_table_validate_orientation (PhotoTable* self, PhotoRow* row);
gboolean photo_table_set_orientation (PhotoTable* self, PhotoID* photo_id, Orientation orientation);
PhotoRow* photo_table_get_row (PhotoTable* self, PhotoID* photo_id);
void dimensions_init (Dimensions *self, gint width, gint height);
GeeHashMap* photo_table_marshall_all_transformations (const gchar* trans);
Rating rating_unserialize (gint value);
PhotoFileFormat photo_file_format_unserialize (gint value);
RawDeveloper raw_developer_from_string (const gchar* value);
GeeArrayList* photo_table_get_all (PhotoTable* self);
void photo_table_duplicate (PhotoTable* self, PhotoID* photo_id, const gchar* new_filename, BackingPhotoID* editable_id, BackingPhotoID* develop_shotwell, BackingPhotoID* develop_camera_id, BackingPhotoID* develop_embedded_id, PhotoID* result);
gchar* photo_table_unmarshall_all_transformations (GeeHashMap* transformations);
gboolean photo_table_set_title (PhotoTable* self, PhotoID* photo_id, const gchar* new_title);
gboolean database_table_update_text_by_id (DatabaseTable* self, gint64 id, const gchar* column, const gchar* text);
gboolean photo_table_set_comment (PhotoTable* self, PhotoID* photo_id, const gchar* new_comment);
void photo_table_set_filepath (PhotoTable* self, PhotoID* photo_id, const gchar* filepath, GError** error);
void database_table_update_text_by_id_2 (DatabaseTable* self, gint64 id, const gchar* column, const gchar* text, GError** error);
void photo_table_update_timestamp (PhotoTable* self, PhotoID* photo_id, time_t timestamp, GError** error);
void database_table_update_int64_by_id_2 (DatabaseTable* self, gint64 id, const gchar* column, gint64 value, GError** error);
gboolean photo_table_set_exposure_time (PhotoTable* self, PhotoID* photo_id, time_t time);
gboolean database_table_update_int64_by_id (DatabaseTable* self, gint64 id, const gchar* column, gint64 value);
void photo_table_set_import_id (PhotoTable* self, PhotoID* photo_id, ImportID* import_id, GError** error);
gboolean photo_table_remove_by_file (PhotoTable* self, GFile* file);
void photo_table_remove (PhotoTable* self, PhotoID* photo_id, GError** error);
void database_table_delete_by_id (DatabaseTable* self, gint64 id, GError** error);
GeeArrayList* photo_table_get_photos (PhotoTable* self);
gboolean database_table_update_int_by_id (DatabaseTable* self, gint64 id, const gchar* column, gint value);
gboolean photo_table_replace_flags (PhotoTable* self, PhotoID* photo_id, guint64 flags);
gboolean photo_table_set_rating (PhotoTable* self, PhotoID* photo_id, Rating rating);
gint photo_table_get_event_photo_count (PhotoTable* self, EventID* event_id);
GeeArrayList* photo_table_get_event_source_ids (PhotoTable* self, EventID* event_id);
gboolean photo_table_event_has_photos (PhotoTable* self, EventID* event_id);
gboolean photo_table_drop_event (PhotoTable* self, EventID* event_id);
gboolean photo_table_set_event (PhotoTable* self, PhotoID* photo_id, EventID* event_id);
static gchar* photo_table_get_raw_transformations (PhotoTable* self, PhotoID* photo_id);
gboolean database_table_select_by_id (DatabaseTable* self, gint64 id, const gchar* columns, sqlite3_stmt* * stmt);
static gboolean photo_table_set_raw_transformations (PhotoTable* self, PhotoID* photo_id, const gchar* trans);
gboolean photo_table_set_transformation_state (PhotoTable* self, PhotoID* photo_id, Orientation orientation, GeeHashMap* transformations);
KeyValueMap* key_value_map_new (const gchar* group);
KeyValueMap* key_value_map_construct (GType object_type, const gchar* group);
void key_value_map_set_string (KeyValueMap* self, const gchar* key, const gchar* value);
GeeSet* key_value_map_get_keys (KeyValueMap* self);
gchar* key_value_map_get_string (KeyValueMap* self, const gchar* key, const gchar* def);
gboolean photo_table_set_transformation (PhotoTable* self, PhotoID* photo_id, KeyValueMap* map);
gchar* key_value_map_get_group (KeyValueMap* self);
gboolean photo_table_remove_transformation (PhotoTable* self, PhotoID* photo_id, const gchar* object);
gboolean photo_table_remove_all_transformations (PhotoTable* self, PhotoID* photo_id);
static sqlite3_stmt* photo_table_get_duplicate_stmt (PhotoTable* self, GFile* file, const gchar* thumbnail_md5, const gchar* md5, PhotoFileFormat file_format);
gboolean photo_table_has_duplicate (PhotoTable* self, GFile* file, const gchar* thumbnail_md5, const gchar* md5, PhotoFileFormat file_format);
PhotoID* photo_table_get_duplicate_ids (PhotoTable* self, GFile* file, const gchar* thumbnail_md5, const gchar* md5, PhotoFileFormat file_format, int* result_length1);
static void _vala_array_add2 (PhotoID* * array, int* length, int* size, const PhotoID* value);
void photo_table_update_backlinks (PhotoTable* self, PhotoID* photo_id, const gchar* backlinks, GError** error);
void photo_table_attach_editable (PhotoTable* self, PhotoRow* row, BackingPhotoID* editable_id, GError** error);
void photo_table_detach_editable (PhotoTable* self, PhotoRow* row, GError** error);
void photo_table_set_metadata_dirty (PhotoTable* self, PhotoID* photo_id, gboolean dirty, GError** error);
void database_table_update_int_by_id_2 (DatabaseTable* self, gint64 id, const gchar* column, gint value, GError** error);
void photo_table_update_raw_development (PhotoTable* self, PhotoRow* row, RawDeveloper rd, BackingPhotoID* backing_photo_id, GError** error);
void photo_table_remove_development (PhotoTable* self, PhotoRow* row, RawDeveloper rd, GError** error);
static void photo_table_finalize (DatabaseTable * obj);
gboolean backing_photo_id_is_invalid (BackingPhotoID *self);
gboolean backing_photo_id_is_valid (BackingPhotoID *self);
enum  {
	BACKING_PHOTO_ROW_DUMMY_PROPERTY
};
gboolean backing_photo_row_matches_file_info (BackingPhotoRow* self, GFileInfo* info);
gboolean backing_photo_row_is_touched (BackingPhotoRow* self, GFileInfo* info);
void backing_photo_row_copy_from (BackingPhotoRow* self, BackingPhotoRow* from);
static void backing_photo_row_finalize (BackingPhotoRow * obj);
GType backing_photo_table_get_type (void) G_GNUC_CONST;
enum  {
	BACKING_PHOTO_TABLE_DUMMY_PROPERTY
};
static BackingPhotoTable* backing_photo_table_new (void);
static BackingPhotoTable* backing_photo_table_construct (GType object_type);
BackingPhotoTable* backing_photo_table_get_instance (void);
void backing_photo_table_add (BackingPhotoTable* self, BackingPhotoRow* state, GError** error);
BackingPhotoRow* backing_photo_table_fetch (BackingPhotoTable* self, BackingPhotoID* id, GError** error);
void backing_photo_table_update (BackingPhotoTable* self, BackingPhotoRow* row, GError** error);
void backing_photo_table_update_attributes (BackingPhotoTable* self, BackingPhotoID* id, time_t timestamp, gint64 filesize, GError** error);
void backing_photo_table_remove (BackingPhotoTable* self, BackingPhotoID* backing_id, GError** error);
void backing_photo_table_set_filepath (BackingPhotoTable* self, BackingPhotoID* id, const gchar* filepath, GError** error);
void backing_photo_table_update_timestamp (BackingPhotoTable* self, BackingPhotoID* id, time_t timestamp, GError** error);
static void backing_photo_table_finalize (DatabaseTable * obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


void photo_id_init (PhotoID *self, gint64 id) {
	gint64 _tmp0_;
#line 12 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	memset (self, 0, sizeof (PhotoID));
#line 13 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = id;
#line 13 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	(*self).id = _tmp0_;
#line 484 "PhotoTable.c"
}


gboolean photo_id_is_invalid (PhotoID *self) {
	gboolean result = FALSE;
	gint64 _tmp0_;
#line 17 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = (*self).id;
#line 17 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp0_ == PHOTO_ID_INVALID;
#line 17 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 497 "PhotoTable.c"
}


gboolean photo_id_is_valid (PhotoID *self) {
	gboolean result = FALSE;
	gint64 _tmp0_;
#line 21 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = (*self).id;
#line 21 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp0_ != PHOTO_ID_INVALID;
#line 21 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 510 "PhotoTable.c"
}


guint photo_id_hash (PhotoID *self) {
	guint result = 0U;
	gint64 _tmp0_;
	guint _tmp1_;
#line 25 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = (*self).id;
#line 25 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = int64_hash (&_tmp0_);
#line 25 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp1_;
#line 25 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 526 "PhotoTable.c"
}


gboolean photo_id_equal (void* a, void* b) {
	gboolean result = FALSE;
	void* _tmp0_;
	gint64 _tmp1_;
	void* _tmp2_;
	gint64 _tmp3_;
#line 29 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = a;
#line 29 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = (*((PhotoID*) _tmp0_)).id;
#line 29 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = b;
#line 29 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = (*((PhotoID*) _tmp2_)).id;
#line 29 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp1_ == _tmp3_;
#line 29 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 548 "PhotoTable.c"
}


gchar* photo_id_upgrade_photo_id_to_source_id (PhotoID* photo_id) {
	gchar* result = NULL;
	PhotoID _tmp0_;
	gint64 _tmp1_;
	gchar* _tmp2_;
#line 32 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, NULL);
#line 33 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 33 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 33 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = g_strdup_printf ("%s%016" G_GINT64_MODIFIER "x", PHOTO_TYPENAME, _tmp1_);
#line 33 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp2_;
#line 33 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 569 "PhotoTable.c"
}


PhotoID* photo_id_dup (const PhotoID* self) {
	PhotoID* dup;
#line 7 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	dup = g_new0 (PhotoID, 1);
#line 7 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	memcpy (dup, self, sizeof (PhotoID));
#line 7 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return dup;
#line 581 "PhotoTable.c"
}


void photo_id_free (PhotoID* self) {
#line 7 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_free (self);
#line 588 "PhotoTable.c"
}


GType photo_id_get_type (void) {
	static volatile gsize photo_id_type_id__volatile = 0;
	if (g_once_init_enter (&photo_id_type_id__volatile)) {
		GType photo_id_type_id;
		photo_id_type_id = g_boxed_type_register_static ("PhotoID", (GBoxedCopyFunc) photo_id_dup, (GBoxedFreeFunc) photo_id_free);
		g_once_init_leave (&photo_id_type_id__volatile, photo_id_type_id);
	}
	return photo_id_type_id__volatile;
}


void import_id_init (ImportID *self, gint64 id) {
	gint64 _tmp0_;
#line 42 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	memset (self, 0, sizeof (ImportID));
#line 43 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = id;
#line 43 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	(*self).id = _tmp0_;
#line 611 "PhotoTable.c"
}


void import_id_generate (ImportID* result) {
	GTimeVal timestamp = {0};
	gint64 id = 0LL;
	GTimeVal _tmp0_;
	glong _tmp1_;
	ImportID _tmp2_ = {0};
#line 47 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_get_current_time (&timestamp);
#line 48 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_get_current_time (&timestamp);
#line 49 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = timestamp;
#line 49 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.tv_sec;
#line 49 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	id = (gint64) _tmp1_;
#line 51 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	import_id_init (&_tmp2_, id);
#line 51 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	*result = _tmp2_;
#line 51 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return;
#line 637 "PhotoTable.c"
}


gboolean import_id_is_invalid (ImportID *self) {
	gboolean result = FALSE;
	gint64 _tmp0_;
#line 55 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = (*self).id;
#line 55 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp0_ == IMPORT_ID_INVALID;
#line 55 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 650 "PhotoTable.c"
}


gboolean import_id_is_valid (ImportID *self) {
	gboolean result = FALSE;
	gint64 _tmp0_;
#line 59 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = (*self).id;
#line 59 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp0_ != IMPORT_ID_INVALID;
#line 59 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 663 "PhotoTable.c"
}


gint import_id_compare_func (ImportID* a, ImportID* b) {
	gint result = 0;
	gboolean _tmp0_ = FALSE;
	ImportID* _tmp1_;
	ImportID* _tmp3_;
	gint64 _tmp4_;
	ImportID* _tmp5_;
	gint64 _tmp6_;
#line 63 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = a;
#line 63 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp1_ != NULL) {
#line 679 "PhotoTable.c"
		ImportID* _tmp2_;
#line 63 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp2_ = b;
#line 63 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = _tmp2_ != NULL;
#line 685 "PhotoTable.c"
	} else {
#line 63 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = FALSE;
#line 689 "PhotoTable.c"
	}
#line 63 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp0_, "a != null && b != null");
#line 64 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = a;
#line 64 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = (*_tmp3_).id;
#line 64 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = b;
#line 64 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = (*_tmp5_).id;
#line 64 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = (gint) (_tmp4_ - _tmp6_);
#line 64 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 705 "PhotoTable.c"
}


gint64 import_id_comparator (void* a, void* b) {
	gint64 result = 0LL;
	void* _tmp0_;
	gint64 _tmp1_;
	void* _tmp2_;
	gint64 _tmp3_;
#line 68 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = a;
#line 68 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = (*((ImportID*) _tmp0_)).id;
#line 68 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = b;
#line 68 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = (*((ImportID*) _tmp2_)).id;
#line 68 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp1_ - _tmp3_;
#line 68 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 727 "PhotoTable.c"
}


ImportID* import_id_dup (const ImportID* self) {
	ImportID* dup;
#line 37 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	dup = g_new0 (ImportID, 1);
#line 37 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	memcpy (dup, self, sizeof (ImportID));
#line 37 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return dup;
#line 739 "PhotoTable.c"
}


void import_id_free (ImportID* self) {
#line 37 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_free (self);
#line 746 "PhotoTable.c"
}


GType import_id_get_type (void) {
	static volatile gsize import_id_type_id__volatile = 0;
	if (g_once_init_enter (&import_id_type_id__volatile)) {
		GType import_id_type_id;
		import_id_type_id = g_boxed_type_register_static ("ImportID", (GBoxedCopyFunc) import_id_dup, (GBoxedFreeFunc) import_id_free);
		g_once_init_leave (&import_id_type_id__volatile, import_id_type_id);
	}
	return import_id_type_id__volatile;
}


PhotoRow* photo_row_construct (GType object_type) {
	PhotoRow* self = NULL;
	BackingPhotoRow* _tmp0_;
	gint _tmp1_;
	RawDeveloper* _tmp2_;
	RawDeveloper* _tmp3_;
	gint _tmp3__length1;
	BackingPhotoID* _tmp4_;
	gint _tmp5_;
	RawDeveloper* _tmp6_;
#line 100 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self = (PhotoRow*) g_type_create_instance (object_type);
#line 101 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = backing_photo_row_new ();
#line 101 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_backing_photo_row_unref0 (self->master);
#line 101 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->master = _tmp0_;
#line 102 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	backing_photo_id_init (&self->editable_id, BACKING_PHOTO_ID_INVALID);
#line 103 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = raw_developer_as_array (&_tmp1_);
#line 103 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = _tmp2_;
#line 103 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3__length1 = _tmp1_;
#line 103 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = g_new0 (BackingPhotoID, _tmp1_);
#line 103 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->development_ids = (g_free (self->development_ids), NULL);
#line 103 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->development_ids = _tmp4_;
#line 103 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->development_ids_length1 = _tmp1_;
#line 103 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = (g_free (_tmp3_), NULL);
#line 104 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = raw_developer_as_array (&_tmp5_);
#line 799 "PhotoTable.c"
	{
		RawDeveloper* d_collection = NULL;
		gint d_collection_length1 = 0;
		gint _d_collection_size_ = 0;
		gint d_it = 0;
#line 104 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		d_collection = _tmp6_;
#line 104 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		d_collection_length1 = _tmp5_;
#line 104 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		for (d_it = 0; d_it < _tmp5_; d_it = d_it + 1) {
#line 811 "PhotoTable.c"
			RawDeveloper d = 0;
#line 104 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			d = d_collection[d_it];
#line 815 "PhotoTable.c"
			{
				BackingPhotoID* _tmp7_;
				gint _tmp7__length1;
				RawDeveloper _tmp8_;
				BackingPhotoID _tmp9_ = {0};
				BackingPhotoID _tmp10_;
#line 105 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp7_ = self->development_ids;
#line 105 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp7__length1 = self->development_ids_length1;
#line 105 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp8_ = d;
#line 105 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				backing_photo_id_init (&_tmp9_, BACKING_PHOTO_ID_INVALID);
#line 105 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp7_[_tmp8_] = _tmp9_;
#line 105 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp10_ = _tmp7_[_tmp8_];
#line 834 "PhotoTable.c"
			}
		}
#line 104 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		d_collection = (g_free (d_collection), NULL);
#line 839 "PhotoTable.c"
	}
#line 100 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return self;
#line 843 "PhotoTable.c"
}


PhotoRow* photo_row_new (void) {
#line 100 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return photo_row_construct (TYPE_PHOTO_ROW);
#line 850 "PhotoTable.c"
}


static void value_photo_row_init (GValue* value) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	value->data[0].v_pointer = NULL;
#line 857 "PhotoTable.c"
}


static void value_photo_row_free_value (GValue* value) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (value->data[0].v_pointer) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		photo_row_unref (value->data[0].v_pointer);
#line 866 "PhotoTable.c"
	}
}


static void value_photo_row_copy_value (const GValue* src_value, GValue* dest_value) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (src_value->data[0].v_pointer) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		dest_value->data[0].v_pointer = photo_row_ref (src_value->data[0].v_pointer);
#line 876 "PhotoTable.c"
	} else {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		dest_value->data[0].v_pointer = NULL;
#line 880 "PhotoTable.c"
	}
}


static gpointer value_photo_row_peek_pointer (const GValue* value) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return value->data[0].v_pointer;
#line 888 "PhotoTable.c"
}


static gchar* value_photo_row_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (collect_values[0].v_pointer) {
#line 895 "PhotoTable.c"
		PhotoRow * object;
		object = collect_values[0].v_pointer;
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (object->parent_instance.g_class == NULL) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 902 "PhotoTable.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 906 "PhotoTable.c"
		}
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		value->data[0].v_pointer = photo_row_ref (object);
#line 910 "PhotoTable.c"
	} else {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		value->data[0].v_pointer = NULL;
#line 914 "PhotoTable.c"
	}
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return NULL;
#line 918 "PhotoTable.c"
}


static gchar* value_photo_row_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PhotoRow ** object_p;
	object_p = collect_values[0].v_pointer;
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (!object_p) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 929 "PhotoTable.c"
	}
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (!value->data[0].v_pointer) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		*object_p = NULL;
#line 935 "PhotoTable.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		*object_p = value->data[0].v_pointer;
#line 939 "PhotoTable.c"
	} else {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		*object_p = photo_row_ref (value->data[0].v_pointer);
#line 943 "PhotoTable.c"
	}
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return NULL;
#line 947 "PhotoTable.c"
}


GParamSpec* param_spec_photo_row (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecPhotoRow* spec;
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_PHOTO_ROW), NULL);
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return G_PARAM_SPEC (spec);
#line 961 "PhotoTable.c"
}


gpointer value_get_photo_row (const GValue* value) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_PHOTO_ROW), NULL);
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return value->data[0].v_pointer;
#line 970 "PhotoTable.c"
}


void value_set_photo_row (GValue* value, gpointer v_object) {
	PhotoRow * old;
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_PHOTO_ROW));
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	old = value->data[0].v_pointer;
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (v_object) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_PHOTO_ROW));
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		value->data[0].v_pointer = v_object;
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		photo_row_ref (value->data[0].v_pointer);
#line 990 "PhotoTable.c"
	} else {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		value->data[0].v_pointer = NULL;
#line 994 "PhotoTable.c"
	}
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (old) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		photo_row_unref (old);
#line 1000 "PhotoTable.c"
	}
}


void value_take_photo_row (GValue* value, gpointer v_object) {
	PhotoRow * old;
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_PHOTO_ROW));
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	old = value->data[0].v_pointer;
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (v_object) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_PHOTO_ROW));
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		value->data[0].v_pointer = v_object;
#line 1019 "PhotoTable.c"
	} else {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		value->data[0].v_pointer = NULL;
#line 1023 "PhotoTable.c"
	}
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (old) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		photo_row_unref (old);
#line 1029 "PhotoTable.c"
	}
}


static void photo_row_class_init (PhotoRowClass * klass) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	photo_row_parent_class = g_type_class_peek_parent (klass);
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	((PhotoRowClass *) klass)->finalize = photo_row_finalize;
#line 1039 "PhotoTable.c"
}


static void photo_row_instance_init (PhotoRow * self) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->ref_count = 1;
#line 1046 "PhotoTable.c"
}


static void photo_row_finalize (PhotoRow * obj) {
	PhotoRow * self;
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PHOTO_ROW, PhotoRow);
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_signal_handlers_destroy (self);
#line 74 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_backing_photo_row_unref0 (self->master);
#line 79 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_object_unref0 (self->transformations);
#line 80 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (self->md5);
#line 81 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (self->thumbnail_md5);
#line 82 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (self->exif_md5);
#line 86 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (self->title);
#line 87 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (self->comment);
#line 88 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (self->backlinks);
#line 97 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->development_ids = (g_free (self->development_ids), NULL);
#line 1074 "PhotoTable.c"
}


GType photo_row_get_type (void) {
	static volatile gsize photo_row_type_id__volatile = 0;
	if (g_once_init_enter (&photo_row_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_photo_row_init, value_photo_row_free_value, value_photo_row_copy_value, value_photo_row_peek_pointer, "p", value_photo_row_collect_value, "p", value_photo_row_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PhotoRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoRow), 0, (GInstanceInitFunc) photo_row_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType photo_row_type_id;
		photo_row_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PhotoRow", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&photo_row_type_id__volatile, photo_row_type_id);
	}
	return photo_row_type_id__volatile;
}


gpointer photo_row_ref (gpointer instance) {
	PhotoRow * self;
	self = instance;
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_atomic_int_inc (&self->ref_count);
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return instance;
#line 1099 "PhotoTable.c"
}


void photo_row_unref (gpointer instance) {
	PhotoRow * self;
	self = instance;
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		PHOTO_ROW_GET_CLASS (self)->finalize (self);
#line 72 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1112 "PhotoTable.c"
	}
}


static PhotoTable* photo_table_construct (GType object_type) {
	PhotoTable* self = NULL;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	sqlite3_stmt* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	sqlite3_stmt* stmt2 = NULL;
	gint res2 = 0;
	sqlite3* _tmp8_;
	sqlite3_stmt* _tmp9_ = NULL;
	gint _tmp10_;
	gint _tmp11_;
	sqlite3_stmt* _tmp12_;
	gint _tmp13_;
	gint _tmp14_;
	sqlite3* _tmp16_;
	sqlite3_stmt* _tmp17_ = NULL;
	gint _tmp18_;
	gint _tmp19_;
	sqlite3_stmt* _tmp20_;
	gint _tmp21_;
	gint _tmp22_;
	sqlite3* _tmp24_;
	sqlite3_stmt* _tmp25_ = NULL;
	gint _tmp26_;
	gint _tmp27_;
	sqlite3_stmt* _tmp28_;
	gint _tmp29_;
	gint _tmp30_;
	sqlite3* _tmp32_;
	sqlite3_stmt* _tmp33_ = NULL;
	gint _tmp34_;
	gint _tmp35_;
	sqlite3_stmt* _tmp36_;
	gint _tmp37_;
	gint _tmp38_;
	sqlite3* _tmp40_;
	sqlite3_stmt* _tmp41_ = NULL;
	gint _tmp42_;
	gint _tmp43_;
	sqlite3_stmt* _tmp44_;
	gint _tmp45_;
	gint _tmp46_;
#line 112 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self = (PhotoTable*) database_table_construct (object_type);
#line 114 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 114 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "CREATE TABLE IF NOT EXISTS PhotoTable (" "id INTEGER PRIMARY KEY, " "filename TEXT UNIQUE NOT NULL, " "width INTEGER, " "height INTEGER, " "filesize INTEGER, " "timestamp INTEGER, " "exposure_time INTEGER, " "orientation INTEGER, " "original_orientation INTEGER, " "import_id INTEGER, " "event_id INTEGER, " "transformations TEXT, " "md5 TEXT, " "thumbnail_md5 TEXT, " "exif_md5 TEXT, " "time_created INTEGER, " "flags INTEGER DEFAULT 0, " "rating INTEGER DEFAULT 0, " "file_format INTEGER DEFAULT 0, " "title TEXT, " "backlinks TEXT, " "time_reimported INTEGER, " "editable_id INTEGER DEFAULT -1, " "metadata_dirty INTEGER DEFAULT 0, " "developer TEXT, " "develop_shotwell_id INTEGER DEFAULT -1, " "develop_camera_id INTEGER DEFAULT -1, " "develop_embedded_id INTEGER DEFAULT -1, " "comment TEXT" ")", -1, &_tmp1_, NULL);
#line 114 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 114 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 114 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 145 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 145 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 147 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 147 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = sqlite3_step (_tmp4_);
#line 147 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp5_;
#line 148 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = res;
#line 148 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp6_ != SQLITE_DONE) {
#line 1191 "PhotoTable.c"
		gint _tmp7_;
#line 149 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp7_ = res;
#line 149 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_fatal ("create photo table", _tmp7_);
#line 1197 "PhotoTable.c"
	}
#line 153 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = database_table_db;
#line 153 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = sqlite3_prepare_v2 (_tmp8_, "CREATE INDEX IF NOT EXISTS PhotoEventIDIndex ON PhotoTable (event_id)", -1, &_tmp9_, NULL);
#line 153 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt2);
#line 153 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt2 = _tmp9_;
#line 153 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res2 = _tmp10_;
#line 155 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = res2;
#line 155 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp11_ == SQLITE_OK, "res2 == Sqlite.OK");
#line 157 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = stmt2;
#line 157 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp13_ = sqlite3_step (_tmp12_);
#line 157 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res2 = _tmp13_;
#line 158 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = res2;
#line 158 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp14_ != SQLITE_DONE) {
#line 1223 "PhotoTable.c"
		gint _tmp15_;
#line 159 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp15_ = res2;
#line 159 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_fatal ("create photo table", _tmp15_);
#line 1229 "PhotoTable.c"
	}
#line 165 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp16_ = database_table_db;
#line 165 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp18_ = sqlite3_prepare_v2 (_tmp16_, "DROP INDEX IF EXISTS PhotoTableMD5Format", -1, &_tmp17_, NULL);
#line 165 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 165 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp17_;
#line 165 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp18_;
#line 166 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp19_ = res;
#line 166 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp19_ == SQLITE_OK, "res == Sqlite.OK");
#line 167 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp20_ = stmt;
#line 167 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp21_ = sqlite3_step (_tmp20_);
#line 167 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp21_;
#line 168 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp22_ = res;
#line 168 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp22_ != SQLITE_DONE) {
#line 1255 "PhotoTable.c"
		gint _tmp23_;
#line 169 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp23_ = res;
#line 169 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_warning ("Failed to drop old PhotoTable index", _tmp23_);
#line 1261 "PhotoTable.c"
	}
#line 172 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp24_ = database_table_db;
#line 172 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp26_ = sqlite3_prepare_v2 (_tmp24_, "CREATE INDEX IF NOT EXISTS PhotoTableMD5FormatV2 on PhotoTable(md5, fi" \
"le_format)", -1, &_tmp25_, NULL);
#line 172 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 172 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp25_;
#line 172 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp26_;
#line 173 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp27_ = res;
#line 173 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp27_ == SQLITE_OK, "res == Sqlite.OK");
#line 174 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp28_ = stmt;
#line 174 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp29_ = sqlite3_step (_tmp28_);
#line 174 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp29_;
#line 175 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp30_ = res;
#line 175 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp30_ != SQLITE_DONE) {
#line 1287 "PhotoTable.c"
		gint _tmp31_;
#line 176 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp31_ = res;
#line 176 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_warning ("Failed to create index on md5 and file_format", _tmp31_);
#line 1293 "PhotoTable.c"
	}
#line 180 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp32_ = database_table_db;
#line 180 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp34_ = sqlite3_prepare_v2 (_tmp32_, "CREATE INDEX IF NOT EXISTS PhotoTableThumbnailMD5Format on PhotoTable(" \
"thumbnail_md5, file_format)", -1, &_tmp33_, NULL);
#line 180 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 180 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp33_;
#line 180 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp34_;
#line 181 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp35_ = res;
#line 181 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp35_ == SQLITE_OK, "res == Sqlite.OK");
#line 182 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp36_ = stmt;
#line 182 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp37_ = sqlite3_step (_tmp36_);
#line 182 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp37_;
#line 183 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp38_ = res;
#line 183 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp38_ != SQLITE_DONE) {
#line 1319 "PhotoTable.c"
		gint _tmp39_;
#line 184 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp39_ = res;
#line 184 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_warning ("Failed to create index on md5 and file_format", _tmp39_);
#line 1325 "PhotoTable.c"
	}
#line 188 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp40_ = database_table_db;
#line 188 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp42_ = sqlite3_prepare_v2 (_tmp40_, "CREATE INDEX IF NOT EXISTS PhotoTableThumbnailMD5MD5 on PhotoTable(thu" \
"mbnail_md5, md5)", -1, &_tmp41_, NULL);
#line 188 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 188 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp41_;
#line 188 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp42_;
#line 189 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp43_ = res;
#line 189 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp43_ == SQLITE_OK, "res == Sqlite.OK");
#line 190 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp44_ = stmt;
#line 190 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp45_ = sqlite3_step (_tmp44_);
#line 190 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp45_;
#line 191 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp46_ = res;
#line 191 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp46_ != SQLITE_DONE) {
#line 1351 "PhotoTable.c"
		gint _tmp47_;
#line 192 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp47_ = res;
#line 192 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_warning ("Failed to create index on thumbnail_md5 and md5", _tmp47_);
#line 1357 "PhotoTable.c"
	}
#line 195 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_set_table_name (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), "PhotoTable");
#line 112 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt2);
#line 112 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 112 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return self;
#line 1367 "PhotoTable.c"
}


static PhotoTable* photo_table_new (void) {
#line 112 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return photo_table_construct (TYPE_PHOTO_TABLE);
#line 1374 "PhotoTable.c"
}


static gpointer _database_table_ref0 (gpointer self) {
#line 202 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return self ? database_table_ref (self) : NULL;
#line 1381 "PhotoTable.c"
}


PhotoTable* photo_table_get_instance (void) {
	PhotoTable* result = NULL;
	PhotoTable* _tmp0_;
	PhotoTable* _tmp2_;
	PhotoTable* _tmp3_;
#line 199 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = photo_table_instance;
#line 199 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp0_ == NULL) {
#line 1394 "PhotoTable.c"
		PhotoTable* _tmp1_;
#line 200 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp1_ = photo_table_new ();
#line 200 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_database_table_unref0 (photo_table_instance);
#line 200 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		photo_table_instance = _tmp1_;
#line 1402 "PhotoTable.c"
	}
#line 202 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = photo_table_instance;
#line 202 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = _database_table_ref0 (_tmp2_);
#line 202 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp3_;
#line 202 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 1412 "PhotoTable.c"
}


void photo_table_add (PhotoTable* self, PhotoRow* photo_row, PhotoID* result) {
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	gulong time_created = 0UL;
	gulong _tmp4_;
	sqlite3_stmt* _tmp5_;
	PhotoRow* _tmp6_;
	BackingPhotoRow* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	GDestroyNotify _tmp10_;
	gint _tmp11_;
	gint _tmp12_;
	sqlite3_stmt* _tmp13_;
	PhotoRow* _tmp14_;
	BackingPhotoRow* _tmp15_;
	Dimensions _tmp16_;
	gint _tmp17_;
	gint _tmp18_;
	gint _tmp19_;
	sqlite3_stmt* _tmp20_;
	PhotoRow* _tmp21_;
	BackingPhotoRow* _tmp22_;
	Dimensions _tmp23_;
	gint _tmp24_;
	gint _tmp25_;
	gint _tmp26_;
	sqlite3_stmt* _tmp27_;
	PhotoRow* _tmp28_;
	BackingPhotoRow* _tmp29_;
	gint64 _tmp30_;
	gint _tmp31_;
	gint _tmp32_;
	sqlite3_stmt* _tmp33_;
	PhotoRow* _tmp34_;
	BackingPhotoRow* _tmp35_;
	time_t _tmp36_;
	gint _tmp37_;
	gint _tmp38_;
	sqlite3_stmt* _tmp39_;
	PhotoRow* _tmp40_;
	time_t _tmp41_;
	gint _tmp42_;
	gint _tmp43_;
	sqlite3_stmt* _tmp44_;
	PhotoRow* _tmp45_;
	BackingPhotoRow* _tmp46_;
	Orientation _tmp47_;
	gint _tmp48_;
	gint _tmp49_;
	sqlite3_stmt* _tmp50_;
	PhotoRow* _tmp51_;
	BackingPhotoRow* _tmp52_;
	Orientation _tmp53_;
	gint _tmp54_;
	gint _tmp55_;
	sqlite3_stmt* _tmp56_;
	PhotoRow* _tmp57_;
	ImportID _tmp58_;
	gint64 _tmp59_;
	gint _tmp60_;
	gint _tmp61_;
	sqlite3_stmt* _tmp62_;
	gint _tmp63_;
	gint _tmp64_;
	sqlite3_stmt* _tmp65_;
	PhotoRow* _tmp66_;
	const gchar* _tmp67_;
	gchar* _tmp68_;
	GDestroyNotify _tmp69_;
	gint _tmp70_;
	gint _tmp71_;
	sqlite3_stmt* _tmp72_;
	PhotoRow* _tmp73_;
	const gchar* _tmp74_;
	gchar* _tmp75_;
	GDestroyNotify _tmp76_;
	gint _tmp77_;
	gint _tmp78_;
	sqlite3_stmt* _tmp79_;
	PhotoRow* _tmp80_;
	const gchar* _tmp81_;
	gchar* _tmp82_;
	GDestroyNotify _tmp83_;
	gint _tmp84_;
	gint _tmp85_;
	sqlite3_stmt* _tmp86_;
	gulong _tmp87_;
	gint _tmp88_;
	gint _tmp89_;
	sqlite3_stmt* _tmp90_;
	PhotoRow* _tmp91_;
	BackingPhotoRow* _tmp92_;
	PhotoFileFormat _tmp93_;
	gint _tmp94_;
	gint _tmp95_;
	gint _tmp96_;
	sqlite3_stmt* _tmp97_;
	PhotoRow* _tmp98_;
	const gchar* _tmp99_;
	gchar* _tmp100_;
	GDestroyNotify _tmp101_;
	gint _tmp102_;
	gint _tmp103_;
	sqlite3_stmt* _tmp104_;
	PhotoRow* _tmp105_;
	Rating _tmp106_;
	gint _tmp107_;
	gint _tmp108_;
	gint _tmp109_;
	sqlite3_stmt* _tmp110_;
	gint _tmp111_;
	gint _tmp112_;
	sqlite3_stmt* _tmp113_;
	PhotoRow* _tmp114_;
	RawDeveloper _tmp115_;
	gchar* _tmp116_;
	GDestroyNotify _tmp117_;
	gint _tmp118_;
	gint _tmp119_;
	sqlite3_stmt* _tmp120_;
	PhotoRow* _tmp121_;
	const gchar* _tmp122_;
	gchar* _tmp123_;
	GDestroyNotify _tmp124_;
	gint _tmp125_;
	gint _tmp126_;
	sqlite3_stmt* _tmp127_;
	gint _tmp128_;
	gint _tmp129_;
	PhotoRow* _tmp133_;
	sqlite3* _tmp134_;
	gint64 _tmp135_;
	PhotoRow* _tmp136_;
	PhotoRow* _tmp137_;
	BackingPhotoRow* _tmp138_;
	Orientation _tmp139_;
	PhotoRow* _tmp140_;
	PhotoRow* _tmp141_;
	gulong _tmp142_;
	PhotoRow* _tmp143_;
	PhotoRow* _tmp144_;
	PhotoID _tmp145_;
#line 207 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 207 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_ROW (photo_row));
#line 209 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 209 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "INSERT INTO PhotoTable (filename, width, height, filesize, timestamp, " \
"exposure_time, " "orientation, original_orientation, import_id, event_id, md5, thumbnail" \
"_md5, " "exif_md5, time_created, file_format, title, rating, editable_id, devel" \
"oper, comment) " "VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)", -1, &_tmp1_, NULL);
#line 209 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 209 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 209 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 215 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 215 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 217 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = now_sec ();
#line 217 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	time_created = _tmp4_;
#line 219 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = stmt;
#line 219 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = photo_row;
#line 219 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = _tmp6_->master;
#line 219 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = _tmp7_->filepath;
#line 219 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = g_strdup (_tmp8_);
#line 219 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = g_free;
#line 219 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = sqlite3_bind_text (_tmp5_, 1, _tmp9_, -1, _tmp10_);
#line 219 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp11_;
#line 220 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = res;
#line 220 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp12_ == SQLITE_OK, "res == Sqlite.OK");
#line 221 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp13_ = stmt;
#line 221 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = photo_row;
#line 221 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_ = _tmp14_->master;
#line 221 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp16_ = _tmp15_->dim;
#line 221 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp17_ = _tmp16_.width;
#line 221 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp18_ = sqlite3_bind_int (_tmp13_, 2, _tmp17_);
#line 221 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp18_;
#line 222 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp19_ = res;
#line 222 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp19_ == SQLITE_OK, "res == Sqlite.OK");
#line 223 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp20_ = stmt;
#line 223 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp21_ = photo_row;
#line 223 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp22_ = _tmp21_->master;
#line 223 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp23_ = _tmp22_->dim;
#line 223 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp24_ = _tmp23_.height;
#line 223 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp25_ = sqlite3_bind_int (_tmp20_, 3, _tmp24_);
#line 223 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp25_;
#line 224 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp26_ = res;
#line 224 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp26_ == SQLITE_OK, "res == Sqlite.OK");
#line 225 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp27_ = stmt;
#line 225 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp28_ = photo_row;
#line 225 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp29_ = _tmp28_->master;
#line 225 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp30_ = _tmp29_->filesize;
#line 225 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp31_ = sqlite3_bind_int64 (_tmp27_, 4, _tmp30_);
#line 225 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp31_;
#line 226 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp32_ = res;
#line 226 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp32_ == SQLITE_OK, "res == Sqlite.OK");
#line 227 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp33_ = stmt;
#line 227 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp34_ = photo_row;
#line 227 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp35_ = _tmp34_->master;
#line 227 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp36_ = _tmp35_->timestamp;
#line 227 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp37_ = sqlite3_bind_int64 (_tmp33_, 5, (gint64) _tmp36_);
#line 227 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp37_;
#line 228 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp38_ = res;
#line 228 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp38_ == SQLITE_OK, "res == Sqlite.OK");
#line 229 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp39_ = stmt;
#line 229 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp40_ = photo_row;
#line 229 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp41_ = _tmp40_->exposure_time;
#line 229 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp42_ = sqlite3_bind_int64 (_tmp39_, 6, (gint64) _tmp41_);
#line 229 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp42_;
#line 230 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp43_ = res;
#line 230 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp43_ == SQLITE_OK, "res == Sqlite.OK");
#line 231 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp44_ = stmt;
#line 231 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp45_ = photo_row;
#line 231 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp46_ = _tmp45_->master;
#line 231 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp47_ = _tmp46_->original_orientation;
#line 231 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp48_ = sqlite3_bind_int (_tmp44_, 7, (gint) _tmp47_);
#line 231 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp48_;
#line 232 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp49_ = res;
#line 232 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp49_ == SQLITE_OK, "res == Sqlite.OK");
#line 233 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp50_ = stmt;
#line 233 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp51_ = photo_row;
#line 233 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp52_ = _tmp51_->master;
#line 233 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp53_ = _tmp52_->original_orientation;
#line 233 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp54_ = sqlite3_bind_int (_tmp50_, 8, (gint) _tmp53_);
#line 233 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp54_;
#line 234 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp55_ = res;
#line 234 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp55_ == SQLITE_OK, "res == Sqlite.OK");
#line 235 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp56_ = stmt;
#line 235 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp57_ = photo_row;
#line 235 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp58_ = _tmp57_->import_id;
#line 235 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp59_ = _tmp58_.id;
#line 235 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp60_ = sqlite3_bind_int64 (_tmp56_, 9, _tmp59_);
#line 235 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp60_;
#line 236 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp61_ = res;
#line 236 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp61_ == SQLITE_OK, "res == Sqlite.OK");
#line 237 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp62_ = stmt;
#line 237 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp63_ = sqlite3_bind_int64 (_tmp62_, 10, EVENT_ID_INVALID);
#line 237 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp63_;
#line 238 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp64_ = res;
#line 238 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp64_ == SQLITE_OK, "res == Sqlite.OK");
#line 239 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp65_ = stmt;
#line 239 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp66_ = photo_row;
#line 239 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp67_ = _tmp66_->md5;
#line 239 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp68_ = g_strdup (_tmp67_);
#line 239 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp69_ = g_free;
#line 239 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp70_ = sqlite3_bind_text (_tmp65_, 11, _tmp68_, -1, _tmp69_);
#line 239 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp70_;
#line 240 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp71_ = res;
#line 240 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp71_ == SQLITE_OK, "res == Sqlite.OK");
#line 241 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp72_ = stmt;
#line 241 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp73_ = photo_row;
#line 241 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp74_ = _tmp73_->thumbnail_md5;
#line 241 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp75_ = g_strdup (_tmp74_);
#line 241 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp76_ = g_free;
#line 241 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp77_ = sqlite3_bind_text (_tmp72_, 12, _tmp75_, -1, _tmp76_);
#line 241 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp77_;
#line 242 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp78_ = res;
#line 242 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp78_ == SQLITE_OK, "res == Sqlite.OK");
#line 243 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp79_ = stmt;
#line 243 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp80_ = photo_row;
#line 243 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp81_ = _tmp80_->exif_md5;
#line 243 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp82_ = g_strdup (_tmp81_);
#line 243 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp83_ = g_free;
#line 243 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp84_ = sqlite3_bind_text (_tmp79_, 13, _tmp82_, -1, _tmp83_);
#line 243 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp84_;
#line 244 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp85_ = res;
#line 244 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp85_ == SQLITE_OK, "res == Sqlite.OK");
#line 245 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp86_ = stmt;
#line 245 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp87_ = time_created;
#line 245 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp88_ = sqlite3_bind_int64 (_tmp86_, 14, (gint64) _tmp87_);
#line 245 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp88_;
#line 246 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp89_ = res;
#line 246 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp89_ == SQLITE_OK, "res == Sqlite.OK");
#line 247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp90_ = stmt;
#line 247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp91_ = photo_row;
#line 247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp92_ = _tmp91_->master;
#line 247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp93_ = _tmp92_->file_format;
#line 247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp94_ = photo_file_format_serialize (_tmp93_);
#line 247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp95_ = sqlite3_bind_int (_tmp90_, 15, _tmp94_);
#line 247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp95_;
#line 248 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp96_ = res;
#line 248 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp96_ == SQLITE_OK, "res == Sqlite.OK");
#line 249 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp97_ = stmt;
#line 249 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp98_ = photo_row;
#line 249 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp99_ = _tmp98_->title;
#line 249 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp100_ = g_strdup (_tmp99_);
#line 249 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp101_ = g_free;
#line 249 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp102_ = sqlite3_bind_text (_tmp97_, 16, _tmp100_, -1, _tmp101_);
#line 249 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp102_;
#line 250 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp103_ = res;
#line 250 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp103_ == SQLITE_OK, "res == Sqlite.OK");
#line 251 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp104_ = stmt;
#line 251 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp105_ = photo_row;
#line 251 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp106_ = _tmp105_->rating;
#line 251 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp107_ = rating_serialize (_tmp106_);
#line 251 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp108_ = sqlite3_bind_int64 (_tmp104_, 17, (gint64) _tmp107_);
#line 251 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp108_;
#line 252 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp109_ = res;
#line 252 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp109_ == SQLITE_OK, "res == Sqlite.OK");
#line 253 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp110_ = stmt;
#line 253 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp111_ = sqlite3_bind_int64 (_tmp110_, 18, BACKING_PHOTO_ID_INVALID);
#line 253 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp111_;
#line 254 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp112_ = res;
#line 254 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp112_ == SQLITE_OK, "res == Sqlite.OK");
#line 255 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp113_ = stmt;
#line 255 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp114_ = photo_row;
#line 255 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp115_ = _tmp114_->developer;
#line 255 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp116_ = raw_developer_to_string (_tmp115_);
#line 255 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp117_ = g_free;
#line 255 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp118_ = sqlite3_bind_text (_tmp113_, 19, _tmp116_, -1, _tmp117_);
#line 255 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp118_;
#line 256 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp119_ = res;
#line 256 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp119_ == SQLITE_OK, "res == Sqlite.OK");
#line 257 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp120_ = stmt;
#line 257 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp121_ = photo_row;
#line 257 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp122_ = _tmp121_->comment;
#line 257 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp123_ = g_strdup (_tmp122_);
#line 257 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp124_ = g_free;
#line 257 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp125_ = sqlite3_bind_text (_tmp120_, 20, _tmp123_, -1, _tmp124_);
#line 257 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp125_;
#line 258 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp126_ = res;
#line 258 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp126_ == SQLITE_OK, "res == Sqlite.OK");
#line 260 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp127_ = stmt;
#line 260 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp128_ = sqlite3_step (_tmp127_);
#line 260 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp128_;
#line 261 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp129_ = res;
#line 261 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp129_ != SQLITE_DONE) {
#line 1919 "PhotoTable.c"
		gint _tmp130_;
		PhotoID _tmp132_ = {0};
#line 262 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp130_ = res;
#line 262 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_tmp130_ != SQLITE_CONSTRAINT) {
#line 1926 "PhotoTable.c"
			gint _tmp131_;
#line 263 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp131_ = res;
#line 263 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			database_table_fatal ("add_photo", _tmp131_);
#line 1932 "PhotoTable.c"
		}
#line 265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		photo_id_init (&_tmp132_, PHOTO_ID_INVALID);
#line 265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		*result = _tmp132_;
#line 265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_sqlite3_finalize0 (stmt);
#line 265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return;
#line 1942 "PhotoTable.c"
	}
#line 269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp133_ = photo_row;
#line 269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp134_ = database_table_db;
#line 269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp135_ = sqlite3_last_insert_rowid (_tmp134_);
#line 269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	photo_id_init (&_tmp133_->photo_id, _tmp135_);
#line 270 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp136_ = photo_row;
#line 270 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp137_ = photo_row;
#line 270 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp138_ = _tmp137_->master;
#line 270 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp139_ = _tmp138_->original_orientation;
#line 270 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp136_->orientation = _tmp139_;
#line 271 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp140_ = photo_row;
#line 271 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	event_id_init (&_tmp140_->event_id, EVENT_ID_INVALID);
#line 272 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp141_ = photo_row;
#line 272 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp142_ = time_created;
#line 272 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp141_->time_created = (time_t) _tmp142_;
#line 273 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp143_ = photo_row;
#line 273 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp143_->flags = (guint64) 0;
#line 275 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp144_ = photo_row;
#line 275 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp145_ = _tmp144_->photo_id;
#line 275 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	*result = _tmp145_;
#line 275 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 275 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return;
#line 1986 "PhotoTable.c"
}


void photo_table_reimport (PhotoTable* self, PhotoRow* row, GError** error) {
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	time_t time_reimported = 0;
	gulong _tmp4_;
	sqlite3_stmt* _tmp5_;
	PhotoRow* _tmp6_;
	BackingPhotoRow* _tmp7_;
	Dimensions _tmp8_;
	gint _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	sqlite3_stmt* _tmp12_;
	PhotoRow* _tmp13_;
	BackingPhotoRow* _tmp14_;
	Dimensions _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	gint _tmp18_;
	sqlite3_stmt* _tmp19_;
	PhotoRow* _tmp20_;
	BackingPhotoRow* _tmp21_;
	gint64 _tmp22_;
	gint _tmp23_;
	gint _tmp24_;
	sqlite3_stmt* _tmp25_;
	PhotoRow* _tmp26_;
	BackingPhotoRow* _tmp27_;
	time_t _tmp28_;
	gint _tmp29_;
	gint _tmp30_;
	sqlite3_stmt* _tmp31_;
	PhotoRow* _tmp32_;
	time_t _tmp33_;
	gint _tmp34_;
	gint _tmp35_;
	sqlite3_stmt* _tmp36_;
	PhotoRow* _tmp37_;
	BackingPhotoRow* _tmp38_;
	Orientation _tmp39_;
	gint _tmp40_;
	gint _tmp41_;
	sqlite3_stmt* _tmp42_;
	PhotoRow* _tmp43_;
	BackingPhotoRow* _tmp44_;
	Orientation _tmp45_;
	gint _tmp46_;
	gint _tmp47_;
	sqlite3_stmt* _tmp48_;
	PhotoRow* _tmp49_;
	const gchar* _tmp50_;
	gchar* _tmp51_;
	GDestroyNotify _tmp52_;
	gint _tmp53_;
	gint _tmp54_;
	sqlite3_stmt* _tmp55_;
	PhotoRow* _tmp56_;
	const gchar* _tmp57_;
	gchar* _tmp58_;
	GDestroyNotify _tmp59_;
	gint _tmp60_;
	gint _tmp61_;
	sqlite3_stmt* _tmp62_;
	PhotoRow* _tmp63_;
	const gchar* _tmp64_;
	gchar* _tmp65_;
	GDestroyNotify _tmp66_;
	gint _tmp67_;
	gint _tmp68_;
	sqlite3_stmt* _tmp69_;
	PhotoRow* _tmp70_;
	BackingPhotoRow* _tmp71_;
	PhotoFileFormat _tmp72_;
	gint _tmp73_;
	gint _tmp74_;
	gint _tmp75_;
	sqlite3_stmt* _tmp76_;
	PhotoRow* _tmp77_;
	const gchar* _tmp78_;
	gchar* _tmp79_;
	GDestroyNotify _tmp80_;
	gint _tmp81_;
	gint _tmp82_;
	sqlite3_stmt* _tmp83_;
	time_t _tmp84_;
	gint _tmp85_;
	gint _tmp86_;
	sqlite3_stmt* _tmp87_;
	PhotoRow* _tmp88_;
	PhotoID _tmp89_;
	gint64 _tmp90_;
	gint _tmp91_;
	gint _tmp92_;
	sqlite3_stmt* _tmp93_;
	gint _tmp94_;
	gint _tmp95_;
	PhotoRow* _tmp97_;
	time_t _tmp98_;
	PhotoRow* _tmp99_;
	PhotoRow* _tmp100_;
	BackingPhotoRow* _tmp101_;
	Orientation _tmp102_;
	GError * _inner_error_ = NULL;
#line 283 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 283 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_ROW (row));
#line 285 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 285 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "UPDATE PhotoTable SET width = ?, height = ?, filesize = ?, timestamp =" \
" ?, " "exposure_time = ?, orientation = ?, original_orientation = ?, md5 = ?," \
" " "exif_md5 = ?, thumbnail_md5 = ?, file_format = ?, title = ?, time_reim" \
"ported = ? " "WHERE id = ?", -1, &_tmp1_, NULL);
#line 285 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 285 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 285 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 290 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 290 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 292 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = now_sec ();
#line 292 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	time_reimported = (time_t) _tmp4_;
#line 294 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = stmt;
#line 294 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = row;
#line 294 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = _tmp6_->master;
#line 294 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = _tmp7_->dim;
#line 294 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = _tmp8_.width;
#line 294 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = sqlite3_bind_int (_tmp5_, 1, _tmp9_);
#line 294 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp10_;
#line 295 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = res;
#line 295 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp11_ == SQLITE_OK, "res == Sqlite.OK");
#line 296 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = stmt;
#line 296 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp13_ = row;
#line 296 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = _tmp13_->master;
#line 296 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_ = _tmp14_->dim;
#line 296 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp16_ = _tmp15_.height;
#line 296 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp17_ = sqlite3_bind_int (_tmp12_, 2, _tmp16_);
#line 296 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp17_;
#line 297 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp18_ = res;
#line 297 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp18_ == SQLITE_OK, "res == Sqlite.OK");
#line 298 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp19_ = stmt;
#line 298 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp20_ = row;
#line 298 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp21_ = _tmp20_->master;
#line 298 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp22_ = _tmp21_->filesize;
#line 298 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp23_ = sqlite3_bind_int64 (_tmp19_, 3, _tmp22_);
#line 298 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp23_;
#line 299 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp24_ = res;
#line 299 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp24_ == SQLITE_OK, "res == Sqlite.OK");
#line 300 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp25_ = stmt;
#line 300 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp26_ = row;
#line 300 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp27_ = _tmp26_->master;
#line 300 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp28_ = _tmp27_->timestamp;
#line 300 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp29_ = sqlite3_bind_int64 (_tmp25_, 4, (gint64) _tmp28_);
#line 300 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp29_;
#line 301 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp30_ = res;
#line 301 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp30_ == SQLITE_OK, "res == Sqlite.OK");
#line 302 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp31_ = stmt;
#line 302 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp32_ = row;
#line 302 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp33_ = _tmp32_->exposure_time;
#line 302 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp34_ = sqlite3_bind_int64 (_tmp31_, 5, (gint64) _tmp33_);
#line 302 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp34_;
#line 303 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp35_ = res;
#line 303 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp35_ == SQLITE_OK, "res == Sqlite.OK");
#line 304 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp36_ = stmt;
#line 304 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp37_ = row;
#line 304 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp38_ = _tmp37_->master;
#line 304 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp39_ = _tmp38_->original_orientation;
#line 304 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp40_ = sqlite3_bind_int (_tmp36_, 6, (gint) _tmp39_);
#line 304 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp40_;
#line 305 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp41_ = res;
#line 305 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp41_ == SQLITE_OK, "res == Sqlite.OK");
#line 306 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp42_ = stmt;
#line 306 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp43_ = row;
#line 306 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp44_ = _tmp43_->master;
#line 306 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp45_ = _tmp44_->original_orientation;
#line 306 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp46_ = sqlite3_bind_int (_tmp42_, 7, (gint) _tmp45_);
#line 306 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp46_;
#line 307 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp47_ = res;
#line 307 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp47_ == SQLITE_OK, "res == Sqlite.OK");
#line 308 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp48_ = stmt;
#line 308 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp49_ = row;
#line 308 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp50_ = _tmp49_->md5;
#line 308 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp51_ = g_strdup (_tmp50_);
#line 308 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp52_ = g_free;
#line 308 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp53_ = sqlite3_bind_text (_tmp48_, 8, _tmp51_, -1, _tmp52_);
#line 308 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp53_;
#line 309 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp54_ = res;
#line 309 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp54_ == SQLITE_OK, "res == Sqlite.OK");
#line 310 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp55_ = stmt;
#line 310 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp56_ = row;
#line 310 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp57_ = _tmp56_->exif_md5;
#line 310 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp58_ = g_strdup (_tmp57_);
#line 310 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp59_ = g_free;
#line 310 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp60_ = sqlite3_bind_text (_tmp55_, 9, _tmp58_, -1, _tmp59_);
#line 310 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp60_;
#line 311 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp61_ = res;
#line 311 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp61_ == SQLITE_OK, "res == Sqlite.OK");
#line 312 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp62_ = stmt;
#line 312 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp63_ = row;
#line 312 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp64_ = _tmp63_->thumbnail_md5;
#line 312 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp65_ = g_strdup (_tmp64_);
#line 312 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp66_ = g_free;
#line 312 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp67_ = sqlite3_bind_text (_tmp62_, 10, _tmp65_, -1, _tmp66_);
#line 312 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp67_;
#line 313 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp68_ = res;
#line 313 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp68_ == SQLITE_OK, "res == Sqlite.OK");
#line 314 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp69_ = stmt;
#line 314 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp70_ = row;
#line 314 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp71_ = _tmp70_->master;
#line 314 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp72_ = _tmp71_->file_format;
#line 314 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp73_ = photo_file_format_serialize (_tmp72_);
#line 314 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp74_ = sqlite3_bind_int (_tmp69_, 11, _tmp73_);
#line 314 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp74_;
#line 315 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp75_ = res;
#line 315 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp75_ == SQLITE_OK, "res == Sqlite.OK");
#line 316 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp76_ = stmt;
#line 316 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp77_ = row;
#line 316 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp78_ = _tmp77_->title;
#line 316 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp79_ = g_strdup (_tmp78_);
#line 316 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp80_ = g_free;
#line 316 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp81_ = sqlite3_bind_text (_tmp76_, 12, _tmp79_, -1, _tmp80_);
#line 316 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp81_;
#line 317 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp82_ = res;
#line 317 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp82_ == SQLITE_OK, "res == Sqlite.OK");
#line 318 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp83_ = stmt;
#line 318 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp84_ = time_reimported;
#line 318 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp85_ = sqlite3_bind_int64 (_tmp83_, 13, (gint64) _tmp84_);
#line 318 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp85_;
#line 319 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp86_ = res;
#line 319 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp86_ == SQLITE_OK, "res == Sqlite.OK");
#line 320 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp87_ = stmt;
#line 320 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp88_ = row;
#line 320 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp89_ = _tmp88_->photo_id;
#line 320 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp90_ = _tmp89_.id;
#line 320 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp91_ = sqlite3_bind_int64 (_tmp87_, 14, _tmp90_);
#line 320 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp91_;
#line 321 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp92_ = res;
#line 321 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp92_ == SQLITE_OK, "res == Sqlite.OK");
#line 323 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp93_ = stmt;
#line 323 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp94_ = sqlite3_step (_tmp93_);
#line 323 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp94_;
#line 324 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp95_ = res;
#line 324 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp95_ != SQLITE_DONE) {
#line 2361 "PhotoTable.c"
		gint _tmp96_;
#line 325 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp96_ = res;
#line 325 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_throw_error ("PhotoTable.reimport_master", _tmp96_, &_inner_error_);
#line 325 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 325 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 325 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_propagate_error (error, _inner_error_);
#line 325 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_sqlite3_finalize0 (stmt);
#line 325 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				return;
#line 2377 "PhotoTable.c"
			} else {
#line 325 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_sqlite3_finalize0 (stmt);
#line 325 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 325 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_clear_error (&_inner_error_);
#line 325 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				return;
#line 2387 "PhotoTable.c"
			}
		}
	}
#line 327 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp97_ = row;
#line 327 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp98_ = time_reimported;
#line 327 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp97_->time_reimported = _tmp98_;
#line 328 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp99_ = row;
#line 328 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp100_ = row;
#line 328 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp101_ = _tmp100_->master;
#line 328 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp102_ = _tmp101_->original_orientation;
#line 328 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp99_->orientation = _tmp102_;
#line 283 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 2409 "PhotoTable.c"
}


gboolean photo_table_master_exif_updated (PhotoTable* self, PhotoID* photoID, gint64 filesize, glong timestamp, const gchar* md5, const gchar* exif_md5, const gchar* thumbnail_md5, PhotoRow* row) {
	gboolean result = FALSE;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	sqlite3_stmt* _tmp4_;
	gint64 _tmp5_;
	gint _tmp6_;
	gint _tmp7_;
	sqlite3_stmt* _tmp8_;
	glong _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	sqlite3_stmt* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_;
	GDestroyNotify _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	sqlite3_stmt* _tmp18_;
	const gchar* _tmp19_;
	gchar* _tmp20_;
	GDestroyNotify _tmp21_;
	gint _tmp22_;
	gint _tmp23_;
	sqlite3_stmt* _tmp24_;
	const gchar* _tmp25_;
	gchar* _tmp26_;
	GDestroyNotify _tmp27_;
	gint _tmp28_;
	gint _tmp29_;
	sqlite3_stmt* _tmp30_;
	PhotoID _tmp31_;
	gint64 _tmp32_;
	gint _tmp33_;
	gint _tmp34_;
	sqlite3_stmt* _tmp35_;
	gint _tmp36_;
	gint _tmp37_;
	PhotoRow* _tmp40_;
	BackingPhotoRow* _tmp41_;
	gint64 _tmp42_;
	PhotoRow* _tmp43_;
	BackingPhotoRow* _tmp44_;
	glong _tmp45_;
	PhotoRow* _tmp46_;
	const gchar* _tmp47_;
	gchar* _tmp48_;
	PhotoRow* _tmp49_;
	const gchar* _tmp50_;
	gchar* _tmp51_;
	PhotoRow* _tmp52_;
	const gchar* _tmp53_;
	gchar* _tmp54_;
#line 331 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 331 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photoID != NULL, FALSE);
#line 331 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (md5 != NULL, FALSE);
#line 331 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_ROW (row), FALSE);
#line 334 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 334 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "UPDATE PhotoTable SET filesize = ?, timestamp = ?, md5 = ?, exif_md5 =" \
" ?," "thumbnail_md5 =? WHERE id = ?", -1, &_tmp1_, NULL);
#line 334 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 334 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 334 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 337 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 337 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 339 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 339 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = filesize;
#line 339 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = sqlite3_bind_int64 (_tmp4_, 1, _tmp5_);
#line 339 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp6_;
#line 340 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = res;
#line 340 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp7_ == SQLITE_OK, "res == Sqlite.OK");
#line 341 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = stmt;
#line 341 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = timestamp;
#line 341 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = sqlite3_bind_int64 (_tmp8_, 2, (gint64) _tmp9_);
#line 341 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp10_;
#line 342 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = res;
#line 342 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp11_ == SQLITE_OK, "res == Sqlite.OK");
#line 343 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = stmt;
#line 343 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp13_ = md5;
#line 343 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = g_strdup (_tmp13_);
#line 343 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_ = g_free;
#line 343 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp16_ = sqlite3_bind_text (_tmp12_, 3, _tmp14_, -1, _tmp15_);
#line 343 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp16_;
#line 344 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp17_ = res;
#line 344 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp17_ == SQLITE_OK, "res == Sqlite.OK");
#line 345 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp18_ = stmt;
#line 345 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp19_ = exif_md5;
#line 345 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp20_ = g_strdup (_tmp19_);
#line 345 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp21_ = g_free;
#line 345 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp22_ = sqlite3_bind_text (_tmp18_, 4, _tmp20_, -1, _tmp21_);
#line 345 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp22_;
#line 346 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp23_ = res;
#line 346 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp23_ == SQLITE_OK, "res == Sqlite.OK");
#line 347 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp24_ = stmt;
#line 347 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp25_ = thumbnail_md5;
#line 347 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp26_ = g_strdup (_tmp25_);
#line 347 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp27_ = g_free;
#line 347 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp28_ = sqlite3_bind_text (_tmp24_, 5, _tmp26_, -1, _tmp27_);
#line 347 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp28_;
#line 348 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp29_ = res;
#line 348 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp29_ == SQLITE_OK, "res == Sqlite.OK");
#line 349 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp30_ = stmt;
#line 349 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp31_ = *photoID;
#line 349 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp32_ = _tmp31_.id;
#line 349 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp33_ = sqlite3_bind_int64 (_tmp30_, 6, _tmp32_);
#line 349 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp33_;
#line 350 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp34_ = res;
#line 350 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp34_ == SQLITE_OK, "res == Sqlite.OK");
#line 352 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp35_ = stmt;
#line 352 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp36_ = sqlite3_step (_tmp35_);
#line 352 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp36_;
#line 353 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp37_ = res;
#line 353 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp37_ != SQLITE_DONE) {
#line 2588 "PhotoTable.c"
		gint _tmp38_;
#line 354 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp38_ = res;
#line 354 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_tmp38_ != SQLITE_CONSTRAINT) {
#line 2594 "PhotoTable.c"
			gint _tmp39_;
#line 355 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp39_ = res;
#line 355 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			database_table_fatal ("write_update_photo", _tmp39_);
#line 2600 "PhotoTable.c"
		}
#line 357 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = FALSE;
#line 357 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_sqlite3_finalize0 (stmt);
#line 357 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 2608 "PhotoTable.c"
	}
#line 360 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp40_ = row;
#line 360 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp41_ = _tmp40_->master;
#line 360 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp42_ = filesize;
#line 360 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp41_->filesize = _tmp42_;
#line 361 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp43_ = row;
#line 361 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp44_ = _tmp43_->master;
#line 361 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp45_ = timestamp;
#line 361 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp44_->timestamp = (time_t) _tmp45_;
#line 362 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp46_ = row;
#line 362 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp47_ = md5;
#line 362 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp48_ = g_strdup (_tmp47_);
#line 362 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (_tmp46_->md5);
#line 362 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp46_->md5 = _tmp48_;
#line 363 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp49_ = row;
#line 363 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp50_ = exif_md5;
#line 363 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp51_ = g_strdup (_tmp50_);
#line 363 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (_tmp49_->exif_md5);
#line 363 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp49_->exif_md5 = _tmp51_;
#line 364 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp52_ = row;
#line 364 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp53_ = thumbnail_md5;
#line 364 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp54_ = g_strdup (_tmp53_);
#line 364 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (_tmp52_->thumbnail_md5);
#line 364 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp52_->thumbnail_md5 = _tmp54_;
#line 366 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = TRUE;
#line 366 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 366 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 2662 "PhotoTable.c"
}


static void photo_table_validate_orientation (PhotoTable* self, PhotoRow* row) {
	gboolean _tmp0_ = FALSE;
	PhotoRow* _tmp1_;
	Orientation _tmp2_;
#line 377 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 377 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_ROW (row));
#line 378 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = row;
#line 378 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = _tmp1_->orientation;
#line 378 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp2_ < ORIENTATION_MIN) {
#line 378 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = TRUE;
#line 2682 "PhotoTable.c"
	} else {
		PhotoRow* _tmp3_;
		Orientation _tmp4_;
#line 379 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp3_ = row;
#line 379 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp4_ = _tmp3_->orientation;
#line 379 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = _tmp4_ > ORIENTATION_MAX;
#line 2692 "PhotoTable.c"
	}
#line 378 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp0_) {
#line 2696 "PhotoTable.c"
		PhotoRow* _tmp5_;
		PhotoID _tmp6_;
		PhotoRow* _tmp7_;
#line 381 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp5_ = row;
#line 381 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp6_ = _tmp5_->photo_id;
#line 381 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		photo_table_set_orientation (self, &_tmp6_, ORIENTATION_MIN);
#line 382 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp7_ = row;
#line 382 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp7_->orientation = ORIENTATION_MIN;
#line 2710 "PhotoTable.c"
	}
}


PhotoRow* photo_table_get_row (PhotoTable* self, PhotoID* photo_id) {
	PhotoRow* result = NULL;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	sqlite3_stmt* _tmp4_;
	PhotoID _tmp5_;
	gint64 _tmp6_;
	gint _tmp7_;
	gint _tmp8_;
	sqlite3_stmt* _tmp9_;
	gint _tmp10_;
	PhotoRow* row = NULL;
	PhotoRow* _tmp11_;
	PhotoRow* _tmp12_;
	PhotoID _tmp13_;
	PhotoRow* _tmp14_;
	BackingPhotoRow* _tmp15_;
	sqlite3_stmt* _tmp16_;
	const gchar* _tmp17_;
	gchar* _tmp18_;
	PhotoRow* _tmp19_;
	BackingPhotoRow* _tmp20_;
	sqlite3_stmt* _tmp21_;
	gint _tmp22_;
	sqlite3_stmt* _tmp23_;
	gint _tmp24_;
	PhotoRow* _tmp25_;
	BackingPhotoRow* _tmp26_;
	sqlite3_stmt* _tmp27_;
	gint64 _tmp28_;
	PhotoRow* _tmp29_;
	BackingPhotoRow* _tmp30_;
	sqlite3_stmt* _tmp31_;
	gint64 _tmp32_;
	PhotoRow* _tmp33_;
	sqlite3_stmt* _tmp34_;
	gint64 _tmp35_;
	PhotoRow* _tmp36_;
	sqlite3_stmt* _tmp37_;
	gint _tmp38_;
	PhotoRow* _tmp39_;
	BackingPhotoRow* _tmp40_;
	sqlite3_stmt* _tmp41_;
	gint _tmp42_;
	PhotoRow* _tmp43_;
	sqlite3_stmt* _tmp44_;
	gint64 _tmp45_;
	PhotoRow* _tmp46_;
	sqlite3_stmt* _tmp47_;
	gint64 _tmp48_;
	PhotoRow* _tmp49_;
	sqlite3_stmt* _tmp50_;
	const gchar* _tmp51_;
	GeeHashMap* _tmp52_;
	PhotoRow* _tmp53_;
	sqlite3_stmt* _tmp54_;
	const gchar* _tmp55_;
	gchar* _tmp56_;
	PhotoRow* _tmp57_;
	sqlite3_stmt* _tmp58_;
	const gchar* _tmp59_;
	gchar* _tmp60_;
	PhotoRow* _tmp61_;
	sqlite3_stmt* _tmp62_;
	const gchar* _tmp63_;
	gchar* _tmp64_;
	PhotoRow* _tmp65_;
	sqlite3_stmt* _tmp66_;
	gint64 _tmp67_;
	PhotoRow* _tmp68_;
	sqlite3_stmt* _tmp69_;
	gint64 _tmp70_;
	PhotoRow* _tmp71_;
	sqlite3_stmt* _tmp72_;
	gint _tmp73_;
	Rating _tmp74_;
	PhotoRow* _tmp75_;
	BackingPhotoRow* _tmp76_;
	sqlite3_stmt* _tmp77_;
	gint _tmp78_;
	PhotoFileFormat _tmp79_;
	PhotoRow* _tmp80_;
	sqlite3_stmt* _tmp81_;
	const gchar* _tmp82_;
	gchar* _tmp83_;
	PhotoRow* _tmp84_;
	sqlite3_stmt* _tmp85_;
	const gchar* _tmp86_;
	gchar* _tmp87_;
	PhotoRow* _tmp88_;
	sqlite3_stmt* _tmp89_;
	gint64 _tmp90_;
	PhotoRow* _tmp91_;
	sqlite3_stmt* _tmp92_;
	gint64 _tmp93_;
	PhotoRow* _tmp94_;
	sqlite3_stmt* _tmp95_;
	gint _tmp96_;
	RawDeveloper _tmp97_ = 0;
	sqlite3_stmt* _tmp98_;
	const gchar* _tmp99_;
	PhotoRow* _tmp103_;
	PhotoRow* _tmp104_;
	BackingPhotoID* _tmp105_;
	gint _tmp105__length1;
	sqlite3_stmt* _tmp106_;
	gint64 _tmp107_;
	BackingPhotoID _tmp108_ = {0};
	BackingPhotoID _tmp109_;
	PhotoRow* _tmp110_;
	BackingPhotoID* _tmp111_;
	gint _tmp111__length1;
	sqlite3_stmt* _tmp112_;
	gint64 _tmp113_;
	BackingPhotoID _tmp114_ = {0};
	BackingPhotoID _tmp115_;
	PhotoRow* _tmp116_;
	BackingPhotoID* _tmp117_;
	gint _tmp117__length1;
	sqlite3_stmt* _tmp118_;
	gint64 _tmp119_;
	BackingPhotoID _tmp120_ = {0};
	BackingPhotoID _tmp121_;
	PhotoRow* _tmp122_;
	sqlite3_stmt* _tmp123_;
	const gchar* _tmp124_;
	gchar* _tmp125_;
#line 386 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), NULL);
#line 386 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, NULL);
#line 388 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 388 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "SELECT filename, width, height, filesize, timestamp, exposure_time, or" \
"ientation, " "original_orientation, import_id, event_id, transformations, md5, thumb" \
"nail_md5, " "exif_md5, time_created, flags, rating, file_format, title, backlinks, " "time_reimported, editable_id, metadata_dirty, developer, develop_shotw" \
"ell_id, " "develop_camera_id, develop_embedded_id, comment " "FROM PhotoTable WHERE id=?", -1, &_tmp1_, NULL);
#line 388 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 388 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 388 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 396 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 396 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 398 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 398 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = *photo_id;
#line 398 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = _tmp5_.id;
#line 398 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = sqlite3_bind_int64 (_tmp4_, 1, _tmp6_);
#line 398 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp7_;
#line 399 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = res;
#line 399 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp8_ == SQLITE_OK, "res == Sqlite.OK");
#line 401 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = stmt;
#line 401 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = sqlite3_step (_tmp9_);
#line 401 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp10_ != SQLITE_ROW) {
#line 402 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = NULL;
#line 402 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_sqlite3_finalize0 (stmt);
#line 402 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 2890 "PhotoTable.c"
	}
#line 404 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = photo_row_new ();
#line 404 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	row = _tmp11_;
#line 405 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = row;
#line 405 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp13_ = *photo_id;
#line 405 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_->photo_id = _tmp13_;
#line 406 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = row;
#line 406 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_ = _tmp14_->master;
#line 406 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp16_ = stmt;
#line 406 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp17_ = sqlite3_column_text (_tmp16_, 0);
#line 406 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp18_ = g_strdup (_tmp17_);
#line 406 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (_tmp15_->filepath);
#line 406 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_->filepath = _tmp18_;
#line 407 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp19_ = row;
#line 407 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp20_ = _tmp19_->master;
#line 407 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp21_ = stmt;
#line 407 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp22_ = sqlite3_column_int (_tmp21_, 1);
#line 407 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp23_ = stmt;
#line 407 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp24_ = sqlite3_column_int (_tmp23_, 2);
#line 407 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	dimensions_init (&_tmp20_->dim, _tmp22_, _tmp24_);
#line 408 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp25_ = row;
#line 408 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp26_ = _tmp25_->master;
#line 408 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp27_ = stmt;
#line 408 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp28_ = sqlite3_column_int64 (_tmp27_, 3);
#line 408 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp26_->filesize = _tmp28_;
#line 409 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp29_ = row;
#line 409 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp30_ = _tmp29_->master;
#line 409 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp31_ = stmt;
#line 409 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp32_ = sqlite3_column_int64 (_tmp31_, 4);
#line 409 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp30_->timestamp = (time_t) _tmp32_;
#line 410 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp33_ = row;
#line 410 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp34_ = stmt;
#line 410 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp35_ = sqlite3_column_int64 (_tmp34_, 5);
#line 410 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp33_->exposure_time = (time_t) _tmp35_;
#line 411 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp36_ = row;
#line 411 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp37_ = stmt;
#line 411 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp38_ = sqlite3_column_int (_tmp37_, 6);
#line 411 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp36_->orientation = (Orientation) _tmp38_;
#line 412 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp39_ = row;
#line 412 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp40_ = _tmp39_->master;
#line 412 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp41_ = stmt;
#line 412 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp42_ = sqlite3_column_int (_tmp41_, 7);
#line 412 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp40_->original_orientation = (Orientation) _tmp42_;
#line 413 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp43_ = row;
#line 413 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp44_ = stmt;
#line 413 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp45_ = sqlite3_column_int64 (_tmp44_, 8);
#line 413 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp43_->import_id.id = _tmp45_;
#line 414 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp46_ = row;
#line 414 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp47_ = stmt;
#line 414 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp48_ = sqlite3_column_int64 (_tmp47_, 9);
#line 414 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp46_->event_id.id = _tmp48_;
#line 415 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp49_ = row;
#line 415 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp50_ = stmt;
#line 415 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp51_ = sqlite3_column_text (_tmp50_, 10);
#line 415 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp52_ = photo_table_marshall_all_transformations (_tmp51_);
#line 415 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_object_unref0 (_tmp49_->transformations);
#line 415 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp49_->transformations = _tmp52_;
#line 416 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp53_ = row;
#line 416 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp54_ = stmt;
#line 416 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp55_ = sqlite3_column_text (_tmp54_, 11);
#line 416 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp56_ = g_strdup (_tmp55_);
#line 416 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (_tmp53_->md5);
#line 416 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp53_->md5 = _tmp56_;
#line 417 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp57_ = row;
#line 417 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp58_ = stmt;
#line 417 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp59_ = sqlite3_column_text (_tmp58_, 12);
#line 417 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp60_ = g_strdup (_tmp59_);
#line 417 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (_tmp57_->thumbnail_md5);
#line 417 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp57_->thumbnail_md5 = _tmp60_;
#line 418 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp61_ = row;
#line 418 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp62_ = stmt;
#line 418 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp63_ = sqlite3_column_text (_tmp62_, 13);
#line 418 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp64_ = g_strdup (_tmp63_);
#line 418 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (_tmp61_->exif_md5);
#line 418 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp61_->exif_md5 = _tmp64_;
#line 419 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp65_ = row;
#line 419 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp66_ = stmt;
#line 419 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp67_ = sqlite3_column_int64 (_tmp66_, 14);
#line 419 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp65_->time_created = (time_t) _tmp67_;
#line 420 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp68_ = row;
#line 420 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp69_ = stmt;
#line 420 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp70_ = sqlite3_column_int64 (_tmp69_, 15);
#line 420 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp68_->flags = (guint64) _tmp70_;
#line 421 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp71_ = row;
#line 421 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp72_ = stmt;
#line 421 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp73_ = sqlite3_column_int (_tmp72_, 16);
#line 421 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp74_ = rating_unserialize (_tmp73_);
#line 421 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp71_->rating = _tmp74_;
#line 422 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp75_ = row;
#line 422 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp76_ = _tmp75_->master;
#line 422 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp77_ = stmt;
#line 422 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp78_ = sqlite3_column_int (_tmp77_, 17);
#line 422 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp79_ = photo_file_format_unserialize (_tmp78_);
#line 422 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp76_->file_format = _tmp79_;
#line 423 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp80_ = row;
#line 423 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp81_ = stmt;
#line 423 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp82_ = sqlite3_column_text (_tmp81_, 18);
#line 423 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp83_ = g_strdup (_tmp82_);
#line 423 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (_tmp80_->title);
#line 423 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp80_->title = _tmp83_;
#line 424 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp84_ = row;
#line 424 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp85_ = stmt;
#line 424 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp86_ = sqlite3_column_text (_tmp85_, 19);
#line 424 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp87_ = g_strdup (_tmp86_);
#line 424 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (_tmp84_->backlinks);
#line 424 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp84_->backlinks = _tmp87_;
#line 425 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp88_ = row;
#line 425 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp89_ = stmt;
#line 425 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp90_ = sqlite3_column_int64 (_tmp89_, 20);
#line 425 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp88_->time_reimported = (time_t) _tmp90_;
#line 426 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp91_ = row;
#line 426 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp92_ = stmt;
#line 426 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp93_ = sqlite3_column_int64 (_tmp92_, 21);
#line 426 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	backing_photo_id_init (&_tmp91_->editable_id, _tmp93_);
#line 427 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp94_ = row;
#line 427 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp95_ = stmt;
#line 427 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp96_ = sqlite3_column_int (_tmp95_, 22);
#line 427 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp94_->metadata_dirty = _tmp96_ != 0;
#line 428 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp98_ = stmt;
#line 428 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp99_ = sqlite3_column_text (_tmp98_, 23);
#line 428 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp99_ != NULL) {
#line 3132 "PhotoTable.c"
		sqlite3_stmt* _tmp100_;
		const gchar* _tmp101_;
		RawDeveloper _tmp102_;
#line 428 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp100_ = stmt;
#line 428 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp101_ = sqlite3_column_text (_tmp100_, 23);
#line 428 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp102_ = raw_developer_from_string (_tmp101_);
#line 428 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp97_ = _tmp102_;
#line 3144 "PhotoTable.c"
	} else {
#line 429 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp97_ = RAW_DEVELOPER_CAMERA;
#line 3148 "PhotoTable.c"
	}
#line 428 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp103_ = row;
#line 428 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp103_->developer = _tmp97_;
#line 430 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp104_ = row;
#line 430 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp105_ = _tmp104_->development_ids;
#line 430 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp105__length1 = _tmp104_->development_ids_length1;
#line 430 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp106_ = stmt;
#line 430 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp107_ = sqlite3_column_int64 (_tmp106_, 24);
#line 430 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	backing_photo_id_init (&_tmp108_, _tmp107_);
#line 430 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp105_[RAW_DEVELOPER_SHOTWELL] = _tmp108_;
#line 430 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp109_ = _tmp105_[RAW_DEVELOPER_SHOTWELL];
#line 431 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp110_ = row;
#line 431 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp111_ = _tmp110_->development_ids;
#line 431 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp111__length1 = _tmp110_->development_ids_length1;
#line 431 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp112_ = stmt;
#line 431 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp113_ = sqlite3_column_int64 (_tmp112_, 25);
#line 431 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	backing_photo_id_init (&_tmp114_, _tmp113_);
#line 431 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp111_[RAW_DEVELOPER_CAMERA] = _tmp114_;
#line 431 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp115_ = _tmp111_[RAW_DEVELOPER_CAMERA];
#line 432 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp116_ = row;
#line 432 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp117_ = _tmp116_->development_ids;
#line 432 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp117__length1 = _tmp116_->development_ids_length1;
#line 432 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp118_ = stmt;
#line 432 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp119_ = sqlite3_column_int64 (_tmp118_, 26);
#line 432 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	backing_photo_id_init (&_tmp120_, _tmp119_);
#line 432 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp117_[RAW_DEVELOPER_EMBEDDED] = _tmp120_;
#line 432 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp121_ = _tmp117_[RAW_DEVELOPER_EMBEDDED];
#line 433 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp122_ = row;
#line 433 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp123_ = stmt;
#line 433 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp124_ = sqlite3_column_text (_tmp123_, 27);
#line 433 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp125_ = g_strdup (_tmp124_);
#line 433 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (_tmp122_->comment);
#line 433 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp122_->comment = _tmp125_;
#line 435 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = row;
#line 435 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 435 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 3220 "PhotoTable.c"
}


GeeArrayList* photo_table_get_all (PhotoTable* self) {
	GeeArrayList* result = NULL;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	GeeArrayList* all = NULL;
	GeeArrayList* _tmp4_;
#line 438 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), NULL);
#line 440 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 440 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "SELECT id, filename, width, height, filesize, timestamp, exposure_time" \
", orientation, " "original_orientation, import_id, event_id, transformations, md5, thumb" \
"nail_md5, " "exif_md5, time_created, flags, rating, file_format, title, backlinks, " \
"time_reimported, " "editable_id, metadata_dirty, developer, develop_shotwell_id, develop_c" \
"amera_id, " "develop_embedded_id, comment FROM PhotoTable", -1, &_tmp1_, NULL);
#line 440 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 440 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 440 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 447 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 447 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 449 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = gee_array_list_new (TYPE_PHOTO_ROW, (GBoxedCopyFunc) photo_row_ref, (GDestroyNotify) photo_row_unref, NULL, NULL, NULL);
#line 449 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	all = _tmp4_;
#line 451 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	while (TRUE) {
#line 3256 "PhotoTable.c"
		sqlite3_stmt* _tmp5_;
		gint _tmp6_;
		gint _tmp7_;
		PhotoRow* row = NULL;
		PhotoRow* _tmp8_;
		PhotoRow* _tmp9_;
		sqlite3_stmt* _tmp10_;
		gint64 _tmp11_;
		PhotoRow* _tmp12_;
		BackingPhotoRow* _tmp13_;
		sqlite3_stmt* _tmp14_;
		const gchar* _tmp15_;
		gchar* _tmp16_;
		PhotoRow* _tmp17_;
		BackingPhotoRow* _tmp18_;
		sqlite3_stmt* _tmp19_;
		gint _tmp20_;
		sqlite3_stmt* _tmp21_;
		gint _tmp22_;
		PhotoRow* _tmp23_;
		BackingPhotoRow* _tmp24_;
		sqlite3_stmt* _tmp25_;
		gint64 _tmp26_;
		PhotoRow* _tmp27_;
		BackingPhotoRow* _tmp28_;
		sqlite3_stmt* _tmp29_;
		gint64 _tmp30_;
		PhotoRow* _tmp31_;
		sqlite3_stmt* _tmp32_;
		gint64 _tmp33_;
		PhotoRow* _tmp34_;
		sqlite3_stmt* _tmp35_;
		gint _tmp36_;
		PhotoRow* _tmp37_;
		BackingPhotoRow* _tmp38_;
		sqlite3_stmt* _tmp39_;
		gint _tmp40_;
		PhotoRow* _tmp41_;
		sqlite3_stmt* _tmp42_;
		gint64 _tmp43_;
		PhotoRow* _tmp44_;
		sqlite3_stmt* _tmp45_;
		gint64 _tmp46_;
		PhotoRow* _tmp47_;
		sqlite3_stmt* _tmp48_;
		const gchar* _tmp49_;
		GeeHashMap* _tmp50_;
		PhotoRow* _tmp51_;
		sqlite3_stmt* _tmp52_;
		const gchar* _tmp53_;
		gchar* _tmp54_;
		PhotoRow* _tmp55_;
		sqlite3_stmt* _tmp56_;
		const gchar* _tmp57_;
		gchar* _tmp58_;
		PhotoRow* _tmp59_;
		sqlite3_stmt* _tmp60_;
		const gchar* _tmp61_;
		gchar* _tmp62_;
		PhotoRow* _tmp63_;
		sqlite3_stmt* _tmp64_;
		gint64 _tmp65_;
		PhotoRow* _tmp66_;
		sqlite3_stmt* _tmp67_;
		gint64 _tmp68_;
		PhotoRow* _tmp69_;
		sqlite3_stmt* _tmp70_;
		gint _tmp71_;
		Rating _tmp72_;
		PhotoRow* _tmp73_;
		BackingPhotoRow* _tmp74_;
		sqlite3_stmt* _tmp75_;
		gint _tmp76_;
		PhotoFileFormat _tmp77_;
		PhotoRow* _tmp78_;
		sqlite3_stmt* _tmp79_;
		const gchar* _tmp80_;
		gchar* _tmp81_;
		PhotoRow* _tmp82_;
		sqlite3_stmt* _tmp83_;
		const gchar* _tmp84_;
		gchar* _tmp85_;
		PhotoRow* _tmp86_;
		sqlite3_stmt* _tmp87_;
		gint64 _tmp88_;
		PhotoRow* _tmp89_;
		sqlite3_stmt* _tmp90_;
		gint64 _tmp91_;
		PhotoRow* _tmp92_;
		sqlite3_stmt* _tmp93_;
		gint _tmp94_;
		RawDeveloper _tmp95_ = 0;
		sqlite3_stmt* _tmp96_;
		const gchar* _tmp97_;
		PhotoRow* _tmp101_;
		PhotoRow* _tmp102_;
		BackingPhotoID* _tmp103_;
		gint _tmp103__length1;
		sqlite3_stmt* _tmp104_;
		gint64 _tmp105_;
		BackingPhotoID _tmp106_ = {0};
		BackingPhotoID _tmp107_;
		PhotoRow* _tmp108_;
		BackingPhotoID* _tmp109_;
		gint _tmp109__length1;
		sqlite3_stmt* _tmp110_;
		gint64 _tmp111_;
		BackingPhotoID _tmp112_ = {0};
		BackingPhotoID _tmp113_;
		PhotoRow* _tmp114_;
		BackingPhotoID* _tmp115_;
		gint _tmp115__length1;
		sqlite3_stmt* _tmp116_;
		gint64 _tmp117_;
		BackingPhotoID _tmp118_ = {0};
		BackingPhotoID _tmp119_;
		PhotoRow* _tmp120_;
		sqlite3_stmt* _tmp121_;
		const gchar* _tmp122_;
		gchar* _tmp123_;
		PhotoRow* _tmp124_;
		GeeArrayList* _tmp125_;
		PhotoRow* _tmp126_;
#line 451 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp5_ = stmt;
#line 451 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp6_ = sqlite3_step (_tmp5_);
#line 451 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		res = _tmp6_;
#line 451 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp7_ = res;
#line 451 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (!(_tmp7_ == SQLITE_ROW)) {
#line 451 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			break;
#line 3392 "PhotoTable.c"
		}
#line 452 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp8_ = photo_row_new ();
#line 452 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		row = _tmp8_;
#line 453 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp9_ = row;
#line 453 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp10_ = stmt;
#line 453 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp11_ = sqlite3_column_int64 (_tmp10_, 0);
#line 453 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp9_->photo_id.id = _tmp11_;
#line 454 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp12_ = row;
#line 454 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp13_ = _tmp12_->master;
#line 454 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp14_ = stmt;
#line 454 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp15_ = sqlite3_column_text (_tmp14_, 1);
#line 454 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp16_ = g_strdup (_tmp15_);
#line 454 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (_tmp13_->filepath);
#line 454 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp13_->filepath = _tmp16_;
#line 455 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp17_ = row;
#line 455 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp18_ = _tmp17_->master;
#line 455 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp19_ = stmt;
#line 455 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp20_ = sqlite3_column_int (_tmp19_, 2);
#line 455 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp21_ = stmt;
#line 455 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp22_ = sqlite3_column_int (_tmp21_, 3);
#line 455 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		dimensions_init (&_tmp18_->dim, _tmp20_, _tmp22_);
#line 456 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp23_ = row;
#line 456 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp24_ = _tmp23_->master;
#line 456 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp25_ = stmt;
#line 456 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp26_ = sqlite3_column_int64 (_tmp25_, 4);
#line 456 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp24_->filesize = _tmp26_;
#line 457 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp27_ = row;
#line 457 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp28_ = _tmp27_->master;
#line 457 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp29_ = stmt;
#line 457 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp30_ = sqlite3_column_int64 (_tmp29_, 5);
#line 457 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp28_->timestamp = (time_t) _tmp30_;
#line 458 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp31_ = row;
#line 458 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp32_ = stmt;
#line 458 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp33_ = sqlite3_column_int64 (_tmp32_, 6);
#line 458 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp31_->exposure_time = (time_t) _tmp33_;
#line 459 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp34_ = row;
#line 459 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp35_ = stmt;
#line 459 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp36_ = sqlite3_column_int (_tmp35_, 7);
#line 459 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp34_->orientation = (Orientation) _tmp36_;
#line 460 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp37_ = row;
#line 460 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp38_ = _tmp37_->master;
#line 460 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp39_ = stmt;
#line 460 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp40_ = sqlite3_column_int (_tmp39_, 8);
#line 460 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp38_->original_orientation = (Orientation) _tmp40_;
#line 461 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp41_ = row;
#line 461 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp42_ = stmt;
#line 461 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp43_ = sqlite3_column_int64 (_tmp42_, 9);
#line 461 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp41_->import_id.id = _tmp43_;
#line 462 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp44_ = row;
#line 462 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp45_ = stmt;
#line 462 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp46_ = sqlite3_column_int64 (_tmp45_, 10);
#line 462 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp44_->event_id.id = _tmp46_;
#line 463 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp47_ = row;
#line 463 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp48_ = stmt;
#line 463 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp49_ = sqlite3_column_text (_tmp48_, 11);
#line 463 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp50_ = photo_table_marshall_all_transformations (_tmp49_);
#line 463 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_object_unref0 (_tmp47_->transformations);
#line 463 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp47_->transformations = _tmp50_;
#line 464 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp51_ = row;
#line 464 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp52_ = stmt;
#line 464 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp53_ = sqlite3_column_text (_tmp52_, 12);
#line 464 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp54_ = g_strdup (_tmp53_);
#line 464 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (_tmp51_->md5);
#line 464 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp51_->md5 = _tmp54_;
#line 465 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp55_ = row;
#line 465 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp56_ = stmt;
#line 465 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp57_ = sqlite3_column_text (_tmp56_, 13);
#line 465 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp58_ = g_strdup (_tmp57_);
#line 465 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (_tmp55_->thumbnail_md5);
#line 465 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp55_->thumbnail_md5 = _tmp58_;
#line 466 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp59_ = row;
#line 466 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp60_ = stmt;
#line 466 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp61_ = sqlite3_column_text (_tmp60_, 14);
#line 466 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp62_ = g_strdup (_tmp61_);
#line 466 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (_tmp59_->exif_md5);
#line 466 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp59_->exif_md5 = _tmp62_;
#line 467 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp63_ = row;
#line 467 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp64_ = stmt;
#line 467 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp65_ = sqlite3_column_int64 (_tmp64_, 15);
#line 467 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp63_->time_created = (time_t) _tmp65_;
#line 468 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp66_ = row;
#line 468 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp67_ = stmt;
#line 468 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp68_ = sqlite3_column_int64 (_tmp67_, 16);
#line 468 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp66_->flags = (guint64) _tmp68_;
#line 469 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp69_ = row;
#line 469 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp70_ = stmt;
#line 469 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp71_ = sqlite3_column_int (_tmp70_, 17);
#line 469 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp72_ = rating_unserialize (_tmp71_);
#line 469 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp69_->rating = _tmp72_;
#line 470 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp73_ = row;
#line 470 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp74_ = _tmp73_->master;
#line 470 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp75_ = stmt;
#line 470 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp76_ = sqlite3_column_int (_tmp75_, 18);
#line 470 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp77_ = photo_file_format_unserialize (_tmp76_);
#line 470 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp74_->file_format = _tmp77_;
#line 471 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp78_ = row;
#line 471 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp79_ = stmt;
#line 471 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp80_ = sqlite3_column_text (_tmp79_, 19);
#line 471 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp81_ = g_strdup (_tmp80_);
#line 471 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (_tmp78_->title);
#line 471 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp78_->title = _tmp81_;
#line 472 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp82_ = row;
#line 472 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp83_ = stmt;
#line 472 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp84_ = sqlite3_column_text (_tmp83_, 20);
#line 472 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp85_ = g_strdup (_tmp84_);
#line 472 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (_tmp82_->backlinks);
#line 472 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp82_->backlinks = _tmp85_;
#line 473 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp86_ = row;
#line 473 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp87_ = stmt;
#line 473 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp88_ = sqlite3_column_int64 (_tmp87_, 21);
#line 473 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp86_->time_reimported = (time_t) _tmp88_;
#line 474 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp89_ = row;
#line 474 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp90_ = stmt;
#line 474 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp91_ = sqlite3_column_int64 (_tmp90_, 22);
#line 474 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		backing_photo_id_init (&_tmp89_->editable_id, _tmp91_);
#line 475 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp92_ = row;
#line 475 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp93_ = stmt;
#line 475 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp94_ = sqlite3_column_int (_tmp93_, 23);
#line 475 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp92_->metadata_dirty = _tmp94_ != 0;
#line 476 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp96_ = stmt;
#line 476 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp97_ = sqlite3_column_text (_tmp96_, 24);
#line 476 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_tmp97_ != NULL) {
#line 3636 "PhotoTable.c"
			sqlite3_stmt* _tmp98_;
			const gchar* _tmp99_;
			RawDeveloper _tmp100_;
#line 476 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp98_ = stmt;
#line 476 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp99_ = sqlite3_column_text (_tmp98_, 24);
#line 476 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp100_ = raw_developer_from_string (_tmp99_);
#line 476 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp95_ = _tmp100_;
#line 3648 "PhotoTable.c"
		} else {
#line 477 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp95_ = RAW_DEVELOPER_CAMERA;
#line 3652 "PhotoTable.c"
		}
#line 476 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp101_ = row;
#line 476 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp101_->developer = _tmp95_;
#line 478 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp102_ = row;
#line 478 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp103_ = _tmp102_->development_ids;
#line 478 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp103__length1 = _tmp102_->development_ids_length1;
#line 478 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp104_ = stmt;
#line 478 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp105_ = sqlite3_column_int64 (_tmp104_, 25);
#line 478 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		backing_photo_id_init (&_tmp106_, _tmp105_);
#line 478 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp103_[RAW_DEVELOPER_SHOTWELL] = _tmp106_;
#line 478 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp107_ = _tmp103_[RAW_DEVELOPER_SHOTWELL];
#line 479 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp108_ = row;
#line 479 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp109_ = _tmp108_->development_ids;
#line 479 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp109__length1 = _tmp108_->development_ids_length1;
#line 479 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp110_ = stmt;
#line 479 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp111_ = sqlite3_column_int64 (_tmp110_, 26);
#line 479 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		backing_photo_id_init (&_tmp112_, _tmp111_);
#line 479 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp109_[RAW_DEVELOPER_CAMERA] = _tmp112_;
#line 479 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp113_ = _tmp109_[RAW_DEVELOPER_CAMERA];
#line 480 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp114_ = row;
#line 480 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp115_ = _tmp114_->development_ids;
#line 480 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp115__length1 = _tmp114_->development_ids_length1;
#line 480 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp116_ = stmt;
#line 480 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp117_ = sqlite3_column_int64 (_tmp116_, 27);
#line 480 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		backing_photo_id_init (&_tmp118_, _tmp117_);
#line 480 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp115_[RAW_DEVELOPER_EMBEDDED] = _tmp118_;
#line 480 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp119_ = _tmp115_[RAW_DEVELOPER_EMBEDDED];
#line 481 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp120_ = row;
#line 481 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp121_ = stmt;
#line 481 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp122_ = sqlite3_column_text (_tmp121_, 28);
#line 481 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp123_ = g_strdup (_tmp122_);
#line 481 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (_tmp120_->comment);
#line 481 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp120_->comment = _tmp123_;
#line 483 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp124_ = row;
#line 483 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		photo_table_validate_orientation (self, _tmp124_);
#line 485 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp125_ = all;
#line 485 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp126_ = row;
#line 485 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp125_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp126_);
#line 451 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_photo_row_unref0 (row);
#line 3730 "PhotoTable.c"
	}
#line 488 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = all;
#line 488 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 488 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 3738 "PhotoTable.c"
}


void photo_table_duplicate (PhotoTable* self, PhotoID* photo_id, const gchar* new_filename, BackingPhotoID* editable_id, BackingPhotoID* develop_shotwell, BackingPhotoID* develop_camera_id, BackingPhotoID* develop_embedded_id, PhotoID* result) {
	PhotoRow* original = NULL;
	PhotoID _tmp0_;
	PhotoRow* _tmp1_;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp2_;
	sqlite3_stmt* _tmp3_ = NULL;
	gint _tmp4_;
	gint _tmp5_;
	sqlite3_stmt* _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	GDestroyNotify _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	sqlite3_stmt* _tmp12_;
	PhotoRow* _tmp13_;
	BackingPhotoRow* _tmp14_;
	Dimensions _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	gint _tmp18_;
	sqlite3_stmt* _tmp19_;
	PhotoRow* _tmp20_;
	BackingPhotoRow* _tmp21_;
	Dimensions _tmp22_;
	gint _tmp23_;
	gint _tmp24_;
	gint _tmp25_;
	sqlite3_stmt* _tmp26_;
	PhotoRow* _tmp27_;
	BackingPhotoRow* _tmp28_;
	gint64 _tmp29_;
	gint _tmp30_;
	gint _tmp31_;
	sqlite3_stmt* _tmp32_;
	PhotoRow* _tmp33_;
	BackingPhotoRow* _tmp34_;
	time_t _tmp35_;
	gint _tmp36_;
	gint _tmp37_;
	sqlite3_stmt* _tmp38_;
	PhotoRow* _tmp39_;
	time_t _tmp40_;
	gint _tmp41_;
	gint _tmp42_;
	sqlite3_stmt* _tmp43_;
	PhotoRow* _tmp44_;
	Orientation _tmp45_;
	gint _tmp46_;
	gint _tmp47_;
	sqlite3_stmt* _tmp48_;
	PhotoRow* _tmp49_;
	BackingPhotoRow* _tmp50_;
	Orientation _tmp51_;
	gint _tmp52_;
	gint _tmp53_;
	sqlite3_stmt* _tmp54_;
	PhotoRow* _tmp55_;
	ImportID _tmp56_;
	gint64 _tmp57_;
	gint _tmp58_;
	gint _tmp59_;
	sqlite3_stmt* _tmp60_;
	PhotoRow* _tmp61_;
	EventID _tmp62_;
	gint64 _tmp63_;
	gint _tmp64_;
	gint _tmp65_;
	sqlite3_stmt* _tmp66_;
	PhotoRow* _tmp67_;
	GeeHashMap* _tmp68_;
	gchar* _tmp69_;
	GDestroyNotify _tmp70_;
	gint _tmp71_;
	gint _tmp72_;
	sqlite3_stmt* _tmp73_;
	PhotoRow* _tmp74_;
	const gchar* _tmp75_;
	gchar* _tmp76_;
	GDestroyNotify _tmp77_;
	gint _tmp78_;
	gint _tmp79_;
	sqlite3_stmt* _tmp80_;
	PhotoRow* _tmp81_;
	const gchar* _tmp82_;
	gchar* _tmp83_;
	GDestroyNotify _tmp84_;
	gint _tmp85_;
	gint _tmp86_;
	sqlite3_stmt* _tmp87_;
	PhotoRow* _tmp88_;
	const gchar* _tmp89_;
	gchar* _tmp90_;
	GDestroyNotify _tmp91_;
	gint _tmp92_;
	gint _tmp93_;
	sqlite3_stmt* _tmp94_;
	gulong _tmp95_;
	gint _tmp96_;
	gint _tmp97_;
	sqlite3_stmt* _tmp98_;
	PhotoRow* _tmp99_;
	guint64 _tmp100_;
	gint _tmp101_;
	gint _tmp102_;
	sqlite3_stmt* _tmp103_;
	PhotoRow* _tmp104_;
	Rating _tmp105_;
	gint _tmp106_;
	gint _tmp107_;
	gint _tmp108_;
	sqlite3_stmt* _tmp109_;
	PhotoRow* _tmp110_;
	BackingPhotoRow* _tmp111_;
	PhotoFileFormat _tmp112_;
	gint _tmp113_;
	gint _tmp114_;
	gint _tmp115_;
	sqlite3_stmt* _tmp116_;
	PhotoRow* _tmp117_;
	const gchar* _tmp118_;
	gchar* _tmp119_;
	GDestroyNotify _tmp120_;
	gint _tmp121_;
	gint _tmp122_;
	sqlite3_stmt* _tmp123_;
	BackingPhotoID _tmp124_;
	gint64 _tmp125_;
	gint _tmp126_;
	gint _tmp127_;
	sqlite3_stmt* _tmp128_;
	PhotoRow* _tmp129_;
	RawDeveloper _tmp130_;
	gchar* _tmp131_;
	GDestroyNotify _tmp132_;
	gint _tmp133_;
	gint _tmp134_;
	sqlite3_stmt* _tmp135_;
	BackingPhotoID _tmp136_;
	gint64 _tmp137_;
	gint _tmp138_;
	gint _tmp139_;
	sqlite3_stmt* _tmp140_;
	BackingPhotoID _tmp141_;
	gint64 _tmp142_;
	gint _tmp143_;
	gint _tmp144_;
	sqlite3_stmt* _tmp145_;
	BackingPhotoID _tmp146_;
	gint64 _tmp147_;
	gint _tmp148_;
	gint _tmp149_;
	sqlite3_stmt* _tmp150_;
	PhotoRow* _tmp151_;
	const gchar* _tmp152_;
	gchar* _tmp153_;
	GDestroyNotify _tmp154_;
	gint _tmp155_;
	gint _tmp156_;
	sqlite3_stmt* _tmp157_;
	gint _tmp158_;
	gint _tmp159_;
	sqlite3* _tmp163_;
	gint64 _tmp164_;
	PhotoID _tmp165_ = {0};
#line 493 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 493 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (photo_id != NULL);
#line 493 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (new_filename != NULL);
#line 493 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (editable_id != NULL);
#line 493 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (develop_shotwell != NULL);
#line 493 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (develop_camera_id != NULL);
#line 493 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (develop_embedded_id != NULL);
#line 497 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 497 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = photo_table_get_row (self, &_tmp0_);
#line 497 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	original = _tmp1_;
#line 500 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = database_table_db;
#line 500 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = sqlite3_prepare_v2 (_tmp2_, "INSERT INTO PhotoTable (filename, width, height, filesize, " "timestamp, exposure_time, orientation, original_orientation, import_id" \
", event_id, " "transformations, md5, thumbnail_md5, exif_md5, time_created, flags, ra" \
"ting, " "file_format, title, editable_id, developer, develop_shotwell_id, devel" \
"op_camera_id, " "develop_embedded_id, comment) " "VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?," \
" ?, ?, ?, ?)", -1, &_tmp3_, NULL);
#line 500 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 500 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp3_;
#line 500 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp4_;
#line 507 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = res;
#line 507 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp5_ == SQLITE_OK, "res == Sqlite.OK");
#line 509 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = stmt;
#line 509 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = new_filename;
#line 509 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = g_strdup (_tmp7_);
#line 509 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = g_free;
#line 509 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = sqlite3_bind_text (_tmp6_, 1, _tmp8_, -1, _tmp9_);
#line 509 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp10_;
#line 510 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = res;
#line 510 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp11_ == SQLITE_OK, "res == Sqlite.OK");
#line 511 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = stmt;
#line 511 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp13_ = original;
#line 511 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = _tmp13_->master;
#line 511 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_ = _tmp14_->dim;
#line 511 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp16_ = _tmp15_.width;
#line 511 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp17_ = sqlite3_bind_int (_tmp12_, 2, _tmp16_);
#line 511 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp17_;
#line 512 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp18_ = res;
#line 512 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp18_ == SQLITE_OK, "res == Sqlite.OK");
#line 513 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp19_ = stmt;
#line 513 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp20_ = original;
#line 513 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp21_ = _tmp20_->master;
#line 513 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp22_ = _tmp21_->dim;
#line 513 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp23_ = _tmp22_.height;
#line 513 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp24_ = sqlite3_bind_int (_tmp19_, 3, _tmp23_);
#line 513 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp24_;
#line 514 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp25_ = res;
#line 514 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp25_ == SQLITE_OK, "res == Sqlite.OK");
#line 515 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp26_ = stmt;
#line 515 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp27_ = original;
#line 515 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp28_ = _tmp27_->master;
#line 515 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp29_ = _tmp28_->filesize;
#line 515 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp30_ = sqlite3_bind_int64 (_tmp26_, 4, _tmp29_);
#line 515 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp30_;
#line 516 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp31_ = res;
#line 516 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp31_ == SQLITE_OK, "res == Sqlite.OK");
#line 517 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp32_ = stmt;
#line 517 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp33_ = original;
#line 517 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp34_ = _tmp33_->master;
#line 517 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp35_ = _tmp34_->timestamp;
#line 517 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp36_ = sqlite3_bind_int64 (_tmp32_, 5, (gint64) _tmp35_);
#line 517 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp36_;
#line 518 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp37_ = res;
#line 518 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp37_ == SQLITE_OK, "res == Sqlite.OK");
#line 519 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp38_ = stmt;
#line 519 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp39_ = original;
#line 519 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp40_ = _tmp39_->exposure_time;
#line 519 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp41_ = sqlite3_bind_int64 (_tmp38_, 6, (gint64) _tmp40_);
#line 519 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp41_;
#line 520 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp42_ = res;
#line 520 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp42_ == SQLITE_OK, "res == Sqlite.OK");
#line 521 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp43_ = stmt;
#line 521 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp44_ = original;
#line 521 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp45_ = _tmp44_->orientation;
#line 521 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp46_ = sqlite3_bind_int (_tmp43_, 7, (gint) _tmp45_);
#line 521 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp46_;
#line 522 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp47_ = res;
#line 522 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp47_ == SQLITE_OK, "res == Sqlite.OK");
#line 523 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp48_ = stmt;
#line 523 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp49_ = original;
#line 523 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp50_ = _tmp49_->master;
#line 523 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp51_ = _tmp50_->original_orientation;
#line 523 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp52_ = sqlite3_bind_int (_tmp48_, 8, (gint) _tmp51_);
#line 523 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp52_;
#line 524 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp53_ = res;
#line 524 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp53_ == SQLITE_OK, "res == Sqlite.OK");
#line 525 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp54_ = stmt;
#line 525 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp55_ = original;
#line 525 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp56_ = _tmp55_->import_id;
#line 525 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp57_ = _tmp56_.id;
#line 525 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp58_ = sqlite3_bind_int64 (_tmp54_, 9, _tmp57_);
#line 525 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp58_;
#line 526 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp59_ = res;
#line 526 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp59_ == SQLITE_OK, "res == Sqlite.OK");
#line 527 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp60_ = stmt;
#line 527 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp61_ = original;
#line 527 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp62_ = _tmp61_->event_id;
#line 527 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp63_ = _tmp62_.id;
#line 527 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp64_ = sqlite3_bind_int64 (_tmp60_, 10, _tmp63_);
#line 527 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp64_;
#line 528 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp65_ = res;
#line 528 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp65_ == SQLITE_OK, "res == Sqlite.OK");
#line 529 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp66_ = stmt;
#line 529 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp67_ = original;
#line 529 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp68_ = _tmp67_->transformations;
#line 529 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp69_ = photo_table_unmarshall_all_transformations (_tmp68_);
#line 529 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp70_ = g_free;
#line 529 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp71_ = sqlite3_bind_text (_tmp66_, 11, _tmp69_, -1, _tmp70_);
#line 529 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp71_;
#line 530 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp72_ = res;
#line 530 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp72_ == SQLITE_OK, "res == Sqlite.OK");
#line 531 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp73_ = stmt;
#line 531 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp74_ = original;
#line 531 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp75_ = _tmp74_->md5;
#line 531 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp76_ = g_strdup (_tmp75_);
#line 531 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp77_ = g_free;
#line 531 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp78_ = sqlite3_bind_text (_tmp73_, 12, _tmp76_, -1, _tmp77_);
#line 531 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp78_;
#line 532 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp79_ = res;
#line 532 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp79_ == SQLITE_OK, "res == Sqlite.OK");
#line 533 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp80_ = stmt;
#line 533 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp81_ = original;
#line 533 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp82_ = _tmp81_->thumbnail_md5;
#line 533 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp83_ = g_strdup (_tmp82_);
#line 533 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp84_ = g_free;
#line 533 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp85_ = sqlite3_bind_text (_tmp80_, 13, _tmp83_, -1, _tmp84_);
#line 533 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp85_;
#line 534 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp86_ = res;
#line 534 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp86_ == SQLITE_OK, "res == Sqlite.OK");
#line 535 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp87_ = stmt;
#line 535 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp88_ = original;
#line 535 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp89_ = _tmp88_->exif_md5;
#line 535 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp90_ = g_strdup (_tmp89_);
#line 535 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp91_ = g_free;
#line 535 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp92_ = sqlite3_bind_text (_tmp87_, 14, _tmp90_, -1, _tmp91_);
#line 535 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp92_;
#line 536 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp93_ = res;
#line 536 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp93_ == SQLITE_OK, "res == Sqlite.OK");
#line 537 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp94_ = stmt;
#line 537 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp95_ = now_sec ();
#line 537 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp96_ = sqlite3_bind_int64 (_tmp94_, 15, (gint64) _tmp95_);
#line 537 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp96_;
#line 538 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp97_ = res;
#line 538 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp97_ == SQLITE_OK, "res == Sqlite.OK");
#line 539 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp98_ = stmt;
#line 539 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp99_ = original;
#line 539 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp100_ = _tmp99_->flags;
#line 539 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp101_ = sqlite3_bind_int64 (_tmp98_, 16, (gint64) _tmp100_);
#line 539 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp101_;
#line 540 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp102_ = res;
#line 540 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp102_ == SQLITE_OK, "res == Sqlite.OK");
#line 541 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp103_ = stmt;
#line 541 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp104_ = original;
#line 541 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp105_ = _tmp104_->rating;
#line 541 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp106_ = rating_serialize (_tmp105_);
#line 541 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp107_ = sqlite3_bind_int64 (_tmp103_, 17, (gint64) _tmp106_);
#line 541 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp107_;
#line 542 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp108_ = res;
#line 542 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp108_ == SQLITE_OK, "res == Sqlite.OK");
#line 543 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp109_ = stmt;
#line 543 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp110_ = original;
#line 543 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp111_ = _tmp110_->master;
#line 543 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp112_ = _tmp111_->file_format;
#line 543 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp113_ = photo_file_format_serialize (_tmp112_);
#line 543 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp114_ = sqlite3_bind_int (_tmp109_, 18, _tmp113_);
#line 543 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp114_;
#line 544 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp115_ = res;
#line 544 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp115_ == SQLITE_OK, "res == Sqlite.OK");
#line 545 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp116_ = stmt;
#line 545 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp117_ = original;
#line 545 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp118_ = _tmp117_->title;
#line 545 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp119_ = g_strdup (_tmp118_);
#line 545 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp120_ = g_free;
#line 545 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp121_ = sqlite3_bind_text (_tmp116_, 19, _tmp119_, -1, _tmp120_);
#line 545 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp121_;
#line 546 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp122_ = res;
#line 546 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp122_ == SQLITE_OK, "res == Sqlite.OK");
#line 547 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp123_ = stmt;
#line 547 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp124_ = *editable_id;
#line 547 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp125_ = _tmp124_.id;
#line 547 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp126_ = sqlite3_bind_int64 (_tmp123_, 20, _tmp125_);
#line 547 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp126_;
#line 548 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp127_ = res;
#line 548 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp127_ == SQLITE_OK, "res == Sqlite.OK");
#line 550 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp128_ = stmt;
#line 550 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp129_ = original;
#line 550 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp130_ = _tmp129_->developer;
#line 550 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp131_ = raw_developer_to_string (_tmp130_);
#line 550 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp132_ = g_free;
#line 550 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp133_ = sqlite3_bind_text (_tmp128_, 21, _tmp131_, -1, _tmp132_);
#line 550 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp133_;
#line 551 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp134_ = res;
#line 551 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp134_ == SQLITE_OK, "res == Sqlite.OK");
#line 552 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp135_ = stmt;
#line 552 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp136_ = *develop_shotwell;
#line 552 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp137_ = _tmp136_.id;
#line 552 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp138_ = sqlite3_bind_int64 (_tmp135_, 22, _tmp137_);
#line 552 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp138_;
#line 553 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp139_ = res;
#line 553 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp139_ == SQLITE_OK, "res == Sqlite.OK");
#line 554 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp140_ = stmt;
#line 554 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp141_ = *develop_camera_id;
#line 554 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp142_ = _tmp141_.id;
#line 554 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp143_ = sqlite3_bind_int64 (_tmp140_, 23, _tmp142_);
#line 554 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp143_;
#line 555 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp144_ = res;
#line 555 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp144_ == SQLITE_OK, "res == Sqlite.OK");
#line 556 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp145_ = stmt;
#line 556 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp146_ = *develop_embedded_id;
#line 556 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp147_ = _tmp146_.id;
#line 556 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp148_ = sqlite3_bind_int64 (_tmp145_, 24, _tmp147_);
#line 556 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp148_;
#line 557 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp149_ = res;
#line 557 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp149_ == SQLITE_OK, "res == Sqlite.OK");
#line 558 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp150_ = stmt;
#line 558 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp151_ = original;
#line 558 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp152_ = _tmp151_->comment;
#line 558 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp153_ = g_strdup (_tmp152_);
#line 558 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp154_ = g_free;
#line 558 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp155_ = sqlite3_bind_text (_tmp150_, 25, _tmp153_, -1, _tmp154_);
#line 558 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp155_;
#line 559 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp156_ = res;
#line 559 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp156_ == SQLITE_OK, "res == Sqlite.OK");
#line 561 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp157_ = stmt;
#line 561 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp158_ = sqlite3_step (_tmp157_);
#line 561 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp158_;
#line 562 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp159_ = res;
#line 562 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp159_ != SQLITE_DONE) {
#line 4355 "PhotoTable.c"
		gint _tmp160_;
		PhotoID _tmp162_ = {0};
#line 563 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp160_ = res;
#line 563 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_tmp160_ != SQLITE_CONSTRAINT) {
#line 4362 "PhotoTable.c"
			gint _tmp161_;
#line 564 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp161_ = res;
#line 564 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			database_table_fatal ("duplicate", _tmp161_);
#line 4368 "PhotoTable.c"
		}
#line 566 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		photo_id_init (&_tmp162_, PHOTO_ID_INVALID);
#line 566 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		*result = _tmp162_;
#line 566 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_sqlite3_finalize0 (stmt);
#line 566 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_photo_row_unref0 (original);
#line 566 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return;
#line 4380 "PhotoTable.c"
	}
#line 569 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp163_ = database_table_db;
#line 569 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp164_ = sqlite3_last_insert_rowid (_tmp163_);
#line 569 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	photo_id_init (&_tmp165_, _tmp164_);
#line 569 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	*result = _tmp165_;
#line 569 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 569 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_photo_row_unref0 (original);
#line 569 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return;
#line 4396 "PhotoTable.c"
}


gboolean photo_table_set_title (PhotoTable* self, PhotoID* photo_id, const gchar* new_title) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_;
	PhotoID _tmp3_;
	gint64 _tmp4_;
	gboolean _tmp5_;
#line 572 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 572 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, FALSE);
#line 573 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = new_title;
#line 573 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp1_ != NULL) {
#line 4415 "PhotoTable.c"
		const gchar* _tmp2_;
#line 573 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp2_ = new_title;
#line 573 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = _tmp2_;
#line 4421 "PhotoTable.c"
	} else {
#line 573 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = "";
#line 4425 "PhotoTable.c"
	}
#line 573 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = *photo_id;
#line 573 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = _tmp3_.id;
#line 573 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = database_table_update_text_by_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp4_, "title", _tmp0_);
#line 573 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp5_;
#line 573 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 4437 "PhotoTable.c"
}


gboolean photo_table_set_comment (PhotoTable* self, PhotoID* photo_id, const gchar* new_comment) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_;
	PhotoID _tmp3_;
	gint64 _tmp4_;
	gboolean _tmp5_;
#line 576 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 576 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, FALSE);
#line 577 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = new_comment;
#line 577 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp1_ != NULL) {
#line 4456 "PhotoTable.c"
		const gchar* _tmp2_;
#line 577 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp2_ = new_comment;
#line 577 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = _tmp2_;
#line 4462 "PhotoTable.c"
	} else {
#line 577 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = "";
#line 4466 "PhotoTable.c"
	}
#line 577 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = *photo_id;
#line 577 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = _tmp3_.id;
#line 577 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = database_table_update_text_by_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp4_, "comment", _tmp0_);
#line 577 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp5_;
#line 577 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 4478 "PhotoTable.c"
}


void photo_table_set_filepath (PhotoTable* self, PhotoID* photo_id, const gchar* filepath, GError** error) {
	PhotoID _tmp0_;
	gint64 _tmp1_;
	const gchar* _tmp2_;
	GError * _inner_error_ = NULL;
#line 580 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 580 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (photo_id != NULL);
#line 580 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (filepath != NULL);
#line 581 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 581 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 581 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = filepath;
#line 581 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_update_text_by_id_2 (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, "filename", _tmp2_, &_inner_error_);
#line 581 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 581 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 581 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_propagate_error (error, _inner_error_);
#line 581 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 4509 "PhotoTable.c"
		} else {
#line 581 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 581 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_clear_error (&_inner_error_);
#line 581 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 4517 "PhotoTable.c"
		}
	}
}


void photo_table_update_timestamp (PhotoTable* self, PhotoID* photo_id, time_t timestamp, GError** error) {
	PhotoID _tmp0_;
	gint64 _tmp1_;
	time_t _tmp2_;
	GError * _inner_error_ = NULL;
#line 584 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 584 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (photo_id != NULL);
#line 585 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 585 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 585 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = timestamp;
#line 585 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_update_int64_by_id_2 (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, "timestamp", (gint64) _tmp2_, &_inner_error_);
#line 585 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 585 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 585 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_propagate_error (error, _inner_error_);
#line 585 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 4548 "PhotoTable.c"
		} else {
#line 585 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 585 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_clear_error (&_inner_error_);
#line 585 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 4556 "PhotoTable.c"
		}
	}
}


gboolean photo_table_set_exposure_time (PhotoTable* self, PhotoID* photo_id, time_t time) {
	gboolean result = FALSE;
	PhotoID _tmp0_;
	gint64 _tmp1_;
	time_t _tmp2_;
	gboolean _tmp3_;
#line 588 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 588 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, FALSE);
#line 589 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 589 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 589 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = time;
#line 589 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = database_table_update_int64_by_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, "exposure_time", (gint64) _tmp2_);
#line 589 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp3_;
#line 589 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 4584 "PhotoTable.c"
}


void photo_table_set_import_id (PhotoTable* self, PhotoID* photo_id, ImportID* import_id, GError** error) {
	PhotoID _tmp0_;
	gint64 _tmp1_;
	ImportID _tmp2_;
	gint64 _tmp3_;
	GError * _inner_error_ = NULL;
#line 592 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 592 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (photo_id != NULL);
#line 592 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (import_id != NULL);
#line 593 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 593 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 593 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = *import_id;
#line 593 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = _tmp2_.id;
#line 593 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_update_int64_by_id_2 (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, "import_id", _tmp3_, &_inner_error_);
#line 593 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 593 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 593 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_propagate_error (error, _inner_error_);
#line 593 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 4618 "PhotoTable.c"
		} else {
#line 593 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 593 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_clear_error (&_inner_error_);
#line 593 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 4626 "PhotoTable.c"
		}
	}
}


gboolean photo_table_remove_by_file (PhotoTable* self, GFile* file) {
	gboolean result = FALSE;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	sqlite3_stmt* _tmp4_;
	GFile* _tmp5_;
	gchar* _tmp6_;
	GDestroyNotify _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	sqlite3_stmt* _tmp10_;
	gint _tmp11_;
	gint _tmp12_;
#line 596 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 596 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (G_IS_FILE (file), FALSE);
#line 598 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 598 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "DELETE FROM PhotoTable WHERE filename=?", -1, &_tmp1_, NULL);
#line 598 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 598 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 598 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 599 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 599 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 601 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 601 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = file;
#line 601 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = g_file_get_path (_tmp5_);
#line 601 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = g_free;
#line 601 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = sqlite3_bind_text (_tmp4_, 1, _tmp6_, -1, _tmp7_);
#line 601 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp8_;
#line 602 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = res;
#line 602 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp9_ == SQLITE_OK, "res == Sqlite.OK");
#line 604 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = stmt;
#line 604 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = sqlite3_step (_tmp10_);
#line 604 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp11_;
#line 605 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = res;
#line 605 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp12_ != SQLITE_DONE) {
#line 4693 "PhotoTable.c"
		gint _tmp13_;
#line 606 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp13_ = res;
#line 606 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_warning ("remove", _tmp13_);
#line 608 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = FALSE;
#line 608 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_sqlite3_finalize0 (stmt);
#line 608 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 4705 "PhotoTable.c"
	}
#line 611 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = TRUE;
#line 611 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 611 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 4713 "PhotoTable.c"
}


void photo_table_remove (PhotoTable* self, PhotoID* photo_id, GError** error) {
	PhotoID _tmp0_;
	gint64 _tmp1_;
	GError * _inner_error_ = NULL;
#line 614 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 614 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (photo_id != NULL);
#line 615 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 615 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 615 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_delete_by_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, &_inner_error_);
#line 615 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 615 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 615 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_propagate_error (error, _inner_error_);
#line 615 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 4739 "PhotoTable.c"
		} else {
#line 615 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 615 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_clear_error (&_inner_error_);
#line 615 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 4747 "PhotoTable.c"
		}
	}
}


GeeArrayList* photo_table_get_photos (PhotoTable* self) {
	GeeArrayList* result = NULL;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	GeeArrayList* photo_ids = NULL;
	GeeArrayList* _tmp4_;
#line 618 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), NULL);
#line 620 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 620 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "SELECT id FROM PhotoTable", -1, &_tmp1_, NULL);
#line 620 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 620 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 620 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 621 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 621 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 623 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = gee_array_list_new (TYPE_PHOTO_ID, (GBoxedCopyFunc) photo_id_dup, (GDestroyNotify) photo_id_free, NULL, NULL, NULL);
#line 623 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	photo_ids = _tmp4_;
#line 4783 "PhotoTable.c"
	{
		gboolean _tmp5_ = FALSE;
#line 624 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp5_ = TRUE;
#line 624 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		while (TRUE) {
#line 4790 "PhotoTable.c"
			sqlite3_stmt* _tmp6_;
			gint _tmp7_;
			gint _tmp8_;
			GeeArrayList* _tmp11_;
			sqlite3_stmt* _tmp12_;
			gint64 _tmp13_;
			PhotoID _tmp14_ = {0};
#line 624 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (!_tmp5_) {
#line 4800 "PhotoTable.c"
			}
#line 624 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp5_ = FALSE;
#line 625 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp6_ = stmt;
#line 625 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp7_ = sqlite3_step (_tmp6_);
#line 625 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			res = _tmp7_;
#line 626 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp8_ = res;
#line 626 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (_tmp8_ == SQLITE_DONE) {
#line 627 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				break;
#line 4816 "PhotoTable.c"
			} else {
				gint _tmp9_;
#line 628 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp9_ = res;
#line 628 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				if (_tmp9_ != SQLITE_ROW) {
#line 4823 "PhotoTable.c"
					gint _tmp10_;
#line 629 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp10_ = res;
#line 629 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					database_table_fatal ("get_photos", _tmp10_);
#line 631 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					break;
#line 4831 "PhotoTable.c"
				}
			}
#line 634 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp11_ = photo_ids;
#line 634 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp12_ = stmt;
#line 634 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp13_ = sqlite3_column_int64 (_tmp12_, 0);
#line 634 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			photo_id_init (&_tmp14_, _tmp13_);
#line 634 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), &_tmp14_);
#line 4844 "PhotoTable.c"
		}
	}
#line 637 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = photo_ids;
#line 637 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 637 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 4853 "PhotoTable.c"
}


gboolean photo_table_set_orientation (PhotoTable* self, PhotoID* photo_id, Orientation orientation) {
	gboolean result = FALSE;
	PhotoID _tmp0_;
	gint64 _tmp1_;
	Orientation _tmp2_;
	gboolean _tmp3_;
#line 640 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 640 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, FALSE);
#line 641 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 641 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 641 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = orientation;
#line 641 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = database_table_update_int_by_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, "orientation", (gint) _tmp2_);
#line 641 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp3_;
#line 641 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 4879 "PhotoTable.c"
}


gboolean photo_table_replace_flags (PhotoTable* self, PhotoID* photo_id, guint64 flags) {
	gboolean result = FALSE;
	PhotoID _tmp0_;
	gint64 _tmp1_;
	guint64 _tmp2_;
	gboolean _tmp3_;
#line 644 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 644 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, FALSE);
#line 645 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 645 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 645 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = flags;
#line 645 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = database_table_update_int64_by_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, "flags", (gint64) _tmp2_);
#line 645 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp3_;
#line 645 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 4905 "PhotoTable.c"
}


gboolean photo_table_set_rating (PhotoTable* self, PhotoID* photo_id, Rating rating) {
	gboolean result = FALSE;
	PhotoID _tmp0_;
	gint64 _tmp1_;
	Rating _tmp2_;
	gint _tmp3_;
	gboolean _tmp4_;
#line 648 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 648 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, FALSE);
#line 649 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 649 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 649 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = rating;
#line 649 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = rating_serialize (_tmp2_);
#line 649 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = database_table_update_int_by_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, "rating", _tmp3_);
#line 649 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp4_;
#line 649 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 4934 "PhotoTable.c"
}


gint photo_table_get_event_photo_count (PhotoTable* self, EventID* event_id) {
	gint result = 0;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	sqlite3_stmt* _tmp4_;
	EventID _tmp5_;
	gint64 _tmp6_;
	gint _tmp7_;
	gint _tmp8_;
	gint count = 0;
#line 652 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), 0);
#line 652 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (event_id != NULL, 0);
#line 654 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 654 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "SELECT id FROM PhotoTable WHERE event_id = ?", -1, &_tmp1_, NULL);
#line 654 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 654 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 654 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 655 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 655 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 657 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 657 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = *event_id;
#line 657 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = _tmp5_.id;
#line 657 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = sqlite3_bind_int64 (_tmp4_, 1, _tmp6_);
#line 657 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp7_;
#line 658 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = res;
#line 658 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp8_ == SQLITE_OK, "res == Sqlite.OK");
#line 660 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	count = 0;
#line 4986 "PhotoTable.c"
	{
		gboolean _tmp9_ = FALSE;
#line 661 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp9_ = TRUE;
#line 661 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		while (TRUE) {
#line 4993 "PhotoTable.c"
			sqlite3_stmt* _tmp10_;
			gint _tmp11_;
			gint _tmp12_;
			gint _tmp15_;
#line 661 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (!_tmp9_) {
#line 5000 "PhotoTable.c"
			}
#line 661 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp9_ = FALSE;
#line 662 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp10_ = stmt;
#line 662 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp11_ = sqlite3_step (_tmp10_);
#line 662 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			res = _tmp11_;
#line 663 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp12_ = res;
#line 663 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (_tmp12_ == SQLITE_DONE) {
#line 664 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				break;
#line 5016 "PhotoTable.c"
			} else {
				gint _tmp13_;
#line 665 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp13_ = res;
#line 665 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				if (_tmp13_ != SQLITE_ROW) {
#line 5023 "PhotoTable.c"
					gint _tmp14_;
#line 666 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp14_ = res;
#line 666 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					database_table_fatal ("get_event_photo_count", _tmp14_);
#line 668 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					break;
#line 5031 "PhotoTable.c"
				}
			}
#line 671 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp15_ = count;
#line 671 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			count = _tmp15_ + 1;
#line 5038 "PhotoTable.c"
		}
	}
#line 674 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = count;
#line 674 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 674 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 5047 "PhotoTable.c"
}


GeeArrayList* photo_table_get_event_source_ids (PhotoTable* self, EventID* event_id) {
	GeeArrayList* result = NULL;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	sqlite3_stmt* _tmp4_;
	EventID _tmp5_;
	gint64 _tmp6_;
	gint _tmp7_;
	gint _tmp8_;
	GeeArrayList* _result_ = NULL;
	GeeArrayList* _tmp9_;
#line 677 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), NULL);
#line 677 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (event_id != NULL, NULL);
#line 679 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 679 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "SELECT id FROM PhotoTable WHERE event_id = ?", -1, &_tmp1_, NULL);
#line 679 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 679 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 679 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 680 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 680 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 682 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 682 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = *event_id;
#line 682 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = _tmp5_.id;
#line 682 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = sqlite3_bind_int64 (_tmp4_, 1, _tmp6_);
#line 682 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp7_;
#line 683 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = res;
#line 683 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp8_ == SQLITE_OK, "res == Sqlite.OK");
#line 685 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL);
#line 685 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_result_ = _tmp9_;
#line 5102 "PhotoTable.c"
	{
		gboolean _tmp10_ = FALSE;
#line 686 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp10_ = TRUE;
#line 686 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		while (TRUE) {
#line 5109 "PhotoTable.c"
			sqlite3_stmt* _tmp11_;
			gint _tmp12_;
			gint _tmp13_;
			GeeArrayList* _tmp16_;
			sqlite3_stmt* _tmp17_;
			gint64 _tmp18_;
			PhotoID _tmp19_ = {0};
			gchar* _tmp20_;
			gchar* _tmp21_;
#line 686 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (!_tmp10_) {
#line 5121 "PhotoTable.c"
			}
#line 686 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp10_ = FALSE;
#line 687 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp11_ = stmt;
#line 687 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp12_ = sqlite3_step (_tmp11_);
#line 687 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			res = _tmp12_;
#line 688 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp13_ = res;
#line 688 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (_tmp13_ == SQLITE_DONE) {
#line 689 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				break;
#line 5137 "PhotoTable.c"
			} else {
				gint _tmp14_;
#line 690 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp14_ = res;
#line 690 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				if (_tmp14_ != SQLITE_ROW) {
#line 5144 "PhotoTable.c"
					gint _tmp15_;
#line 691 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp15_ = res;
#line 691 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					database_table_fatal ("get_event_source_ids", _tmp15_);
#line 693 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					break;
#line 5152 "PhotoTable.c"
				}
			}
#line 696 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp16_ = _result_;
#line 696 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp17_ = stmt;
#line 696 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp18_ = sqlite3_column_int64 (_tmp17_, 0);
#line 696 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			photo_id_init (&_tmp19_, _tmp18_);
#line 696 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp20_ = photo_id_upgrade_photo_id_to_source_id (&_tmp19_);
#line 696 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp21_ = _tmp20_;
#line 696 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp21_);
#line 696 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_free0 (_tmp21_);
#line 5171 "PhotoTable.c"
		}
	}
#line 699 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _result_;
#line 699 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 699 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 5180 "PhotoTable.c"
}


gboolean photo_table_event_has_photos (PhotoTable* self, EventID* event_id) {
	gboolean result = FALSE;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	sqlite3_stmt* _tmp4_;
	EventID _tmp5_;
	gint64 _tmp6_;
	gint _tmp7_;
	gint _tmp8_;
	sqlite3_stmt* _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
#line 702 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 702 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (event_id != NULL, FALSE);
#line 704 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 704 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "SELECT id FROM PhotoTable WHERE event_id = ? LIMIT 1", -1, &_tmp1_, NULL);
#line 704 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 704 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 704 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 705 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 705 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 707 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 707 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = *event_id;
#line 707 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = _tmp5_.id;
#line 707 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = sqlite3_bind_int64 (_tmp4_, 1, _tmp6_);
#line 707 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp7_;
#line 708 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = res;
#line 708 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp8_ == SQLITE_OK, "res == Sqlite.OK");
#line 710 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = stmt;
#line 710 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = sqlite3_step (_tmp9_);
#line 710 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp10_;
#line 711 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = res;
#line 711 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp11_ == SQLITE_DONE) {
#line 712 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = FALSE;
#line 712 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_sqlite3_finalize0 (stmt);
#line 712 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 5248 "PhotoTable.c"
	} else {
		gint _tmp12_;
#line 713 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp12_ = res;
#line 713 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_tmp12_ != SQLITE_ROW) {
#line 5255 "PhotoTable.c"
			gint _tmp13_;
#line 714 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp13_ = res;
#line 714 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			database_table_fatal ("event_has_photos", _tmp13_);
#line 716 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			result = FALSE;
#line 716 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_sqlite3_finalize0 (stmt);
#line 716 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return result;
#line 5267 "PhotoTable.c"
		}
	}
#line 719 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = TRUE;
#line 719 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 719 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 5276 "PhotoTable.c"
}


gboolean photo_table_drop_event (PhotoTable* self, EventID* event_id) {
	gboolean result = FALSE;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	sqlite3_stmt* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	sqlite3_stmt* _tmp7_;
	EventID _tmp8_;
	gint64 _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	sqlite3_stmt* _tmp12_;
	gint _tmp13_;
	gint _tmp14_;
#line 722 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 722 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (event_id != NULL, FALSE);
#line 724 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 724 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "UPDATE PhotoTable SET event_id = ? WHERE event_id = ?", -1, &_tmp1_, NULL);
#line 724 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 724 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 724 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 725 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 725 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 727 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 727 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = sqlite3_bind_int64 (_tmp4_, 1, EVENT_ID_INVALID);
#line 727 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp5_;
#line 728 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = res;
#line 728 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp6_ == SQLITE_OK, "res == Sqlite.OK");
#line 729 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = stmt;
#line 729 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = *event_id;
#line 729 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = _tmp8_.id;
#line 729 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = sqlite3_bind_int64 (_tmp7_, 2, _tmp9_);
#line 729 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp10_;
#line 730 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = res;
#line 730 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp11_ == SQLITE_OK, "res == Sqlite.OK");
#line 732 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = stmt;
#line 732 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp13_ = sqlite3_step (_tmp12_);
#line 732 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp13_;
#line 733 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = res;
#line 733 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp14_ != SQLITE_DONE) {
#line 5351 "PhotoTable.c"
		gint _tmp15_;
#line 734 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp15_ = res;
#line 734 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_fatal ("drop_event", _tmp15_);
#line 736 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = FALSE;
#line 736 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_sqlite3_finalize0 (stmt);
#line 736 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 5363 "PhotoTable.c"
	}
#line 739 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = TRUE;
#line 739 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 739 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 5371 "PhotoTable.c"
}


gboolean photo_table_set_event (PhotoTable* self, PhotoID* photo_id, EventID* event_id) {
	gboolean result = FALSE;
	PhotoID _tmp0_;
	gint64 _tmp1_;
	EventID _tmp2_;
	gint64 _tmp3_;
	gboolean _tmp4_;
#line 742 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 742 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, FALSE);
#line 742 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (event_id != NULL, FALSE);
#line 743 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 743 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 743 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = *event_id;
#line 743 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = _tmp2_.id;
#line 743 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = database_table_update_int64_by_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, "event_id", _tmp3_);
#line 743 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp4_;
#line 743 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 5402 "PhotoTable.c"
}


static gchar* photo_table_get_raw_transformations (PhotoTable* self, PhotoID* photo_id) {
	gchar* result = NULL;
	sqlite3_stmt* stmt = NULL;
	PhotoID _tmp0_;
	gint64 _tmp1_;
	sqlite3_stmt* _tmp2_ = NULL;
	gboolean _tmp3_;
	gchar* trans = NULL;
	sqlite3_stmt* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gboolean _tmp7_ = FALSE;
	const gchar* _tmp8_;
#line 746 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), NULL);
#line 746 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, NULL);
#line 748 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 748 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 748 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = database_table_select_by_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, "transformations", &_tmp2_);
#line 748 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 748 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp2_;
#line 748 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (!_tmp3_) {
#line 749 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = NULL;
#line 749 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_sqlite3_finalize0 (stmt);
#line 749 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 5441 "PhotoTable.c"
	}
#line 751 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 751 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = sqlite3_column_text (_tmp4_, 0);
#line 751 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 751 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	trans = _tmp6_;
#line 752 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = trans;
#line 752 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp8_ == NULL) {
#line 752 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp7_ = TRUE;
#line 5457 "PhotoTable.c"
	} else {
		const gchar* _tmp9_;
		gint _tmp10_;
		gint _tmp11_;
#line 752 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp9_ = trans;
#line 752 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp10_ = strlen (_tmp9_);
#line 752 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp11_ = _tmp10_;
#line 752 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp7_ = _tmp11_ == 0;
#line 5470 "PhotoTable.c"
	}
#line 752 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp7_) {
#line 753 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = NULL;
#line 753 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (trans);
#line 753 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_sqlite3_finalize0 (stmt);
#line 753 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 5482 "PhotoTable.c"
	}
#line 755 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = trans;
#line 755 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 755 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 5490 "PhotoTable.c"
}


static gboolean photo_table_set_raw_transformations (PhotoTable* self, PhotoID* photo_id, const gchar* trans) {
	gboolean result = FALSE;
	PhotoID _tmp0_;
	gint64 _tmp1_;
	const gchar* _tmp2_;
	gboolean _tmp3_;
#line 758 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 758 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, FALSE);
#line 758 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (trans != NULL, FALSE);
#line 759 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 759 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 759 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = trans;
#line 759 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = database_table_update_text_by_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, "transformations", _tmp2_);
#line 759 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp3_;
#line 759 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 5518 "PhotoTable.c"
}


gboolean photo_table_set_transformation_state (PhotoTable* self, PhotoID* photo_id, Orientation orientation, GeeHashMap* transformations) {
	gboolean result = FALSE;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	sqlite3_stmt* _tmp4_;
	Orientation _tmp5_;
	gint _tmp6_;
	gint _tmp7_;
	sqlite3_stmt* _tmp8_;
	GeeHashMap* _tmp9_;
	gchar* _tmp10_;
	GDestroyNotify _tmp11_;
	gint _tmp12_;
	gint _tmp13_;
	sqlite3_stmt* _tmp14_;
	PhotoID _tmp15_;
	gint64 _tmp16_;
	gint _tmp17_;
	gint _tmp18_;
	sqlite3_stmt* _tmp19_;
	gint _tmp20_;
	gint _tmp21_;
#line 762 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 762 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, FALSE);
#line 762 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail ((transformations == NULL) || GEE_IS_HASH_MAP (transformations), FALSE);
#line 765 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 765 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "UPDATE PhotoTable SET orientation = ?, transformations = ? WHERE id = " \
"?", -1, &_tmp1_, NULL);
#line 765 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 765 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 765 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 767 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 767 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 769 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 769 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = orientation;
#line 769 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = sqlite3_bind_int (_tmp4_, 1, (gint) _tmp5_);
#line 769 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp6_;
#line 770 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = res;
#line 770 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp7_ == SQLITE_OK, "res == Sqlite.OK");
#line 771 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = stmt;
#line 771 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = transformations;
#line 771 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = photo_table_unmarshall_all_transformations (_tmp9_);
#line 771 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = g_free;
#line 771 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = sqlite3_bind_text (_tmp8_, 2, _tmp10_, -1, _tmp11_);
#line 771 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp12_;
#line 772 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp13_ = res;
#line 772 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp13_ == SQLITE_OK, "res == Sqlite.OK");
#line 773 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = stmt;
#line 773 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_ = *photo_id;
#line 773 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp16_ = _tmp15_.id;
#line 773 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp17_ = sqlite3_bind_int64 (_tmp14_, 3, _tmp16_);
#line 773 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp17_;
#line 774 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp18_ = res;
#line 774 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp18_ == SQLITE_OK, "res == Sqlite.OK");
#line 776 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp19_ = stmt;
#line 776 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp20_ = sqlite3_step (_tmp19_);
#line 776 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp20_;
#line 777 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp21_ = res;
#line 777 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp21_ != SQLITE_DONE) {
#line 5620 "PhotoTable.c"
		gint _tmp22_;
#line 778 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp22_ = res;
#line 778 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_fatal ("set_transformation_state", _tmp22_);
#line 780 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = FALSE;
#line 780 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_sqlite3_finalize0 (stmt);
#line 780 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 5632 "PhotoTable.c"
	}
#line 783 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = TRUE;
#line 783 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 783 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 5640 "PhotoTable.c"
}


GeeHashMap* photo_table_marshall_all_transformations (const gchar* trans) {
	GeeHashMap* result = NULL;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	GError * _inner_error_ = NULL;
#line 787 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = trans;
#line 787 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp1_ == NULL) {
#line 787 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = TRUE;
#line 5655 "PhotoTable.c"
	} else {
		const gchar* _tmp2_;
		gint _tmp3_;
		gint _tmp4_;
#line 787 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp2_ = trans;
#line 787 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp3_ = strlen (_tmp2_);
#line 787 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp4_ = _tmp3_;
#line 787 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = _tmp4_ == 0;
#line 5668 "PhotoTable.c"
	}
#line 787 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp0_) {
#line 788 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = NULL;
#line 788 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 5676 "PhotoTable.c"
	}
	{
		GKeyFile* keyfile = NULL;
		GKeyFile* _tmp5_;
		gboolean _tmp6_ = FALSE;
		GKeyFile* _tmp7_;
		const gchar* _tmp8_;
		const gchar* _tmp9_;
		gint _tmp10_;
		gint _tmp11_;
		gboolean _tmp12_;
		GeeHashMap* map = NULL;
		GeeHashMap* _tmp13_;
		gchar** objects = NULL;
		GKeyFile* _tmp14_;
		gsize _tmp15_;
		gchar** _tmp16_;
		gint objects_length1;
		gint _objects_size_;
		gchar** _tmp17_;
		gint _tmp17__length1;
#line 791 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp5_ = g_key_file_new ();
#line 791 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		keyfile = _tmp5_;
#line 792 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp7_ = keyfile;
#line 792 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp8_ = trans;
#line 792 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp9_ = trans;
#line 792 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp10_ = strlen (_tmp9_);
#line 792 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp11_ = _tmp10_;
#line 792 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp12_ = g_key_file_load_from_data (_tmp7_, _tmp8_, (gsize) _tmp11_, G_KEY_FILE_NONE, &_inner_error_);
#line 792 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp6_ = _tmp12_;
#line 792 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 792 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_key_file_unref0 (keyfile);
#line 5720 "PhotoTable.c"
			goto __catch17_g_error;
		}
#line 792 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (!_tmp6_) {
#line 793 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			result = NULL;
#line 793 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_key_file_unref0 (keyfile);
#line 793 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return result;
#line 5731 "PhotoTable.c"
		}
#line 795 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp13_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TYPE_KEY_VALUE_MAP, (GBoxedCopyFunc) key_value_map_ref, (GDestroyNotify) key_value_map_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 795 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		map = _tmp13_;
#line 797 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp14_ = keyfile;
#line 797 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp16_ = g_key_file_get_groups (_tmp14_, &_tmp15_);
#line 797 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		objects = _tmp16_;
#line 797 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		objects_length1 = _tmp15_;
#line 797 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_objects_size_ = objects_length1;
#line 798 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp17_ = objects;
#line 798 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp17__length1 = objects_length1;
#line 5751 "PhotoTable.c"
		{
			gchar** object_collection = NULL;
			gint object_collection_length1 = 0;
			gint _object_collection_size_ = 0;
			gint object_it = 0;
#line 798 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			object_collection = _tmp17_;
#line 798 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			object_collection_length1 = _tmp17__length1;
#line 798 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			for (object_it = 0; object_it < _tmp17__length1; object_it = object_it + 1) {
#line 5763 "PhotoTable.c"
				gchar* _tmp18_;
				gchar* object = NULL;
#line 798 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp18_ = g_strdup (object_collection[object_it]);
#line 798 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				object = _tmp18_;
#line 5770 "PhotoTable.c"
				{
					gchar** keys = NULL;
					GKeyFile* _tmp19_;
					const gchar* _tmp20_;
					gsize _tmp21_;
					gchar** _tmp22_;
					gint keys_length1;
					gint _keys_size_;
					gboolean _tmp23_ = FALSE;
					gchar** _tmp24_;
					gint _tmp24__length1;
					KeyValueMap* key_map = NULL;
					const gchar* _tmp26_;
					KeyValueMap* _tmp27_;
					GeeHashMap* _tmp43_;
					const gchar* _tmp44_;
					KeyValueMap* _tmp45_;
#line 799 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp19_ = keyfile;
#line 799 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp20_ = object;
#line 799 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp22_ = g_key_file_get_keys (_tmp19_, _tmp20_, &_tmp21_, &_inner_error_);
#line 799 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					keys = _tmp22_;
#line 799 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					keys_length1 = _tmp21_;
#line 799 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_keys_size_ = keys_length1;
#line 799 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 799 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
						_g_free0 (object);
#line 799 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
						objects = (_vala_array_free (objects, objects_length1, (GDestroyNotify) g_free), NULL);
#line 799 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
						_g_object_unref0 (map);
#line 799 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
						_g_key_file_unref0 (keyfile);
#line 5810 "PhotoTable.c"
						goto __catch17_g_error;
					}
#line 800 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp24_ = keys;
#line 800 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp24__length1 = keys_length1;
#line 800 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					if (_tmp24_ == NULL) {
#line 800 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
						_tmp23_ = TRUE;
#line 5821 "PhotoTable.c"
					} else {
						gchar** _tmp25_;
						gint _tmp25__length1;
#line 800 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
						_tmp25_ = keys;
#line 800 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
						_tmp25__length1 = keys_length1;
#line 800 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
						_tmp23_ = _tmp25__length1 == 0;
#line 5831 "PhotoTable.c"
					}
#line 800 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					if (_tmp23_) {
#line 801 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
						keys = (_vala_array_free (keys, keys_length1, (GDestroyNotify) g_free), NULL);
#line 801 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
						_g_free0 (object);
#line 801 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
						continue;
#line 5841 "PhotoTable.c"
					}
#line 803 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp26_ = object;
#line 803 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp27_ = key_value_map_new (_tmp26_);
#line 803 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					key_map = _tmp27_;
#line 5849 "PhotoTable.c"
					{
						gint ctr = 0;
#line 804 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
						ctr = 0;
#line 5854 "PhotoTable.c"
						{
							gboolean _tmp28_ = FALSE;
#line 804 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
							_tmp28_ = TRUE;
#line 804 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
							while (TRUE) {
#line 5861 "PhotoTable.c"
								gint _tmp30_;
								gchar** _tmp31_;
								gint _tmp31__length1;
								gchar* _tmp32_ = NULL;
								GKeyFile* _tmp33_;
								const gchar* _tmp34_;
								gchar** _tmp35_;
								gint _tmp35__length1;
								gint _tmp36_;
								const gchar* _tmp37_;
								gchar* _tmp38_;
								KeyValueMap* _tmp39_;
								gchar** _tmp40_;
								gint _tmp40__length1;
								gint _tmp41_;
								const gchar* _tmp42_;
#line 804 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								if (!_tmp28_) {
#line 5880 "PhotoTable.c"
									gint _tmp29_;
#line 804 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
									_tmp29_ = ctr;
#line 804 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
									ctr = _tmp29_ + 1;
#line 5886 "PhotoTable.c"
								}
#line 804 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp28_ = FALSE;
#line 804 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp30_ = ctr;
#line 804 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp31_ = keys;
#line 804 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp31__length1 = keys_length1;
#line 804 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								if (!(_tmp30_ < _tmp31__length1)) {
#line 804 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
									break;
#line 5900 "PhotoTable.c"
								}
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp33_ = keyfile;
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp34_ = object;
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp35_ = keys;
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp35__length1 = keys_length1;
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp36_ = ctr;
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp37_ = _tmp35_[_tmp36_];
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp38_ = g_key_file_get_string (_tmp33_, _tmp34_, _tmp37_, &_inner_error_);
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp32_ = _tmp38_;
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
									_key_value_map_unref0 (key_map);
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
									keys = (_vala_array_free (keys, keys_length1, (GDestroyNotify) g_free), NULL);
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
									_g_free0 (object);
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
									objects = (_vala_array_free (objects, objects_length1, (GDestroyNotify) g_free), NULL);
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
									_g_object_unref0 (map);
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
									_g_key_file_unref0 (keyfile);
#line 5932 "PhotoTable.c"
									goto __catch17_g_error;
								}
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp39_ = key_map;
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp40_ = keys;
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp40__length1 = keys_length1;
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp41_ = ctr;
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_tmp42_ = _tmp40_[_tmp41_];
#line 805 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								key_value_map_set_string (_tmp39_, _tmp42_, _tmp32_);
#line 804 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
								_g_free0 (_tmp32_);
#line 5949 "PhotoTable.c"
							}
						}
					}
#line 807 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp43_ = map;
#line 807 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp44_ = object;
#line 807 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp45_ = key_map;
#line 807 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp44_, _tmp45_);
#line 798 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_key_value_map_unref0 (key_map);
#line 798 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					keys = (_vala_array_free (keys, keys_length1, (GDestroyNotify) g_free), NULL);
#line 798 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_g_free0 (object);
#line 5967 "PhotoTable.c"
				}
			}
		}
#line 810 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = map;
#line 810 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		objects = (_vala_array_free (objects, objects_length1, (GDestroyNotify) g_free), NULL);
#line 810 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_key_file_unref0 (keyfile);
#line 810 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 5979 "PhotoTable.c"
	}
	goto __finally17;
	__catch17_g_error:
	{
		GError* err = NULL;
		const gchar* _tmp46_;
#line 790 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		err = _inner_error_;
#line 790 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_inner_error_ = NULL;
#line 812 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp46_ = err->message;
#line 812 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_error ("PhotoTable.vala:812: %s", _tmp46_);
#line 790 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_error_free0 (err);
#line 5996 "PhotoTable.c"
	}
	__finally17:
#line 790 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 790 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_clear_error (&_inner_error_);
#line 790 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return NULL;
#line 6005 "PhotoTable.c"
}


gchar* photo_table_unmarshall_all_transformations (GeeHashMap* transformations) {
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	GeeHashMap* _tmp1_;
	GKeyFile* keyfile = NULL;
	GKeyFile* _tmp8_;
	gsize length = 0UL;
	gchar* unmarshalled = NULL;
	GKeyFile* _tmp39_;
	gsize _tmp40_ = 0UL;
	gchar* _tmp41_;
	const gchar* _tmp42_;
	const gchar* _tmp43_;
	gint _tmp44_;
	gint _tmp45_;
#line 816 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail ((transformations == NULL) || GEE_IS_HASH_MAP (transformations), NULL);
#line 817 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = transformations;
#line 817 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp1_ == NULL) {
#line 817 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = TRUE;
#line 6032 "PhotoTable.c"
	} else {
		GeeHashMap* _tmp2_;
		GeeSet* _tmp3_;
		GeeSet* _tmp4_;
		GeeSet* _tmp5_;
		gint _tmp6_;
		gint _tmp7_;
#line 817 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp2_ = transformations;
#line 817 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp3_ = gee_abstract_map_get_keys (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap));
#line 817 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp4_ = _tmp3_;
#line 817 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp5_ = _tmp4_;
#line 817 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp6_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GEE_TYPE_COLLECTION, GeeCollection));
#line 817 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp7_ = _tmp6_;
#line 817 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = _tmp7_ == 0;
#line 817 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_object_unref0 (_tmp5_);
#line 6056 "PhotoTable.c"
	}
#line 817 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp0_) {
#line 818 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = NULL;
#line 818 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 6064 "PhotoTable.c"
	}
#line 820 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = g_key_file_new ();
#line 820 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	keyfile = _tmp8_;
#line 6070 "PhotoTable.c"
	{
		GeeIterator* _object_it = NULL;
		GeeHashMap* _tmp9_;
		GeeSet* _tmp10_;
		GeeSet* _tmp11_;
		GeeSet* _tmp12_;
		GeeIterator* _tmp13_;
		GeeIterator* _tmp14_;
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp9_ = transformations;
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp10_ = gee_abstract_map_get_keys (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap));
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp11_ = _tmp10_;
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp12_ = _tmp11_;
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp13_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_ITERABLE, GeeIterable));
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp14_ = _tmp13_;
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_object_unref0 (_tmp12_);
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_object_it = _tmp14_;
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		while (TRUE) {
#line 6097 "PhotoTable.c"
			GeeIterator* _tmp15_;
			gboolean _tmp16_;
			gchar* object = NULL;
			GeeIterator* _tmp17_;
			gpointer _tmp18_;
			KeyValueMap* map = NULL;
			GeeHashMap* _tmp19_;
			const gchar* _tmp20_;
			gpointer _tmp21_;
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp15_ = _object_it;
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp16_ = gee_iterator_next (_tmp15_);
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (!_tmp16_) {
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				break;
#line 6115 "PhotoTable.c"
			}
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp17_ = _object_it;
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp18_ = gee_iterator_get (_tmp17_);
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			object = (gchar*) _tmp18_;
#line 823 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp19_ = transformations;
#line 823 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp20_ = object;
#line 823 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp21_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp20_);
#line 823 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			map = (KeyValueMap*) _tmp21_;
#line 6131 "PhotoTable.c"
			{
				GeeIterator* _key_it = NULL;
				KeyValueMap* _tmp22_;
				GeeSet* _tmp23_;
				GeeSet* _tmp24_;
				GeeIterator* _tmp25_;
				GeeIterator* _tmp26_;
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp22_ = map;
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp23_ = key_value_map_get_keys (_tmp22_);
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp24_ = _tmp23_;
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp25_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, GEE_TYPE_ITERABLE, GeeIterable));
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp26_ = _tmp25_;
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_g_object_unref0 (_tmp24_);
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_key_it = _tmp26_;
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				while (TRUE) {
#line 6155 "PhotoTable.c"
					GeeIterator* _tmp27_;
					gboolean _tmp28_;
					gchar* key = NULL;
					GeeIterator* _tmp29_;
					gpointer _tmp30_;
					gchar* value = NULL;
					KeyValueMap* _tmp31_;
					const gchar* _tmp32_;
					gchar* _tmp33_;
					const gchar* _tmp34_;
					GKeyFile* _tmp35_;
					const gchar* _tmp36_;
					const gchar* _tmp37_;
					const gchar* _tmp38_;
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp27_ = _key_it;
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp28_ = gee_iterator_next (_tmp27_);
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					if (!_tmp28_) {
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
						break;
#line 6178 "PhotoTable.c"
					}
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp29_ = _key_it;
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp30_ = gee_iterator_get (_tmp29_);
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					key = (gchar*) _tmp30_;
#line 826 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp31_ = map;
#line 826 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp32_ = key;
#line 826 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp33_ = key_value_map_get_string (_tmp31_, _tmp32_, NULL);
#line 826 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					value = _tmp33_;
#line 827 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp34_ = value;
#line 827 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_vala_assert (_tmp34_ != NULL, "value != null");
#line 829 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp35_ = keyfile;
#line 829 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp36_ = object;
#line 829 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp37_ = key;
#line 829 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_tmp38_ = value;
#line 829 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					g_key_file_set_string (_tmp35_, _tmp36_, _tmp37_, _tmp38_);
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_g_free0 (value);
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_g_free0 (key);
#line 6212 "PhotoTable.c"
				}
#line 825 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_g_object_unref0 (_key_it);
#line 6216 "PhotoTable.c"
			}
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_key_value_map_unref0 (map);
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_free0 (object);
#line 6222 "PhotoTable.c"
		}
#line 822 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_object_unref0 (_object_it);
#line 6226 "PhotoTable.c"
	}
#line 834 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp39_ = keyfile;
#line 834 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp41_ = g_key_file_to_data (_tmp39_, &_tmp40_, NULL);
#line 834 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	length = _tmp40_;
#line 834 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	unmarshalled = _tmp41_;
#line 835 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp42_ = unmarshalled;
#line 835 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp42_ != NULL, "unmarshalled != null");
#line 836 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp43_ = unmarshalled;
#line 836 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp44_ = strlen (_tmp43_);
#line 836 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp45_ = _tmp44_;
#line 836 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp45_ > 0, "unmarshalled.length > 0");
#line 838 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = unmarshalled;
#line 838 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_key_file_unref0 (keyfile);
#line 838 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 6254 "PhotoTable.c"
}


gboolean photo_table_set_transformation (PhotoTable* self, PhotoID* photo_id, KeyValueMap* map) {
	gboolean result = FALSE;
	gchar* trans = NULL;
	PhotoID _tmp0_;
	gchar* _tmp1_;
	PhotoID _tmp38_;
	const gchar* _tmp39_;
	gboolean _tmp40_;
	GError * _inner_error_ = NULL;
#line 841 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 841 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, FALSE);
#line 841 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_KEY_VALUE_MAP (map), FALSE);
#line 842 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 842 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = photo_table_get_raw_transformations (self, &_tmp0_);
#line 842 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	trans = _tmp1_;
#line 6279 "PhotoTable.c"
	{
		GKeyFile* keyfile = NULL;
		GKeyFile* _tmp2_;
		const gchar* _tmp3_;
		GeeSet* keys = NULL;
		KeyValueMap* _tmp11_;
		GeeSet* _tmp12_;
		gsize length = 0UL;
		GKeyFile* _tmp29_;
		gsize _tmp30_ = 0UL;
		gchar* _tmp31_;
		const gchar* _tmp32_;
		const gchar* _tmp33_;
		gint _tmp34_;
		gint _tmp35_;
#line 845 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp2_ = g_key_file_new ();
#line 845 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		keyfile = _tmp2_;
#line 846 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp3_ = trans;
#line 846 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_tmp3_ != NULL) {
#line 6303 "PhotoTable.c"
			gboolean _tmp4_ = FALSE;
			GKeyFile* _tmp5_;
			const gchar* _tmp6_;
			const gchar* _tmp7_;
			gint _tmp8_;
			gint _tmp9_;
			gboolean _tmp10_;
#line 847 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp5_ = keyfile;
#line 847 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp6_ = trans;
#line 847 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp7_ = trans;
#line 847 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp8_ = strlen (_tmp7_);
#line 847 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp9_ = _tmp8_;
#line 847 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp10_ = g_key_file_load_from_data (_tmp5_, _tmp6_, (gsize) _tmp9_, G_KEY_FILE_NONE, &_inner_error_);
#line 847 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp4_ = _tmp10_;
#line 847 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 847 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_g_key_file_unref0 (keyfile);
#line 6329 "PhotoTable.c"
				goto __catch18_g_error;
			}
#line 847 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (!_tmp4_) {
#line 848 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				result = FALSE;
#line 848 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_g_key_file_unref0 (keyfile);
#line 848 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_g_free0 (trans);
#line 848 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				return result;
#line 6342 "PhotoTable.c"
			}
		}
#line 851 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp11_ = map;
#line 851 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp12_ = key_value_map_get_keys (_tmp11_);
#line 851 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		keys = _tmp12_;
#line 6351 "PhotoTable.c"
		{
			GeeIterator* _key_it = NULL;
			GeeSet* _tmp13_;
			GeeIterator* _tmp14_;
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp13_ = keys;
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp14_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GEE_TYPE_ITERABLE, GeeIterable));
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_key_it = _tmp14_;
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			while (TRUE) {
#line 6364 "PhotoTable.c"
				GeeIterator* _tmp15_;
				gboolean _tmp16_;
				gchar* key = NULL;
				GeeIterator* _tmp17_;
				gpointer _tmp18_;
				gchar* value = NULL;
				KeyValueMap* _tmp19_;
				const gchar* _tmp20_;
				gchar* _tmp21_;
				const gchar* _tmp22_;
				GKeyFile* _tmp23_;
				KeyValueMap* _tmp24_;
				gchar* _tmp25_;
				gchar* _tmp26_;
				const gchar* _tmp27_;
				const gchar* _tmp28_;
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp15_ = _key_it;
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp16_ = gee_iterator_next (_tmp15_);
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				if (!_tmp16_) {
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					break;
#line 6389 "PhotoTable.c"
				}
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp17_ = _key_it;
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp18_ = gee_iterator_get (_tmp17_);
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				key = (gchar*) _tmp18_;
#line 853 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp19_ = map;
#line 853 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp20_ = key;
#line 853 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp21_ = key_value_map_get_string (_tmp19_, _tmp20_, NULL);
#line 853 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				value = _tmp21_;
#line 854 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp22_ = value;
#line 854 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_vala_assert (_tmp22_ != NULL, "value != null");
#line 856 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp23_ = keyfile;
#line 856 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp24_ = map;
#line 856 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp25_ = key_value_map_get_group (_tmp24_);
#line 856 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp26_ = _tmp25_;
#line 856 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp27_ = key;
#line 856 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp28_ = value;
#line 856 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_key_file_set_string (_tmp23_, _tmp26_, _tmp27_, _tmp28_);
#line 856 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_g_free0 (_tmp26_);
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_g_free0 (value);
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_g_free0 (key);
#line 6429 "PhotoTable.c"
			}
#line 852 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_object_unref0 (_key_it);
#line 6433 "PhotoTable.c"
		}
#line 860 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp29_ = keyfile;
#line 860 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp31_ = g_key_file_to_data (_tmp29_, &_tmp30_, NULL);
#line 860 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		length = _tmp30_;
#line 860 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (trans);
#line 860 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		trans = _tmp31_;
#line 861 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp32_ = trans;
#line 861 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_vala_assert (_tmp32_ != NULL, "trans != null");
#line 862 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp33_ = trans;
#line 862 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp34_ = strlen (_tmp33_);
#line 862 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp35_ = _tmp34_;
#line 862 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_vala_assert (_tmp35_ > 0, "trans.length > 0");
#line 844 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_object_unref0 (keys);
#line 844 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_key_file_unref0 (keyfile);
#line 6461 "PhotoTable.c"
	}
	goto __finally18;
	__catch18_g_error:
	{
		GError* err = NULL;
		const gchar* _tmp36_;
#line 844 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		err = _inner_error_;
#line 844 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_inner_error_ = NULL;
#line 864 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp36_ = err->message;
#line 864 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_error ("PhotoTable.vala:864: %s", _tmp36_);
#line 844 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_error_free0 (err);
#line 6478 "PhotoTable.c"
	}
	__finally18:
#line 844 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6483 "PhotoTable.c"
		gboolean _tmp37_ = FALSE;
#line 844 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (trans);
#line 844 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 844 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_clear_error (&_inner_error_);
#line 844 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return _tmp37_;
#line 6493 "PhotoTable.c"
	}
#line 867 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp38_ = *photo_id;
#line 867 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp39_ = trans;
#line 867 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp40_ = photo_table_set_raw_transformations (self, &_tmp38_, _tmp39_);
#line 867 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp40_;
#line 867 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (trans);
#line 867 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 6507 "PhotoTable.c"
}


gboolean photo_table_remove_transformation (PhotoTable* self, PhotoID* photo_id, const gchar* object) {
	gboolean result = FALSE;
	gchar* trans = NULL;
	PhotoID _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	PhotoID _tmp22_;
	const gchar* _tmp23_;
	gboolean _tmp24_;
	GError * _inner_error_ = NULL;
#line 870 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 870 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, FALSE);
#line 870 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (object != NULL, FALSE);
#line 871 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 871 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = photo_table_get_raw_transformations (self, &_tmp0_);
#line 871 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	trans = _tmp1_;
#line 872 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = trans;
#line 872 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp2_ == NULL) {
#line 873 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = TRUE;
#line 873 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (trans);
#line 873 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 6543 "PhotoTable.c"
	}
	{
		GKeyFile* keyfile = NULL;
		GKeyFile* _tmp3_;
		gboolean _tmp4_ = FALSE;
		GKeyFile* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		gboolean _tmp10_;
		GKeyFile* _tmp11_;
		const gchar* _tmp12_;
		gboolean _tmp13_;
		GKeyFile* _tmp14_;
		const gchar* _tmp15_;
		gsize length = 0UL;
		GKeyFile* _tmp16_;
		gsize _tmp17_ = 0UL;
		gchar* _tmp18_;
		const gchar* _tmp19_;
#line 876 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp3_ = g_key_file_new ();
#line 876 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		keyfile = _tmp3_;
#line 877 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp5_ = keyfile;
#line 877 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp6_ = trans;
#line 877 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp7_ = trans;
#line 877 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp8_ = strlen (_tmp7_);
#line 877 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp9_ = _tmp8_;
#line 877 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp10_ = g_key_file_load_from_data (_tmp5_, _tmp6_, (gsize) _tmp9_, G_KEY_FILE_NONE, &_inner_error_);
#line 877 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp4_ = _tmp10_;
#line 877 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 877 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_key_file_unref0 (keyfile);
#line 6587 "PhotoTable.c"
			goto __catch19_g_error;
		}
#line 877 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (!_tmp4_) {
#line 878 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			result = FALSE;
#line 878 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_key_file_unref0 (keyfile);
#line 878 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_free0 (trans);
#line 878 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return result;
#line 6600 "PhotoTable.c"
		}
#line 880 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp11_ = keyfile;
#line 880 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp12_ = object;
#line 880 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp13_ = g_key_file_has_group (_tmp11_, _tmp12_);
#line 880 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (!_tmp13_) {
#line 881 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			result = TRUE;
#line 881 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_key_file_unref0 (keyfile);
#line 881 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_free0 (trans);
#line 881 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return result;
#line 6618 "PhotoTable.c"
		}
#line 883 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp14_ = keyfile;
#line 883 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp15_ = object;
#line 883 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_key_file_remove_group (_tmp14_, _tmp15_, &_inner_error_);
#line 883 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 883 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_key_file_unref0 (keyfile);
#line 6630 "PhotoTable.c"
			goto __catch19_g_error;
		}
#line 886 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp16_ = keyfile;
#line 886 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp18_ = g_key_file_to_data (_tmp16_, &_tmp17_, NULL);
#line 886 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		length = _tmp17_;
#line 886 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (trans);
#line 886 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		trans = _tmp18_;
#line 887 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp19_ = trans;
#line 887 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_vala_assert (_tmp19_ != NULL, "trans != null");
#line 875 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_key_file_unref0 (keyfile);
#line 6649 "PhotoTable.c"
	}
	goto __finally19;
	__catch19_g_error:
	{
		GError* err = NULL;
		const gchar* _tmp20_;
#line 875 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		err = _inner_error_;
#line 875 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_inner_error_ = NULL;
#line 889 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp20_ = err->message;
#line 889 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_error ("PhotoTable.vala:889: %s", _tmp20_);
#line 875 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_error_free0 (err);
#line 6666 "PhotoTable.c"
	}
	__finally19:
#line 875 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6671 "PhotoTable.c"
		gboolean _tmp21_ = FALSE;
#line 875 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (trans);
#line 875 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 875 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_clear_error (&_inner_error_);
#line 875 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return _tmp21_;
#line 6681 "PhotoTable.c"
	}
#line 892 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp22_ = *photo_id;
#line 892 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp23_ = trans;
#line 892 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp24_ = photo_table_set_raw_transformations (self, &_tmp22_, _tmp23_);
#line 892 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp24_;
#line 892 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (trans);
#line 892 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 6695 "PhotoTable.c"
}


gboolean photo_table_remove_all_transformations (PhotoTable* self, PhotoID* photo_id) {
	gboolean result = FALSE;
	PhotoID _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gboolean _tmp3_;
	PhotoID _tmp4_;
	gint64 _tmp5_;
	gboolean _tmp6_;
#line 895 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 895 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (photo_id != NULL, FALSE);
#line 896 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *photo_id;
#line 896 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = photo_table_get_raw_transformations (self, &_tmp0_);
#line 896 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = _tmp1_;
#line 896 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = _tmp2_ == NULL;
#line 896 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (_tmp2_);
#line 896 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp3_) {
#line 897 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = FALSE;
#line 897 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 6728 "PhotoTable.c"
	}
#line 899 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = *photo_id;
#line 899 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = _tmp4_.id;
#line 899 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = database_table_update_text_by_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp5_, "transformations", "");
#line 899 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp6_;
#line 899 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 6740 "PhotoTable.c"
}


static sqlite3_stmt* photo_table_get_duplicate_stmt (PhotoTable* self, GFile* file, const gchar* thumbnail_md5, const gchar* md5, PhotoFileFormat file_format) {
	sqlite3_stmt* result = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GFile* _tmp2_;
	gchar* sql = NULL;
	gchar* _tmp5_;
	gboolean first = FALSE;
	GFile* _tmp6_;
	gboolean _tmp9_ = FALSE;
	const gchar* _tmp10_;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp33_;
	const gchar* _tmp34_;
	sqlite3_stmt* _tmp35_ = NULL;
	gint _tmp36_;
	gint _tmp37_;
	gint col = 0;
	GFile* _tmp38_;
	const gchar* _tmp46_;
	const gchar* _tmp54_;
	gboolean _tmp62_ = FALSE;
	gboolean _tmp63_ = FALSE;
	const gchar* _tmp64_;
#line 904 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), NULL);
#line 904 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail ((file == NULL) || G_IS_FILE (file), NULL);
#line 906 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = file;
#line 906 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp2_ != NULL) {
#line 906 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp1_ = TRUE;
#line 6779 "PhotoTable.c"
	} else {
		const gchar* _tmp3_;
#line 906 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp3_ = thumbnail_md5;
#line 906 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp1_ = _tmp3_ != NULL;
#line 6786 "PhotoTable.c"
	}
#line 906 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp1_) {
#line 906 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = TRUE;
#line 6792 "PhotoTable.c"
	} else {
		const gchar* _tmp4_;
#line 906 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp4_ = md5;
#line 906 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = _tmp4_ != NULL;
#line 6799 "PhotoTable.c"
	}
#line 906 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp0_, "file != null || thumbnail_md5 != null || md5 != null");
#line 908 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = g_strdup ("SELECT id FROM PhotoTable WHERE");
#line 908 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	sql = _tmp5_;
#line 909 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	first = TRUE;
#line 911 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = file;
#line 911 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp6_ != NULL) {
#line 6813 "PhotoTable.c"
		const gchar* _tmp7_;
		gchar* _tmp8_;
#line 912 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp7_ = sql;
#line 912 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp8_ = g_strconcat (_tmp7_, " filename=?", NULL);
#line 912 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (sql);
#line 912 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		sql = _tmp8_;
#line 913 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		first = FALSE;
#line 6826 "PhotoTable.c"
	}
#line 916 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = thumbnail_md5;
#line 916 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp10_ != NULL) {
#line 916 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp9_ = TRUE;
#line 6834 "PhotoTable.c"
	} else {
		const gchar* _tmp11_;
#line 916 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp11_ = md5;
#line 916 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp9_ = _tmp11_ != NULL;
#line 6841 "PhotoTable.c"
	}
#line 916 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp9_) {
#line 6845 "PhotoTable.c"
		gboolean _tmp12_;
		const gchar* _tmp17_;
		const gchar* _tmp20_;
		const gchar* _tmp26_;
		gchar* _tmp27_;
		PhotoFileFormat _tmp28_;
		const gchar* _tmp31_;
		gchar* _tmp32_;
#line 917 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp12_ = first;
#line 917 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_tmp12_) {
#line 6858 "PhotoTable.c"
			const gchar* _tmp13_;
			gchar* _tmp14_;
#line 918 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp13_ = sql;
#line 918 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp14_ = g_strconcat (_tmp13_, " ((", NULL);
#line 918 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_free0 (sql);
#line 918 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			sql = _tmp14_;
#line 6869 "PhotoTable.c"
		} else {
			const gchar* _tmp15_;
			gchar* _tmp16_;
#line 920 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp15_ = sql;
#line 920 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp16_ = g_strconcat (_tmp15_, " OR ((", NULL);
#line 920 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_free0 (sql);
#line 920 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			sql = _tmp16_;
#line 6881 "PhotoTable.c"
		}
#line 921 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		first = FALSE;
#line 923 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp17_ = md5;
#line 923 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_tmp17_ != NULL) {
#line 6889 "PhotoTable.c"
			const gchar* _tmp18_;
			gchar* _tmp19_;
#line 924 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp18_ = sql;
#line 924 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp19_ = g_strconcat (_tmp18_, " md5=?", NULL);
#line 924 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_free0 (sql);
#line 924 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			sql = _tmp19_;
#line 6900 "PhotoTable.c"
		}
#line 927 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp20_ = thumbnail_md5;
#line 927 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_tmp20_ != NULL) {
#line 6906 "PhotoTable.c"
			const gchar* _tmp21_;
#line 928 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp21_ = md5;
#line 928 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (_tmp21_ == NULL) {
#line 6912 "PhotoTable.c"
				const gchar* _tmp22_;
				gchar* _tmp23_;
#line 929 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp22_ = sql;
#line 929 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp23_ = g_strconcat (_tmp22_, " thumbnail_md5=?", NULL);
#line 929 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_g_free0 (sql);
#line 929 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				sql = _tmp23_;
#line 6923 "PhotoTable.c"
			} else {
				const gchar* _tmp24_;
				gchar* _tmp25_;
#line 931 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp24_ = sql;
#line 931 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_tmp25_ = g_strconcat (_tmp24_, " OR (md5 IS NULL AND thumbnail_md5=?)", NULL);
#line 931 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_g_free0 (sql);
#line 931 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				sql = _tmp25_;
#line 6935 "PhotoTable.c"
			}
		}
#line 934 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp26_ = sql;
#line 934 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp27_ = g_strconcat (_tmp26_, ")", NULL);
#line 934 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (sql);
#line 934 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		sql = _tmp27_;
#line 936 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp28_ = file_format;
#line 936 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_tmp28_ != PHOTO_FILE_FORMAT_UNKNOWN) {
#line 6950 "PhotoTable.c"
			const gchar* _tmp29_;
			gchar* _tmp30_;
#line 937 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp29_ = sql;
#line 937 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp30_ = g_strconcat (_tmp29_, " AND file_format=?", NULL);
#line 937 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_free0 (sql);
#line 937 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			sql = _tmp30_;
#line 6961 "PhotoTable.c"
		}
#line 939 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp31_ = sql;
#line 939 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp32_ = g_strconcat (_tmp31_, ")", NULL);
#line 939 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (sql);
#line 939 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		sql = _tmp32_;
#line 6971 "PhotoTable.c"
	}
#line 943 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp33_ = database_table_db;
#line 943 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp34_ = sql;
#line 943 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp36_ = sqlite3_prepare_v2 (_tmp33_, _tmp34_, -1, &_tmp35_, NULL);
#line 943 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 943 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp35_;
#line 943 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp36_;
#line 944 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp37_ = res;
#line 944 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp37_ == SQLITE_OK, "res == Sqlite.OK");
#line 946 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	col = 1;
#line 948 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp38_ = file;
#line 948 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp38_ != NULL) {
#line 6995 "PhotoTable.c"
		sqlite3_stmt* _tmp39_;
		gint _tmp40_;
		GFile* _tmp41_;
		gchar* _tmp42_;
		GDestroyNotify _tmp43_;
		gint _tmp44_;
		gint _tmp45_;
#line 949 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp39_ = stmt;
#line 949 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp40_ = col;
#line 949 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		col = _tmp40_ + 1;
#line 949 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp41_ = file;
#line 949 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp42_ = g_file_get_path (_tmp41_);
#line 949 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp43_ = g_free;
#line 949 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp44_ = sqlite3_bind_text (_tmp39_, _tmp40_, _tmp42_, -1, _tmp43_);
#line 949 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		res = _tmp44_;
#line 950 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp45_ = res;
#line 950 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_vala_assert (_tmp45_ == SQLITE_OK, "res == Sqlite.OK");
#line 7023 "PhotoTable.c"
	}
#line 953 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp46_ = thumbnail_md5;
#line 953 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp46_ != NULL) {
#line 7029 "PhotoTable.c"
		sqlite3_stmt* _tmp47_;
		gint _tmp48_;
		const gchar* _tmp49_;
		gchar* _tmp50_;
		GDestroyNotify _tmp51_;
		gint _tmp52_;
		gint _tmp53_;
#line 954 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp47_ = stmt;
#line 954 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp48_ = col;
#line 954 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		col = _tmp48_ + 1;
#line 954 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp49_ = thumbnail_md5;
#line 954 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp50_ = g_strdup (_tmp49_);
#line 954 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp51_ = g_free;
#line 954 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp52_ = sqlite3_bind_text (_tmp47_, _tmp48_, _tmp50_, -1, _tmp51_);
#line 954 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		res = _tmp52_;
#line 955 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp53_ = res;
#line 955 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_vala_assert (_tmp53_ == SQLITE_OK, "res == Sqlite.OK");
#line 7057 "PhotoTable.c"
	}
#line 958 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp54_ = md5;
#line 958 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp54_ != NULL) {
#line 7063 "PhotoTable.c"
		sqlite3_stmt* _tmp55_;
		gint _tmp56_;
		const gchar* _tmp57_;
		gchar* _tmp58_;
		GDestroyNotify _tmp59_;
		gint _tmp60_;
		gint _tmp61_;
#line 959 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp55_ = stmt;
#line 959 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp56_ = col;
#line 959 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		col = _tmp56_ + 1;
#line 959 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp57_ = md5;
#line 959 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp58_ = g_strdup (_tmp57_);
#line 959 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp59_ = g_free;
#line 959 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp60_ = sqlite3_bind_text (_tmp55_, _tmp56_, _tmp58_, -1, _tmp59_);
#line 959 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		res = _tmp60_;
#line 960 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp61_ = res;
#line 960 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_vala_assert (_tmp61_ == SQLITE_OK, "res == Sqlite.OK");
#line 7091 "PhotoTable.c"
	}
#line 963 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp64_ = thumbnail_md5;
#line 963 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp64_ != NULL) {
#line 963 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp63_ = TRUE;
#line 7099 "PhotoTable.c"
	} else {
		const gchar* _tmp65_;
#line 963 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp65_ = md5;
#line 963 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp63_ = _tmp65_ != NULL;
#line 7106 "PhotoTable.c"
	}
#line 963 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp63_) {
#line 7110 "PhotoTable.c"
		PhotoFileFormat _tmp66_;
#line 963 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp66_ = file_format;
#line 963 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp62_ = _tmp66_ != PHOTO_FILE_FORMAT_UNKNOWN;
#line 7116 "PhotoTable.c"
	} else {
#line 963 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp62_ = FALSE;
#line 7120 "PhotoTable.c"
	}
#line 963 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp62_) {
#line 7124 "PhotoTable.c"
		sqlite3_stmt* _tmp67_;
		gint _tmp68_;
		PhotoFileFormat _tmp69_;
		gint _tmp70_;
		gint _tmp71_;
		gint _tmp72_;
#line 964 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp67_ = stmt;
#line 964 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp68_ = col;
#line 964 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		col = _tmp68_ + 1;
#line 964 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp69_ = file_format;
#line 964 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp70_ = photo_file_format_serialize (_tmp69_);
#line 964 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp71_ = sqlite3_bind_int (_tmp67_, _tmp68_, _tmp70_);
#line 964 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		res = _tmp71_;
#line 965 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp72_ = res;
#line 965 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_vala_assert (_tmp72_ == SQLITE_OK, "res == Sqlite.OK");
#line 7149 "PhotoTable.c"
	}
#line 968 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = stmt;
#line 968 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (sql);
#line 968 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 7157 "PhotoTable.c"
}


gboolean photo_table_has_duplicate (PhotoTable* self, GFile* file, const gchar* thumbnail_md5, const gchar* md5, PhotoFileFormat file_format) {
	gboolean result = FALSE;
	sqlite3_stmt* stmt = NULL;
	GFile* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	PhotoFileFormat _tmp3_;
	sqlite3_stmt* _tmp4_;
	gint res = 0;
	sqlite3_stmt* _tmp5_;
	gint _tmp6_;
	gint _tmp7_;
#line 971 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), FALSE);
#line 971 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail ((file == NULL) || G_IS_FILE (file), FALSE);
#line 972 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = file;
#line 972 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = thumbnail_md5;
#line 972 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = md5;
#line 972 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = file_format;
#line 972 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = photo_table_get_duplicate_stmt (self, _tmp0_, _tmp1_, _tmp2_, _tmp3_);
#line 972 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp4_;
#line 973 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = stmt;
#line 973 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = sqlite3_step (_tmp5_);
#line 973 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp6_;
#line 975 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = res;
#line 975 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp7_ == SQLITE_DONE) {
#line 977 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = FALSE;
#line 977 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_sqlite3_finalize0 (stmt);
#line 977 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 7205 "PhotoTable.c"
	} else {
		gint _tmp8_;
#line 978 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp8_ = res;
#line 978 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_tmp8_ == SQLITE_ROW) {
#line 980 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			result = TRUE;
#line 980 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_sqlite3_finalize0 (stmt);
#line 980 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return result;
#line 7218 "PhotoTable.c"
		} else {
			gint _tmp9_;
#line 982 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp9_ = res;
#line 982 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			database_table_fatal ("has_duplicate", _tmp9_);
#line 984 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			result = FALSE;
#line 984 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_sqlite3_finalize0 (stmt);
#line 984 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return result;
#line 7231 "PhotoTable.c"
		}
	}
#line 971 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 7236 "PhotoTable.c"
}


static void _vala_array_add2 (PhotoID* * array, int* length, int* size, const PhotoID* value) {
#line 996 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if ((*length) == (*size)) {
#line 996 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 996 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		*array = g_renew (PhotoID, *array, *size);
#line 7247 "PhotoTable.c"
	}
#line 996 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	(*array)[(*length)++] = *value;
#line 7251 "PhotoTable.c"
}


PhotoID* photo_table_get_duplicate_ids (PhotoTable* self, GFile* file, const gchar* thumbnail_md5, const gchar* md5, PhotoFileFormat file_format, int* result_length1) {
	PhotoID* result = NULL;
	sqlite3_stmt* stmt = NULL;
	GFile* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	PhotoFileFormat _tmp3_;
	sqlite3_stmt* _tmp4_;
	PhotoID* ids = NULL;
	PhotoID* _tmp5_;
	gint ids_length1;
	gint _ids_size_;
	gint res = 0;
	sqlite3_stmt* _tmp6_;
	gint _tmp7_;
	PhotoID* _tmp15_;
	gint _tmp15__length1;
#line 988 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_PHOTO_TABLE (self), NULL);
#line 988 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail ((file == NULL) || G_IS_FILE (file), NULL);
#line 990 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = file;
#line 990 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = thumbnail_md5;
#line 990 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = md5;
#line 990 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = file_format;
#line 990 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = photo_table_get_duplicate_stmt (self, _tmp0_, _tmp1_, _tmp2_, _tmp3_);
#line 990 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp4_;
#line 992 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = g_new0 (PhotoID, 0);
#line 992 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	ids = _tmp5_;
#line 992 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	ids_length1 = 0;
#line 992 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_ids_size_ = ids_length1;
#line 994 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = stmt;
#line 994 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = sqlite3_step (_tmp6_);
#line 994 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp7_;
#line 995 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	while (TRUE) {
#line 7304 "PhotoTable.c"
		gint _tmp8_;
		PhotoID* _tmp9_;
		gint _tmp9__length1;
		sqlite3_stmt* _tmp10_;
		gint64 _tmp11_;
		PhotoID _tmp12_ = {0};
		sqlite3_stmt* _tmp13_;
		gint _tmp14_;
#line 995 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp8_ = res;
#line 995 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (!(_tmp8_ == SQLITE_ROW)) {
#line 995 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			break;
#line 7319 "PhotoTable.c"
		}
#line 996 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp9_ = ids;
#line 996 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp9__length1 = ids_length1;
#line 996 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp10_ = stmt;
#line 996 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp11_ = sqlite3_column_int64 (_tmp10_, 0);
#line 996 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		photo_id_init (&_tmp12_, _tmp11_);
#line 996 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_vala_array_add2 (&ids, &ids_length1, &_ids_size_, &_tmp12_);
#line 997 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp13_ = stmt;
#line 997 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp14_ = sqlite3_step (_tmp13_);
#line 997 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		res = _tmp14_;
#line 7339 "PhotoTable.c"
	}
#line 1000 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_ = ids;
#line 1000 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15__length1 = ids_length1;
#line 1000 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (result_length1) {
#line 1000 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		*result_length1 = _tmp15__length1;
#line 7349 "PhotoTable.c"
	}
#line 1000 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp15_;
#line 1000 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 1000 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 7357 "PhotoTable.c"
}


void photo_table_update_backlinks (PhotoTable* self, PhotoID* photo_id, const gchar* backlinks, GError** error) {
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_;
	PhotoID _tmp3_;
	gint64 _tmp4_;
	GError * _inner_error_ = NULL;
#line 1003 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 1003 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (photo_id != NULL);
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = backlinks;
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp1_ != NULL) {
#line 7375 "PhotoTable.c"
		const gchar* _tmp2_;
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp2_ = backlinks;
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = _tmp2_;
#line 7381 "PhotoTable.c"
	} else {
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = "";
#line 7385 "PhotoTable.c"
	}
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = *photo_id;
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = _tmp3_.id;
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_update_text_by_id_2 (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp4_, "backlinks", _tmp0_, &_inner_error_);
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_propagate_error (error, _inner_error_);
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 7401 "PhotoTable.c"
		} else {
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_clear_error (&_inner_error_);
#line 1004 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 7409 "PhotoTable.c"
		}
	}
}


void photo_table_attach_editable (PhotoTable* self, PhotoRow* row, BackingPhotoID* editable_id, GError** error) {
	PhotoRow* _tmp0_;
	PhotoID _tmp1_;
	gint64 _tmp2_;
	BackingPhotoID _tmp3_;
	gint64 _tmp4_;
	PhotoRow* _tmp5_;
	BackingPhotoID _tmp6_;
	GError * _inner_error_ = NULL;
#line 1007 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 1007 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_ROW (row));
#line 1007 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (editable_id != NULL);
#line 1008 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = row;
#line 1008 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_->photo_id;
#line 1008 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = _tmp1_.id;
#line 1008 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = *editable_id;
#line 1008 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = _tmp3_.id;
#line 1008 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_update_int64_by_id_2 (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp2_, "editable_id", _tmp4_, &_inner_error_);
#line 1008 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1008 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 1008 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_propagate_error (error, _inner_error_);
#line 1008 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 7450 "PhotoTable.c"
		} else {
#line 1008 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1008 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_clear_error (&_inner_error_);
#line 1008 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 7458 "PhotoTable.c"
		}
	}
#line 1010 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = row;
#line 1010 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = *editable_id;
#line 1010 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_->editable_id = _tmp6_;
#line 7467 "PhotoTable.c"
}


void photo_table_detach_editable (PhotoTable* self, PhotoRow* row, GError** error) {
	PhotoRow* _tmp0_;
	PhotoID _tmp1_;
	gint64 _tmp2_;
	PhotoRow* _tmp3_;
	GError * _inner_error_ = NULL;
#line 1013 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 1013 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_ROW (row));
#line 1014 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = row;
#line 1014 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_->photo_id;
#line 1014 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = _tmp1_.id;
#line 1014 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_update_int64_by_id_2 (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp2_, "editable_id", BACKING_PHOTO_ID_INVALID, &_inner_error_);
#line 1014 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1014 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 1014 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_propagate_error (error, _inner_error_);
#line 1014 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 7497 "PhotoTable.c"
		} else {
#line 1014 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1014 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_clear_error (&_inner_error_);
#line 1014 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 7505 "PhotoTable.c"
		}
	}
#line 1016 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = row;
#line 1016 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	backing_photo_id_init (&_tmp3_->editable_id, BACKING_PHOTO_ID_INVALID);
#line 7512 "PhotoTable.c"
}


void photo_table_set_metadata_dirty (PhotoTable* self, PhotoID* photo_id, gboolean dirty, GError** error) {
	gint _tmp0_ = 0;
	gboolean _tmp1_;
	PhotoID _tmp2_;
	gint64 _tmp3_;
	GError * _inner_error_ = NULL;
#line 1019 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 1019 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (photo_id != NULL);
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = dirty;
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp1_) {
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = 1;
#line 7532 "PhotoTable.c"
	} else {
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp0_ = 0;
#line 7536 "PhotoTable.c"
	}
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = *photo_id;
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = _tmp2_.id;
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_update_int_by_id_2 (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp3_, "metadata_dirty", _tmp0_, &_inner_error_);
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_propagate_error (error, _inner_error_);
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 7552 "PhotoTable.c"
		} else {
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_clear_error (&_inner_error_);
#line 1020 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 7560 "PhotoTable.c"
		}
	}
}


void photo_table_update_raw_development (PhotoTable* self, PhotoRow* row, RawDeveloper rd, BackingPhotoID* backing_photo_id, GError** error) {
	gchar* col = NULL;
	RawDeveloper _tmp0_;
	PhotoRow* _tmp4_;
	BackingPhotoID* _tmp5_;
	gint _tmp5__length1;
	RawDeveloper _tmp6_;
	BackingPhotoID _tmp7_;
	BackingPhotoID _tmp8_;
	PhotoRow* _tmp9_;
	PhotoID _tmp10_;
	gint64 _tmp11_;
	const gchar* _tmp12_;
	BackingPhotoID _tmp13_;
	gint64 _tmp14_;
	BackingPhotoID _tmp15_;
	gint64 _tmp16_;
	GError * _inner_error_ = NULL;
#line 1023 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 1023 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_ROW (row));
#line 1023 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (backing_photo_id != NULL);
#line 1027 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = rd;
#line 1027 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	switch (_tmp0_) {
#line 1027 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		case RAW_DEVELOPER_SHOTWELL:
#line 7596 "PhotoTable.c"
		{
			gchar* _tmp1_;
#line 1029 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp1_ = g_strdup ("develop_shotwell_id");
#line 1029 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_free0 (col);
#line 1029 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			col = _tmp1_;
#line 1030 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			break;
#line 7607 "PhotoTable.c"
		}
#line 1027 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		case RAW_DEVELOPER_CAMERA:
#line 7611 "PhotoTable.c"
		{
			gchar* _tmp2_;
#line 1033 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp2_ = g_strdup ("develop_camera_id");
#line 1033 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_free0 (col);
#line 1033 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			col = _tmp2_;
#line 1034 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			break;
#line 7622 "PhotoTable.c"
		}
#line 1027 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		case RAW_DEVELOPER_EMBEDDED:
#line 7626 "PhotoTable.c"
		{
			gchar* _tmp3_;
#line 1037 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp3_ = g_strdup ("develop_embedded_id");
#line 1037 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_free0 (col);
#line 1037 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			col = _tmp3_;
#line 1038 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			break;
#line 7637 "PhotoTable.c"
		}
		default:
		{
#line 1041 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_assert_not_reached ();
#line 7643 "PhotoTable.c"
		}
	}
#line 1044 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = row;
#line 1044 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = _tmp4_->development_ids;
#line 1044 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5__length1 = _tmp4_->development_ids_length1;
#line 1044 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = rd;
#line 1044 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = *backing_photo_id;
#line 1044 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_[_tmp6_] = _tmp7_;
#line 1044 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = _tmp5_[_tmp6_];
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = row;
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = _tmp9_->photo_id;
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = _tmp10_.id;
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = col;
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp13_ = *backing_photo_id;
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = _tmp13_.id;
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_update_int64_by_id_2 (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp11_, _tmp12_, _tmp14_, &_inner_error_);
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_propagate_error (error, _inner_error_);
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_free0 (col);
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 7684 "PhotoTable.c"
		} else {
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_g_free0 (col);
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_clear_error (&_inner_error_);
#line 1045 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 7694 "PhotoTable.c"
		}
	}
#line 1047 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_ = *backing_photo_id;
#line 1047 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp16_ = _tmp15_.id;
#line 1047 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp16_ != BACKING_PHOTO_ID_INVALID) {
#line 7703 "PhotoTable.c"
		PhotoRow* _tmp17_;
		PhotoID _tmp18_;
		gint64 _tmp19_;
		RawDeveloper _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp17_ = row;
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp18_ = _tmp17_->photo_id;
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp19_ = _tmp18_.id;
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp20_ = rd;
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp21_ = raw_developer_to_string (_tmp20_);
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp22_ = _tmp21_;
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_update_text_by_id_2 (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp19_, "developer", _tmp22_, &_inner_error_);
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_g_free0 (_tmp22_);
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_propagate_error (error, _inner_error_);
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_g_free0 (col);
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				return;
#line 7736 "PhotoTable.c"
			} else {
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_g_free0 (col);
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_clear_error (&_inner_error_);
#line 1048 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				return;
#line 7746 "PhotoTable.c"
			}
		}
	}
#line 1023 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (col);
#line 7752 "PhotoTable.c"
}


void photo_table_remove_development (PhotoTable* self, PhotoRow* row, RawDeveloper rd, GError** error) {
	PhotoRow* _tmp0_;
	RawDeveloper _tmp1_;
	BackingPhotoID _tmp2_ = {0};
	GError * _inner_error_ = NULL;
#line 1051 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_TABLE (self));
#line 1051 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_PHOTO_ROW (row));
#line 1052 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = row;
#line 1052 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = rd;
#line 1052 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	backing_photo_id_init (&_tmp2_, BACKING_PHOTO_ID_INVALID);
#line 1052 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	photo_table_update_raw_development (self, _tmp0_, _tmp1_, &_tmp2_, &_inner_error_);
#line 1052 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1052 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 1052 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_propagate_error (error, _inner_error_);
#line 1052 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 7781 "PhotoTable.c"
		} else {
#line 1052 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1052 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_clear_error (&_inner_error_);
#line 1052 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 7789 "PhotoTable.c"
		}
	}
}


static void photo_table_class_init (PhotoTableClass * klass) {
#line 109 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	photo_table_parent_class = g_type_class_peek_parent (klass);
#line 109 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	((DatabaseTableClass *) klass)->finalize = photo_table_finalize;
#line 7800 "PhotoTable.c"
}


static void photo_table_instance_init (PhotoTable * self) {
}


static void photo_table_finalize (DatabaseTable * obj) {
	PhotoTable * self;
#line 109 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PHOTO_TABLE, PhotoTable);
#line 109 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	DATABASE_TABLE_CLASS (photo_table_parent_class)->finalize (obj);
#line 7814 "PhotoTable.c"
}


GType photo_table_get_type (void) {
	static volatile gsize photo_table_type_id__volatile = 0;
	if (g_once_init_enter (&photo_table_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PhotoTableClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) photo_table_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PhotoTable), 0, (GInstanceInitFunc) photo_table_instance_init, NULL };
		GType photo_table_type_id;
		photo_table_type_id = g_type_register_static (TYPE_DATABASE_TABLE, "PhotoTable", &g_define_type_info, 0);
		g_once_init_leave (&photo_table_type_id__volatile, photo_table_type_id);
	}
	return photo_table_type_id__volatile;
}


void backing_photo_id_init (BackingPhotoID *self, gint64 id) {
	gint64 _tmp0_;
#line 1072 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	memset (self, 0, sizeof (BackingPhotoID));
#line 1073 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = id;
#line 1073 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	(*self).id = _tmp0_;
#line 7838 "PhotoTable.c"
}


gboolean backing_photo_id_is_invalid (BackingPhotoID *self) {
	gboolean result = FALSE;
	gint64 _tmp0_;
#line 1077 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = (*self).id;
#line 1077 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp0_ == BACKING_PHOTO_ID_INVALID;
#line 1077 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 7851 "PhotoTable.c"
}


gboolean backing_photo_id_is_valid (BackingPhotoID *self) {
	gboolean result = FALSE;
	gint64 _tmp0_;
#line 1081 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = (*self).id;
#line 1081 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp0_ != BACKING_PHOTO_ID_INVALID;
#line 1081 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 7864 "PhotoTable.c"
}


BackingPhotoID* backing_photo_id_dup (const BackingPhotoID* self) {
	BackingPhotoID* dup;
#line 1067 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	dup = g_new0 (BackingPhotoID, 1);
#line 1067 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	memcpy (dup, self, sizeof (BackingPhotoID));
#line 1067 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return dup;
#line 7876 "PhotoTable.c"
}


void backing_photo_id_free (BackingPhotoID* self) {
#line 1067 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_free (self);
#line 7883 "PhotoTable.c"
}


GType backing_photo_id_get_type (void) {
	static volatile gsize backing_photo_id_type_id__volatile = 0;
	if (g_once_init_enter (&backing_photo_id_type_id__volatile)) {
		GType backing_photo_id_type_id;
		backing_photo_id_type_id = g_boxed_type_register_static ("BackingPhotoID", (GBoxedCopyFunc) backing_photo_id_dup, (GBoxedFreeFunc) backing_photo_id_free);
		g_once_init_leave (&backing_photo_id_type_id__volatile, backing_photo_id_type_id);
	}
	return backing_photo_id_type_id__volatile;
}


gboolean backing_photo_row_matches_file_info (BackingPhotoRow* self, GFileInfo* info) {
	gboolean result = FALSE;
	gint64 _tmp0_;
	GFileInfo* _tmp1_;
	gint64 _tmp2_;
	time_t _tmp3_;
	GFileInfo* _tmp4_;
	GTimeVal _tmp5_ = {0};
	glong _tmp6_;
#line 1095 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_BACKING_PHOTO_ROW (self), FALSE);
#line 1095 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (G_IS_FILE_INFO (info), FALSE);
#line 1096 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = self->filesize;
#line 1096 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = info;
#line 1096 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = g_file_info_get_size (_tmp1_);
#line 1096 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp0_ != _tmp2_) {
#line 1097 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = FALSE;
#line 1097 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 7923 "PhotoTable.c"
	}
#line 1099 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = self->timestamp;
#line 1099 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = info;
#line 1099 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_file_info_get_modification_time (_tmp4_, &_tmp5_);
#line 1099 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = _tmp5_.tv_sec;
#line 1099 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp3_ == ((time_t) _tmp6_);
#line 1099 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 7937 "PhotoTable.c"
}


gboolean backing_photo_row_is_touched (BackingPhotoRow* self, GFileInfo* info) {
	gboolean result = FALSE;
	gint64 _tmp0_;
	GFileInfo* _tmp1_;
	gint64 _tmp2_;
	time_t _tmp3_;
	GFileInfo* _tmp4_;
	GTimeVal _tmp5_ = {0};
	glong _tmp6_;
#line 1102 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_BACKING_PHOTO_ROW (self), FALSE);
#line 1102 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (G_IS_FILE_INFO (info), FALSE);
#line 1103 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = self->filesize;
#line 1103 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = info;
#line 1103 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = g_file_info_get_size (_tmp1_);
#line 1103 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp0_ != _tmp2_) {
#line 1104 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = FALSE;
#line 1104 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 7966 "PhotoTable.c"
	}
#line 1106 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = self->timestamp;
#line 1106 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = info;
#line 1106 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_file_info_get_modification_time (_tmp4_, &_tmp5_);
#line 1106 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = _tmp5_.tv_sec;
#line 1106 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp3_ != ((time_t) _tmp6_);
#line 1106 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 7980 "PhotoTable.c"
}


void backing_photo_row_copy_from (BackingPhotoRow* self, BackingPhotoRow* from) {
	BackingPhotoRow* _tmp0_;
	BackingPhotoID _tmp1_;
	BackingPhotoRow* _tmp2_;
	time_t _tmp3_;
	BackingPhotoRow* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	BackingPhotoRow* _tmp7_;
	gint64 _tmp8_;
	BackingPhotoRow* _tmp9_;
	time_t _tmp10_;
	BackingPhotoRow* _tmp11_;
	PhotoFileFormat _tmp12_;
	BackingPhotoRow* _tmp13_;
	Dimensions _tmp14_;
	BackingPhotoRow* _tmp15_;
	Orientation _tmp16_;
#line 1110 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_BACKING_PHOTO_ROW (self));
#line 1110 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_BACKING_PHOTO_ROW (from));
#line 1111 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = from;
#line 1111 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_->id;
#line 1111 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->id = _tmp1_;
#line 1112 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = from;
#line 1112 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = _tmp2_->time_created;
#line 1112 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->time_created = _tmp3_;
#line 1113 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = from;
#line 1113 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = _tmp4_->filepath;
#line 1113 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 1113 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (self->filepath);
#line 1113 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->filepath = _tmp6_;
#line 1114 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = from;
#line 1114 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = _tmp7_->filesize;
#line 1114 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->filesize = _tmp8_;
#line 1115 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = from;
#line 1115 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = _tmp9_->timestamp;
#line 1115 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->timestamp = _tmp10_;
#line 1116 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = from;
#line 1116 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = _tmp11_->file_format;
#line 1116 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->file_format = _tmp12_;
#line 1117 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp13_ = from;
#line 1117 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = _tmp13_->dim;
#line 1117 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->dim = _tmp14_;
#line 1118 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_ = from;
#line 1118 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp16_ = _tmp15_->original_orientation;
#line 1118 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->original_orientation = _tmp16_;
#line 8058 "PhotoTable.c"
}


BackingPhotoRow* backing_photo_row_construct (GType object_type) {
	BackingPhotoRow* self = NULL;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self = (BackingPhotoRow*) g_type_create_instance (object_type);
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return self;
#line 8068 "PhotoTable.c"
}


BackingPhotoRow* backing_photo_row_new (void) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return backing_photo_row_construct (TYPE_BACKING_PHOTO_ROW);
#line 8075 "PhotoTable.c"
}


static void value_backing_photo_row_init (GValue* value) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	value->data[0].v_pointer = NULL;
#line 8082 "PhotoTable.c"
}


static void value_backing_photo_row_free_value (GValue* value) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (value->data[0].v_pointer) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		backing_photo_row_unref (value->data[0].v_pointer);
#line 8091 "PhotoTable.c"
	}
}


static void value_backing_photo_row_copy_value (const GValue* src_value, GValue* dest_value) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (src_value->data[0].v_pointer) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		dest_value->data[0].v_pointer = backing_photo_row_ref (src_value->data[0].v_pointer);
#line 8101 "PhotoTable.c"
	} else {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		dest_value->data[0].v_pointer = NULL;
#line 8105 "PhotoTable.c"
	}
}


static gpointer value_backing_photo_row_peek_pointer (const GValue* value) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return value->data[0].v_pointer;
#line 8113 "PhotoTable.c"
}


static gchar* value_backing_photo_row_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (collect_values[0].v_pointer) {
#line 8120 "PhotoTable.c"
		BackingPhotoRow * object;
		object = collect_values[0].v_pointer;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (object->parent_instance.g_class == NULL) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 8127 "PhotoTable.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 8131 "PhotoTable.c"
		}
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		value->data[0].v_pointer = backing_photo_row_ref (object);
#line 8135 "PhotoTable.c"
	} else {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		value->data[0].v_pointer = NULL;
#line 8139 "PhotoTable.c"
	}
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return NULL;
#line 8143 "PhotoTable.c"
}


static gchar* value_backing_photo_row_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	BackingPhotoRow ** object_p;
	object_p = collect_values[0].v_pointer;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (!object_p) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 8154 "PhotoTable.c"
	}
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (!value->data[0].v_pointer) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		*object_p = NULL;
#line 8160 "PhotoTable.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		*object_p = value->data[0].v_pointer;
#line 8164 "PhotoTable.c"
	} else {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		*object_p = backing_photo_row_ref (value->data[0].v_pointer);
#line 8168 "PhotoTable.c"
	}
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return NULL;
#line 8172 "PhotoTable.c"
}


GParamSpec* param_spec_backing_photo_row (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecBackingPhotoRow* spec;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_BACKING_PHOTO_ROW), NULL);
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return G_PARAM_SPEC (spec);
#line 8186 "PhotoTable.c"
}


gpointer value_get_backing_photo_row (const GValue* value) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_BACKING_PHOTO_ROW), NULL);
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return value->data[0].v_pointer;
#line 8195 "PhotoTable.c"
}


void value_set_backing_photo_row (GValue* value, gpointer v_object) {
	BackingPhotoRow * old;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_BACKING_PHOTO_ROW));
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	old = value->data[0].v_pointer;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (v_object) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_BACKING_PHOTO_ROW));
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		value->data[0].v_pointer = v_object;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		backing_photo_row_ref (value->data[0].v_pointer);
#line 8215 "PhotoTable.c"
	} else {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		value->data[0].v_pointer = NULL;
#line 8219 "PhotoTable.c"
	}
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (old) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		backing_photo_row_unref (old);
#line 8225 "PhotoTable.c"
	}
}


void value_take_backing_photo_row (GValue* value, gpointer v_object) {
	BackingPhotoRow * old;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_BACKING_PHOTO_ROW));
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	old = value->data[0].v_pointer;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (v_object) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_BACKING_PHOTO_ROW));
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		value->data[0].v_pointer = v_object;
#line 8244 "PhotoTable.c"
	} else {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		value->data[0].v_pointer = NULL;
#line 8248 "PhotoTable.c"
	}
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (old) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		backing_photo_row_unref (old);
#line 8254 "PhotoTable.c"
	}
}


static void backing_photo_row_class_init (BackingPhotoRowClass * klass) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	backing_photo_row_parent_class = g_type_class_peek_parent (klass);
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	((BackingPhotoRowClass *) klass)->finalize = backing_photo_row_finalize;
#line 8264 "PhotoTable.c"
}


static void backing_photo_row_instance_init (BackingPhotoRow * self) {
#line 1088 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->filepath = NULL;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self->ref_count = 1;
#line 8273 "PhotoTable.c"
}


static void backing_photo_row_finalize (BackingPhotoRow * obj) {
	BackingPhotoRow * self;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_BACKING_PHOTO_ROW, BackingPhotoRow);
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_signal_handlers_destroy (self);
#line 1088 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (self->filepath);
#line 8285 "PhotoTable.c"
}


GType backing_photo_row_get_type (void) {
	static volatile gsize backing_photo_row_type_id__volatile = 0;
	if (g_once_init_enter (&backing_photo_row_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_backing_photo_row_init, value_backing_photo_row_free_value, value_backing_photo_row_copy_value, value_backing_photo_row_peek_pointer, "p", value_backing_photo_row_collect_value, "p", value_backing_photo_row_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (BackingPhotoRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) backing_photo_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BackingPhotoRow), 0, (GInstanceInitFunc) backing_photo_row_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType backing_photo_row_type_id;
		backing_photo_row_type_id = g_type_register_fundamental (g_type_fundamental_next (), "BackingPhotoRow", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&backing_photo_row_type_id__volatile, backing_photo_row_type_id);
	}
	return backing_photo_row_type_id__volatile;
}


gpointer backing_photo_row_ref (gpointer instance) {
	BackingPhotoRow * self;
	self = instance;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_atomic_int_inc (&self->ref_count);
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return instance;
#line 8310 "PhotoTable.c"
}


void backing_photo_row_unref (gpointer instance) {
	BackingPhotoRow * self;
	self = instance;
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		BACKING_PHOTO_ROW_GET_CLASS (self)->finalize (self);
#line 1085 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 8323 "PhotoTable.c"
	}
}


static BackingPhotoTable* backing_photo_table_construct (GType object_type) {
	BackingPhotoTable* self = NULL;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	sqlite3_stmt* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
#line 1125 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self = (BackingPhotoTable*) database_table_construct (object_type);
#line 1126 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_set_table_name (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), "BackingPhotoTable");
#line 1129 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 1129 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "CREATE TABLE IF NOT EXISTS " "BackingPhotoTable " "(" "id INTEGER PRIMARY KEY, " "filepath TEXT UNIQUE NOT NULL, " "timestamp INTEGER, " "filesize INTEGER, " "width INTEGER, " "height INTEGER, " "original_orientation INTEGER, " "file_format INTEGER, " "time_created INTEGER " ")", -1, &_tmp1_, NULL);
#line 1129 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 1129 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 1129 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 1142 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 1142 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 1144 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 1144 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = sqlite3_step (_tmp4_);
#line 1144 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp5_;
#line 1145 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = res;
#line 1145 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp6_ != SQLITE_DONE) {
#line 8367 "PhotoTable.c"
		gint _tmp7_;
#line 1146 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp7_ = res;
#line 1146 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_fatal ("create PhotoBackingTable", _tmp7_);
#line 8373 "PhotoTable.c"
	}
#line 1125 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 1125 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return self;
#line 8379 "PhotoTable.c"
}


static BackingPhotoTable* backing_photo_table_new (void) {
#line 1125 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return backing_photo_table_construct (TYPE_BACKING_PHOTO_TABLE);
#line 8386 "PhotoTable.c"
}


BackingPhotoTable* backing_photo_table_get_instance (void) {
	BackingPhotoTable* result = NULL;
	BackingPhotoTable* _tmp0_;
	BackingPhotoTable* _tmp2_;
	BackingPhotoTable* _tmp3_;
#line 1150 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = backing_photo_table_instance;
#line 1150 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp0_ == NULL) {
#line 8399 "PhotoTable.c"
		BackingPhotoTable* _tmp1_;
#line 1151 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp1_ = backing_photo_table_new ();
#line 1151 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_database_table_unref0 (backing_photo_table_instance);
#line 1151 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		backing_photo_table_instance = _tmp1_;
#line 8407 "PhotoTable.c"
	}
#line 1153 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = backing_photo_table_instance;
#line 1153 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = _database_table_ref0 (_tmp2_);
#line 1153 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = _tmp3_;
#line 1153 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 8417 "PhotoTable.c"
}


void backing_photo_table_add (BackingPhotoTable* self, BackingPhotoRow* state, GError** error) {
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	time_t time_created = 0;
	gulong _tmp4_;
	sqlite3_stmt* _tmp5_;
	BackingPhotoRow* _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	GDestroyNotify _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	sqlite3_stmt* _tmp12_;
	BackingPhotoRow* _tmp13_;
	time_t _tmp14_;
	gint _tmp15_;
	gint _tmp16_;
	sqlite3_stmt* _tmp17_;
	BackingPhotoRow* _tmp18_;
	gint64 _tmp19_;
	gint _tmp20_;
	gint _tmp21_;
	sqlite3_stmt* _tmp22_;
	BackingPhotoRow* _tmp23_;
	Dimensions _tmp24_;
	gint _tmp25_;
	gint _tmp26_;
	gint _tmp27_;
	sqlite3_stmt* _tmp28_;
	BackingPhotoRow* _tmp29_;
	Dimensions _tmp30_;
	gint _tmp31_;
	gint _tmp32_;
	gint _tmp33_;
	sqlite3_stmt* _tmp34_;
	BackingPhotoRow* _tmp35_;
	Orientation _tmp36_;
	gint _tmp37_;
	gint _tmp38_;
	sqlite3_stmt* _tmp39_;
	BackingPhotoRow* _tmp40_;
	PhotoFileFormat _tmp41_;
	gint _tmp42_;
	gint _tmp43_;
	gint _tmp44_;
	sqlite3_stmt* _tmp45_;
	time_t _tmp46_;
	gint _tmp47_;
	gint _tmp48_;
	sqlite3_stmt* _tmp49_;
	gint _tmp50_;
	gint _tmp51_;
	BackingPhotoRow* _tmp53_;
	sqlite3* _tmp54_;
	gint64 _tmp55_;
	BackingPhotoRow* _tmp56_;
	time_t _tmp57_;
	GError * _inner_error_ = NULL;
#line 1156 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_BACKING_PHOTO_TABLE (self));
#line 1156 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_BACKING_PHOTO_ROW (state));
#line 1158 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 1158 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "INSERT INTO BackingPhotoTable " "(filepath, timestamp, filesize, width, height, original_orientation, " "file_format, time_created) " "VALUES (?, ?, ?, ?, ?, ?, ?, ?)", -1, &_tmp1_, NULL);
#line 1158 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 1158 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 1158 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 1163 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 1163 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 1165 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = now_sec ();
#line 1165 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	time_created = (time_t) _tmp4_;
#line 1167 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = stmt;
#line 1167 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = state;
#line 1167 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = _tmp6_->filepath;
#line 1167 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = g_strdup (_tmp7_);
#line 1167 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = g_free;
#line 1167 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = sqlite3_bind_text (_tmp5_, 1, _tmp8_, -1, _tmp9_);
#line 1167 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp10_;
#line 1168 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = res;
#line 1168 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp11_ == SQLITE_OK, "res == Sqlite.OK");
#line 1169 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = stmt;
#line 1169 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp13_ = state;
#line 1169 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = _tmp13_->timestamp;
#line 1169 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_ = sqlite3_bind_int64 (_tmp12_, 2, (gint64) _tmp14_);
#line 1169 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp15_;
#line 1170 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp16_ = res;
#line 1170 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp16_ == SQLITE_OK, "res == Sqlite.OK");
#line 1171 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp17_ = stmt;
#line 1171 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp18_ = state;
#line 1171 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp19_ = _tmp18_->filesize;
#line 1171 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp20_ = sqlite3_bind_int64 (_tmp17_, 3, _tmp19_);
#line 1171 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp20_;
#line 1172 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp21_ = res;
#line 1172 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp21_ == SQLITE_OK, "res == Sqlite.OK");
#line 1173 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp22_ = stmt;
#line 1173 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp23_ = state;
#line 1173 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp24_ = _tmp23_->dim;
#line 1173 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp25_ = _tmp24_.width;
#line 1173 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp26_ = sqlite3_bind_int (_tmp22_, 4, _tmp25_);
#line 1173 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp26_;
#line 1174 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp27_ = res;
#line 1174 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp27_ == SQLITE_OK, "res == Sqlite.OK");
#line 1175 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp28_ = stmt;
#line 1175 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp29_ = state;
#line 1175 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp30_ = _tmp29_->dim;
#line 1175 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp31_ = _tmp30_.height;
#line 1175 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp32_ = sqlite3_bind_int (_tmp28_, 5, _tmp31_);
#line 1175 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp32_;
#line 1176 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp33_ = res;
#line 1176 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp33_ == SQLITE_OK, "res == Sqlite.OK");
#line 1177 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp34_ = stmt;
#line 1177 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp35_ = state;
#line 1177 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp36_ = _tmp35_->original_orientation;
#line 1177 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp37_ = sqlite3_bind_int (_tmp34_, 6, (gint) _tmp36_);
#line 1177 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp37_;
#line 1178 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp38_ = res;
#line 1178 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp38_ == SQLITE_OK, "res == Sqlite.OK");
#line 1179 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp39_ = stmt;
#line 1179 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp40_ = state;
#line 1179 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp41_ = _tmp40_->file_format;
#line 1179 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp42_ = photo_file_format_serialize (_tmp41_);
#line 1179 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp43_ = sqlite3_bind_int (_tmp39_, 7, _tmp42_);
#line 1179 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp43_;
#line 1180 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp44_ = res;
#line 1180 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp44_ == SQLITE_OK, "res == Sqlite.OK");
#line 1181 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp45_ = stmt;
#line 1181 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp46_ = time_created;
#line 1181 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp47_ = sqlite3_bind_int64 (_tmp45_, 8, (gint64) _tmp46_);
#line 1181 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp47_;
#line 1182 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp48_ = res;
#line 1182 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp48_ == SQLITE_OK, "res == Sqlite.OK");
#line 1184 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp49_ = stmt;
#line 1184 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp50_ = sqlite3_step (_tmp49_);
#line 1184 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp50_;
#line 1185 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp51_ = res;
#line 1185 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp51_ != SQLITE_DONE) {
#line 8635 "PhotoTable.c"
		gint _tmp52_;
#line 1186 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp52_ = res;
#line 1186 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_throw_error ("PhotoBackingTable.add", _tmp52_, &_inner_error_);
#line 1186 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1186 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 1186 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_propagate_error (error, _inner_error_);
#line 1186 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_sqlite3_finalize0 (stmt);
#line 1186 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				return;
#line 8651 "PhotoTable.c"
			} else {
#line 1186 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_sqlite3_finalize0 (stmt);
#line 1186 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1186 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_clear_error (&_inner_error_);
#line 1186 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				return;
#line 8661 "PhotoTable.c"
			}
		}
	}
#line 1188 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp53_ = state;
#line 1188 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp54_ = database_table_db;
#line 1188 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp55_ = sqlite3_last_insert_rowid (_tmp54_);
#line 1188 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	backing_photo_id_init (&_tmp53_->id, _tmp55_);
#line 1189 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp56_ = state;
#line 1189 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp57_ = time_created;
#line 1189 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp56_->time_created = _tmp57_;
#line 1156 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 8681 "PhotoTable.c"
}


BackingPhotoRow* backing_photo_table_fetch (BackingPhotoTable* self, BackingPhotoID* id, GError** error) {
	BackingPhotoRow* result = NULL;
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	sqlite3_stmt* _tmp4_;
	BackingPhotoID _tmp5_;
	gint64 _tmp6_;
	gint _tmp7_;
	gint _tmp8_;
	sqlite3_stmt* _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	BackingPhotoRow* row = NULL;
	BackingPhotoRow* _tmp14_;
	BackingPhotoRow* _tmp15_;
	BackingPhotoID _tmp16_;
	BackingPhotoRow* _tmp17_;
	sqlite3_stmt* _tmp18_;
	const gchar* _tmp19_;
	gchar* _tmp20_;
	BackingPhotoRow* _tmp21_;
	sqlite3_stmt* _tmp22_;
	gint64 _tmp23_;
	BackingPhotoRow* _tmp24_;
	sqlite3_stmt* _tmp25_;
	gint64 _tmp26_;
	BackingPhotoRow* _tmp27_;
	sqlite3_stmt* _tmp28_;
	gint _tmp29_;
	sqlite3_stmt* _tmp30_;
	gint _tmp31_;
	BackingPhotoRow* _tmp32_;
	sqlite3_stmt* _tmp33_;
	gint _tmp34_;
	BackingPhotoRow* _tmp35_;
	sqlite3_stmt* _tmp36_;
	gint _tmp37_;
	PhotoFileFormat _tmp38_;
	BackingPhotoRow* _tmp39_;
	sqlite3_stmt* _tmp40_;
	gint64 _tmp41_;
	GError * _inner_error_ = NULL;
#line 1192 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (IS_BACKING_PHOTO_TABLE (self), NULL);
#line 1192 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_val_if_fail (id != NULL, NULL);
#line 1194 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 1194 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "SELECT filepath, timestamp, filesize, width, height, " "original_orientation, file_format, time_created FROM BackingPhotoTable" \
" WHERE id=?", -1, &_tmp1_, NULL);
#line 1194 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 1194 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 1194 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 1197 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 1197 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 1199 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 1199 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = *id;
#line 1199 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = _tmp5_.id;
#line 1199 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = sqlite3_bind_int64 (_tmp4_, 1, _tmp6_);
#line 1199 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp7_;
#line 1200 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = res;
#line 1200 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp8_ == SQLITE_OK, "res == Sqlite.OK");
#line 1202 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = stmt;
#line 1202 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = sqlite3_step (_tmp9_);
#line 1202 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp10_;
#line 1203 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = res;
#line 1203 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp11_ == SQLITE_DONE) {
#line 1204 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		result = NULL;
#line 1204 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_sqlite3_finalize0 (stmt);
#line 1204 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		return result;
#line 8779 "PhotoTable.c"
	} else {
		gint _tmp12_;
#line 1205 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp12_ = res;
#line 1205 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_tmp12_ != SQLITE_ROW) {
#line 8786 "PhotoTable.c"
			gint _tmp13_;
#line 1206 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			_tmp13_ = res;
#line 1206 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			database_table_throw_error ("BackingPhotoTable.fetch_for_photo", _tmp13_, &_inner_error_);
#line 1206 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1206 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				if (_inner_error_->domain == DATABASE_ERROR) {
#line 1206 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					g_propagate_error (error, _inner_error_);
#line 1206 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_sqlite3_finalize0 (stmt);
#line 1206 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					return NULL;
#line 8802 "PhotoTable.c"
				} else {
#line 1206 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					_sqlite3_finalize0 (stmt);
#line 1206 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1206 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					g_clear_error (&_inner_error_);
#line 1206 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
					return NULL;
#line 8812 "PhotoTable.c"
				}
			}
		}
	}
#line 1208 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = backing_photo_row_new ();
#line 1208 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	row = _tmp14_;
#line 1209 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_ = row;
#line 1209 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp16_ = *id;
#line 1209 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_->id = _tmp16_;
#line 1210 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp17_ = row;
#line 1210 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp18_ = stmt;
#line 1210 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp19_ = sqlite3_column_text (_tmp18_, 0);
#line 1210 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp20_ = g_strdup (_tmp19_);
#line 1210 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_g_free0 (_tmp17_->filepath);
#line 1210 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp17_->filepath = _tmp20_;
#line 1211 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp21_ = row;
#line 1211 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp22_ = stmt;
#line 1211 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp23_ = sqlite3_column_int64 (_tmp22_, 1);
#line 1211 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp21_->timestamp = (time_t) _tmp23_;
#line 1212 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp24_ = row;
#line 1212 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp25_ = stmt;
#line 1212 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp26_ = sqlite3_column_int64 (_tmp25_, 2);
#line 1212 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp24_->filesize = _tmp26_;
#line 1213 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp27_ = row;
#line 1213 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp28_ = stmt;
#line 1213 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp29_ = sqlite3_column_int (_tmp28_, 3);
#line 1213 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp30_ = stmt;
#line 1213 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp31_ = sqlite3_column_int (_tmp30_, 4);
#line 1213 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	dimensions_init (&_tmp27_->dim, _tmp29_, _tmp31_);
#line 1214 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp32_ = row;
#line 1214 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp33_ = stmt;
#line 1214 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp34_ = sqlite3_column_int (_tmp33_, 5);
#line 1214 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp32_->original_orientation = (Orientation) _tmp34_;
#line 1215 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp35_ = row;
#line 1215 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp36_ = stmt;
#line 1215 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp37_ = sqlite3_column_int (_tmp36_, 6);
#line 1215 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp38_ = photo_file_format_unserialize (_tmp37_);
#line 1215 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp35_->file_format = _tmp38_;
#line 1216 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp39_ = row;
#line 1216 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp40_ = stmt;
#line 1216 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp41_ = sqlite3_column_int64 (_tmp40_, 7);
#line 1216 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp39_->time_created = (time_t) _tmp41_;
#line 1218 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	result = row;
#line 1218 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 1218 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	return result;
#line 8899 "PhotoTable.c"
}


void backing_photo_table_update (BackingPhotoTable* self, BackingPhotoRow* row, GError** error) {
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	sqlite3_stmt* _tmp4_;
	BackingPhotoRow* _tmp5_;
	time_t _tmp6_;
	gint _tmp7_;
	gint _tmp8_;
	sqlite3_stmt* _tmp9_;
	BackingPhotoRow* _tmp10_;
	gint64 _tmp11_;
	gint _tmp12_;
	gint _tmp13_;
	sqlite3_stmt* _tmp14_;
	BackingPhotoRow* _tmp15_;
	Dimensions _tmp16_;
	gint _tmp17_;
	gint _tmp18_;
	gint _tmp19_;
	sqlite3_stmt* _tmp20_;
	BackingPhotoRow* _tmp21_;
	Dimensions _tmp22_;
	gint _tmp23_;
	gint _tmp24_;
	gint _tmp25_;
	sqlite3_stmt* _tmp26_;
	BackingPhotoRow* _tmp27_;
	Orientation _tmp28_;
	gint _tmp29_;
	gint _tmp30_;
	sqlite3_stmt* _tmp31_;
	BackingPhotoRow* _tmp32_;
	PhotoFileFormat _tmp33_;
	gint _tmp34_;
	gint _tmp35_;
	gint _tmp36_;
	sqlite3_stmt* _tmp37_;
	BackingPhotoRow* _tmp38_;
	BackingPhotoID _tmp39_;
	gint64 _tmp40_;
	gint _tmp41_;
	gint _tmp42_;
	sqlite3_stmt* _tmp43_;
	gint _tmp44_;
	gint _tmp45_;
	GError * _inner_error_ = NULL;
#line 1222 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_BACKING_PHOTO_TABLE (self));
#line 1222 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_BACKING_PHOTO_ROW (row));
#line 1224 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 1224 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "UPDATE BackingPhotoTable SET timestamp=?, filesize=?, " "width=?, height=?, original_orientation=?, file_format=? " "WHERE id=?", -1, &_tmp1_, NULL);
#line 1224 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 1224 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 1224 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 1228 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 1228 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 1230 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 1230 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = row;
#line 1230 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = _tmp5_->timestamp;
#line 1230 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = sqlite3_bind_int64 (_tmp4_, 1, (gint64) _tmp6_);
#line 1230 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp7_;
#line 1231 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = res;
#line 1231 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp8_ == SQLITE_OK, "res == Sqlite.OK");
#line 1232 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = stmt;
#line 1232 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = row;
#line 1232 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = _tmp10_->filesize;
#line 1232 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = sqlite3_bind_int64 (_tmp9_, 2, _tmp11_);
#line 1232 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp12_;
#line 1233 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp13_ = res;
#line 1233 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp13_ == SQLITE_OK, "res == Sqlite.OK");
#line 1234 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = stmt;
#line 1234 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_ = row;
#line 1234 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp16_ = _tmp15_->dim;
#line 1234 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp17_ = _tmp16_.width;
#line 1234 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp18_ = sqlite3_bind_int (_tmp14_, 3, _tmp17_);
#line 1234 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp18_;
#line 1235 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp19_ = res;
#line 1235 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp19_ == SQLITE_OK, "res == Sqlite.OK");
#line 1236 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp20_ = stmt;
#line 1236 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp21_ = row;
#line 1236 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp22_ = _tmp21_->dim;
#line 1236 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp23_ = _tmp22_.height;
#line 1236 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp24_ = sqlite3_bind_int (_tmp20_, 4, _tmp23_);
#line 1236 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp24_;
#line 1237 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp25_ = res;
#line 1237 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp25_ == SQLITE_OK, "res == Sqlite.OK");
#line 1238 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp26_ = stmt;
#line 1238 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp27_ = row;
#line 1238 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp28_ = _tmp27_->original_orientation;
#line 1238 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp29_ = sqlite3_bind_int (_tmp26_, 5, (gint) _tmp28_);
#line 1238 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp29_;
#line 1239 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp30_ = res;
#line 1239 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp30_ == SQLITE_OK, "res == Sqlite.OK");
#line 1240 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp31_ = stmt;
#line 1240 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp32_ = row;
#line 1240 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp33_ = _tmp32_->file_format;
#line 1240 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp34_ = photo_file_format_serialize (_tmp33_);
#line 1240 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp35_ = sqlite3_bind_int (_tmp31_, 6, _tmp34_);
#line 1240 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp35_;
#line 1241 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp36_ = res;
#line 1241 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp36_ == SQLITE_OK, "res == Sqlite.OK");
#line 1242 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp37_ = stmt;
#line 1242 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp38_ = row;
#line 1242 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp39_ = _tmp38_->id;
#line 1242 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp40_ = _tmp39_.id;
#line 1242 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp41_ = sqlite3_bind_int64 (_tmp37_, 7, _tmp40_);
#line 1242 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp41_;
#line 1243 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp42_ = res;
#line 1243 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp42_ == SQLITE_OK, "res == Sqlite.OK");
#line 1245 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp43_ = stmt;
#line 1245 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp44_ = sqlite3_step (_tmp43_);
#line 1245 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp44_;
#line 1246 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp45_ = res;
#line 1246 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp45_ != SQLITE_DONE) {
#line 9087 "PhotoTable.c"
		gint _tmp46_;
#line 1247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp46_ = res;
#line 1247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_throw_error ("BackingPhotoTable.update", _tmp46_, &_inner_error_);
#line 1247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 1247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_propagate_error (error, _inner_error_);
#line 1247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_sqlite3_finalize0 (stmt);
#line 1247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				return;
#line 9103 "PhotoTable.c"
			} else {
#line 1247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_sqlite3_finalize0 (stmt);
#line 1247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_clear_error (&_inner_error_);
#line 1247 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				return;
#line 9113 "PhotoTable.c"
			}
		}
	}
#line 1222 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 9119 "PhotoTable.c"
}


void backing_photo_table_update_attributes (BackingPhotoTable* self, BackingPhotoID* id, time_t timestamp, gint64 filesize, GError** error) {
	sqlite3_stmt* stmt = NULL;
	gint res = 0;
	sqlite3* _tmp0_;
	sqlite3_stmt* _tmp1_ = NULL;
	gint _tmp2_;
	gint _tmp3_;
	sqlite3_stmt* _tmp4_;
	time_t _tmp5_;
	gint _tmp6_;
	gint _tmp7_;
	sqlite3_stmt* _tmp8_;
	gint64 _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	sqlite3_stmt* _tmp12_;
	BackingPhotoID _tmp13_;
	gint64 _tmp14_;
	gint _tmp15_;
	gint _tmp16_;
	sqlite3_stmt* _tmp17_;
	gint _tmp18_;
	gint _tmp19_;
	GError * _inner_error_ = NULL;
#line 1250 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_BACKING_PHOTO_TABLE (self));
#line 1250 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (id != NULL);
#line 1252 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = database_table_db;
#line 1252 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = sqlite3_prepare_v2 (_tmp0_, "UPDATE BackingPhotoTable SET timestamp=?, filesize=? WHERE id=?", -1, &_tmp1_, NULL);
#line 1252 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 1252 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	stmt = _tmp1_;
#line 1252 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp2_;
#line 1254 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp3_ = res;
#line 1254 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp3_ == SQLITE_OK, "res == Sqlite.OK");
#line 1256 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp4_ = stmt;
#line 1256 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp5_ = timestamp;
#line 1256 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp6_ = sqlite3_bind_int64 (_tmp4_, 1, (gint64) _tmp5_);
#line 1256 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp6_;
#line 1257 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp7_ = res;
#line 1257 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp7_ == SQLITE_OK, "res == Sqlite.OK");
#line 1258 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp8_ = stmt;
#line 1258 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp9_ = filesize;
#line 1258 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp10_ = sqlite3_bind_int64 (_tmp8_, 2, _tmp9_);
#line 1258 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp10_;
#line 1259 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp11_ = res;
#line 1259 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp11_ == SQLITE_OK, "res == Sqlite.OK");
#line 1260 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp12_ = stmt;
#line 1260 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp13_ = *id;
#line 1260 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp14_ = _tmp13_.id;
#line 1260 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp15_ = sqlite3_bind_int64 (_tmp12_, 3, _tmp14_);
#line 1260 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp15_;
#line 1261 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp16_ = res;
#line 1261 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_vala_assert (_tmp16_ == SQLITE_OK, "res == Sqlite.OK");
#line 1263 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp17_ = stmt;
#line 1263 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp18_ = sqlite3_step (_tmp17_);
#line 1263 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	res = _tmp18_;
#line 1264 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp19_ = res;
#line 1264 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (_tmp19_ != SQLITE_DONE) {
#line 9213 "PhotoTable.c"
		gint _tmp20_;
#line 1265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		_tmp20_ = res;
#line 1265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		database_table_throw_error ("BackingPhotoTable.update_attributes", _tmp20_, &_inner_error_);
#line 1265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			if (_inner_error_->domain == DATABASE_ERROR) {
#line 1265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_propagate_error (error, _inner_error_);
#line 1265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_sqlite3_finalize0 (stmt);
#line 1265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				return;
#line 9229 "PhotoTable.c"
			} else {
#line 1265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				_sqlite3_finalize0 (stmt);
#line 1265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				g_clear_error (&_inner_error_);
#line 1265 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
				return;
#line 9239 "PhotoTable.c"
			}
		}
	}
#line 1250 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_sqlite3_finalize0 (stmt);
#line 9245 "PhotoTable.c"
}


void backing_photo_table_remove (BackingPhotoTable* self, BackingPhotoID* backing_id, GError** error) {
	BackingPhotoID _tmp0_;
	gint64 _tmp1_;
	GError * _inner_error_ = NULL;
#line 1268 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_BACKING_PHOTO_TABLE (self));
#line 1268 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (backing_id != NULL);
#line 1269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *backing_id;
#line 1269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 1269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_delete_by_id (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, &_inner_error_);
#line 1269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 1269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_propagate_error (error, _inner_error_);
#line 1269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 9271 "PhotoTable.c"
		} else {
#line 1269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_clear_error (&_inner_error_);
#line 1269 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 9279 "PhotoTable.c"
		}
	}
}


void backing_photo_table_set_filepath (BackingPhotoTable* self, BackingPhotoID* id, const gchar* filepath, GError** error) {
	BackingPhotoID _tmp0_;
	gint64 _tmp1_;
	const gchar* _tmp2_;
	GError * _inner_error_ = NULL;
#line 1272 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_BACKING_PHOTO_TABLE (self));
#line 1272 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (id != NULL);
#line 1272 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (filepath != NULL);
#line 1273 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *id;
#line 1273 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 1273 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = filepath;
#line 1273 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_update_text_by_id_2 (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, "filepath", _tmp2_, &_inner_error_);
#line 1273 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1273 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 1273 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_propagate_error (error, _inner_error_);
#line 1273 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 9312 "PhotoTable.c"
		} else {
#line 1273 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1273 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_clear_error (&_inner_error_);
#line 1273 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 9320 "PhotoTable.c"
		}
	}
}


void backing_photo_table_update_timestamp (BackingPhotoTable* self, BackingPhotoID* id, time_t timestamp, GError** error) {
	BackingPhotoID _tmp0_;
	gint64 _tmp1_;
	time_t _tmp2_;
	GError * _inner_error_ = NULL;
#line 1276 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (IS_BACKING_PHOTO_TABLE (self));
#line 1276 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	g_return_if_fail (id != NULL);
#line 1277 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp0_ = *id;
#line 1277 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp1_ = _tmp0_.id;
#line 1277 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	_tmp2_ = timestamp;
#line 1277 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	database_table_update_int64_by_id_2 (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DATABASE_TABLE, DatabaseTable), _tmp1_, "timestamp", (gint64) _tmp2_, &_inner_error_);
#line 1277 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1277 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
		if (_inner_error_->domain == DATABASE_ERROR) {
#line 1277 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_propagate_error (error, _inner_error_);
#line 1277 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 9351 "PhotoTable.c"
		} else {
#line 1277 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1277 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			g_clear_error (&_inner_error_);
#line 1277 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
			return;
#line 9359 "PhotoTable.c"
		}
	}
}


static void backing_photo_table_class_init (BackingPhotoTableClass * klass) {
#line 1122 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	backing_photo_table_parent_class = g_type_class_peek_parent (klass);
#line 1122 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	((DatabaseTableClass *) klass)->finalize = backing_photo_table_finalize;
#line 9370 "PhotoTable.c"
}


static void backing_photo_table_instance_init (BackingPhotoTable * self) {
}


static void backing_photo_table_finalize (DatabaseTable * obj) {
	BackingPhotoTable * self;
#line 1122 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_BACKING_PHOTO_TABLE, BackingPhotoTable);
#line 1122 "/home/jens/Source/shotwell/src/db/PhotoTable.vala"
	DATABASE_TABLE_CLASS (backing_photo_table_parent_class)->finalize (obj);
#line 9384 "PhotoTable.c"
}


GType backing_photo_table_get_type (void) {
	static volatile gsize backing_photo_table_type_id__volatile = 0;
	if (g_once_init_enter (&backing_photo_table_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BackingPhotoTableClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) backing_photo_table_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BackingPhotoTable), 0, (GInstanceInitFunc) backing_photo_table_instance_init, NULL };
		GType backing_photo_table_type_id;
		backing_photo_table_type_id = g_type_register_static (TYPE_DATABASE_TABLE, "BackingPhotoTable", &g_define_type_info, 0);
		g_once_init_leave (&backing_photo_table_type_id__volatile, backing_photo_table_type_id);
	}
	return backing_photo_table_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



