/* Page.c generated by valac 0.36.6, the Vala compiler
 * generated from Page.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gdk/gdk.h>
#include <cairo.h>
#include <float.h>
#include <math.h>
#include <glib/gi18n-lib.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <pango/pango.h>
#include <pango/pangocairo.h>
#include "shotwell-plugin-dev-1.0.h"
#include <gobject/gvaluecollector.h>


#define TYPE_INJECTION_GROUP (injection_group_get_type ())
#define INJECTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INJECTION_GROUP, InjectionGroup))
#define INJECTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INJECTION_GROUP, InjectionGroupClass))
#define IS_INJECTION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INJECTION_GROUP))
#define IS_INJECTION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INJECTION_GROUP))
#define INJECTION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INJECTION_GROUP, InjectionGroupClass))

typedef struct _InjectionGroup InjectionGroup;
typedef struct _InjectionGroupClass InjectionGroupClass;
typedef struct _InjectionGroupPrivate InjectionGroupPrivate;

#define INJECTION_GROUP_TYPE_ELEMENT (injection_group_element_get_type ())
#define INJECTION_GROUP_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), INJECTION_GROUP_TYPE_ELEMENT, InjectionGroupElement))
#define INJECTION_GROUP_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), INJECTION_GROUP_TYPE_ELEMENT, InjectionGroupElementClass))
#define INJECTION_GROUP_IS_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), INJECTION_GROUP_TYPE_ELEMENT))
#define INJECTION_GROUP_IS_ELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), INJECTION_GROUP_TYPE_ELEMENT))
#define INJECTION_GROUP_ELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), INJECTION_GROUP_TYPE_ELEMENT, InjectionGroupElementClass))

typedef struct _InjectionGroupElement InjectionGroupElement;
typedef struct _InjectionGroupElementClass InjectionGroupElementClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define INJECTION_GROUP_ELEMENT_TYPE_ITEM_TYPE (injection_group_element_item_type_get_type ())
#define _injection_group_element_unref0(var) ((var == NULL) ? NULL : (var = (injection_group_element_unref (var), NULL)))
typedef struct _InjectionGroupElementPrivate InjectionGroupElementPrivate;
typedef struct _InjectionGroupParamSpecElement InjectionGroupParamSpecElement;
typedef struct _ParamSpecInjectionGroup ParamSpecInjectionGroup;

#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;
typedef struct _PagePrivate PagePrivate;

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_FULLSCREEN_WINDOW (fullscreen_window_get_type ())
#define FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindow))
#define FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))
#define IS_FULLSCREEN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FULLSCREEN_WINDOW))
#define IS_FULLSCREEN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FULLSCREEN_WINDOW))
#define FULLSCREEN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FULLSCREEN_WINDOW, FullscreenWindowClass))

typedef struct _FullscreenWindow FullscreenWindow;
typedef struct _FullscreenWindowClass FullscreenWindowClass;

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_VIEW_COLLECTION (view_collection_get_type ())
#define VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_COLLECTION, ViewCollection))
#define VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_COLLECTION, ViewCollectionClass))
#define IS_VIEW_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_COLLECTION))
#define IS_VIEW_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_COLLECTION))
#define VIEW_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_COLLECTION, ViewCollectionClass))

typedef struct _ViewCollection ViewCollection;
typedef struct _ViewCollectionClass ViewCollectionClass;

#define TYPE_ONE_SHOT_SCHEDULER (one_shot_scheduler_get_type ())
#define ONE_SHOT_SCHEDULER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ONE_SHOT_SCHEDULER, OneShotScheduler))
#define ONE_SHOT_SCHEDULER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ONE_SHOT_SCHEDULER, OneShotSchedulerClass))
#define IS_ONE_SHOT_SCHEDULER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ONE_SHOT_SCHEDULER))
#define IS_ONE_SHOT_SCHEDULER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ONE_SHOT_SCHEDULER))
#define ONE_SHOT_SCHEDULER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ONE_SHOT_SCHEDULER, OneShotSchedulerClass))

typedef struct _OneShotScheduler OneShotScheduler;
typedef struct _OneShotSchedulerClass OneShotSchedulerClass;
#define _data_collection_unref0(var) ((var == NULL) ? NULL : (var = (data_collection_unref (var), NULL)))
#define _one_shot_scheduler_unref0(var) ((var == NULL) ? NULL : (var = (one_shot_scheduler_unref (var), NULL)))
#define _injection_group_unref0(var) ((var == NULL) ? NULL : (var = (injection_group_unref (var), NULL)))

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))

#define TYPE_COMMAND_MANAGER (command_manager_get_type ())
#define COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND_MANAGER, CommandManager))
#define COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND_MANAGER, CommandManagerClass))
#define IS_COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND_MANAGER))
#define IS_COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND_MANAGER))
#define COMMAND_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND_MANAGER, CommandManagerClass))

typedef struct _CommandManager CommandManager;
typedef struct _CommandManagerClass CommandManagerClass;

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_VIEW (data_view_get_type ())
#define DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_VIEW, DataView))
#define DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_VIEW, DataViewClass))
#define IS_DATA_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_VIEW))
#define IS_DATA_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_VIEW))
#define DATA_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_VIEW, DataViewClass))

typedef struct _DataView DataView;
typedef struct _DataViewClass DataViewClass;

#define TYPE_APPLICATION (application_get_type ())
#define APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APPLICATION, Application))
#define APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APPLICATION, ApplicationClass))
#define IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APPLICATION))
#define IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APPLICATION))
#define APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APPLICATION, ApplicationClass))

typedef struct _Application Application;
typedef struct _ApplicationClass ApplicationClass;
#define _application_unref0(var) ((var == NULL) ? NULL : (var = (application_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_CHECKERBOARD_PAGE (checkerboard_page_get_type ())
#define CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPage))
#define CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))
#define IS_CHECKERBOARD_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_PAGE))
#define IS_CHECKERBOARD_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_PAGE))
#define CHECKERBOARD_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_PAGE, CheckerboardPageClass))

typedef struct _CheckerboardPage CheckerboardPage;
typedef struct _CheckerboardPageClass CheckerboardPageClass;
typedef struct _CheckerboardPagePrivate CheckerboardPagePrivate;

#define TYPE_THUMBNAIL_VIEW (thumbnail_view_get_type ())
#define THUMBNAIL_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_VIEW, ThumbnailView))
#define THUMBNAIL_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_VIEW, ThumbnailViewClass))
#define IS_THUMBNAIL_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_VIEW))
#define IS_THUMBNAIL_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_VIEW))
#define THUMBNAIL_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_VIEW, ThumbnailViewClass))

typedef struct _ThumbnailView ThumbnailView;
typedef struct _ThumbnailViewClass ThumbnailViewClass;

#define TYPE_CHECKERBOARD_ITEM (checkerboard_item_get_type ())
#define CHECKERBOARD_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_ITEM, CheckerboardItem))
#define CHECKERBOARD_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_ITEM, CheckerboardItemClass))
#define IS_CHECKERBOARD_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_ITEM))
#define IS_CHECKERBOARD_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_ITEM))
#define CHECKERBOARD_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_ITEM, CheckerboardItemClass))

typedef struct _CheckerboardItem CheckerboardItem;
typedef struct _CheckerboardItemClass CheckerboardItemClass;

#define CHECKERBOARD_PAGE_TYPE_ACTIVATOR (checkerboard_page_activator_get_type ())

#define CHECKERBOARD_PAGE_TYPE_KEYBOARD_MODIFIERS (checkerboard_page_keyboard_modifiers_get_type ())
typedef struct _CheckerboardPageKeyboardModifiers CheckerboardPageKeyboardModifiers;

#define TYPE_VIEW_FILTER (view_filter_get_type ())
#define VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIEW_FILTER, ViewFilter))
#define VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIEW_FILTER, ViewFilterClass))
#define IS_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIEW_FILTER))
#define IS_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIEW_FILTER))
#define VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIEW_FILTER, ViewFilterClass))

typedef struct _ViewFilter ViewFilter;
typedef struct _ViewFilterClass ViewFilterClass;

#define TYPE_SEARCH_VIEW_FILTER (search_view_filter_get_type ())
#define SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SEARCH_VIEW_FILTER, SearchViewFilter))
#define SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SEARCH_VIEW_FILTER, SearchViewFilterClass))
#define IS_SEARCH_VIEW_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SEARCH_VIEW_FILTER))
#define IS_SEARCH_VIEW_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SEARCH_VIEW_FILTER))
#define SEARCH_VIEW_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SEARCH_VIEW_FILTER, SearchViewFilterClass))

typedef struct _SearchViewFilter SearchViewFilter;
typedef struct _SearchViewFilterClass SearchViewFilterClass;

#define CORE_TYPE_TRACKER (core_tracker_get_type ())
#define CORE_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CORE_TYPE_TRACKER, CoreTracker))
#define CORE_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CORE_TYPE_TRACKER, CoreTrackerClass))
#define CORE_IS_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CORE_TYPE_TRACKER))
#define CORE_IS_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CORE_TYPE_TRACKER))
#define CORE_TRACKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CORE_TYPE_TRACKER, CoreTrackerClass))

typedef struct _CoreTracker CoreTracker;
typedef struct _CoreTrackerClass CoreTrackerClass;

#define CORE_TYPE_VIEW_TRACKER (core_view_tracker_get_type ())
#define CORE_VIEW_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CORE_TYPE_VIEW_TRACKER, CoreViewTracker))
#define CORE_VIEW_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CORE_TYPE_VIEW_TRACKER, CoreViewTrackerClass))
#define CORE_IS_VIEW_TRACKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CORE_TYPE_VIEW_TRACKER))
#define CORE_IS_VIEW_TRACKER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CORE_TYPE_VIEW_TRACKER))
#define CORE_VIEW_TRACKER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CORE_TYPE_VIEW_TRACKER, CoreViewTrackerClass))

typedef struct _CoreViewTracker CoreViewTracker;
typedef struct _CoreViewTrackerClass CoreViewTrackerClass;

#define TYPE_CHECKERBOARD_LAYOUT (checkerboard_layout_get_type ())
#define CHECKERBOARD_LAYOUT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CHECKERBOARD_LAYOUT, CheckerboardLayout))
#define CHECKERBOARD_LAYOUT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CHECKERBOARD_LAYOUT, CheckerboardLayoutClass))
#define IS_CHECKERBOARD_LAYOUT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CHECKERBOARD_LAYOUT))
#define IS_CHECKERBOARD_LAYOUT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CHECKERBOARD_LAYOUT))
#define CHECKERBOARD_LAYOUT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CHECKERBOARD_LAYOUT, CheckerboardLayoutClass))

typedef struct _CheckerboardLayout CheckerboardLayout;
typedef struct _CheckerboardLayoutClass CheckerboardLayoutClass;
#define _view_filter_unref0(var) ((var == NULL) ? NULL : (var = (view_filter_unref (var), NULL)))

#define TYPE_ADJUSTMENT_RELATION (adjustment_relation_get_type ())
typedef struct _DataObjectPrivate DataObjectPrivate;

#define TYPE_ALTERATION (alteration_get_type ())
#define ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ALTERATION, Alteration))
#define ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ALTERATION, AlterationClass))
#define IS_ALTERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ALTERATION))
#define IS_ALTERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ALTERATION))
#define ALTERATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ALTERATION, AlterationClass))

typedef struct _Alteration Alteration;
typedef struct _AlterationClass AlterationClass;
typedef struct _DataViewPrivate DataViewPrivate;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;
typedef struct _ThumbnailViewPrivate ThumbnailViewPrivate;
typedef struct _CheckerboardItemPrivate CheckerboardItemPrivate;

#define TYPE_DIMENSIONS (dimensions_get_type ())
typedef struct _Dimensions Dimensions;

#define TYPE_COMPASS_POINT (compass_point_get_type ())

#define TYPE_MARKER (marker_get_type ())
#define MARKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MARKER, Marker))
#define IS_MARKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MARKER))
#define MARKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_MARKER, MarkerIface))

typedef struct _Marker Marker;
typedef struct _MarkerIface MarkerIface;

#define TYPE_SINGLE_PHOTO_PAGE (single_photo_page_get_type ())
#define SINGLE_PHOTO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPage))
#define SINGLE_PHOTO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPageClass))
#define IS_SINGLE_PHOTO_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SINGLE_PHOTO_PAGE))
#define IS_SINGLE_PHOTO_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SINGLE_PHOTO_PAGE))
#define SINGLE_PHOTO_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPageClass))

typedef struct _SinglePhotoPage SinglePhotoPage;
typedef struct _SinglePhotoPageClass SinglePhotoPageClass;
typedef struct _SinglePhotoPagePrivate SinglePhotoPagePrivate;

#define TYPE_ZOOM_BUFFER (zoom_buffer_get_type ())
#define ZOOM_BUFFER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ZOOM_BUFFER, ZoomBuffer))
#define ZOOM_BUFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ZOOM_BUFFER, ZoomBufferClass))
#define IS_ZOOM_BUFFER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ZOOM_BUFFER))
#define IS_ZOOM_BUFFER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ZOOM_BUFFER))
#define ZOOM_BUFFER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ZOOM_BUFFER, ZoomBufferClass))

typedef struct _ZoomBuffer ZoomBuffer;
typedef struct _ZoomBufferClass ZoomBufferClass;

#define SINGLE_PHOTO_PAGE_TYPE_UPDATE_REASON (single_photo_page_update_reason_get_type ())

#define TYPE_TRANSITION_CLOCK (transition_clock_get_type ())
#define TRANSITION_CLOCK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TRANSITION_CLOCK, TransitionClock))
#define TRANSITION_CLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TRANSITION_CLOCK, TransitionClockClass))
#define IS_TRANSITION_CLOCK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TRANSITION_CLOCK))
#define IS_TRANSITION_CLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TRANSITION_CLOCK))
#define TRANSITION_CLOCK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TRANSITION_CLOCK, TransitionClockClass))

typedef struct _TransitionClock TransitionClock;
typedef struct _TransitionClockClass TransitionClockClass;

#define TYPE_ZOOM_STATE (zoom_state_get_type ())
typedef struct _ZoomState ZoomState;
#define _transition_clock_unref0(var) ((var == NULL) ? NULL : (var = (transition_clock_unref (var), NULL)))
#define _cairo_surface_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_surface_destroy (var), NULL)))
#define _cairo_destroy0(var) ((var == NULL) ? NULL : (var = (cairo_destroy (var), NULL)))

#define TYPE_TRANSITION_EFFECTS_MANAGER (transition_effects_manager_get_type ())
#define TRANSITION_EFFECTS_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TRANSITION_EFFECTS_MANAGER, TransitionEffectsManager))
#define TRANSITION_EFFECTS_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TRANSITION_EFFECTS_MANAGER, TransitionEffectsManagerClass))
#define IS_TRANSITION_EFFECTS_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TRANSITION_EFFECTS_MANAGER))
#define IS_TRANSITION_EFFECTS_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TRANSITION_EFFECTS_MANAGER))
#define TRANSITION_EFFECTS_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TRANSITION_EFFECTS_MANAGER, TransitionEffectsManagerClass))

typedef struct _TransitionEffectsManager TransitionEffectsManager;
typedef struct _TransitionEffectsManagerClass TransitionEffectsManagerClass;
#define _transition_effects_manager_unref0(var) ((var == NULL) ? NULL : (var = (transition_effects_manager_unref (var), NULL)))

#define TYPE_DIRECTION (direction_get_type ())

#define TYPE_SCALING (scaling_get_type ())

#define TYPE_SCALE_CONSTRAINT (scale_constraint_get_type ())
typedef struct _Scaling Scaling;

#define TYPE_DRAG_AND_DROP_HANDLER (drag_and_drop_handler_get_type ())
#define DRAG_AND_DROP_HANDLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DRAG_AND_DROP_HANDLER, DragAndDropHandler))
#define DRAG_AND_DROP_HANDLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DRAG_AND_DROP_HANDLER, DragAndDropHandlerClass))
#define IS_DRAG_AND_DROP_HANDLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DRAG_AND_DROP_HANDLER))
#define IS_DRAG_AND_DROP_HANDLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DRAG_AND_DROP_HANDLER))
#define DRAG_AND_DROP_HANDLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DRAG_AND_DROP_HANDLER, DragAndDropHandlerClass))

typedef struct _DragAndDropHandler DragAndDropHandler;
typedef struct _DragAndDropHandlerClass DragAndDropHandlerClass;
typedef struct _DragAndDropHandlerPrivate DragAndDropHandlerPrivate;

#define TYPE_EXPORTER_UI (exporter_ui_get_type ())
#define EXPORTER_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORTER_UI, ExporterUI))
#define EXPORTER_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORTER_UI, ExporterUIClass))
#define IS_EXPORTER_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORTER_UI))
#define IS_EXPORTER_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORTER_UI))
#define EXPORTER_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORTER_UI, ExporterUIClass))

typedef struct _ExporterUI ExporterUI;
typedef struct _ExporterUIClass ExporterUIClass;

#define DRAG_AND_DROP_HANDLER_TYPE_TARGET_TYPE (drag_and_drop_handler_target_type_get_type ())
#define _exporter_ui_unref0(var) ((var == NULL) ? NULL : (var = (exporter_ui_unref (var), NULL)))

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_PHOTO_SOURCE (photo_source_get_type ())
#define PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_SOURCE, PhotoSource))
#define PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_SOURCE, PhotoSourceClass))
#define IS_PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_SOURCE))
#define IS_PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_SOURCE))
#define PHOTO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_SOURCE, PhotoSourceClass))

typedef struct _PhotoSource PhotoSource;
typedef struct _PhotoSourceClass PhotoSourceClass;

#define TYPE_PHOTO (photo_get_type ())
#define PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO, Photo))
#define PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO, PhotoClass))
#define IS_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO))
#define IS_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO))
#define PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO, PhotoClass))

typedef struct _Photo Photo;
typedef struct _PhotoClass PhotoClass;

#define TYPE_EXPORT_FORMAT_PARAMETERS (export_format_parameters_get_type ())

#define TYPE_EXPORT_FORMAT_MODE (export_format_mode_get_type ())

#define TYPE_PHOTO_FILE_FORMAT (photo_file_format_get_type ())

#define JPEG_TYPE_QUALITY (jpeg_quality_get_type ())
typedef struct _ExportFormatParameters ExportFormatParameters;

#define TYPE_EXPORTER (exporter_get_type ())
#define EXPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORTER, Exporter))
#define EXPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORTER, ExporterClass))
#define IS_EXPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORTER))
#define IS_EXPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORTER))
#define EXPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORTER, ExporterClass))

typedef struct _Exporter Exporter;
typedef struct _ExporterClass ExporterClass;
typedef struct _ParamSpecDragAndDropHandler ParamSpecDragAndDropHandler;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _InjectionGroup {
	GTypeInstance parent_instance;
	volatile int ref_count;
	InjectionGroupPrivate * priv;
};

struct _InjectionGroupClass {
	GTypeClass parent_class;
	void (*finalize) (InjectionGroup *self);
};

struct _InjectionGroupPrivate {
	gchar* path;
	GeeArrayList* elements;
	gint separator_id;
};

typedef enum  {
	INJECTION_GROUP_ELEMENT_ITEM_TYPE_MENUITEM,
	INJECTION_GROUP_ELEMENT_ITEM_TYPE_MENU,
	INJECTION_GROUP_ELEMENT_ITEM_TYPE_SEPARATOR
} InjectionGroupElementItemType;

struct _InjectionGroupElement {
	GTypeInstance parent_instance;
	volatile int ref_count;
	InjectionGroupElementPrivate * priv;
	gchar* name;
	gchar* action;
	gchar* accellerator;
	InjectionGroupElementItemType kind;
};

struct _InjectionGroupElementClass {
	GTypeClass parent_class;
	void (*finalize) (InjectionGroupElement *self);
};

struct _InjectionGroupParamSpecElement {
	GParamSpec parent_instance;
};

struct _ParamSpecInjectionGroup {
	GParamSpec parent_instance;
};

struct _Page {
	GtkScrolledWindow parent_instance;
	PagePrivate * priv;
	GtkBuilder* builder;
	GtkToolbar* toolbar;
	gboolean in_view;
};

struct _PageClass {
	GtkScrolledWindowClass parent_class;
	void (*set_page_name) (Page* self, const gchar* page_name);
	void (*set_container) (Page* self, GtkWindow* container);
	void (*clear_container) (Page* self);
	GtkToolbar* (*get_toolbar) (Page* self);
	GtkMenu* (*get_page_context_menu) (Page* self);
	void (*switching_from) (Page* self);
	void (*switched_to) (Page* self);
	void (*ready) (Page* self);
	void (*switching_to_fullscreen) (Page* self, FullscreenWindow* fsw);
	void (*returning_from_fullscreen) (Page* self, FullscreenWindow* fsw);
	void (*add_actions) (Page* self, GActionMap* map);
	void (*remove_actions) (Page* self, GActionMap* map);
	void (*init_collect_ui_filenames) (Page* self, GeeList* ui_filenames);
	InjectionGroup** (*init_collect_injection_groups) (Page* self, int* result_length1);
	void (*init_actions) (Page* self, gint selected_count, gint count);
	void (*update_actions) (Page* self, gint selected_count, gint count);
	gboolean (*source_drag_failed) (Page* self, GdkDragContext* context, GtkDragResult drag_result);
	gboolean (*on_left_click) (Page* self, GdkEventButton* event);
	gboolean (*on_middle_click) (Page* self, GdkEventButton* event);
	gboolean (*on_right_click) (Page* self, GdkEventButton* event);
	gboolean (*on_left_released) (Page* self, GdkEventButton* event);
	gboolean (*on_middle_released) (Page* self, GdkEventButton* event);
	gboolean (*on_right_released) (Page* self, GdkEventButton* event);
	gboolean (*on_ctrl_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_ctrl_released) (Page* self, GdkEventKey* event);
	gboolean (*on_alt_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_alt_released) (Page* self, GdkEventKey* event);
	gboolean (*on_shift_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_shift_released) (Page* self, GdkEventKey* event);
	gboolean (*on_super_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_super_released) (Page* self, GdkEventKey* event);
	gboolean (*on_app_key_pressed) (Page* self, GdkEventKey* event);
	gboolean (*on_app_key_released) (Page* self, GdkEventKey* event);
	void (*on_move) (Page* self, GdkRectangle* rect);
	void (*on_move_start) (Page* self, GdkRectangle* rect);
	void (*on_move_finished) (Page* self, GdkRectangle* rect);
	void (*on_resize) (Page* self, GdkRectangle* rect);
	void (*on_resize_start) (Page* self, GdkRectangle* rect);
	void (*on_resize_finished) (Page* self, GdkRectangle* rect);
	gboolean (*on_configure) (Page* self, GdkEventConfigure* event, GdkRectangle* rect);
	gboolean (*on_motion) (Page* self, GdkEventMotion* event, gint x, gint y, GdkModifierType mask);
	gboolean (*on_leave_notify_event) (Page* self);
	gboolean (*on_mousewheel_up) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_down) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_left) (Page* self, GdkEventScroll* event);
	gboolean (*on_mousewheel_right) (Page* self, GdkEventScroll* event);
	gboolean (*on_context_keypress) (Page* self);
	gboolean (*on_context_buttonpress) (Page* self, GdkEventButton* event);
	gboolean (*on_context_invoked) (Page* self);
	void (*set_page_cursor) (Page* self, GdkCursorType cursor_type);
};

struct _PagePrivate {
	gchar* page_name;
	ViewCollection* view;
	GtkWindow* container;
	gchar* toolbar_path;
	GdkRectangle last_position;
	GtkWidget* event_source;
	gboolean dnd_enabled;
	gulong last_configure_ms;
	gboolean report_move_finished;
	gboolean report_resize_finished;
	GdkPoint last_down;
	gboolean is_destroyed;
	gboolean ctrl_pressed;
	gboolean alt_pressed;
	gboolean shift_pressed;
	gboolean super_pressed;
	GdkCursorType last_cursor;
	gboolean cursor_hidden;
	gint cursor_hide_msec;
	guint last_timeout_id;
	gint cursor_hide_time_cached;
	gboolean are_actions_attached;
	OneShotScheduler* update_actions_scheduler;
	gboolean menubar_injected;
};

typedef void (*OneShotCallback) (void* user_data);
typedef enum  {
	CHECKERBOARD_PAGE_ACTIVATOR_KEYBOARD,
	CHECKERBOARD_PAGE_ACTIVATOR_MOUSE
} CheckerboardPageActivator;

struct _CheckerboardPageKeyboardModifiers {
	gboolean ctrl_pressed;
	gboolean alt_pressed;
	gboolean shift_pressed;
	gboolean super_pressed;
};

struct _CheckerboardPage {
	Page parent_instance;
	CheckerboardPagePrivate * priv;
	CheckerboardItem* anchor;
	CheckerboardItem* cursor;
};

struct _CheckerboardPageClass {
	PageClass parent_class;
	GtkMenu* (*get_item_context_menu) (CheckerboardPage* self);
	gchar* (*get_view_empty_message) (CheckerboardPage* self);
	gchar* (*get_filter_no_match_message) (CheckerboardPage* self);
	void (*on_item_activated) (CheckerboardPage* self, CheckerboardItem* item, CheckerboardPageActivator activator, CheckerboardPageKeyboardModifiers* modifiers);
	SearchViewFilter* (*get_search_view_filter) (CheckerboardPage* self);
	CoreViewTracker* (*get_view_tracker) (CheckerboardPage* self);
	gboolean (*on_mouse_over) (CheckerboardPage* self, CheckerboardItem* item, gint x, gint y, GdkModifierType mask);
	void (*set_display_titles) (CheckerboardPage* self, gboolean display);
	void (*set_display_comments) (CheckerboardPage* self, gboolean display);
};

struct _CheckerboardPagePrivate {
	CheckerboardLayout* layout;
	gchar* item_context_menu_path;
	gchar* page_context_menu_path;
	GtkViewport* viewport;
	CheckerboardItem* highlighted;
	gboolean autoscroll_scheduled;
	CheckerboardItem* activated_item;
	GeeArrayList* previously_selected;
	GtkMenu* item_context_menu;
	GtkMenu* page_context_menu;
};

typedef enum  {
	ADJUSTMENT_RELATION_BELOW,
	ADJUSTMENT_RELATION_IN_RANGE,
	ADJUSTMENT_RELATION_ABOVE
} AdjustmentRelation;

struct _DataObject {
	GObject parent_instance;
	DataObjectPrivate * priv;
};

struct _DataObjectClass {
	GObjectClass parent_class;
	void (*notify_altered) (DataObject* self, Alteration* alteration);
	void (*notify_membership_changed) (DataObject* self, DataCollection* collection);
	void (*notify_collection_property_set) (DataObject* self, const gchar* name, GValue* old, GValue* val);
	void (*notify_collection_property_cleared) (DataObject* self, const gchar* name);
	gchar* (*get_name) (DataObject* self);
	gchar* (*to_string) (DataObject* self);
};

struct _DataView {
	DataObject parent_instance;
	DataViewPrivate * priv;
};

struct _DataViewClass {
	DataObjectClass parent_class;
	void (*notify_view_altered) (DataView* self);
	void (*notify_geometry_altered) (DataView* self);
	void (*notify_unsubscribed) (DataView* self, DataSource* source);
	void (*state_changed) (DataView* self, gboolean selected);
	void (*visibility_changed) (DataView* self, gboolean visible);
	void (*view_altered) (DataView* self);
	void (*geometry_altered) (DataView* self);
	void (*unsubscribed) (DataView* self, DataSource* source);
};

struct _ThumbnailView {
	DataView parent_instance;
	ThumbnailViewPrivate * priv;
};

struct _ThumbnailViewClass {
	DataViewClass parent_class;
	void (*notify_thumbnail_altered) (ThumbnailView* self);
	void (*thumbnail_altered) (ThumbnailView* self);
};

struct _Dimensions {
	gint width;
	gint height;
};

struct _CheckerboardItem {
	ThumbnailView parent_instance;
	CheckerboardItemPrivate * priv;
	Dimensions requisition;
	GdkRectangle allocation;
};

struct _CheckerboardItemClass {
	ThumbnailViewClass parent_class;
	void (*exposed) (CheckerboardItem* self);
	void (*unexposed) (CheckerboardItem* self);
	gboolean (*is_exposed) (CheckerboardItem* self);
	void (*paint_shadow) (CheckerboardItem* self, cairo_t* ctx, Dimensions* dimensions, GdkPoint* origin, gint radius, gfloat initial_alpha);
	void (*paint_border) (CheckerboardItem* self, cairo_t* ctx, Dimensions* object_dimensions, GdkPoint* object_origin, gint border_width);
	void (*paint_image) (CheckerboardItem* self, cairo_t* ctx, GdkPixbuf* pixbuf, GdkPoint* origin);
	GdkPixbuf* (*get_top_left_trinket) (CheckerboardItem* self, gint scale);
	GdkPixbuf* (*get_top_right_trinket) (CheckerboardItem* self, gint scale);
	GdkPixbuf* (*get_bottom_left_trinket) (CheckerboardItem* self, gint scale);
	GdkPixbuf* (*get_bottom_right_trinket) (CheckerboardItem* self, gint scale);
};

typedef enum  {
	COMPASS_POINT_NORTH,
	COMPASS_POINT_SOUTH,
	COMPASS_POINT_EAST,
	COMPASS_POINT_WEST
} CompassPoint;

struct _MarkerIface {
	GTypeInterface parent_iface;
	void (*mark) (Marker* self, DataObject* object);
	void (*unmark) (Marker* self, DataObject* object);
	gboolean (*toggle) (Marker* self, DataObject* object);
	void (*mark_many) (Marker* self, GeeCollection* list);
	void (*unmark_many) (Marker* self, GeeCollection* list);
	void (*mark_all) (Marker* self);
	gint (*get_count) (Marker* self);
	GeeCollection* (*get_all) (Marker* self);
};

typedef gboolean (*ValueEqualFunc) (GValue* a, GValue* b, void* user_data);
typedef enum  {
	SINGLE_PHOTO_PAGE_UPDATE_REASON_NEW_PIXBUF,
	SINGLE_PHOTO_PAGE_UPDATE_REASON_QUALITY_IMPROVEMENT,
	SINGLE_PHOTO_PAGE_UPDATE_REASON_RESIZED_CANVAS
} SinglePhotoPageUpdateReason;

struct _SinglePhotoPage {
	Page parent_instance;
	SinglePhotoPagePrivate * priv;
	GtkDrawingArea* canvas;
	GtkViewport* viewport;
};

struct _SinglePhotoPageClass {
	PageClass parent_class;
	gboolean (*is_zoom_supported) (SinglePhotoPage* self);
	void (*cancel_zoom) (SinglePhotoPage* self);
	void (*save_zoom_state) (SinglePhotoPage* self);
	void (*restore_zoom_state) (SinglePhotoPage* self);
	ZoomBuffer* (*get_zoom_buffer) (SinglePhotoPage* self);
	void (*new_surface) (SinglePhotoPage* self, cairo_t* ctx, Dimensions* ctx_dim);
	void (*updated_pixbuf) (SinglePhotoPage* self, GdkPixbuf* pixbuf, SinglePhotoPageUpdateReason reason, Dimensions* old_dim);
	void (*paint) (SinglePhotoPage* self, cairo_t* ctx, Dimensions* ctx_dim);
	void (*on_previous_photo) (SinglePhotoPage* self);
	void (*on_next_photo) (SinglePhotoPage* self);
};

struct _ZoomState {
	Dimensions content_dimensions;
	Dimensions viewport_dimensions;
	gdouble zoom_factor;
	gdouble interpolation_factor;
	gdouble min_factor;
	gdouble max_factor;
	GdkPoint viewport_center;
};

struct _SinglePhotoPagePrivate {
	gboolean scale_up_to_viewport;
	TransitionClock* transition_clock;
	gint transition_duration_msec;
	cairo_surface_t* pixmap;
	cairo_t* pixmap_ctx;
	cairo_t* text_ctx;
	Dimensions pixmap_dim;
	GdkPixbuf* unscaled;
	Dimensions max_dim;
	GdkPixbuf* scaled;
	GdkPixbuf* old_scaled;
	GdkRectangle scaled_pos;
	ZoomState static_zoom_state;
	gboolean zoom_high_quality;
	ZoomState saved_zoom_state;
	gboolean has_saved_zoom_state;
	guint32 last_nav_key;
};

typedef enum  {
	DIRECTION_FORWARD,
	DIRECTION_BACKWARD
} Direction;

typedef enum  {
	SCALE_CONSTRAINT_ORIGINAL,
	SCALE_CONSTRAINT_DIMENSIONS,
	SCALE_CONSTRAINT_WIDTH,
	SCALE_CONSTRAINT_HEIGHT,
	SCALE_CONSTRAINT_FILL_VIEWPORT
} ScaleConstraint;

struct _Scaling {
	ScaleConstraint constraint;
	gint scale;
	Dimensions viewport;
	gboolean scale_up;
};

typedef void (*TransitionClockRepaintCallback) (void* user_data);
struct _DragAndDropHandler {
	GTypeInstance parent_instance;
	volatile int ref_count;
	DragAndDropHandlerPrivate * priv;
};

struct _DragAndDropHandlerClass {
	GTypeClass parent_class;
	void (*finalize) (DragAndDropHandler *self);
};

struct _DragAndDropHandlerPrivate {
	Page* page;
	GtkWidget* event_source;
	GFile* drag_destination;
	ExporterUI* exporter;
};

typedef enum  {
	DRAG_AND_DROP_HANDLER_TARGET_TYPE_XDS,
	DRAG_AND_DROP_HANDLER_TARGET_TYPE_MEDIA_LIST
} DragAndDropHandlerTargetType;

typedef enum  {
	EXPORT_FORMAT_MODE_UNMODIFIED,
	EXPORT_FORMAT_MODE_CURRENT,
	EXPORT_FORMAT_MODE_SPECIFIED,
	EXPORT_FORMAT_MODE_LAST
} ExportFormatMode;

typedef enum  {
	PHOTO_FILE_FORMAT_JFIF,
	PHOTO_FILE_FORMAT_RAW,
	PHOTO_FILE_FORMAT_PNG,
	PHOTO_FILE_FORMAT_TIFF,
	PHOTO_FILE_FORMAT_BMP,
	PHOTO_FILE_FORMAT_UNKNOWN
} PhotoFileFormat;

typedef enum  {
	JPEG_QUALITY_LOW = 50,
	JPEG_QUALITY_MEDIUM = 75,
	JPEG_QUALITY_HIGH = 90,
	JPEG_QUALITY_MAXIMUM = 100
} JpegQuality;

struct _ExportFormatParameters {
	ExportFormatMode mode;
	PhotoFileFormat specified_format;
	JpegQuality quality;
	gboolean export_metadata;
};

typedef void (*ExporterCompletionCallback) (Exporter* exporter, gboolean is_cancelled, void* user_data);
struct _ParamSpecDragAndDropHandler {
	GParamSpec parent_instance;
};


static gpointer injection_group_parent_class = NULL;
static gpointer injection_group_element_parent_class = NULL;
static gpointer page_parent_class = NULL;
static gpointer checkerboard_page_parent_class = NULL;
static gpointer single_photo_page_parent_class = NULL;
static gpointer drag_and_drop_handler_parent_class = NULL;
static GdkAtom* drag_and_drop_handler_XDS_ATOM;
static GdkAtom* drag_and_drop_handler_XDS_ATOM = NULL;
static GdkAtom* drag_and_drop_handler_TEXT_ATOM;
static GdkAtom* drag_and_drop_handler_TEXT_ATOM = NULL;
static guint8* drag_and_drop_handler_XDS_FAKE_TARGET;
static gint drag_and_drop_handler_XDS_FAKE_TARGET_length1;
static guint8* drag_and_drop_handler_XDS_FAKE_TARGET = NULL;
static gint drag_and_drop_handler_XDS_FAKE_TARGET_length1 = 0;
static gint _drag_and_drop_handler_XDS_FAKE_TARGET_size_ = 0;

gpointer injection_group_ref (gpointer instance);
void injection_group_unref (gpointer instance);
GParamSpec* param_spec_injection_group (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_injection_group (GValue* value, gpointer v_object);
void value_take_injection_group (GValue* value, gpointer v_object);
gpointer value_get_injection_group (const GValue* value);
GType injection_group_get_type (void) G_GNUC_CONST;
gpointer injection_group_element_ref (gpointer instance);
void injection_group_element_unref (gpointer instance);
GParamSpec* injection_group_param_spec_element (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void injection_group_value_set_element (GValue* value, gpointer v_object);
void injection_group_value_take_element (GValue* value, gpointer v_object);
gpointer injection_group_value_get_element (const GValue* value);
GType injection_group_element_get_type (void) G_GNUC_CONST;
#define INJECTION_GROUP_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_INJECTION_GROUP, InjectionGroupPrivate))
enum  {
	INJECTION_GROUP_DUMMY_PROPERTY
};
InjectionGroup* injection_group_new (const gchar* path);
InjectionGroup* injection_group_construct (GType object_type, const gchar* path);
gchar* injection_group_get_path (InjectionGroup* self);
GeeList* injection_group_get_elements (InjectionGroup* self);
void injection_group_add_menu_item (InjectionGroup* self, const gchar* name, const gchar* action, const gchar* accellerator);
GType injection_group_element_item_type_get_type (void) G_GNUC_CONST;
InjectionGroupElement* injection_group_element_new (const gchar* name, const gchar* action, const gchar* accellerator, InjectionGroupElementItemType kind);
InjectionGroupElement* injection_group_element_construct (GType object_type, const gchar* name, const gchar* action, const gchar* accellerator, InjectionGroupElementItemType kind);
void injection_group_add_menu (InjectionGroup* self, const gchar* name, const gchar* action);
void injection_group_add_separator (InjectionGroup* self);
enum  {
	INJECTION_GROUP_ELEMENT_DUMMY_PROPERTY
};
static void injection_group_element_finalize (InjectionGroupElement * obj);
static void injection_group_finalize (InjectionGroup * obj);
GType page_get_type (void) G_GNUC_CONST;
GType page_window_get_type (void) G_GNUC_CONST;
GType fullscreen_window_get_type (void) G_GNUC_CONST;
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_data_collection (GValue* value, gpointer v_object);
void value_take_data_collection (GValue* value, gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType view_collection_get_type (void) G_GNUC_CONST;
gpointer one_shot_scheduler_ref (gpointer instance);
void one_shot_scheduler_unref (gpointer instance);
GParamSpec* param_spec_one_shot_scheduler (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_one_shot_scheduler (GValue* value, gpointer v_object);
void value_take_one_shot_scheduler (GValue* value, gpointer v_object);
gpointer value_get_one_shot_scheduler (const GValue* value);
GType one_shot_scheduler_get_type (void) G_GNUC_CONST;
#define PAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PAGE, PagePrivate))
enum  {
	PAGE_DUMMY_PROPERTY
};
#define PAGE_CONSIDER_CONFIGURE_HALTED_MSEC 400
Page* page_construct (GType object_type, const gchar* page_name);
ViewCollection* view_collection_new (const gchar* name);
ViewCollection* view_collection_construct (GType object_type, const gchar* name);
gboolean page_on_context_keypress (Page* self);
static gboolean _page_on_context_keypress_gtk_widget_popup_menu (GtkWidget* _sender, gpointer self);
static void page_attach_view_signals (Page* self);
static void _page_attach_view_signals_gtk_widget_realize (GtkWidget* _sender, gpointer self);
static void page_real_destroy (GtkWidget* base);
static void page_detach_event_source (Page* self);
static void page_detach_view_signals (Page* self);
void data_collection_close (DataCollection* self);
void page_clear_container (Page* self);
void one_shot_scheduler_cancel (OneShotScheduler* self);
gchar* page_get_page_name (Page* self);
void page_set_page_name (Page* self, const gchar* page_name);
static void page_real_set_page_name (Page* self, const gchar* page_name);
gchar* page_to_string (Page* self);
ViewCollection* page_get_view (Page* self);
GtkWindow* page_get_container (Page* self);
void page_set_container (Page* self, GtkWindow* container);
static void page_real_set_container (Page* self, GtkWindow* container);
static void page_real_clear_container (Page* self);
void page_set_event_source (Page* self, GtkWidget* event_source);
static gboolean page_on_button_pressed_internal (Page* self, GdkEventButton* event);
static gboolean _page_on_button_pressed_internal_gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
static gboolean page_on_button_released_internal (Page* self, GdkEventButton* event);
static gboolean _page_on_button_released_internal_gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
static gboolean page_on_motion_internal (Page* self, GdkEventMotion* event);
static gboolean _page_on_motion_internal_gtk_widget_motion_notify_event (GtkWidget* _sender, GdkEventMotion* event, gpointer self);
gboolean page_on_leave_notify_event (Page* self);
static gboolean _page_on_leave_notify_event_gtk_widget_leave_notify_event (GtkWidget* _sender, GdkEventCrossing* event, gpointer self);
static gboolean page_on_mousewheel_internal (Page* self, GdkEventScroll* event);
static gboolean _page_on_mousewheel_internal_gtk_widget_scroll_event (GtkWidget* _sender, GdkEventScroll* event, gpointer self);
void page_on_event_source_realize (Page* self);
static void _page_on_event_source_realize_gtk_widget_realize (GtkWidget* _sender, gpointer self);
void page_disable_drag_source (Page* self);
GtkWidget* page_get_event_source (Page* self);
GMenuModel* page_get_menubar (Page* self);
InjectionGroup** page_init_collect_injection_groups (Page* self, int* result_length1);
GMenuModel* page_find_extension_point (Page* self, GMenuModel* model, const gchar* extension_point);
GtkToolbar* page_get_toolbar (Page* self);
static GtkToolbar* page_real_get_toolbar (Page* self);
GtkMenu* page_get_page_context_menu (Page* self);
static GtkMenu* page_real_get_page_context_menu (Page* self);
void page_switching_from (Page* self);
static void page_real_switching_from (Page* self);
void page_remove_actions (Page* self, GActionMap* map);
void page_switched_to (Page* self);
static void page_real_switched_to (Page* self);
static void page_add_ui (Page* self);
void page_add_actions (Page* self, GActionMap* map);
gint view_collection_get_selected_count (ViewCollection* self);
gint data_collection_get_count (DataCollection* self);
void page_init_actions (Page* self, gint selected_count, gint count);
void page_update_actions (Page* self, gint selected_count, gint count);
static void page_update_modifiers (Page* self);
void page_ready (Page* self);
static void page_real_ready (Page* self);
gboolean page_is_in_view (Page* self);
void page_switching_to_fullscreen (Page* self, FullscreenWindow* fsw);
static void page_real_switching_to_fullscreen (Page* self, FullscreenWindow* fsw);
void page_returning_from_fullscreen (Page* self, FullscreenWindow* fsw);
static void page_real_returning_from_fullscreen (Page* self, FullscreenWindow* fsw);
GAction* page_get_action (Page* self, const gchar* name);
GType app_window_get_type (void) G_GNUC_CONST;
AppWindow* app_window_get_instance (void);
void page_set_action_sensitive (Page* self, const gchar* name, gboolean sensitive);
void page_set_action_important (Page* self, const gchar* name, gboolean important);
void page_set_action_visible (Page* self, const gchar* name, gboolean visible);
void page_set_action_short_label (Page* self, const gchar* name, const gchar* short_label);
void page_set_action_details (Page* self, const gchar* name, const gchar* label, const gchar* tooltip, gboolean sensitive);
void page_update_menu_item_label (Page* self, const gchar* id, const gchar* new_label);
void page_activate_action (Page* self, const gchar* name);
GAction* page_get_common_action (Page* self, const gchar* name, gboolean log_warning);
void page_set_common_action_sensitive (Page* self, const gchar* name, gboolean sensitive);
void page_set_common_action_label (Page* self, const gchar* name, const gchar* label);
void page_set_common_action_important (Page* self, const gchar* name, gboolean important);
void page_activate_common_action (Page* self, const gchar* name);
gboolean page_get_ctrl_pressed (Page* self);
gboolean page_get_alt_pressed (Page* self);
gboolean page_get_shift_pressed (Page* self);
gboolean page_get_super_pressed (Page* self);
void page_set_action_active (Page* self, const gchar* name, gboolean active);
static GVariant* _variant_new20 (gboolean value);
static gboolean page_get_modifiers (Page* self, gboolean* ctrl, gboolean* alt, gboolean* shift, gboolean* super);
gboolean page_on_ctrl_released (Page* self, GdkEventKey* event);
gboolean page_on_ctrl_pressed (Page* self, GdkEventKey* event);
gboolean page_on_alt_released (Page* self, GdkEventKey* event);
gboolean page_on_alt_pressed (Page* self, GdkEventKey* event);
gboolean page_on_shift_released (Page* self, GdkEventKey* event);
gboolean page_on_shift_pressed (Page* self, GdkEventKey* event);
gboolean page_on_super_released (Page* self, GdkEventKey* event);
gboolean page_on_super_pressed (Page* self, GdkEventKey* event);
PageWindow* page_get_page_window (Page* self);
gpointer command_manager_ref (gpointer instance);
void command_manager_unref (gpointer instance);
GParamSpec* param_spec_command_manager (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_command_manager (GValue* value, gpointer v_object);
void value_take_command_manager (GValue* value, gpointer v_object);
gpointer value_get_command_manager (const GValue* value);
GType command_manager_get_type (void) G_GNUC_CONST;
CommandManager* page_get_command_manager (Page* self);
CommandManager* app_window_get_command_manager (void);
static void page_real_add_actions (Page* self, GActionMap* map);
static void page_real_remove_actions (Page* self, GActionMap* map);
void page_on_action_toggle (Page* self, GAction* action, GVariant* value);
static gboolean _variant_get21 (GVariant* value);
static GVariant* _variant_new22 (gboolean value);
void page_on_action_radio (Page* self, GAction* action, GVariant* value);
void page_init_collect_ui_filenames (Page* self, GeeList* ui_filenames);
static void page_init_load_ui (Page* self, const gchar* ui_filename);
void page_init_toolbar (Page* self, const gchar* path);
static void page_on_update_actions (Page* self);
GType data_object_get_type (void) G_GNUC_CONST;
GType data_view_get_type (void) G_GNUC_CONST;
static void _page_on_update_actions_view_collection_items_state_changed (ViewCollection* _sender, GeeIterable* changed, gpointer self);
static void _page_on_update_actions_view_collection_selection_group_altered (ViewCollection* _sender, gpointer self);
static void _page_on_update_actions_view_collection_items_visibility_changed (ViewCollection* _sender, GeeCollection* changed, gpointer self);
static void _page_on_update_actions_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self);
static void page_on_update_actions_on_idle (Page* self);
static void _page_on_update_actions_on_idle_one_shot_callback (gpointer self);
OneShotScheduler* one_shot_scheduler_new (const gchar* name, OneShotCallback callback, void* callback_target);
OneShotScheduler* one_shot_scheduler_construct (GType object_type, const gchar* name, OneShotCallback callback, void* callback_target);
void one_shot_scheduler_at_priority_idle (OneShotScheduler* self, gint priority);
gchar* resources_get_ui (const gchar* filename);
void app_window_error_message (const gchar* message, GtkWindow* parent);
gpointer application_ref (gpointer instance);
void application_unref (gpointer instance);
GParamSpec* param_spec_application (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_application (GValue* value, gpointer v_object);
void value_take_application (GValue* value, gpointer v_object);
gpointer value_get_application (const GValue* value);
GType application_get_type (void) G_GNUC_CONST;
Application* application_get_instance (void);
void application_panic (Application* self);
static void page_real_init_collect_ui_filenames (Page* self, GeeList* ui_filenames);
static InjectionGroup** page_real_init_collect_injection_groups (Page* self, int* result_length1);
static void page_real_init_actions (Page* self, gint selected_count, gint count);
static void page_real_update_actions (Page* self, gint selected_count, gint count);
void page_enable_drag_source (Page* self, GdkDragAction actions, GtkTargetEntry* source_target_entries, int source_target_entries_length1);
static void page_on_drag_begin (Page* self, GdkDragContext* context);
static void _page_on_drag_begin_gtk_widget_drag_begin (GtkWidget* _sender, GdkDragContext* context, gpointer self);
static void page_on_drag_data_get (Page* self, GdkDragContext* context, GtkSelectionData* selection_data, guint info, guint time);
static void _page_on_drag_data_get_gtk_widget_drag_data_get (GtkWidget* _sender, GdkDragContext* context, GtkSelectionData* selection_data, guint info, guint time_, gpointer self);
static void page_on_drag_data_delete (Page* self, GdkDragContext* context);
static void _page_on_drag_data_delete_gtk_widget_drag_data_delete (GtkWidget* _sender, GdkDragContext* context, gpointer self);
static void page_on_drag_end (Page* self, GdkDragContext* context);
static void _page_on_drag_end_gtk_widget_drag_end (GtkWidget* _sender, GdkDragContext* context, gpointer self);
static gboolean page_on_drag_failed (Page* self, GdkDragContext* context, GtkDragResult drag_result);
static gboolean _page_on_drag_failed_gtk_widget_drag_failed (GtkWidget* _sender, GdkDragContext* context, GtkDragResult _result_, gpointer self);
gboolean page_is_dnd_enabled (Page* self);
gboolean page_source_drag_failed (Page* self, GdkDragContext* context, GtkDragResult drag_result);
static gboolean page_real_source_drag_failed (Page* self, GdkDragContext* context, GtkDragResult drag_result);
gboolean page_get_event_source_pointer (Page* self, gint* x, gint* y, GdkModifierType* mask);
gboolean page_on_left_click (Page* self, GdkEventButton* event);
static gboolean page_real_on_left_click (Page* self, GdkEventButton* event);
gboolean page_on_middle_click (Page* self, GdkEventButton* event);
static gboolean page_real_on_middle_click (Page* self, GdkEventButton* event);
gboolean page_on_right_click (Page* self, GdkEventButton* event);
static gboolean page_real_on_right_click (Page* self, GdkEventButton* event);
gboolean page_on_left_released (Page* self, GdkEventButton* event);
static gboolean page_real_on_left_released (Page* self, GdkEventButton* event);
gboolean page_on_middle_released (Page* self, GdkEventButton* event);
static gboolean page_real_on_middle_released (Page* self, GdkEventButton* event);
gboolean page_on_right_released (Page* self, GdkEventButton* event);
static gboolean page_real_on_right_released (Page* self, GdkEventButton* event);
static gboolean page_real_on_ctrl_pressed (Page* self, GdkEventKey* event);
static gboolean page_real_on_ctrl_released (Page* self, GdkEventKey* event);
static gboolean page_real_on_alt_pressed (Page* self, GdkEventKey* event);
static gboolean page_real_on_alt_released (Page* self, GdkEventKey* event);
static gboolean page_real_on_shift_pressed (Page* self, GdkEventKey* event);
static gboolean page_real_on_shift_released (Page* self, GdkEventKey* event);
static gboolean page_real_on_super_pressed (Page* self, GdkEventKey* event);
static gboolean page_real_on_super_released (Page* self, GdkEventKey* event);
gboolean page_on_app_key_pressed (Page* self, GdkEventKey* event);
static gboolean page_real_on_app_key_pressed (Page* self, GdkEventKey* event);
gboolean page_on_app_key_released (Page* self, GdkEventKey* event);
static gboolean page_real_on_app_key_released (Page* self, GdkEventKey* event);
gboolean page_notify_app_key_pressed (Page* self, GdkEventKey* event);
gboolean page_notify_app_key_released (Page* self, GdkEventKey* event);
gboolean page_notify_app_focus_in (Page* self, GdkEventFocus* event);
gboolean page_notify_app_focus_out (Page* self, GdkEventFocus* event);
void page_on_move (Page* self, GdkRectangle* rect);
static void page_real_on_move (Page* self, GdkRectangle* rect);
void page_on_move_start (Page* self, GdkRectangle* rect);
static void page_real_on_move_start (Page* self, GdkRectangle* rect);
void page_on_move_finished (Page* self, GdkRectangle* rect);
static void page_real_on_move_finished (Page* self, GdkRectangle* rect);
void page_on_resize (Page* self, GdkRectangle* rect);
static void page_real_on_resize (Page* self, GdkRectangle* rect);
void page_on_resize_start (Page* self, GdkRectangle* rect);
static void page_real_on_resize_start (Page* self, GdkRectangle* rect);
void page_on_resize_finished (Page* self, GdkRectangle* rect);
static void page_real_on_resize_finished (Page* self, GdkRectangle* rect);
gboolean page_on_configure (Page* self, GdkEventConfigure* event, GdkRectangle* rect);
static gboolean page_real_on_configure (Page* self, GdkEventConfigure* event, GdkRectangle* rect);
gboolean page_notify_configure_event (Page* self, GdkEventConfigure* event);
static gboolean page_check_configure_halted (Page* self);
static gboolean _page_check_configure_halted_gsource_func (gpointer self);
gulong now_ms (void);
gboolean page_on_motion (Page* self, GdkEventMotion* event, gint x, gint y, GdkModifierType mask);
static gboolean page_real_on_motion (Page* self, GdkEventMotion* event, gint x, gint y, GdkModifierType mask);
static void page_check_cursor_hiding (Page* self);
static gboolean page_real_on_leave_notify_event (Page* self);
gboolean page_on_mousewheel_up (Page* self, GdkEventScroll* event);
gboolean page_on_mousewheel_down (Page* self, GdkEventScroll* event);
gboolean page_on_mousewheel_left (Page* self, GdkEventScroll* event);
gboolean page_on_mousewheel_right (Page* self, GdkEventScroll* event);
static gboolean page_real_on_mousewheel_up (Page* self, GdkEventScroll* event);
static gboolean page_real_on_mousewheel_down (Page* self, GdkEventScroll* event);
static gboolean page_real_on_mousewheel_left (Page* self, GdkEventScroll* event);
static gboolean page_real_on_mousewheel_right (Page* self, GdkEventScroll* event);
static gboolean page_real_on_context_keypress (Page* self);
gboolean page_on_context_buttonpress (Page* self, GdkEventButton* event);
static gboolean page_real_on_context_buttonpress (Page* self, GdkEventButton* event);
gboolean page_on_context_invoked (Page* self);
static gboolean page_real_on_context_invoked (Page* self);
gboolean page_popup_context_menu (Page* self, GtkMenu* context_menu, GdkEventButton* event);
void page_set_cursor_hide_time (Page* self, gint hide_time);
void page_start_cursor_hiding (Page* self);
void page_stop_cursor_hiding (Page* self);
void page_suspend_cursor_hiding (Page* self);
void page_restore_cursor_hiding (Page* self);
void page_set_page_cursor (Page* self, GdkCursorType cursor_type);
static void page_real_set_page_cursor (Page* self, GdkCursorType cursor_type);
static gboolean page_on_hide_cursor (Page* self);
static gboolean _page_on_hide_cursor_gsource_func (gpointer self);
void app_window_update_menu_item_label (AppWindow* self, const gchar* id, const gchar* new_label);
static void page_finalize (GObject * obj);
GType checkerboard_page_get_type (void) G_GNUC_CONST;
GType thumbnail_view_get_type (void) G_GNUC_CONST;
GType checkerboard_item_get_type (void) G_GNUC_CONST;
GType checkerboard_page_activator_get_type (void) G_GNUC_CONST;
GType checkerboard_page_keyboard_modifiers_get_type (void) G_GNUC_CONST;
CheckerboardPageKeyboardModifiers* checkerboard_page_keyboard_modifiers_dup (const CheckerboardPageKeyboardModifiers* self);
void checkerboard_page_keyboard_modifiers_free (CheckerboardPageKeyboardModifiers* self);
gpointer view_filter_ref (gpointer instance);
void view_filter_unref (gpointer instance);
GParamSpec* param_spec_view_filter (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_view_filter (GValue* value, gpointer v_object);
void value_take_view_filter (GValue* value, gpointer v_object);
gpointer value_get_view_filter (const GValue* value);
GType view_filter_get_type (void) G_GNUC_CONST;
GType search_view_filter_get_type (void) G_GNUC_CONST;
gpointer core_tracker_ref (gpointer instance);
void core_tracker_unref (gpointer instance);
GParamSpec* core_param_spec_tracker (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void core_value_set_tracker (GValue* value, gpointer v_object);
void core_value_take_tracker (GValue* value, gpointer v_object);
gpointer core_value_get_tracker (const GValue* value);
GType core_tracker_get_type (void) G_GNUC_CONST;
GType core_view_tracker_get_type (void) G_GNUC_CONST;
GType checkerboard_layout_get_type (void) G_GNUC_CONST;
#define CHECKERBOARD_PAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_CHECKERBOARD_PAGE, CheckerboardPagePrivate))
enum  {
	CHECKERBOARD_PAGE_DUMMY_PROPERTY
};
#define CHECKERBOARD_PAGE_AUTOSCROLL_PIXELS 50
#define CHECKERBOARD_PAGE_AUTOSCROLL_TICKS_MSEC 50
CheckerboardPage* checkerboard_page_construct (GType object_type, const gchar* page_name);
CheckerboardLayout* checkerboard_layout_new (ViewCollection* view);
CheckerboardLayout* checkerboard_layout_construct (GType object_type, ViewCollection* view);
void checkerboard_layout_set_name (CheckerboardLayout* self, const gchar* name);
void checkerboard_layout_set_adjustments (CheckerboardLayout* self, GtkAdjustment* hadjustment, GtkAdjustment* vadjustment);
static void checkerboard_page_on_items_hidden (CheckerboardPage* self, GeeIterable* hidden);
static void _checkerboard_page_on_items_hidden_view_collection_items_hidden (ViewCollection* _sender, GeeCollection* hidden, gpointer self);
static void checkerboard_page_on_contents_altered (CheckerboardPage* self, GeeIterable* added, GeeIterable* removed);
static void _checkerboard_page_on_contents_altered_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self);
static void checkerboard_page_on_items_state_changed (CheckerboardPage* self, GeeIterable* changed);
static void _checkerboard_page_on_items_state_changed_view_collection_items_state_changed (ViewCollection* _sender, GeeIterable* changed, gpointer self);
static void checkerboard_page_on_items_visibility_changed (CheckerboardPage* self, GeeCollection* changed);
static void _checkerboard_page_on_items_visibility_changed_view_collection_items_visibility_changed (ViewCollection* _sender, GeeCollection* changed, gpointer self);
void checkerboard_page_init_item_context_menu (CheckerboardPage* self, const gchar* path);
void checkerboard_page_init_page_context_menu (CheckerboardPage* self, const gchar* path);
GtkMenu* checkerboard_page_get_context_menu (CheckerboardPage* self);
GtkMenu* checkerboard_page_get_item_context_menu (CheckerboardPage* self);
static GtkMenu* checkerboard_page_real_get_item_context_menu (CheckerboardPage* self);
static GtkMenu* checkerboard_page_real_get_page_context_menu (Page* base);
static gboolean checkerboard_page_real_on_context_keypress (Page* base);
gchar* checkerboard_page_get_view_empty_message (CheckerboardPage* self);
static gchar* checkerboard_page_real_get_view_empty_message (CheckerboardPage* self);
gchar* checkerboard_page_get_filter_no_match_message (CheckerboardPage* self);
static gchar* checkerboard_page_real_get_filter_no_match_message (CheckerboardPage* self);
void checkerboard_page_on_item_activated (CheckerboardPage* self, CheckerboardItem* item, CheckerboardPageActivator activator, CheckerboardPageKeyboardModifiers* modifiers);
static void checkerboard_page_real_on_item_activated (CheckerboardPage* self, CheckerboardItem* item, CheckerboardPageActivator activator, CheckerboardPageKeyboardModifiers* modifiers);
CheckerboardLayout* checkerboard_page_get_checkerboard_layout (CheckerboardPage* self);
SearchViewFilter* checkerboard_page_get_search_view_filter (CheckerboardPage* self);
static SearchViewFilter* checkerboard_page_real_get_search_view_filter (CheckerboardPage* self);
CoreViewTracker* checkerboard_page_get_view_tracker (CheckerboardPage* self);
static CoreViewTracker* checkerboard_page_real_get_view_tracker (CheckerboardPage* self);
static void checkerboard_page_real_switching_from (Page* base);
void checkerboard_layout_set_in_view (CheckerboardLayout* self, gboolean in_view);
static void checkerboard_page_on_view_filter_refresh (CheckerboardPage* self);
static void _checkerboard_page_on_view_filter_refresh_view_filter_refresh (ViewFilter* _sender, gpointer self);
void view_collection_unselect_all (ViewCollection* self);
static void checkerboard_page_real_switched_to (Page* base);
DataView* view_collection_get_selected_at (ViewCollection* self, gint index);
GType adjustment_relation_get_type (void) G_GNUC_CONST;
AdjustmentRelation get_adjustment_relation (GtkAdjustment* adjustment, gint value);
gpointer alteration_ref (gpointer instance);
void alteration_unref (gpointer instance);
GParamSpec* param_spec_alteration (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_alteration (GValue* value, gpointer v_object);
void value_take_alteration (GValue* value, gpointer v_object);
gpointer value_get_alteration (const GValue* value);
GType alteration_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType dimensions_get_type (void) G_GNUC_CONST;
Dimensions* dimensions_dup (const Dimensions* self);
void dimensions_free (Dimensions* self);
#define CHECKERBOARD_LAYOUT_ROW_GUTTER_PADDING 24
static void checkerboard_page_update_view_filter_message (CheckerboardPage* self);
gboolean view_collection_are_items_filtered_out (ViewCollection* self);
void checkerboard_page_set_page_message (CheckerboardPage* self, const gchar* message);
void checkerboard_page_unset_page_message (CheckerboardPage* self);
void checkerboard_layout_set_message (CheckerboardLayout* self, const gchar* text);
void checkerboard_layout_unset_message (CheckerboardLayout* self);
static void checkerboard_page_real_set_page_name (Page* base, const gchar* name);
CheckerboardItem* checkerboard_page_get_item_at_pixel (CheckerboardPage* self, gdouble x, gdouble y);
CheckerboardItem* checkerboard_layout_get_item_at_pixel (CheckerboardLayout* self, gdouble xd, gdouble yd);
static gboolean checkerboard_page_real_key_press_event (GtkWidget* base, GdkEventKey* event);
GType compass_point_get_type (void) G_GNUC_CONST;
void checkerboard_page_move_cursor (CheckerboardPage* self, CompassPoint point);
void checkerboard_page_select_anchor_to_cursor (CheckerboardPage* self, guint state);
DataView* view_collection_get_first (ViewCollection* self);
void checkerboard_page_cursor_to_item (CheckerboardPage* self, CheckerboardItem* item);
DataView* view_collection_get_last (ViewCollection* self);
void checkerboard_page_keyboard_modifiers_init (CheckerboardPageKeyboardModifiers *self, Page* page);
GType marker_get_type (void) G_GNUC_CONST;
Marker* data_collection_mark (DataCollection* self, DataObject* object);
CheckerboardItem* checkerboard_layout_get_cursor (CheckerboardLayout* self);
void view_collection_toggle_marked (ViewCollection* self, Marker* marker);
static gboolean checkerboard_page_real_on_left_click (Page* base, GdkEventButton* event);
gboolean checkerboard_layout_handle_left_click (CheckerboardLayout* self, CheckerboardItem* item, gdouble xd, gdouble yd, GdkModifierType mask);
gboolean data_view_is_selected (DataView* self);
void checkerboard_page_select_between_items (CheckerboardPage* self, CheckerboardItem* item_start, CheckerboardItem* item_end);
Marker* data_collection_start_marking (DataCollection* self);
void marker_mark_many (Marker* self, GeeCollection* list);
GeeList* view_collection_get_selected (ViewCollection* self);
void view_collection_unselect_and_select_marked (ViewCollection* self, Marker* unselect, Marker* select);
void checkerboard_layout_set_cursor (CheckerboardLayout* self, CheckerboardItem* item);
void checkerboard_layout_set_drag_select_origin (CheckerboardLayout* self, gint x, gint y);
static gboolean checkerboard_page_real_on_left_released (Page* base, GdkEventButton* event);
gboolean checkerboard_layout_is_drag_select_active (CheckerboardLayout* self);
void checkerboard_layout_clear_drag_select (CheckerboardLayout* self);
void view_collection_unselect_all_but (ViewCollection* self, DataView* exception);
static gboolean checkerboard_page_real_on_right_click (Page* base, GdkEventButton* event);
gboolean checkerboard_page_on_mouse_over (CheckerboardPage* self, CheckerboardItem* item, gint x, gint y, GdkModifierType mask);
static gboolean checkerboard_page_real_on_mouse_over (CheckerboardPage* self, CheckerboardItem* item, gint x, gint y, GdkModifierType mask);
gboolean checkerboard_layout_handle_mouse_motion (CheckerboardLayout* self, CheckerboardItem* item, gint x, gint y, GdkModifierType mask);
void checkerboard_item_unbrighten (CheckerboardItem* self);
void checkerboard_item_brighten (CheckerboardItem* self);
static gboolean checkerboard_page_real_on_motion (Page* base, GdkEventMotion* event, gint x, gint y, GdkModifierType mask);
void checkerboard_layout_set_drag_select_endpoint (CheckerboardLayout* self, gint x, gint y);
static void checkerboard_page_updated_selection_band (CheckerboardPage* self);
static gboolean checkerboard_page_selection_autoscroll (CheckerboardPage* self);
static gboolean _checkerboard_page_selection_autoscroll_gsource_func (gpointer self);
GeeList* checkerboard_layout_items_in_selection_band (CheckerboardLayout* self);
void marker_unmark_many (Marker* self, GeeCollection* list);
gboolean marker_toggle (Marker* self, DataObject* object);
void marker_unmark (Marker* self, DataObject* object);
void marker_mark (Marker* self, DataObject* object);
void view_collection_select_marked (ViewCollection* self, Marker* marker);
void view_collection_unselect_marked (ViewCollection* self, Marker* marker);
gboolean data_collection_contains (DataCollection* self, DataObject* object);
CheckerboardItem* checkerboard_layout_get_item_at_coordinate (CheckerboardLayout* self, gint col, gint row);
CheckerboardItem* checkerboard_layout_get_item_relative_to (CheckerboardLayout* self, CheckerboardItem* item, CompassPoint point);
void checkerboard_page_set_cursor (CheckerboardPage* self, CheckerboardItem* item);
GeeCollection* data_collection_get_all (DataCollection* self);
void checkerboard_page_set_display_titles (CheckerboardPage* self, gboolean display);
static void checkerboard_page_real_set_display_titles (CheckerboardPage* self, gboolean display);
void data_collection_freeze_notifications (DataCollection* self);
void data_collection_set_property (DataCollection* self, const gchar* name, GValue* val, ValueEqualFunc value_equals, void* value_equals_target);
#define CHECKERBOARD_ITEM_PROP_SHOW_TITLES "show-titles"
void data_collection_thaw_notifications (DataCollection* self);
void checkerboard_page_set_display_comments (CheckerboardPage* self, gboolean display);
static void checkerboard_page_real_set_display_comments (CheckerboardPage* self, gboolean display);
#define CHECKERBOARD_ITEM_PROP_SHOW_COMMENTS "show-comments"
static void checkerboard_page_finalize (GObject * obj);
GType single_photo_page_get_type (void) G_GNUC_CONST;
GType zoom_buffer_get_type (void) G_GNUC_CONST;
GType single_photo_page_update_reason_get_type (void) G_GNUC_CONST;
gpointer transition_clock_ref (gpointer instance);
void transition_clock_unref (gpointer instance);
GParamSpec* param_spec_transition_clock (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_transition_clock (GValue* value, gpointer v_object);
void value_take_transition_clock (GValue* value, gpointer v_object);
gpointer value_get_transition_clock (const GValue* value);
GType transition_clock_get_type (void) G_GNUC_CONST;
GType zoom_state_get_type (void) G_GNUC_CONST;
ZoomState* zoom_state_dup (const ZoomState* self);
void zoom_state_free (ZoomState* self);
#define SINGLE_PHOTO_PAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPagePrivate))
enum  {
	SINGLE_PHOTO_PAGE_DUMMY_PROPERTY
};
void dimensions_init (Dimensions *self, gint width, gint height);
#define SINGLE_PHOTO_PAGE_FAST_INTERP GDK_INTERP_NEAREST
#define SINGLE_PHOTO_PAGE_QUALITY_INTERP GDK_INTERP_BILINEAR
#define SINGLE_PHOTO_PAGE_KEY_REPEAT_INTERVAL_MSEC 200
SinglePhotoPage* single_photo_page_construct (GType object_type, const gchar* page_name, gboolean scale_up_to_viewport);
gpointer transition_effects_manager_ref (gpointer instance);
void transition_effects_manager_unref (gpointer instance);
GParamSpec* param_spec_transition_effects_manager (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_transition_effects_manager (GValue* value, gpointer v_object);
void value_take_transition_effects_manager (GValue* value, gpointer v_object);
gpointer value_get_transition_effects_manager (const GValue* value);
GType transition_effects_manager_get_type (void) G_GNUC_CONST;
TransitionEffectsManager* transition_effects_manager_get_instance (void);
TransitionClock* transition_effects_manager_create_null_transition_clock (TransitionEffectsManager* self);
static void single_photo_page_on_viewport_resize (SinglePhotoPage* self);
static void _single_photo_page_on_viewport_resize_gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self);
static gboolean single_photo_page_on_canvas_exposed (SinglePhotoPage* self, cairo_t* exposed_ctx);
static gboolean _single_photo_page_on_canvas_exposed_gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self);
gboolean single_photo_page_is_transition_in_progress (SinglePhotoPage* self);
gboolean transition_clock_is_in_progress (TransitionClock* self);
void single_photo_page_cancel_transition (SinglePhotoPage* self);
void transition_clock_cancel (TransitionClock* self);
void single_photo_page_set_transition (SinglePhotoPage* self, const gchar* effect_id, gint duration_msec);
TransitionClock* transition_effects_manager_create_transition_clock (TransitionEffectsManager* self, const gchar* effect_id);
static void single_photo_page_render_zoomed_to_pixmap (SinglePhotoPage* self, ZoomState* zoom_state);
gboolean single_photo_page_is_zoom_supported (SinglePhotoPage* self);
void zoom_state_get_viewing_rectangle_wrt_content (ZoomState *self, GdkRectangle* result);
ZoomBuffer* single_photo_page_get_zoom_buffer (SinglePhotoPage* self);
GdkPixbuf* zoom_buffer_get_zoomed_image (ZoomBuffer* self, ZoomState* zoom_state);
GdkPixbuf* zoom_buffer_get_zoom_preview_image (ZoomBuffer* self, ZoomState* zoom_state);
void zoom_state_get_viewing_rectangle_projection (ZoomState *self, GdkPixbuf* for_pixbuf, GdkRectangle* result);
void single_photo_page_on_interactive_zoom (SinglePhotoPage* self, ZoomState* interactive_zoom_state);
void set_source_color_from_string (cairo_t* ctx, const gchar* spec);
void single_photo_page_on_interactive_pan (SinglePhotoPage* self, ZoomState* interactive_zoom_state);
static gboolean single_photo_page_real_is_zoom_supported (SinglePhotoPage* self);
void single_photo_page_cancel_zoom (SinglePhotoPage* self);
static void single_photo_page_real_cancel_zoom (SinglePhotoPage* self);
void single_photo_page_save_zoom_state (SinglePhotoPage* self);
static void single_photo_page_real_save_zoom_state (SinglePhotoPage* self);
void single_photo_page_restore_zoom_state (SinglePhotoPage* self);
static void single_photo_page_real_restore_zoom_state (SinglePhotoPage* self);
GType direction_get_type (void) G_GNUC_CONST;
void single_photo_page_repaint (SinglePhotoPage* self, Direction* direction);
static ZoomBuffer* single_photo_page_real_get_zoom_buffer (SinglePhotoPage* self);
void single_photo_page_get_saved_zoom_state (SinglePhotoPage* self, ZoomState* result);
void single_photo_page_set_zoom_state (SinglePhotoPage* self, ZoomState* zoom_state);
void single_photo_page_get_zoom_state (SinglePhotoPage* self, ZoomState* result);
static void single_photo_page_real_switched_to (Page* base);
static void single_photo_page_real_set_container (Page* base, GtkWindow* container);
void single_photo_page_set_pixbuf (SinglePhotoPage* self, GdkPixbuf* unscaled, Dimensions* max_dim, Direction* direction);
gdouble zoom_state_get_interpolation_factor (ZoomState *self);
void zoom_state_get_viewport_center (ZoomState *self, GdkPoint* result);
void zoom_state_init (ZoomState *self, Dimensions* content_dimensions, Dimensions* viewport_dimensions, gdouble slider_val, GdkPoint* viewport_center);
void single_photo_page_blank_display (SinglePhotoPage* self);
void single_photo_page_invalidate_all (SinglePhotoPage* self);
cairo_surface_t* single_photo_page_get_surface (SinglePhotoPage* self);
void single_photo_page_get_surface_dim (SinglePhotoPage* self, Dimensions* result);
cairo_t* single_photo_page_get_cairo_context (SinglePhotoPage* self);
void single_photo_page_paint_text (SinglePhotoPage* self, PangoLayout* pango_layout, gint x, gint y);
GType scaling_get_type (void) G_GNUC_CONST;
GType scale_constraint_get_type (void) G_GNUC_CONST;
Scaling* scaling_dup (const Scaling* self);
void scaling_free (Scaling* self);
void single_photo_page_get_canvas_scaling (SinglePhotoPage* self, Scaling* result);
void scaling_for_screen (GtkWindow* window, gboolean scale_up, Scaling* result);
void scaling_for_widget (GtkWidget* widget, gboolean scale_up, Scaling* result);
GdkPixbuf* single_photo_page_get_unscaled_pixbuf (SinglePhotoPage* self);
GdkPixbuf* single_photo_page_get_scaled_pixbuf (SinglePhotoPage* self);
void single_photo_page_get_scaled_pixbuf_position (SinglePhotoPage* self, GdkRectangle* result);
gboolean single_photo_page_is_inside_pixbuf (SinglePhotoPage* self, gint x, gint y);
gboolean coord_in_rectangle (gint x, gint y, GdkRectangle* rect);
void single_photo_page_invalidate (SinglePhotoPage* self, GdkRectangle* rect);
static void single_photo_page_internal_repaint (SinglePhotoPage* self, gboolean fast, Direction* direction);
static void single_photo_page_real_on_resize_finished (Page* base, GdkRectangle* rect);
void single_photo_page_new_surface (SinglePhotoPage* self, cairo_t* ctx, Dimensions* ctx_dim);
static void single_photo_page_real_new_surface (SinglePhotoPage* self, cairo_t* ctx, Dimensions* ctx_dim);
void single_photo_page_updated_pixbuf (SinglePhotoPage* self, GdkPixbuf* pixbuf, SinglePhotoPageUpdateReason reason, Dimensions* old_dim);
static void single_photo_page_real_updated_pixbuf (SinglePhotoPage* self, GdkPixbuf* pixbuf, SinglePhotoPageUpdateReason reason, Dimensions* old_dim);
void single_photo_page_paint (SinglePhotoPage* self, cairo_t* ctx, Dimensions* ctx_dim);
static void single_photo_page_real_paint (SinglePhotoPage* self, cairo_t* ctx, Dimensions* ctx_dim);
gboolean zoom_state_is_default (ZoomState *self);
gboolean transition_clock_paint (TransitionClock* self, cairo_t* ctx, gint width, gint height);
static void single_photo_page_repaint_pixmap (SinglePhotoPage* self);
void dimensions_for_rectangle (GdkRectangle* rect, Dimensions* result);
static void single_photo_page_init_pixmap (SinglePhotoPage* self, gint width, gint height);
void dimensions_for_pixbuf (GdkPixbuf* pixbuf, Dimensions* result);
gboolean dimensions_has_area (Dimensions *self);
void dimensions_get_scaled_proportional (Dimensions *self, Dimensions* viewport, Dimensions* result);
GdkPixbuf* resize_pixbuf (GdkPixbuf* pixbuf, Dimensions* resized, GdkInterpType interp);
void parse_color (const gchar* spec, GdkRGBA* result);
void transition_clock_start (TransitionClock* self, SpitTransitionsVisuals* visuals, SpitTransitionsDirection direction, gint duration_msec, TransitionClockRepaintCallback repaint, void* repaint_target);
SpitTransitionsDirection direction_to_transition_direction (Direction self);
static void _single_photo_page_repaint_pixmap_transition_clock_repaint_callback (gpointer self);
static gboolean single_photo_page_real_on_context_keypress (Page* base);
void single_photo_page_on_previous_photo (SinglePhotoPage* self);
static void single_photo_page_real_on_previous_photo (SinglePhotoPage* self);
void single_photo_page_on_next_photo (SinglePhotoPage* self);
static void single_photo_page_real_on_next_photo (SinglePhotoPage* self);
static gboolean single_photo_page_real_key_press_event (GtkWidget* base, GdkEventKey* event);
static void single_photo_page_finalize (GObject * obj);
gpointer drag_and_drop_handler_ref (gpointer instance);
void drag_and_drop_handler_unref (gpointer instance);
GParamSpec* param_spec_drag_and_drop_handler (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_drag_and_drop_handler (GValue* value, gpointer v_object);
void value_take_drag_and_drop_handler (GValue* value, gpointer v_object);
gpointer value_get_drag_and_drop_handler (const GValue* value);
GType drag_and_drop_handler_get_type (void) G_GNUC_CONST;
gpointer exporter_ui_ref (gpointer instance);
void exporter_ui_unref (gpointer instance);
GParamSpec* param_spec_exporter_ui (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_exporter_ui (GValue* value, gpointer v_object);
void value_take_exporter_ui (GValue* value, gpointer v_object);
gpointer value_get_exporter_ui (const GValue* value);
GType exporter_ui_get_type (void) G_GNUC_CONST;
#define DRAG_AND_DROP_HANDLER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_DRAG_AND_DROP_HANDLER, DragAndDropHandlerPrivate))
enum  {
	DRAG_AND_DROP_HANDLER_DUMMY_PROPERTY
};
static void drag_and_drop_handler_on_drag_begin (DragAndDropHandler* self, GdkDragContext* context);
static void _drag_and_drop_handler_on_drag_begin_gtk_widget_drag_begin (GtkWidget* _sender, GdkDragContext* context, gpointer self);
static void drag_and_drop_handler_on_drag_data_get (DragAndDropHandler* self, GdkDragContext* context, GtkSelectionData* selection_data, guint target_type, guint time);
static void _drag_and_drop_handler_on_drag_data_get_gtk_widget_drag_data_get (GtkWidget* _sender, GdkDragContext* context, GtkSelectionData* selection_data, guint info, guint time_, gpointer self);
static void drag_and_drop_handler_on_drag_end (DragAndDropHandler* self);
static void _drag_and_drop_handler_on_drag_end_gtk_widget_drag_end (GtkWidget* _sender, GdkDragContext* context, gpointer self);
static gboolean drag_and_drop_handler_on_drag_failed (DragAndDropHandler* self, GdkDragContext* context, GtkDragResult drag_result);
static gboolean _drag_and_drop_handler_on_drag_failed_gtk_widget_drag_failed (GtkWidget* _sender, GdkDragContext* context, GtkDragResult _result_, gpointer self);
static GType drag_and_drop_handler_target_type_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
DragAndDropHandler* drag_and_drop_handler_new (Page* page);
DragAndDropHandler* drag_and_drop_handler_construct (GType object_type, Page* page);
static GdkAtom* _gdk_atom_dup (GdkAtom* self);
guchar* string_to_uchar_array (const gchar* str, int* result_length1);
GType thumbnail_source_get_type (void) G_GNUC_CONST;
DataSource* data_view_get_source (DataView* self);
GdkPixbuf* thumbnail_source_get_thumbnail (ThumbnailSource* self, gint scale, GError** error);
#define APP_WINDOW_DND_ICON_SCALE 128
gchar* data_object_to_string (DataObject* self);
gchar* uchar_array_to_string (guchar* data, int data_length1, gint length);
GType media_source_get_type (void) G_GNUC_CONST;
GeeList* view_collection_get_selected_sources (ViewCollection* self);
guchar* serialize_media_sources (GeeCollection* media, int* result_length1);
GType photo_source_get_type (void) G_GNUC_CONST;
GType photo_get_type (void) G_GNUC_CONST;
void scaling_for_original (Scaling* result);
GType export_format_parameters_get_type (void) G_GNUC_CONST;
GType export_format_mode_get_type (void) G_GNUC_CONST;
GType photo_file_format_get_type (void) G_GNUC_CONST;
GType jpeg_quality_get_type (void) G_GNUC_CONST;
ExportFormatParameters* export_format_parameters_dup (const ExportFormatParameters* self);
void export_format_parameters_free (ExportFormatParameters* self);
void export_format_parameters_current (ExportFormatParameters* result);
Exporter* exporter_new (GeeCollection* to_export, GFile* dir, Scaling* scaling, ExportFormatParameters* export_params, gboolean auto_replace_all);
Exporter* exporter_construct (GType object_type, GeeCollection* to_export, GFile* dir, Scaling* scaling, ExportFormatParameters* export_params, gboolean auto_replace_all);
GType exporter_get_type (void) G_GNUC_CONST;
ExporterUI* exporter_ui_new (Exporter* exporter);
ExporterUI* exporter_ui_construct (GType object_type, Exporter* exporter);
void exporter_ui_export (ExporterUI* self, ExporterCompletionCallback completion_callback, void* completion_callback_target);
static void drag_and_drop_handler_on_export_completed (DragAndDropHandler* self);
static void _drag_and_drop_handler_on_export_completed_exporter_completion_callback (Exporter* exporter, gboolean is_cancelled, gpointer self);
static void drag_and_drop_handler_finalize (DragAndDropHandler * obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);

static const GtkTargetEntry DRAG_AND_DROP_HANDLER_SOURCE_TARGET_ENTRIES[2] = {{"XdndDirectSave0", (guint) GTK_TARGET_OTHER_APP, (guint) DRAG_AND_DROP_HANDLER_TARGET_TYPE_XDS}, {"shotwell/media-id-atom", (guint) GTK_TARGET_SAME_APP, (guint) DRAG_AND_DROP_HANDLER_TARGET_TYPE_MEDIA_LIST}};

InjectionGroup* injection_group_construct (GType object_type, const gchar* path) {
	InjectionGroup* self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 31 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 31 "/home/jens/Source/shotwell/src/Page.vala"
	self = (InjectionGroup*) g_type_create_instance (object_type);
#line 32 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = path;
#line 32 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 32 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->priv->path);
#line 32 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->path = _tmp1_;
#line 31 "/home/jens/Source/shotwell/src/Page.vala"
	return self;
#line 1510 "Page.c"
}


InjectionGroup* injection_group_new (const gchar* path) {
#line 31 "/home/jens/Source/shotwell/src/Page.vala"
	return injection_group_construct (TYPE_INJECTION_GROUP, path);
#line 1517 "Page.c"
}


gchar* injection_group_get_path (InjectionGroup* self) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 35 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_INJECTION_GROUP (self), NULL);
#line 36 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->path;
#line 36 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 36 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 36 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 1535 "Page.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 40 "/home/jens/Source/shotwell/src/Page.vala"
	return self ? g_object_ref (self) : NULL;
#line 1542 "Page.c"
}


GeeList* injection_group_get_elements (InjectionGroup* self) {
	GeeList* result = NULL;
	GeeArrayList* _tmp0_;
	GeeList* _tmp1_;
#line 39 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_INJECTION_GROUP (self), NULL);
#line 40 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->elements;
#line 40 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_LIST, GeeList));
#line 40 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 40 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 1560 "Page.c"
}


void injection_group_add_menu_item (InjectionGroup* self, const gchar* name, const gchar* action, const gchar* accellerator) {
	GeeArrayList* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	InjectionGroupElement* _tmp4_;
	InjectionGroupElement* _tmp5_;
#line 43 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_INJECTION_GROUP (self));
#line 43 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 44 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->elements;
#line 44 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = name;
#line 44 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = action;
#line 44 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = accellerator;
#line 44 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = injection_group_element_new (_tmp1_, _tmp2_, _tmp3_, INJECTION_GROUP_ELEMENT_ITEM_TYPE_MENUITEM);
#line 44 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _tmp4_;
#line 44 "/home/jens/Source/shotwell/src/Page.vala"
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp5_);
#line 44 "/home/jens/Source/shotwell/src/Page.vala"
	_injection_group_element_unref0 (_tmp5_);
#line 1591 "Page.c"
}


void injection_group_add_menu (InjectionGroup* self, const gchar* name, const gchar* action) {
	GeeArrayList* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	InjectionGroupElement* _tmp3_;
	InjectionGroupElement* _tmp4_;
#line 47 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_INJECTION_GROUP (self));
#line 47 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 48 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->elements;
#line 48 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = name;
#line 48 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = action;
#line 48 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = injection_group_element_new (_tmp1_, _tmp2_, NULL, INJECTION_GROUP_ELEMENT_ITEM_TYPE_MENU);
#line 48 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = _tmp3_;
#line 48 "/home/jens/Source/shotwell/src/Page.vala"
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp4_);
#line 48 "/home/jens/Source/shotwell/src/Page.vala"
	_injection_group_element_unref0 (_tmp4_);
#line 1619 "Page.c"
}


void injection_group_add_separator (InjectionGroup* self) {
	GeeArrayList* _tmp0_;
	gint _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	InjectionGroupElement* _tmp4_;
	InjectionGroupElement* _tmp5_;
#line 51 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_INJECTION_GROUP (self));
#line 52 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->elements;
#line 52 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->separator_id;
#line 52 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->separator_id = _tmp1_ + 1;
#line 52 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = g_strdup_printf ("%d-separator", _tmp1_);
#line 52 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_;
#line 52 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = injection_group_element_new (_tmp3_, NULL, NULL, INJECTION_GROUP_ELEMENT_ITEM_TYPE_SEPARATOR);
#line 52 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _tmp4_;
#line 52 "/home/jens/Source/shotwell/src/Page.vala"
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp5_);
#line 52 "/home/jens/Source/shotwell/src/Page.vala"
	_injection_group_element_unref0 (_tmp5_);
#line 52 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (_tmp3_);
#line 1652 "Page.c"
}


GType injection_group_element_item_type_get_type (void) {
	static volatile gsize injection_group_element_item_type_type_id__volatile = 0;
	if (g_once_init_enter (&injection_group_element_item_type_type_id__volatile)) {
		static const GEnumValue values[] = {{INJECTION_GROUP_ELEMENT_ITEM_TYPE_MENUITEM, "INJECTION_GROUP_ELEMENT_ITEM_TYPE_MENUITEM", "menuitem"}, {INJECTION_GROUP_ELEMENT_ITEM_TYPE_MENU, "INJECTION_GROUP_ELEMENT_ITEM_TYPE_MENU", "menu"}, {INJECTION_GROUP_ELEMENT_ITEM_TYPE_SEPARATOR, "INJECTION_GROUP_ELEMENT_ITEM_TYPE_SEPARATOR", "separator"}, {0, NULL, NULL}};
		GType injection_group_element_item_type_type_id;
		injection_group_element_item_type_type_id = g_enum_register_static ("InjectionGroupElementItemType", values);
		g_once_init_leave (&injection_group_element_item_type_type_id__volatile, injection_group_element_item_type_type_id);
	}
	return injection_group_element_item_type_type_id__volatile;
}


InjectionGroupElement* injection_group_element_construct (GType object_type, const gchar* name, const gchar* action, const gchar* accellerator, InjectionGroupElementItemType kind) {
	InjectionGroupElement* self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	InjectionGroupElementItemType _tmp9_;
#line 19 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 19 "/home/jens/Source/shotwell/src/Page.vala"
	self = (InjectionGroupElement*) g_type_create_instance (object_type);
#line 20 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 20 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 20 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->name);
#line 20 "/home/jens/Source/shotwell/src/Page.vala"
	self->name = _tmp1_;
#line 21 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = action;
#line 21 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_ != NULL) {
#line 1694 "Page.c"
		const gchar* _tmp4_;
#line 21 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = action;
#line 21 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = _tmp4_;
#line 1700 "Page.c"
	} else {
		const gchar* _tmp5_;
#line 21 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = name;
#line 21 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = _tmp5_;
#line 1707 "Page.c"
	}
#line 21 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = g_strdup (_tmp2_);
#line 21 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->action);
#line 21 "/home/jens/Source/shotwell/src/Page.vala"
	self->action = _tmp6_;
#line 22 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = accellerator;
#line 22 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = g_strdup (_tmp7_);
#line 22 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->accellerator);
#line 22 "/home/jens/Source/shotwell/src/Page.vala"
	self->accellerator = _tmp8_;
#line 23 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = kind;
#line 23 "/home/jens/Source/shotwell/src/Page.vala"
	self->kind = _tmp9_;
#line 19 "/home/jens/Source/shotwell/src/Page.vala"
	return self;
#line 1729 "Page.c"
}


InjectionGroupElement* injection_group_element_new (const gchar* name, const gchar* action, const gchar* accellerator, InjectionGroupElementItemType kind) {
#line 19 "/home/jens/Source/shotwell/src/Page.vala"
	return injection_group_element_construct (INJECTION_GROUP_TYPE_ELEMENT, name, action, accellerator, kind);
#line 1736 "Page.c"
}


static void injection_group_value_element_init (GValue* value) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	value->data[0].v_pointer = NULL;
#line 1743 "Page.c"
}


static void injection_group_value_element_free_value (GValue* value) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	if (value->data[0].v_pointer) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		injection_group_element_unref (value->data[0].v_pointer);
#line 1752 "Page.c"
	}
}


static void injection_group_value_element_copy_value (const GValue* src_value, GValue* dest_value) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	if (src_value->data[0].v_pointer) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		dest_value->data[0].v_pointer = injection_group_element_ref (src_value->data[0].v_pointer);
#line 1762 "Page.c"
	} else {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1766 "Page.c"
	}
}


static gpointer injection_group_value_element_peek_pointer (const GValue* value) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	return value->data[0].v_pointer;
#line 1774 "Page.c"
}


static gchar* injection_group_value_element_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	if (collect_values[0].v_pointer) {
#line 1781 "Page.c"
		InjectionGroupElement * object;
		object = collect_values[0].v_pointer;
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		if (object->parent_instance.g_class == NULL) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1788 "Page.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1792 "Page.c"
		}
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = injection_group_element_ref (object);
#line 1796 "Page.c"
	} else {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = NULL;
#line 1800 "Page.c"
	}
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	return NULL;
#line 1804 "Page.c"
}


static gchar* injection_group_value_element_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	InjectionGroupElement ** object_p;
	object_p = collect_values[0].v_pointer;
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	if (!object_p) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1815 "Page.c"
	}
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	if (!value->data[0].v_pointer) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		*object_p = NULL;
#line 1821 "Page.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		*object_p = value->data[0].v_pointer;
#line 1825 "Page.c"
	} else {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		*object_p = injection_group_element_ref (value->data[0].v_pointer);
#line 1829 "Page.c"
	}
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	return NULL;
#line 1833 "Page.c"
}


GParamSpec* injection_group_param_spec_element (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	InjectionGroupParamSpecElement* spec;
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (g_type_is_a (object_type, INJECTION_GROUP_TYPE_ELEMENT), NULL);
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	return G_PARAM_SPEC (spec);
#line 1847 "Page.c"
}


gpointer injection_group_value_get_element (const GValue* value) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, INJECTION_GROUP_TYPE_ELEMENT), NULL);
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	return value->data[0].v_pointer;
#line 1856 "Page.c"
}


void injection_group_value_set_element (GValue* value, gpointer v_object) {
	InjectionGroupElement * old;
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, INJECTION_GROUP_TYPE_ELEMENT));
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	old = value->data[0].v_pointer;
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	if (v_object) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, INJECTION_GROUP_TYPE_ELEMENT));
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = v_object;
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		injection_group_element_ref (value->data[0].v_pointer);
#line 1876 "Page.c"
	} else {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = NULL;
#line 1880 "Page.c"
	}
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	if (old) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		injection_group_element_unref (old);
#line 1886 "Page.c"
	}
}


void injection_group_value_take_element (GValue* value, gpointer v_object) {
	InjectionGroupElement * old;
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, INJECTION_GROUP_TYPE_ELEMENT));
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	old = value->data[0].v_pointer;
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	if (v_object) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, INJECTION_GROUP_TYPE_ELEMENT));
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = v_object;
#line 1905 "Page.c"
	} else {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = NULL;
#line 1909 "Page.c"
	}
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	if (old) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		injection_group_element_unref (old);
#line 1915 "Page.c"
	}
}


static void injection_group_element_class_init (InjectionGroupElementClass * klass) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	injection_group_element_parent_class = g_type_class_peek_parent (klass);
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	((InjectionGroupElementClass *) klass)->finalize = injection_group_element_finalize;
#line 1925 "Page.c"
}


static void injection_group_element_instance_init (InjectionGroupElement * self) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	self->ref_count = 1;
#line 1932 "Page.c"
}


static void injection_group_element_finalize (InjectionGroupElement * obj) {
	InjectionGroupElement * self;
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, INJECTION_GROUP_TYPE_ELEMENT, InjectionGroupElement);
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_destroy (self);
#line 14 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->name);
#line 15 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->action);
#line 16 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->accellerator);
#line 1948 "Page.c"
}


GType injection_group_element_get_type (void) {
	static volatile gsize injection_group_element_type_id__volatile = 0;
	if (g_once_init_enter (&injection_group_element_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { injection_group_value_element_init, injection_group_value_element_free_value, injection_group_value_element_copy_value, injection_group_value_element_peek_pointer, "p", injection_group_value_element_collect_value, "p", injection_group_value_element_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (InjectionGroupElementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) injection_group_element_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (InjectionGroupElement), 0, (GInstanceInitFunc) injection_group_element_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType injection_group_element_type_id;
		injection_group_element_type_id = g_type_register_fundamental (g_type_fundamental_next (), "InjectionGroupElement", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&injection_group_element_type_id__volatile, injection_group_element_type_id);
	}
	return injection_group_element_type_id__volatile;
}


gpointer injection_group_element_ref (gpointer instance) {
	InjectionGroupElement * self;
	self = instance;
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	g_atomic_int_inc (&self->ref_count);
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	return instance;
#line 1973 "Page.c"
}


void injection_group_element_unref (gpointer instance) {
	InjectionGroupElement * self;
	self = instance;
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		INJECTION_GROUP_ELEMENT_GET_CLASS (self)->finalize (self);
#line 8 "/home/jens/Source/shotwell/src/Page.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1986 "Page.c"
	}
}


static void value_injection_group_init (GValue* value) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	value->data[0].v_pointer = NULL;
#line 1994 "Page.c"
}


static void value_injection_group_free_value (GValue* value) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	if (value->data[0].v_pointer) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		injection_group_unref (value->data[0].v_pointer);
#line 2003 "Page.c"
	}
}


static void value_injection_group_copy_value (const GValue* src_value, GValue* dest_value) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	if (src_value->data[0].v_pointer) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		dest_value->data[0].v_pointer = injection_group_ref (src_value->data[0].v_pointer);
#line 2013 "Page.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		dest_value->data[0].v_pointer = NULL;
#line 2017 "Page.c"
	}
}


static gpointer value_injection_group_peek_pointer (const GValue* value) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	return value->data[0].v_pointer;
#line 2025 "Page.c"
}


static gchar* value_injection_group_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	if (collect_values[0].v_pointer) {
#line 2032 "Page.c"
		InjectionGroup * object;
		object = collect_values[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		if (object->parent_instance.g_class == NULL) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2039 "Page.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2043 "Page.c"
		}
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = injection_group_ref (object);
#line 2047 "Page.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = NULL;
#line 2051 "Page.c"
	}
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	return NULL;
#line 2055 "Page.c"
}


static gchar* value_injection_group_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	InjectionGroup ** object_p;
	object_p = collect_values[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	if (!object_p) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 2066 "Page.c"
	}
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	if (!value->data[0].v_pointer) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		*object_p = NULL;
#line 2072 "Page.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		*object_p = value->data[0].v_pointer;
#line 2076 "Page.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		*object_p = injection_group_ref (value->data[0].v_pointer);
#line 2080 "Page.c"
	}
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	return NULL;
#line 2084 "Page.c"
}


GParamSpec* param_spec_injection_group (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecInjectionGroup* spec;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_INJECTION_GROUP), NULL);
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	return G_PARAM_SPEC (spec);
#line 2098 "Page.c"
}


gpointer value_get_injection_group (const GValue* value) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_INJECTION_GROUP), NULL);
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	return value->data[0].v_pointer;
#line 2107 "Page.c"
}


void value_set_injection_group (GValue* value, gpointer v_object) {
	InjectionGroup * old;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_INJECTION_GROUP));
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	old = value->data[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	if (v_object) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_INJECTION_GROUP));
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = v_object;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		injection_group_ref (value->data[0].v_pointer);
#line 2127 "Page.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = NULL;
#line 2131 "Page.c"
	}
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	if (old) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		injection_group_unref (old);
#line 2137 "Page.c"
	}
}


void value_take_injection_group (GValue* value, gpointer v_object) {
	InjectionGroup * old;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_INJECTION_GROUP));
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	old = value->data[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	if (v_object) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_INJECTION_GROUP));
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = v_object;
#line 2156 "Page.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = NULL;
#line 2160 "Page.c"
	}
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	if (old) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		injection_group_unref (old);
#line 2166 "Page.c"
	}
}


static void injection_group_class_init (InjectionGroupClass * klass) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	injection_group_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	((InjectionGroupClass *) klass)->finalize = injection_group_finalize;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	g_type_class_add_private (klass, sizeof (InjectionGroupPrivate));
#line 2178 "Page.c"
}


static void injection_group_instance_init (InjectionGroup * self) {
	GeeArrayList* _tmp0_;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv = INJECTION_GROUP_GET_PRIVATE (self);
#line 28 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = gee_array_list_new (INJECTION_GROUP_TYPE_ELEMENT, (GBoxedCopyFunc) injection_group_element_ref, (GDestroyNotify) injection_group_element_unref, NULL, NULL, NULL);
#line 28 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->elements = _tmp0_;
#line 29 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->separator_id = 0;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	self->ref_count = 1;
#line 2194 "Page.c"
}


static void injection_group_finalize (InjectionGroup * obj) {
	InjectionGroup * self;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_INJECTION_GROUP, InjectionGroup);
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_destroy (self);
#line 27 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->priv->path);
#line 28 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->elements);
#line 2208 "Page.c"
}


GType injection_group_get_type (void) {
	static volatile gsize injection_group_type_id__volatile = 0;
	if (g_once_init_enter (&injection_group_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_injection_group_init, value_injection_group_free_value, value_injection_group_copy_value, value_injection_group_peek_pointer, "p", value_injection_group_collect_value, "p", value_injection_group_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (InjectionGroupClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) injection_group_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (InjectionGroup), 0, (GInstanceInitFunc) injection_group_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType injection_group_type_id;
		injection_group_type_id = g_type_register_fundamental (g_type_fundamental_next (), "InjectionGroup", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&injection_group_type_id__volatile, injection_group_type_id);
	}
	return injection_group_type_id__volatile;
}


gpointer injection_group_ref (gpointer instance) {
	InjectionGroup * self;
	self = instance;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	g_atomic_int_inc (&self->ref_count);
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	return instance;
#line 2233 "Page.c"
}


void injection_group_unref (gpointer instance) {
	InjectionGroup * self;
	self = instance;
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		INJECTION_GROUP_GET_CLASS (self)->finalize (self);
#line 7 "/home/jens/Source/shotwell/src/Page.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2246 "Page.c"
	}
}


static gboolean _page_on_context_keypress_gtk_widget_popup_menu (GtkWidget* _sender, gpointer self) {
	gboolean result;
	result = page_on_context_keypress ((Page*) self);
#line 98 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 2256 "Page.c"
}


static void _page_attach_view_signals_gtk_widget_realize (GtkWidget* _sender, gpointer self) {
#line 100 "/home/jens/Source/shotwell/src/Page.vala"
	page_attach_view_signals ((Page*) self);
#line 2263 "Page.c"
}


Page* page_construct (GType object_type, const gchar* page_name) {
	Page * self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	ViewCollection* _tmp5_;
	GdkPoint _tmp6_ = {0};
#line 89 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (page_name != NULL, NULL);
#line 89 "/home/jens/Source/shotwell/src/Page.vala"
	self = (Page*) g_object_new (object_type, NULL);
#line 90 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_name;
#line 90 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 90 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->priv->page_name);
#line 90 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->page_name = _tmp1_;
#line 92 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = page_name;
#line 92 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = g_strdup_printf ("ViewCollection for Page %s", _tmp2_);
#line 92 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = _tmp3_;
#line 92 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = view_collection_new (_tmp4_);
#line 92 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (self->priv->view);
#line 92 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->view = _tmp5_;
#line 92 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (_tmp4_);
#line 94 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_.x = -1;
#line 94 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_.y = -1;
#line 94 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->last_down = _tmp6_;
#line 96 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_widget_set_can_focus (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), TRUE);
#line 98 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "popup-menu", (GCallback) _page_on_context_keypress_gtk_widget_popup_menu, self, 0);
#line 100 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "realize", (GCallback) _page_attach_view_signals_gtk_widget_realize, self, 0);
#line 89 "/home/jens/Source/shotwell/src/Page.vala"
	return self;
#line 2316 "Page.c"
}


static void page_real_destroy (GtkWidget* base) {
	Page * self;
	gboolean _tmp0_;
	ViewCollection* _tmp1_;
	GtkToolbar* _tmp2_;
	OneShotScheduler* _tmp4_;
	gchar* _tmp6_;
	gchar* _tmp7_;
#line 111 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PAGE, Page);
#line 112 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->is_destroyed;
#line 112 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_) {
#line 113 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 2336 "Page.c"
	}
#line 116 "/home/jens/Source/shotwell/src/Page.vala"
	page_detach_event_source (self);
#line 117 "/home/jens/Source/shotwell/src/Page.vala"
	page_detach_view_signals (self);
#line 118 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->view;
#line 118 "/home/jens/Source/shotwell/src/Page.vala"
	data_collection_close (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DATA_COLLECTION, DataCollection));
#line 121 "/home/jens/Source/shotwell/src/Page.vala"
	page_clear_container (self);
#line 123 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->toolbar;
#line 123 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_ != NULL) {
#line 2352 "Page.c"
		GtkToolbar* _tmp3_;
#line 124 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = self->toolbar;
#line 124 "/home/jens/Source/shotwell/src/Page.vala"
		gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget));
#line 2358 "Page.c"
	}
#line 127 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = self->priv->update_actions_scheduler;
#line 127 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_ != NULL) {
#line 2364 "Page.c"
		OneShotScheduler* _tmp5_;
#line 128 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = self->priv->update_actions_scheduler;
#line 128 "/home/jens/Source/shotwell/src/Page.vala"
		one_shot_scheduler_cancel (_tmp5_);
#line 2370 "Page.c"
	}
#line 130 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->is_destroyed = TRUE;
#line 132 "/home/jens/Source/shotwell/src/Page.vala"
	GTK_WIDGET_CLASS (page_parent_class)->destroy (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow), gtk_widget_get_type (), GtkWidget));
#line 134 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = page_get_page_name (self);
#line 134 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = _tmp6_;
#line 134 "/home/jens/Source/shotwell/src/Page.vala"
	g_debug ("Page.vala:134: Page %s Destroyed", _tmp7_);
#line 134 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (_tmp7_);
#line 2384 "Page.c"
}


gchar* page_get_page_name (Page* self) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 137 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 138 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->page_name;
#line 138 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 138 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 138 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 2402 "Page.c"
}


static void page_real_set_page_name (Page* self, const gchar* page_name) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 141 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (page_name != NULL);
#line 142 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_name;
#line 142 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 142 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->priv->page_name);
#line 142 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->page_name = _tmp1_;
#line 2419 "Page.c"
}


void page_set_page_name (Page* self, const gchar* page_name) {
#line 141 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 141 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->set_page_name (self, page_name);
#line 2428 "Page.c"
}


gchar* page_to_string (Page* self) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 145 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 146 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->page_name;
#line 146 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 146 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 146 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 2446 "Page.c"
}


static gpointer _data_collection_ref0 (gpointer self) {
#line 150 "/home/jens/Source/shotwell/src/Page.vala"
	return self ? data_collection_ref (self) : NULL;
#line 2453 "Page.c"
}


ViewCollection* page_get_view (Page* self) {
	ViewCollection* result = NULL;
	ViewCollection* _tmp0_;
	ViewCollection* _tmp1_;
#line 149 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 150 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->view;
#line 150 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _data_collection_ref0 (_tmp0_);
#line 150 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 150 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 2471 "Page.c"
}


GtkWindow* page_get_container (Page* self) {
	GtkWindow* result = NULL;
	GtkWindow* _tmp0_;
	GtkWindow* _tmp1_;
#line 153 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 154 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->container;
#line 154 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 154 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 154 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 2489 "Page.c"
}


static void page_real_set_container (Page* self, GtkWindow* container) {
	GtkWindow* _tmp0_;
	GtkWindow* _tmp1_;
	GtkWindow* _tmp2_;
#line 157 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GTK_IS_WINDOW (container));
#line 158 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->container;
#line 158 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp0_ == NULL, "this.container == null");
#line 160 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = container;
#line 160 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 160 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->container);
#line 160 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->container = _tmp2_;
#line 2511 "Page.c"
}


void page_set_container (Page* self, GtkWindow* container) {
#line 157 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 157 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->set_container (self, container);
#line 2520 "Page.c"
}


static void page_real_clear_container (Page* self) {
#line 164 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->container);
#line 164 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->container = NULL;
#line 2529 "Page.c"
}


void page_clear_container (Page* self) {
#line 163 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 163 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->clear_container (self);
#line 2538 "Page.c"
}


static gboolean _page_on_button_pressed_internal_gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = page_on_button_pressed_internal ((Page*) self, event);
#line 178 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 2547 "Page.c"
}


static gboolean _page_on_button_released_internal_gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = page_on_button_released_internal ((Page*) self, event);
#line 179 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 2556 "Page.c"
}


static gboolean _page_on_motion_internal_gtk_widget_motion_notify_event (GtkWidget* _sender, GdkEventMotion* event, gpointer self) {
	gboolean result;
	result = page_on_motion_internal ((Page*) self, event);
#line 180 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 2565 "Page.c"
}


static gboolean _page_on_leave_notify_event_gtk_widget_leave_notify_event (GtkWidget* _sender, GdkEventCrossing* event, gpointer self) {
	gboolean result;
	result = page_on_leave_notify_event ((Page*) self);
#line 181 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 2574 "Page.c"
}


static gboolean _page_on_mousewheel_internal_gtk_widget_scroll_event (GtkWidget* _sender, GdkEventScroll* event, gpointer self) {
	gboolean result;
	result = page_on_mousewheel_internal ((Page*) self, event);
#line 182 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 2583 "Page.c"
}


static void _page_on_event_source_realize_gtk_widget_realize (GtkWidget* _sender, gpointer self) {
#line 183 "/home/jens/Source/shotwell/src/Page.vala"
	page_on_event_source_realize ((Page*) self);
#line 2590 "Page.c"
}


void page_set_event_source (Page* self, GtkWidget* event_source) {
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
	GtkWidget* _tmp3_;
	GtkWidget* _tmp4_;
	GtkWidget* _tmp5_;
	GtkWidget* _tmp6_;
	GtkWidget* _tmp7_;
	GtkWidget* _tmp8_;
	GtkWidget* _tmp9_;
	GtkWidget* _tmp10_;
#line 167 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 167 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GTK_IS_WIDGET (event_source));
#line 168 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->event_source;
#line 168 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp0_ == NULL, "this.event_source == null");
#line 170 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = event_source;
#line 170 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 170 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->event_source);
#line 170 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->event_source = _tmp2_;
#line 171 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = event_source;
#line 171 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_widget_set_can_focus (_tmp3_, TRUE);
#line 174 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = event_source;
#line 174 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_widget_add_events (_tmp4_, (gint) (((((((GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK) | GDK_POINTER_MOTION_MASK) | GDK_POINTER_MOTION_HINT_MASK) | GDK_BUTTON_MOTION_MASK) | GDK_LEAVE_NOTIFY_MASK) | GDK_SCROLL_MASK) | GDK_SMOOTH_SCROLL_MASK));
#line 178 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = event_source;
#line 178 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp5_, "button-press-event", (GCallback) _page_on_button_pressed_internal_gtk_widget_button_press_event, self, 0);
#line 179 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = event_source;
#line 179 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp6_, "button-release-event", (GCallback) _page_on_button_released_internal_gtk_widget_button_release_event, self, 0);
#line 180 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = event_source;
#line 180 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp7_, "motion-notify-event", (GCallback) _page_on_motion_internal_gtk_widget_motion_notify_event, self, 0);
#line 181 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = event_source;
#line 181 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp8_, "leave-notify-event", (GCallback) _page_on_leave_notify_event_gtk_widget_leave_notify_event, self, 0);
#line 182 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = event_source;
#line 182 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp9_, "scroll-event", (GCallback) _page_on_mousewheel_internal_gtk_widget_scroll_event, self, 0);
#line 183 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = event_source;
#line 183 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp10_, "realize", (GCallback) _page_on_event_source_realize_gtk_widget_realize, self, 0);
#line 2654 "Page.c"
}


static void page_detach_event_source (Page* self) {
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	guint _tmp2_;
	GtkWidget* _tmp3_;
	guint _tmp4_;
	GtkWidget* _tmp5_;
	guint _tmp6_;
	GtkWidget* _tmp7_;
	guint _tmp8_;
	GtkWidget* _tmp9_;
	guint _tmp10_;
#line 186 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 187 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->event_source;
#line 187 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ == NULL) {
#line 188 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 2678 "Page.c"
	}
#line 190 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->event_source;
#line 190 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("button-press-event", gtk_widget_get_type (), &_tmp2_, NULL, FALSE);
#line 190 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (_tmp1_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp2_, 0, NULL, (GCallback) _page_on_button_pressed_internal_gtk_widget_button_press_event, self);
#line 191 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = self->priv->event_source;
#line 191 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("button-release-event", gtk_widget_get_type (), &_tmp4_, NULL, FALSE);
#line 191 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (_tmp3_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp4_, 0, NULL, (GCallback) _page_on_button_released_internal_gtk_widget_button_release_event, self);
#line 192 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = self->priv->event_source;
#line 192 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("motion-notify-event", gtk_widget_get_type (), &_tmp6_, NULL, FALSE);
#line 192 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (_tmp5_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp6_, 0, NULL, (GCallback) _page_on_motion_internal_gtk_widget_motion_notify_event, self);
#line 193 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = self->priv->event_source;
#line 193 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("leave-notify-event", gtk_widget_get_type (), &_tmp8_, NULL, FALSE);
#line 193 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (_tmp7_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp8_, 0, NULL, (GCallback) _page_on_leave_notify_event_gtk_widget_leave_notify_event, self);
#line 194 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = self->priv->event_source;
#line 194 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("scroll-event", gtk_widget_get_type (), &_tmp10_, NULL, FALSE);
#line 194 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (_tmp9_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp10_, 0, NULL, (GCallback) _page_on_mousewheel_internal_gtk_widget_scroll_event, self);
#line 196 "/home/jens/Source/shotwell/src/Page.vala"
	page_disable_drag_source (self);
#line 198 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->event_source);
#line 198 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->event_source = NULL;
#line 2716 "Page.c"
}


GtkWidget* page_get_event_source (Page* self) {
	GtkWidget* result = NULL;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
#line 201 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 202 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->event_source;
#line 202 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 202 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 202 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 2734 "Page.c"
}


static gpointer _injection_group_ref0 (gpointer self) {
#line 215 "/home/jens/Source/shotwell/src/Page.vala"
	return self ? injection_group_ref (self) : NULL;
#line 2741 "Page.c"
}


GMenuModel* page_get_menubar (Page* self) {
	GMenuModel* result = NULL;
	GMenu* model = NULL;
	GtkBuilder* _tmp0_;
	GObject* _tmp1_;
	GMenu* _tmp2_;
	GMenu* _tmp3_;
	gboolean _tmp5_;
#line 206 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 207 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->builder;
#line 207 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = gtk_builder_get_object (_tmp0_, "MenuBar");
#line 207 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, g_menu_get_type ()) ? ((GMenu*) _tmp1_) : NULL);
#line 207 "/home/jens/Source/shotwell/src/Page.vala"
	model = _tmp2_;
#line 208 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = model;
#line 208 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_ == NULL) {
#line 2767 "Page.c"
		GMenu* _tmp4_;
#line 209 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = g_menu_new ();
#line 209 "/home/jens/Source/shotwell/src/Page.vala"
		result = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, g_menu_model_get_type (), GMenuModel);
#line 209 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (model);
#line 209 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 2777 "Page.c"
	}
#line 212 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = self->priv->menubar_injected;
#line 212 "/home/jens/Source/shotwell/src/Page.vala"
	if (!_tmp5_) {
#line 2783 "Page.c"
		InjectionGroup** injection_groups = NULL;
		gint _tmp6_;
		InjectionGroup** _tmp7_;
		gint injection_groups_length1;
		gint _injection_groups_size_;
		InjectionGroup** _tmp8_;
		gint _tmp8__length1;
#line 214 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = page_init_collect_injection_groups (self, &_tmp6_);
#line 214 "/home/jens/Source/shotwell/src/Page.vala"
		injection_groups = _tmp7_;
#line 214 "/home/jens/Source/shotwell/src/Page.vala"
		injection_groups_length1 = _tmp6_;
#line 214 "/home/jens/Source/shotwell/src/Page.vala"
		_injection_groups_size_ = injection_groups_length1;
#line 215 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = injection_groups;
#line 215 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8__length1 = injection_groups_length1;
#line 2803 "Page.c"
		{
			InjectionGroup** group_collection = NULL;
			gint group_collection_length1 = 0;
			gint _group_collection_size_ = 0;
			gint group_it = 0;
#line 215 "/home/jens/Source/shotwell/src/Page.vala"
			group_collection = _tmp8_;
#line 215 "/home/jens/Source/shotwell/src/Page.vala"
			group_collection_length1 = _tmp8__length1;
#line 215 "/home/jens/Source/shotwell/src/Page.vala"
			for (group_it = 0; group_it < _tmp8__length1; group_it = group_it + 1) {
#line 2815 "Page.c"
				InjectionGroup* _tmp9_;
				InjectionGroup* group = NULL;
#line 215 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp9_ = _injection_group_ref0 (group_collection[group_it]);
#line 215 "/home/jens/Source/shotwell/src/Page.vala"
				group = _tmp9_;
#line 2822 "Page.c"
				{
					gint items = 0;
					GMenu* _tmp10_;
					gint _tmp11_;
#line 216 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp10_ = model;
#line 216 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp11_ = g_menu_model_get_n_items (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, g_menu_model_get_type (), GMenuModel));
#line 216 "/home/jens/Source/shotwell/src/Page.vala"
					items = _tmp11_;
#line 2833 "Page.c"
					{
						gint i = 0;
#line 217 "/home/jens/Source/shotwell/src/Page.vala"
						i = 0;
#line 2838 "Page.c"
						{
							gboolean _tmp12_ = FALSE;
#line 217 "/home/jens/Source/shotwell/src/Page.vala"
							_tmp12_ = TRUE;
#line 217 "/home/jens/Source/shotwell/src/Page.vala"
							while (TRUE) {
#line 2845 "Page.c"
								gint _tmp14_;
								gint _tmp15_;
								GMenuModel* submenu = NULL;
								GMenu* _tmp16_;
								gint _tmp17_;
								GMenuModel* _tmp18_;
								GMenuModel* section = NULL;
								GMenuModel* _tmp19_;
								InjectionGroup* _tmp20_;
								gchar* _tmp21_;
								gchar* _tmp22_;
								GMenuModel* _tmp23_;
								GMenuModel* _tmp24_;
								GMenuModel* _tmp25_;
#line 217 "/home/jens/Source/shotwell/src/Page.vala"
								if (!_tmp12_) {
#line 2862 "Page.c"
									gint _tmp13_;
#line 217 "/home/jens/Source/shotwell/src/Page.vala"
									_tmp13_ = i;
#line 217 "/home/jens/Source/shotwell/src/Page.vala"
									i = _tmp13_ + 1;
#line 2868 "Page.c"
								}
#line 217 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp12_ = FALSE;
#line 217 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp14_ = i;
#line 217 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp15_ = items;
#line 217 "/home/jens/Source/shotwell/src/Page.vala"
								if (!(_tmp14_ < _tmp15_)) {
#line 217 "/home/jens/Source/shotwell/src/Page.vala"
									break;
#line 2880 "Page.c"
								}
#line 218 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp16_ = model;
#line 218 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp17_ = i;
#line 218 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp18_ = g_menu_model_get_item_link (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, g_menu_model_get_type (), GMenuModel), _tmp17_, G_MENU_LINK_SUBMENU);
#line 218 "/home/jens/Source/shotwell/src/Page.vala"
								submenu = _tmp18_;
#line 220 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp19_ = submenu;
#line 220 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp20_ = group;
#line 220 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp21_ = injection_group_get_path (_tmp20_);
#line 220 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp22_ = _tmp21_;
#line 220 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp23_ = page_find_extension_point (self, _tmp19_, _tmp22_);
#line 220 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp24_ = _tmp23_;
#line 220 "/home/jens/Source/shotwell/src/Page.vala"
								_g_free0 (_tmp22_);
#line 220 "/home/jens/Source/shotwell/src/Page.vala"
								section = _tmp24_;
#line 223 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp25_ = section;
#line 223 "/home/jens/Source/shotwell/src/Page.vala"
								if (_tmp25_ == NULL) {
#line 224 "/home/jens/Source/shotwell/src/Page.vala"
									_g_object_unref0 (section);
#line 224 "/home/jens/Source/shotwell/src/Page.vala"
									_g_object_unref0 (submenu);
#line 224 "/home/jens/Source/shotwell/src/Page.vala"
									continue;
#line 2916 "Page.c"
								}
								{
									GeeList* _element_list = NULL;
									InjectionGroup* _tmp26_;
									GeeList* _tmp27_;
									gint _element_size = 0;
									GeeList* _tmp28_;
									gint _tmp29_;
									gint _tmp30_;
									gint _element_index = 0;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
									_tmp26_ = group;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
									_tmp27_ = injection_group_get_elements (_tmp26_);
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
									_element_list = _tmp27_;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
									_tmp28_ = _element_list;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
									_tmp29_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, GEE_TYPE_COLLECTION, GeeCollection));
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
									_tmp30_ = _tmp29_;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
									_element_size = _tmp30_;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
									_element_index = -1;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
									while (TRUE) {
#line 2945 "Page.c"
										gint _tmp31_;
										gint _tmp32_;
										gint _tmp33_;
										InjectionGroupElement* element = NULL;
										GeeList* _tmp34_;
										gint _tmp35_;
										gpointer _tmp36_;
										GMenu* menu = NULL;
										GMenuModel* _tmp37_;
										GMenu* _tmp38_;
										InjectionGroupElement* _tmp39_;
										InjectionGroupElementItemType _tmp40_;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
										_tmp31_ = _element_index;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
										_element_index = _tmp31_ + 1;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
										_tmp32_ = _element_index;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
										_tmp33_ = _element_size;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
										if (!(_tmp32_ < _tmp33_)) {
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
											break;
#line 2970 "Page.c"
										}
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
										_tmp34_ = _element_list;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
										_tmp35_ = _element_index;
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
										_tmp36_ = gee_list_get (_tmp34_, _tmp35_);
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
										element = (InjectionGroupElement*) _tmp36_;
#line 228 "/home/jens/Source/shotwell/src/Page.vala"
										_tmp37_ = section;
#line 228 "/home/jens/Source/shotwell/src/Page.vala"
										_tmp38_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, g_menu_get_type ()) ? ((GMenu*) _tmp37_) : NULL);
#line 228 "/home/jens/Source/shotwell/src/Page.vala"
										menu = _tmp38_;
#line 229 "/home/jens/Source/shotwell/src/Page.vala"
										_tmp39_ = element;
#line 229 "/home/jens/Source/shotwell/src/Page.vala"
										_tmp40_ = _tmp39_->kind;
#line 229 "/home/jens/Source/shotwell/src/Page.vala"
										switch (_tmp40_) {
#line 229 "/home/jens/Source/shotwell/src/Page.vala"
											case INJECTION_GROUP_ELEMENT_ITEM_TYPE_MENUITEM:
#line 2994 "Page.c"
											{
												GMenuItem* item = NULL;
												InjectionGroupElement* _tmp41_;
												const gchar* _tmp42_;
												InjectionGroupElement* _tmp43_;
												const gchar* _tmp44_;
												gchar* _tmp45_;
												gchar* _tmp46_;
												GMenuItem* _tmp47_;
												GMenuItem* _tmp48_;
												InjectionGroupElement* _tmp49_;
												const gchar* _tmp50_;
												GMenu* _tmp54_;
												GMenuItem* _tmp55_;
#line 231 "/home/jens/Source/shotwell/src/Page.vala"
												_tmp41_ = element;
#line 231 "/home/jens/Source/shotwell/src/Page.vala"
												_tmp42_ = _tmp41_->name;
#line 231 "/home/jens/Source/shotwell/src/Page.vala"
												_tmp43_ = element;
#line 231 "/home/jens/Source/shotwell/src/Page.vala"
												_tmp44_ = _tmp43_->action;
#line 231 "/home/jens/Source/shotwell/src/Page.vala"
												_tmp45_ = g_strconcat ("win.", _tmp44_, NULL);
#line 231 "/home/jens/Source/shotwell/src/Page.vala"
												_tmp46_ = _tmp45_;
#line 231 "/home/jens/Source/shotwell/src/Page.vala"
												_tmp47_ = g_menu_item_new (_tmp42_, _tmp46_);
#line 231 "/home/jens/Source/shotwell/src/Page.vala"
												_tmp48_ = _tmp47_;
#line 231 "/home/jens/Source/shotwell/src/Page.vala"
												_g_free0 (_tmp46_);
#line 231 "/home/jens/Source/shotwell/src/Page.vala"
												item = _tmp48_;
#line 233 "/home/jens/Source/shotwell/src/Page.vala"
												_tmp49_ = element;
#line 233 "/home/jens/Source/shotwell/src/Page.vala"
												_tmp50_ = _tmp49_->accellerator;
#line 233 "/home/jens/Source/shotwell/src/Page.vala"
												if (_tmp50_ != NULL) {
#line 3035 "Page.c"
													GMenuItem* _tmp51_;
													InjectionGroupElement* _tmp52_;
													const gchar* _tmp53_;
#line 234 "/home/jens/Source/shotwell/src/Page.vala"
													_tmp51_ = item;
#line 234 "/home/jens/Source/shotwell/src/Page.vala"
													_tmp52_ = element;
#line 234 "/home/jens/Source/shotwell/src/Page.vala"
													_tmp53_ = _tmp52_->accellerator;
#line 234 "/home/jens/Source/shotwell/src/Page.vala"
													g_menu_item_set_attribute (_tmp51_, "accel", "s", _tmp53_, NULL);
#line 3047 "Page.c"
												}
#line 239 "/home/jens/Source/shotwell/src/Page.vala"
												_tmp54_ = menu;
#line 239 "/home/jens/Source/shotwell/src/Page.vala"
												_tmp55_ = item;
#line 239 "/home/jens/Source/shotwell/src/Page.vala"
												g_menu_append_item (_tmp54_, _tmp55_);
#line 240 "/home/jens/Source/shotwell/src/Page.vala"
												_g_object_unref0 (item);
#line 240 "/home/jens/Source/shotwell/src/Page.vala"
												break;
#line 3059 "Page.c"
											}
											default:
											{
#line 242 "/home/jens/Source/shotwell/src/Page.vala"
												break;
#line 3065 "Page.c"
											}
										}
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
										_g_object_unref0 (menu);
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
										_injection_group_element_unref0 (element);
#line 3072 "Page.c"
									}
#line 227 "/home/jens/Source/shotwell/src/Page.vala"
									_g_object_unref0 (_element_list);
#line 3076 "Page.c"
								}
#line 217 "/home/jens/Source/shotwell/src/Page.vala"
								_g_object_unref0 (section);
#line 217 "/home/jens/Source/shotwell/src/Page.vala"
								_g_object_unref0 (submenu);
#line 3082 "Page.c"
							}
						}
					}
#line 215 "/home/jens/Source/shotwell/src/Page.vala"
					_injection_group_unref0 (group);
#line 3088 "Page.c"
				}
			}
		}
#line 248 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->menubar_injected = TRUE;
#line 212 "/home/jens/Source/shotwell/src/Page.vala"
		injection_groups = (_vala_array_free (injection_groups, injection_groups_length1, (GDestroyNotify) injection_group_unref), NULL);
#line 3096 "Page.c"
	}
#line 251 "/home/jens/Source/shotwell/src/Page.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (model, g_menu_model_get_type (), GMenuModel);
#line 251 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 3102 "Page.c"
}


static GtkToolbar* page_real_get_toolbar (Page* self) {
	GtkToolbar* result = NULL;
	GtkToolbar* _tmp0_;
	GtkToolbar* _tmp12_;
	GtkToolbar* _tmp13_;
#line 255 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->toolbar;
#line 255 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ == NULL) {
#line 3115 "Page.c"
		GtkToolbar* _tmp1_ = NULL;
		const gchar* _tmp2_;
		GtkToolbar* _tmp8_;
		GtkToolbar* _tmp9_;
		GtkStyleContext* _tmp10_;
		GtkToolbar* _tmp11_;
#line 256 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = self->priv->toolbar_path;
#line 256 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp2_ == NULL) {
#line 3126 "Page.c"
			GtkToolbar* _tmp3_;
#line 256 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp3_ = (GtkToolbar*) gtk_toolbar_new ();
#line 256 "/home/jens/Source/shotwell/src/Page.vala"
			g_object_ref_sink (_tmp3_);
#line 256 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (_tmp1_);
#line 256 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp1_ = _tmp3_;
#line 3136 "Page.c"
		} else {
			GtkBuilder* _tmp4_;
			const gchar* _tmp5_;
			GObject* _tmp6_;
			GtkToolbar* _tmp7_;
#line 257 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp4_ = self->builder;
#line 257 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp5_ = self->priv->toolbar_path;
#line 257 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp6_ = gtk_builder_get_object (_tmp4_, _tmp5_);
#line 257 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, gtk_toolbar_get_type ()) ? ((GtkToolbar*) _tmp6_) : NULL);
#line 257 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (_tmp1_);
#line 257 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp1_ = _tmp7_;
#line 3154 "Page.c"
		}
#line 256 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = _g_object_ref0 (_tmp1_);
#line 256 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (self->toolbar);
#line 256 "/home/jens/Source/shotwell/src/Page.vala"
		self->toolbar = _tmp8_;
#line 259 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = self->toolbar;
#line 259 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = gtk_widget_get_style_context (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget));
#line 259 "/home/jens/Source/shotwell/src/Page.vala"
		gtk_style_context_add_class (_tmp10_, "bottom-toolbar");
#line 260 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = self->toolbar;
#line 260 "/home/jens/Source/shotwell/src/Page.vala"
		gtk_toolbar_set_icon_size (_tmp11_, GTK_ICON_SIZE_SMALL_TOOLBAR);
#line 255 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp1_);
#line 3174 "Page.c"
	}
#line 262 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = self->toolbar;
#line 262 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp13_ = _g_object_ref0 (_tmp12_);
#line 262 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp13_;
#line 262 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 3184 "Page.c"
}


GtkToolbar* page_get_toolbar (Page* self) {
#line 254 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 254 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->get_toolbar (self);
#line 3193 "Page.c"
}


static GtkMenu* page_real_get_page_context_menu (Page* self) {
	GtkMenu* result = NULL;
#line 266 "/home/jens/Source/shotwell/src/Page.vala"
	result = NULL;
#line 266 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 3203 "Page.c"
}


GtkMenu* page_get_page_context_menu (Page* self) {
#line 265 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 265 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->get_page_context_menu (self);
#line 3212 "Page.c"
}


static void page_real_switching_from (Page* self) {
	GActionMap* map = NULL;
	GtkWindow* _tmp0_;
	GActionMap* _tmp1_;
	GActionMap* _tmp2_;
	const gchar* _tmp4_;
#line 270 "/home/jens/Source/shotwell/src/Page.vala"
	self->in_view = FALSE;
#line 272 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_get_container (self);
#line 272 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, g_action_map_get_type ()) ? ((GActionMap*) _tmp0_) : NULL;
#line 272 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_ == NULL) {
#line 272 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp0_);
#line 3232 "Page.c"
	}
#line 272 "/home/jens/Source/shotwell/src/Page.vala"
	map = _tmp1_;
#line 273 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = map;
#line 273 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_ != NULL) {
#line 3240 "Page.c"
		GActionMap* _tmp3_;
#line 274 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = map;
#line 274 "/home/jens/Source/shotwell/src/Page.vala"
		page_remove_actions (self, _tmp3_);
#line 3246 "Page.c"
	}
#line 276 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = self->priv->toolbar_path;
#line 276 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_ != NULL) {
#line 277 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (self->toolbar);
#line 277 "/home/jens/Source/shotwell/src/Page.vala"
		self->toolbar = NULL;
#line 3256 "Page.c"
	}
#line 269 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (map);
#line 3260 "Page.c"
}


void page_switching_from (Page* self) {
#line 269 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 269 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->switching_from (self);
#line 3269 "Page.c"
}


static void page_real_switched_to (Page* self) {
	GActionMap* map = NULL;
	GtkWindow* _tmp0_;
	GActionMap* _tmp1_;
	GActionMap* _tmp2_;
	gint selected_count = 0;
	ViewCollection* _tmp4_;
	ViewCollection* _tmp5_;
	gint _tmp6_;
	gint _tmp7_;
	gint count = 0;
	ViewCollection* _tmp8_;
	ViewCollection* _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
#line 281 "/home/jens/Source/shotwell/src/Page.vala"
	self->in_view = TRUE;
#line 282 "/home/jens/Source/shotwell/src/Page.vala"
	page_add_ui (self);
#line 283 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_get_container (self);
#line 283 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, g_action_map_get_type ()) ? ((GActionMap*) _tmp0_) : NULL;
#line 283 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_ == NULL) {
#line 283 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp0_);
#line 3300 "Page.c"
	}
#line 283 "/home/jens/Source/shotwell/src/Page.vala"
	map = _tmp1_;
#line 284 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = map;
#line 284 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_ != NULL) {
#line 3308 "Page.c"
		GActionMap* _tmp3_;
#line 285 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = map;
#line 285 "/home/jens/Source/shotwell/src/Page.vala"
		page_add_actions (self, _tmp3_);
#line 3314 "Page.c"
	}
#line 287 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = page_get_view (self);
#line 287 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _tmp4_;
#line 287 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = view_collection_get_selected_count (_tmp5_);
#line 287 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = _tmp6_;
#line 287 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp5_);
#line 287 "/home/jens/Source/shotwell/src/Page.vala"
	selected_count = _tmp7_;
#line 288 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = page_get_view (self);
#line 288 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = _tmp8_;
#line 288 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_DATA_COLLECTION, DataCollection));
#line 288 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = _tmp10_;
#line 288 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp9_);
#line 288 "/home/jens/Source/shotwell/src/Page.vala"
	count = _tmp11_;
#line 289 "/home/jens/Source/shotwell/src/Page.vala"
	page_init_actions (self, selected_count, count);
#line 290 "/home/jens/Source/shotwell/src/Page.vala"
	page_update_actions (self, selected_count, count);
#line 291 "/home/jens/Source/shotwell/src/Page.vala"
	page_update_modifiers (self);
#line 280 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (map);
#line 3348 "Page.c"
}


void page_switched_to (Page* self) {
#line 280 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 280 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->switched_to (self);
#line 3357 "Page.c"
}


static void page_real_ready (Page* self) {
}


void page_ready (Page* self) {
#line 294 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 294 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->ready (self);
#line 3370 "Page.c"
}


gboolean page_is_in_view (Page* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 297 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 298 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->in_view;
#line 298 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp0_;
#line 298 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 3385 "Page.c"
}


static void page_real_switching_to_fullscreen (Page* self, FullscreenWindow* fsw) {
	FullscreenWindow* _tmp0_;
#line 301 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (fsw));
#line 302 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = fsw;
#line 302 "/home/jens/Source/shotwell/src/Page.vala"
	page_add_actions (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, g_action_map_get_type (), GActionMap));
#line 3397 "Page.c"
}


void page_switching_to_fullscreen (Page* self, FullscreenWindow* fsw) {
#line 301 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 301 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->switching_to_fullscreen (self, fsw);
#line 3406 "Page.c"
}


static void page_real_returning_from_fullscreen (Page* self, FullscreenWindow* fsw) {
	FullscreenWindow* _tmp0_;
#line 305 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_FULLSCREEN_WINDOW (fsw));
#line 306 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = fsw;
#line 306 "/home/jens/Source/shotwell/src/Page.vala"
	page_remove_actions (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, g_action_map_get_type (), GActionMap));
#line 307 "/home/jens/Source/shotwell/src/Page.vala"
	page_switched_to (self);
#line 3420 "Page.c"
}


void page_returning_from_fullscreen (Page* self, FullscreenWindow* fsw) {
#line 305 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 305 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->returning_from_fullscreen (self, fsw);
#line 3429 "Page.c"
}


GAction* page_get_action (Page* self, const gchar* name) {
	GAction* result = NULL;
	GActionMap* map = NULL;
	GtkWindow* _tmp0_;
	GActionMap* _tmp5_;
#line 310 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 310 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 311 "/home/jens/Source/shotwell/src/Page.vala"
	map = NULL;
#line 312 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->container;
#line 312 "/home/jens/Source/shotwell/src/Page.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_FULLSCREEN_WINDOW)) {
#line 3448 "Page.c"
		GtkWindow* _tmp1_;
		GActionMap* _tmp2_;
#line 313 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = self->priv->container;
#line 313 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, g_action_map_get_type ()) ? ((GActionMap*) _tmp1_) : NULL);
#line 313 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (map);
#line 313 "/home/jens/Source/shotwell/src/Page.vala"
		map = _tmp2_;
#line 3459 "Page.c"
	} else {
		AppWindow* _tmp3_;
		GActionMap* _tmp4_;
#line 315 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = app_window_get_instance ();
#line 315 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, g_action_map_get_type ()) ? ((GActionMap*) _tmp3_) : NULL;
#line 315 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp4_ == NULL) {
#line 315 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (_tmp3_);
#line 3471 "Page.c"
		}
#line 315 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (map);
#line 315 "/home/jens/Source/shotwell/src/Page.vala"
		map = _tmp4_;
#line 3477 "Page.c"
	}
#line 318 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = map;
#line 318 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp5_ != NULL) {
#line 3483 "Page.c"
		GActionMap* _tmp6_;
		const gchar* _tmp7_;
		GAction* _tmp8_;
		GAction* _tmp9_;
#line 319 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = map;
#line 319 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = name;
#line 319 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = g_action_map_lookup_action (_tmp6_, _tmp7_);
#line 319 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = _g_object_ref0 (_tmp8_);
#line 319 "/home/jens/Source/shotwell/src/Page.vala"
		result = _tmp9_;
#line 319 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (map);
#line 319 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 3502 "Page.c"
	}
#line 322 "/home/jens/Source/shotwell/src/Page.vala"
	result = NULL;
#line 322 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (map);
#line 322 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 3510 "Page.c"
}


void page_set_action_sensitive (Page* self, const gchar* name, gboolean sensitive) {
	GSimpleAction* action = NULL;
	const gchar* _tmp0_;
	GAction* _tmp1_;
	GSimpleAction* _tmp2_;
	GSimpleAction* _tmp3_;
#line 325 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 325 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 326 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 326 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_action (self, _tmp0_);
#line 326 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp1_) : NULL;
#line 326 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_ == NULL) {
#line 326 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp1_);
#line 3534 "Page.c"
	}
#line 326 "/home/jens/Source/shotwell/src/Page.vala"
	action = _tmp2_;
#line 327 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = action;
#line 327 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_ != NULL) {
#line 3542 "Page.c"
		GSimpleAction* _tmp4_;
		gboolean _tmp5_;
#line 328 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = action;
#line 328 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = sensitive;
#line 328 "/home/jens/Source/shotwell/src/Page.vala"
		g_simple_action_set_enabled (_tmp4_, _tmp5_);
#line 3551 "Page.c"
	}
#line 325 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (action);
#line 3555 "Page.c"
}


void page_set_action_important (Page* self, const gchar* name, gboolean important) {
	const gchar* _tmp0_;
	gboolean _tmp1_;
#line 331 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 331 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 332 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 332 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = important;
#line 332 "/home/jens/Source/shotwell/src/Page.vala"
	page_set_action_sensitive (self, _tmp0_, _tmp1_);
#line 3572 "Page.c"
}


void page_set_action_visible (Page* self, const gchar* name, gboolean visible) {
	const gchar* _tmp0_;
	gboolean _tmp1_;
#line 335 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 335 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 336 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 336 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = visible;
#line 336 "/home/jens/Source/shotwell/src/Page.vala"
	page_set_action_sensitive (self, _tmp0_, _tmp1_);
#line 3589 "Page.c"
}


void page_set_action_short_label (Page* self, const gchar* name, const gchar* short_label) {
	const gchar* _tmp0_;
#line 339 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 339 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 339 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (short_label != NULL);
#line 340 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 340 "/home/jens/Source/shotwell/src/Page.vala"
	g_debug ("Page.vala:340: => Set action short_label called for %s", _tmp0_);
#line 3605 "Page.c"
}


void page_set_action_details (Page* self, const gchar* name, const gchar* label, const gchar* tooltip, gboolean sensitive) {
	GSimpleAction* action = NULL;
	const gchar* _tmp0_;
	GAction* _tmp1_;
	GSimpleAction* _tmp2_;
	GSimpleAction* _tmp3_;
	const gchar* _tmp4_;
	GSimpleAction* _tmp7_;
	gboolean _tmp8_;
#line 343 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 343 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 344 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 344 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_action (self, _tmp0_);
#line 344 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp1_) : NULL;
#line 344 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_ == NULL) {
#line 344 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp1_);
#line 3632 "Page.c"
	}
#line 344 "/home/jens/Source/shotwell/src/Page.vala"
	action = _tmp2_;
#line 346 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = action;
#line 346 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_ == NULL) {
#line 347 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (action);
#line 347 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 3644 "Page.c"
	}
#line 349 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = label;
#line 349 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_ != NULL) {
#line 3650 "Page.c"
		const gchar* _tmp5_;
		const gchar* _tmp6_;
#line 350 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = name;
#line 350 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = label;
#line 350 "/home/jens/Source/shotwell/src/Page.vala"
		page_update_menu_item_label (self, _tmp5_, _tmp6_);
#line 3659 "Page.c"
	}
#line 352 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = action;
#line 352 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = sensitive;
#line 352 "/home/jens/Source/shotwell/src/Page.vala"
	g_simple_action_set_enabled (_tmp7_, _tmp8_);
#line 343 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (action);
#line 3669 "Page.c"
}


void page_activate_action (Page* self, const gchar* name) {
	GAction* action = NULL;
	const gchar* _tmp0_;
	GAction* _tmp1_;
	GAction* _tmp2_;
#line 355 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 355 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 356 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 356 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_action (self, _tmp0_);
#line 356 "/home/jens/Source/shotwell/src/Page.vala"
	action = _tmp1_;
#line 358 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = action;
#line 358 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_ != NULL) {
#line 3692 "Page.c"
		GAction* _tmp3_;
#line 359 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = action;
#line 359 "/home/jens/Source/shotwell/src/Page.vala"
		g_action_activate (_tmp3_, NULL);
#line 3698 "Page.c"
	}
#line 355 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (action);
#line 3702 "Page.c"
}


GAction* page_get_common_action (Page* self, const gchar* name, gboolean log_warning) {
	GAction* result = NULL;
	GAction* action = NULL;
	const gchar* _tmp0_;
	GAction* _tmp1_;
	GAction* _tmp2_;
	gboolean _tmp3_;
#line 362 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 362 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 363 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 363 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_action (self, _tmp0_);
#line 363 "/home/jens/Source/shotwell/src/Page.vala"
	action = _tmp1_;
#line 365 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = action;
#line 365 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_ != NULL) {
#line 366 "/home/jens/Source/shotwell/src/Page.vala"
		result = action;
#line 366 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 3731 "Page.c"
	}
#line 368 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = log_warning;
#line 368 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_) {
#line 3737 "Page.c"
		gchar* _tmp4_;
		gchar* _tmp5_;
		const gchar* _tmp6_;
#line 369 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = page_get_page_name (self);
#line 369 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = _tmp4_;
#line 369 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = name;
#line 369 "/home/jens/Source/shotwell/src/Page.vala"
		g_warning ("Page.vala:369: Page %s: Unable to locate common action %s", _tmp5_, _tmp6_);
#line 369 "/home/jens/Source/shotwell/src/Page.vala"
		_g_free0 (_tmp5_);
#line 3751 "Page.c"
	}
#line 371 "/home/jens/Source/shotwell/src/Page.vala"
	result = NULL;
#line 371 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (action);
#line 371 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 3759 "Page.c"
}


void page_set_common_action_sensitive (Page* self, const gchar* name, gboolean sensitive) {
	GSimpleAction* action = NULL;
	const gchar* _tmp0_;
	GAction* _tmp1_;
	GSimpleAction* _tmp2_;
	GSimpleAction* _tmp3_;
#line 374 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 374 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 375 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 375 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_common_action (self, _tmp0_, TRUE);
#line 375 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp1_) : NULL;
#line 375 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_ == NULL) {
#line 375 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp1_);
#line 3783 "Page.c"
	}
#line 375 "/home/jens/Source/shotwell/src/Page.vala"
	action = _tmp2_;
#line 376 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = action;
#line 376 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_ != NULL) {
#line 3791 "Page.c"
		GSimpleAction* _tmp4_;
		gboolean _tmp5_;
#line 377 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = action;
#line 377 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = sensitive;
#line 377 "/home/jens/Source/shotwell/src/Page.vala"
		g_simple_action_set_enabled (_tmp4_, _tmp5_);
#line 3800 "Page.c"
	}
#line 374 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (action);
#line 3804 "Page.c"
}


void page_set_common_action_label (Page* self, const gchar* name, const gchar* label) {
	const gchar* _tmp0_;
#line 380 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 380 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 380 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (label != NULL);
#line 381 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 381 "/home/jens/Source/shotwell/src/Page.vala"
	g_debug ("Page.vala:381: Trying to set common action label for %s", _tmp0_);
#line 3820 "Page.c"
}


void page_set_common_action_important (Page* self, const gchar* name, gboolean important) {
	const gchar* _tmp0_;
#line 384 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 384 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 385 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 385 "/home/jens/Source/shotwell/src/Page.vala"
	g_debug ("Page.vala:385: Setting action to important: %s", _tmp0_);
#line 3834 "Page.c"
}


void page_activate_common_action (Page* self, const gchar* name) {
	GSimpleAction* action = NULL;
	const gchar* _tmp0_;
	GAction* _tmp1_;
	GSimpleAction* _tmp2_;
	GSimpleAction* _tmp3_;
#line 388 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 388 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 389 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 389 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_common_action (self, _tmp0_, TRUE);
#line 389 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp1_) : NULL;
#line 389 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_ == NULL) {
#line 389 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp1_);
#line 3858 "Page.c"
	}
#line 389 "/home/jens/Source/shotwell/src/Page.vala"
	action = _tmp2_;
#line 390 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = action;
#line 390 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_ != NULL) {
#line 3866 "Page.c"
		GSimpleAction* _tmp4_;
#line 391 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = action;
#line 391 "/home/jens/Source/shotwell/src/Page.vala"
		g_signal_emit_by_name (_tmp4_, "activate", NULL);
#line 3872 "Page.c"
	}
#line 388 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (action);
#line 3876 "Page.c"
}


gboolean page_get_ctrl_pressed (Page* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 394 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 395 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->ctrl_pressed;
#line 395 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp0_;
#line 395 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 3891 "Page.c"
}


gboolean page_get_alt_pressed (Page* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 398 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 399 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->alt_pressed;
#line 399 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp0_;
#line 399 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 3906 "Page.c"
}


gboolean page_get_shift_pressed (Page* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 402 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 403 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->shift_pressed;
#line 403 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp0_;
#line 403 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 3921 "Page.c"
}


gboolean page_get_super_pressed (Page* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 406 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 407 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->super_pressed;
#line 407 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp0_;
#line 407 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 3936 "Page.c"
}


static GVariant* _variant_new20 (gboolean value) {
#line 413 "/home/jens/Source/shotwell/src/Page.vala"
	return g_variant_ref_sink (g_variant_new_boolean (value));
#line 3943 "Page.c"
}


void page_set_action_active (Page* self, const gchar* name, gboolean active) {
	GSimpleAction* action = NULL;
	const gchar* _tmp0_;
	GAction* _tmp1_;
	GSimpleAction* _tmp2_;
	GSimpleAction* _tmp3_;
#line 410 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 410 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 411 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 411 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_action (self, _tmp0_);
#line 411 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, g_simple_action_get_type ()) ? ((GSimpleAction*) _tmp1_) : NULL;
#line 411 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_ == NULL) {
#line 411 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp1_);
#line 3967 "Page.c"
	}
#line 411 "/home/jens/Source/shotwell/src/Page.vala"
	action = _tmp2_;
#line 412 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = action;
#line 412 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_ != NULL) {
#line 3975 "Page.c"
		GSimpleAction* _tmp4_;
		gboolean _tmp5_;
		GVariant* _tmp6_;
#line 413 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = action;
#line 413 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = active;
#line 413 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = _variant_new20 (_tmp5_);
#line 413 "/home/jens/Source/shotwell/src/Page.vala"
		g_simple_action_set_state (_tmp4_, _tmp6_);
#line 413 "/home/jens/Source/shotwell/src/Page.vala"
		_g_variant_unref0 (_tmp6_);
#line 3989 "Page.c"
	}
#line 410 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (action);
#line 3993 "Page.c"
}


static gboolean page_get_modifiers (Page* self, gboolean* ctrl, gboolean* alt, gboolean* shift, gboolean* super) {
	gboolean _vala_ctrl = FALSE;
	gboolean _vala_alt = FALSE;
	gboolean _vala_shift = FALSE;
	gboolean _vala_super = FALSE;
	gboolean result = FALSE;
	AppWindow* _tmp0_;
	AppWindow* _tmp1_;
	GdkWindow* _tmp2_;
	gboolean _tmp3_;
	gint x = 0;
	gint y = 0;
	GdkModifierType mask = 0;
	AppWindow* _tmp4_;
	AppWindow* _tmp5_;
	GdkWindow* _tmp6_;
	GdkDisplay* _tmp7_;
	GdkDeviceManager* _tmp8_;
	GdkDevice* _tmp9_;
	gint _tmp10_ = 0;
	gint _tmp11_ = 0;
	GdkModifierType _tmp12_ = 0;
	GdkModifierType _tmp13_;
	GdkModifierType _tmp14_;
	GdkModifierType _tmp15_;
	GdkModifierType _tmp16_;
#line 417 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 418 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = app_window_get_instance ();
#line 418 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_;
#line 418 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 418 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_ == NULL;
#line 418 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (_tmp1_);
#line 418 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_) {
#line 419 "/home/jens/Source/shotwell/src/Page.vala"
		_vala_ctrl = FALSE;
#line 420 "/home/jens/Source/shotwell/src/Page.vala"
		_vala_alt = FALSE;
#line 421 "/home/jens/Source/shotwell/src/Page.vala"
		_vala_shift = FALSE;
#line 422 "/home/jens/Source/shotwell/src/Page.vala"
		_vala_super = FALSE;
#line 424 "/home/jens/Source/shotwell/src/Page.vala"
		result = FALSE;
#line 424 "/home/jens/Source/shotwell/src/Page.vala"
		if (ctrl) {
#line 424 "/home/jens/Source/shotwell/src/Page.vala"
			*ctrl = _vala_ctrl;
#line 4051 "Page.c"
		}
#line 424 "/home/jens/Source/shotwell/src/Page.vala"
		if (alt) {
#line 424 "/home/jens/Source/shotwell/src/Page.vala"
			*alt = _vala_alt;
#line 4057 "Page.c"
		}
#line 424 "/home/jens/Source/shotwell/src/Page.vala"
		if (shift) {
#line 424 "/home/jens/Source/shotwell/src/Page.vala"
			*shift = _vala_shift;
#line 4063 "Page.c"
		}
#line 424 "/home/jens/Source/shotwell/src/Page.vala"
		if (super) {
#line 424 "/home/jens/Source/shotwell/src/Page.vala"
			*super = _vala_super;
#line 4069 "Page.c"
		}
#line 424 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 4073 "Page.c"
	}
#line 429 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = app_window_get_instance ();
#line 429 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _tmp4_;
#line 429 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget));
#line 429 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = gdk_display_get_default ();
#line 429 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = gdk_display_get_device_manager (_tmp7_);
#line 429 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = gdk_device_manager_get_client_pointer (_tmp8_);
#line 429 "/home/jens/Source/shotwell/src/Page.vala"
	gdk_window_get_device_position (_tmp6_, _tmp9_, &_tmp10_, &_tmp11_, &_tmp12_);
#line 429 "/home/jens/Source/shotwell/src/Page.vala"
	x = _tmp10_;
#line 429 "/home/jens/Source/shotwell/src/Page.vala"
	y = _tmp11_;
#line 429 "/home/jens/Source/shotwell/src/Page.vala"
	mask = _tmp12_;
#line 429 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (_tmp5_);
#line 432 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp13_ = mask;
#line 432 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_ctrl = (_tmp13_ & GDK_CONTROL_MASK) != 0;
#line 433 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp14_ = mask;
#line 433 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_alt = (_tmp14_ & GDK_MOD1_MASK) != 0;
#line 434 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp15_ = mask;
#line 434 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_shift = (_tmp15_ & GDK_SHIFT_MASK) != 0;
#line 435 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp16_ = mask;
#line 435 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_super = (_tmp16_ & GDK_MOD4_MASK) != 0;
#line 437 "/home/jens/Source/shotwell/src/Page.vala"
	result = TRUE;
#line 437 "/home/jens/Source/shotwell/src/Page.vala"
	if (ctrl) {
#line 437 "/home/jens/Source/shotwell/src/Page.vala"
		*ctrl = _vala_ctrl;
#line 4119 "Page.c"
	}
#line 437 "/home/jens/Source/shotwell/src/Page.vala"
	if (alt) {
#line 437 "/home/jens/Source/shotwell/src/Page.vala"
		*alt = _vala_alt;
#line 4125 "Page.c"
	}
#line 437 "/home/jens/Source/shotwell/src/Page.vala"
	if (shift) {
#line 437 "/home/jens/Source/shotwell/src/Page.vala"
		*shift = _vala_shift;
#line 4131 "Page.c"
	}
#line 437 "/home/jens/Source/shotwell/src/Page.vala"
	if (super) {
#line 437 "/home/jens/Source/shotwell/src/Page.vala"
		*super = _vala_super;
#line 4137 "Page.c"
	}
#line 437 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 4141 "Page.c"
}


static void page_update_modifiers (Page* self) {
	gboolean ctrl_currently_pressed = FALSE;
	gboolean alt_currently_pressed = FALSE;
	gboolean shift_currently_pressed = FALSE;
	gboolean super_currently_pressed = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_;
	gboolean _tmp11_ = FALSE;
	gboolean _tmp12_;
	gboolean _tmp17_ = FALSE;
	gboolean _tmp18_;
	gboolean _tmp23_ = FALSE;
	gboolean _tmp24_;
	gboolean _tmp29_;
	gboolean _tmp30_;
	gboolean _tmp31_;
	gboolean _tmp32_;
#line 440 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 443 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = page_get_modifiers (self, &_tmp0_, &_tmp1_, &_tmp2_, &_tmp3_);
#line 443 "/home/jens/Source/shotwell/src/Page.vala"
	ctrl_currently_pressed = _tmp0_;
#line 443 "/home/jens/Source/shotwell/src/Page.vala"
	alt_currently_pressed = _tmp1_;
#line 443 "/home/jens/Source/shotwell/src/Page.vala"
	shift_currently_pressed = _tmp2_;
#line 443 "/home/jens/Source/shotwell/src/Page.vala"
	super_currently_pressed = _tmp3_;
#line 443 "/home/jens/Source/shotwell/src/Page.vala"
	if (!_tmp4_) {
#line 445 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 4183 "Page.c"
	}
#line 448 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = self->priv->ctrl_pressed;
#line 448 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp6_) {
#line 4189 "Page.c"
		gboolean _tmp7_;
#line 448 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = ctrl_currently_pressed;
#line 448 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = !_tmp7_;
#line 4195 "Page.c"
	} else {
#line 448 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = FALSE;
#line 4199 "Page.c"
	}
#line 448 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp5_) {
#line 449 "/home/jens/Source/shotwell/src/Page.vala"
		page_on_ctrl_released (self, NULL);
#line 4205 "Page.c"
	} else {
		gboolean _tmp8_ = FALSE;
		gboolean _tmp9_;
#line 450 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = self->priv->ctrl_pressed;
#line 450 "/home/jens/Source/shotwell/src/Page.vala"
		if (!_tmp9_) {
#line 4213 "Page.c"
			gboolean _tmp10_;
#line 450 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp10_ = ctrl_currently_pressed;
#line 450 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp8_ = _tmp10_;
#line 4219 "Page.c"
		} else {
#line 450 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp8_ = FALSE;
#line 4223 "Page.c"
		}
#line 450 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp8_) {
#line 451 "/home/jens/Source/shotwell/src/Page.vala"
			page_on_ctrl_pressed (self, NULL);
#line 4229 "Page.c"
		}
	}
#line 453 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = self->priv->alt_pressed;
#line 453 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp12_) {
#line 4236 "Page.c"
		gboolean _tmp13_;
#line 453 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp13_ = alt_currently_pressed;
#line 453 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = !_tmp13_;
#line 4242 "Page.c"
	} else {
#line 453 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = FALSE;
#line 4246 "Page.c"
	}
#line 453 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp11_) {
#line 454 "/home/jens/Source/shotwell/src/Page.vala"
		page_on_alt_released (self, NULL);
#line 4252 "Page.c"
	} else {
		gboolean _tmp14_ = FALSE;
		gboolean _tmp15_;
#line 455 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp15_ = self->priv->alt_pressed;
#line 455 "/home/jens/Source/shotwell/src/Page.vala"
		if (!_tmp15_) {
#line 4260 "Page.c"
			gboolean _tmp16_;
#line 455 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp16_ = alt_currently_pressed;
#line 455 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp14_ = _tmp16_;
#line 4266 "Page.c"
		} else {
#line 455 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp14_ = FALSE;
#line 4270 "Page.c"
		}
#line 455 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp14_) {
#line 456 "/home/jens/Source/shotwell/src/Page.vala"
			page_on_alt_pressed (self, NULL);
#line 4276 "Page.c"
		}
	}
#line 458 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp18_ = self->priv->shift_pressed;
#line 458 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp18_) {
#line 4283 "Page.c"
		gboolean _tmp19_;
#line 458 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp19_ = shift_currently_pressed;
#line 458 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp17_ = !_tmp19_;
#line 4289 "Page.c"
	} else {
#line 458 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp17_ = FALSE;
#line 4293 "Page.c"
	}
#line 458 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp17_) {
#line 459 "/home/jens/Source/shotwell/src/Page.vala"
		page_on_shift_released (self, NULL);
#line 4299 "Page.c"
	} else {
		gboolean _tmp20_ = FALSE;
		gboolean _tmp21_;
#line 460 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp21_ = self->priv->shift_pressed;
#line 460 "/home/jens/Source/shotwell/src/Page.vala"
		if (!_tmp21_) {
#line 4307 "Page.c"
			gboolean _tmp22_;
#line 460 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp22_ = shift_currently_pressed;
#line 460 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp20_ = _tmp22_;
#line 4313 "Page.c"
		} else {
#line 460 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp20_ = FALSE;
#line 4317 "Page.c"
		}
#line 460 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp20_) {
#line 461 "/home/jens/Source/shotwell/src/Page.vala"
			page_on_shift_pressed (self, NULL);
#line 4323 "Page.c"
		}
	}
#line 463 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp24_ = self->priv->super_pressed;
#line 463 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp24_) {
#line 4330 "Page.c"
		gboolean _tmp25_;
#line 463 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp25_ = super_currently_pressed;
#line 463 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp23_ = !_tmp25_;
#line 4336 "Page.c"
	} else {
#line 463 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp23_ = FALSE;
#line 4340 "Page.c"
	}
#line 463 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp23_) {
#line 464 "/home/jens/Source/shotwell/src/Page.vala"
		page_on_super_released (self, NULL);
#line 4346 "Page.c"
	} else {
		gboolean _tmp26_ = FALSE;
		gboolean _tmp27_;
#line 465 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp27_ = self->priv->super_pressed;
#line 465 "/home/jens/Source/shotwell/src/Page.vala"
		if (!_tmp27_) {
#line 4354 "Page.c"
			gboolean _tmp28_;
#line 465 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp28_ = super_currently_pressed;
#line 465 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp26_ = _tmp28_;
#line 4360 "Page.c"
		} else {
#line 465 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp26_ = FALSE;
#line 4364 "Page.c"
		}
#line 465 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp26_) {
#line 466 "/home/jens/Source/shotwell/src/Page.vala"
			page_on_super_pressed (self, NULL);
#line 4370 "Page.c"
		}
	}
#line 468 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp29_ = ctrl_currently_pressed;
#line 468 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->ctrl_pressed = _tmp29_;
#line 469 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp30_ = alt_currently_pressed;
#line 469 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->alt_pressed = _tmp30_;
#line 470 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp31_ = shift_currently_pressed;
#line 470 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->shift_pressed = _tmp31_;
#line 471 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp32_ = super_currently_pressed;
#line 471 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->super_pressed = _tmp32_;
#line 4389 "Page.c"
}


PageWindow* page_get_page_window (Page* self) {
	PageWindow* result = NULL;
	GtkWidget* p = NULL;
	GtkContainer* _tmp0_;
	GtkContainer* _tmp1_;
	GtkWidget* _tmp2_;
#line 474 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 475 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = gtk_widget_get_parent (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 475 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_;
#line 475 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 475 "/home/jens/Source/shotwell/src/Page.vala"
	p = _tmp2_;
#line 476 "/home/jens/Source/shotwell/src/Page.vala"
	while (TRUE) {
#line 4411 "Page.c"
		GtkWidget* _tmp3_;
		GtkWidget* _tmp4_;
		GtkWidget* _tmp7_;
		GtkContainer* _tmp8_;
		GtkContainer* _tmp9_;
		GtkWidget* _tmp10_;
#line 476 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = p;
#line 476 "/home/jens/Source/shotwell/src/Page.vala"
		if (!(_tmp3_ != NULL)) {
#line 476 "/home/jens/Source/shotwell/src/Page.vala"
			break;
#line 4424 "Page.c"
		}
#line 477 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = p;
#line 477 "/home/jens/Source/shotwell/src/Page.vala"
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, TYPE_PAGE_WINDOW)) {
#line 4430 "Page.c"
			GtkWidget* _tmp5_;
			PageWindow* _tmp6_;
#line 478 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp5_ = p;
#line 478 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_PAGE_WINDOW, PageWindow));
#line 478 "/home/jens/Source/shotwell/src/Page.vala"
			result = _tmp6_;
#line 478 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (p);
#line 478 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 4443 "Page.c"
		}
#line 480 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = p;
#line 480 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = gtk_widget_get_parent (_tmp7_);
#line 480 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = _tmp8_;
#line 480 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget));
#line 480 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (p);
#line 480 "/home/jens/Source/shotwell/src/Page.vala"
		p = _tmp10_;
#line 4457 "Page.c"
	}
#line 483 "/home/jens/Source/shotwell/src/Page.vala"
	result = NULL;
#line 483 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (p);
#line 483 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 4465 "Page.c"
}


CommandManager* page_get_command_manager (Page* self) {
	CommandManager* result = NULL;
	CommandManager* _tmp0_;
#line 486 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 487 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = app_window_get_command_manager ();
#line 487 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp0_;
#line 487 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 4480 "Page.c"
}


static void page_real_add_actions (Page* self, GActionMap* map) {
#line 490 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (G_IS_ACTION_MAP (map));
#line 4487 "Page.c"
}


void page_add_actions (Page* self, GActionMap* map) {
#line 490 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 490 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->add_actions (self, map);
#line 4496 "Page.c"
}


static void page_real_remove_actions (Page* self, GActionMap* map) {
#line 491 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (G_IS_ACTION_MAP (map));
#line 4503 "Page.c"
}


void page_remove_actions (Page* self, GActionMap* map) {
#line 491 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 491 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->remove_actions (self, map);
#line 4512 "Page.c"
}


static gboolean _variant_get21 (GVariant* value) {
#line 494 "/home/jens/Source/shotwell/src/Page.vala"
	return g_variant_get_boolean (value);
#line 4519 "Page.c"
}


static GVariant* _variant_new22 (gboolean value) {
#line 494 "/home/jens/Source/shotwell/src/Page.vala"
	return g_variant_ref_sink (g_variant_new_boolean (value));
#line 4526 "Page.c"
}


void page_on_action_toggle (Page* self, GAction* action, GVariant* value) {
	GVariant* new_state = NULL;
	GAction* _tmp0_;
	GVariant* _tmp1_;
	GVariant* _tmp2_;
	gboolean _tmp3_;
	GVariant* _tmp4_;
	GVariant* _tmp5_;
	GAction* _tmp6_;
#line 493 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 493 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (G_IS_ACTION (action));
#line 494 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = action;
#line 494 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = g_action_get_state (_tmp0_);
#line 494 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_;
#line 494 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _variant_get21 (_tmp2_);
#line 494 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = _variant_new22 (!_tmp3_);
#line 494 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _tmp4_;
#line 494 "/home/jens/Source/shotwell/src/Page.vala"
	_g_variant_unref0 (_tmp2_);
#line 494 "/home/jens/Source/shotwell/src/Page.vala"
	new_state = _tmp5_;
#line 495 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = action;
#line 495 "/home/jens/Source/shotwell/src/Page.vala"
	g_action_change_state (_tmp6_, new_state);
#line 493 "/home/jens/Source/shotwell/src/Page.vala"
	_g_variant_unref0 (new_state);
#line 4565 "Page.c"
}


void page_on_action_radio (Page* self, GAction* action, GVariant* value) {
	GAction* _tmp0_;
	GVariant* _tmp1_;
#line 498 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 498 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (G_IS_ACTION (action));
#line 499 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = action;
#line 499 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = value;
#line 499 "/home/jens/Source/shotwell/src/Page.vala"
	g_action_change_state (_tmp0_, _tmp1_);
#line 4582 "Page.c"
}


static void page_add_ui (Page* self) {
	GeeList* ui_filenames = NULL;
	GeeArrayList* _tmp0_;
	GeeList* _tmp1_;
	GeeList* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
#line 502 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 504 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL);
#line 504 "/home/jens/Source/shotwell/src/Page.vala"
	ui_filenames = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_LIST, GeeList);
#line 505 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = ui_filenames;
#line 505 "/home/jens/Source/shotwell/src/Page.vala"
	page_init_collect_ui_filenames (self, _tmp1_);
#line 506 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = ui_filenames;
#line 506 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection));
#line 506 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = _tmp3_;
#line 506 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_ == 0) {
#line 4611 "Page.c"
		gchar* _tmp5_;
		gchar* _tmp6_;
#line 507 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = page_get_page_name (self);
#line 507 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = _tmp5_;
#line 507 "/home/jens/Source/shotwell/src/Page.vala"
		g_message ("Page.vala:507: No UI file specified for %s", _tmp6_);
#line 507 "/home/jens/Source/shotwell/src/Page.vala"
		_g_free0 (_tmp6_);
#line 4622 "Page.c"
	}
	{
		GeeList* _ui_filename_list = NULL;
		GeeList* _tmp7_;
		GeeList* _tmp8_;
		gint _ui_filename_size = 0;
		GeeList* _tmp9_;
		gint _tmp10_;
		gint _tmp11_;
		gint _ui_filename_index = 0;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = ui_filenames;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = _g_object_ref0 (_tmp7_);
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
		_ui_filename_list = _tmp8_;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = _ui_filename_list;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_COLLECTION, GeeCollection));
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = _tmp10_;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
		_ui_filename_size = _tmp11_;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
		_ui_filename_index = -1;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
		while (TRUE) {
#line 4651 "Page.c"
			gint _tmp12_;
			gint _tmp13_;
			gint _tmp14_;
			gchar* ui_filename = NULL;
			GeeList* _tmp15_;
			gint _tmp16_;
			gpointer _tmp17_;
			const gchar* _tmp18_;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp12_ = _ui_filename_index;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
			_ui_filename_index = _tmp12_ + 1;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp13_ = _ui_filename_index;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp14_ = _ui_filename_size;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
			if (!(_tmp13_ < _tmp14_)) {
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 4672 "Page.c"
			}
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp15_ = _ui_filename_list;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp16_ = _ui_filename_index;
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp17_ = gee_list_get (_tmp15_, _tmp16_);
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
			ui_filename = (gchar*) _tmp17_;
#line 510 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp18_ = ui_filename;
#line 510 "/home/jens/Source/shotwell/src/Page.vala"
			page_init_load_ui (self, _tmp18_);
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
			_g_free0 (ui_filename);
#line 4688 "Page.c"
		}
#line 509 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_ui_filename_list);
#line 4692 "Page.c"
	}
#line 502 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (ui_filenames);
#line 4696 "Page.c"
}


void page_init_toolbar (Page* self, const gchar* path) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 515 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 515 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (path != NULL);
#line 516 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = path;
#line 516 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 516 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->priv->toolbar_path);
#line 516 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->toolbar_path = _tmp1_;
#line 4715 "Page.c"
}


static void _page_on_update_actions_view_collection_items_state_changed (ViewCollection* _sender, GeeIterable* changed, gpointer self) {
#line 531 "/home/jens/Source/shotwell/src/Page.vala"
	page_on_update_actions ((Page*) self);
#line 4722 "Page.c"
}


static void _page_on_update_actions_view_collection_selection_group_altered (ViewCollection* _sender, gpointer self) {
#line 532 "/home/jens/Source/shotwell/src/Page.vala"
	page_on_update_actions ((Page*) self);
#line 4729 "Page.c"
}


static void _page_on_update_actions_view_collection_items_visibility_changed (ViewCollection* _sender, GeeCollection* changed, gpointer self) {
#line 533 "/home/jens/Source/shotwell/src/Page.vala"
	page_on_update_actions ((Page*) self);
#line 4736 "Page.c"
}


static void _page_on_update_actions_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self) {
#line 534 "/home/jens/Source/shotwell/src/Page.vala"
	page_on_update_actions ((Page*) self);
#line 4743 "Page.c"
}


static void page_attach_view_signals (Page* self) {
	gboolean _tmp0_;
	gint selected_count = 0;
	ViewCollection* _tmp1_;
	ViewCollection* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	gint count = 0;
	ViewCollection* _tmp5_;
	ViewCollection* _tmp6_;
	gint _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
	gint _tmp12_;
	ViewCollection* _tmp13_;
	ViewCollection* _tmp14_;
	ViewCollection* _tmp15_;
	ViewCollection* _tmp16_;
	ViewCollection* _tmp17_;
	ViewCollection* _tmp18_;
	ViewCollection* _tmp19_;
	ViewCollection* _tmp20_;
#line 520 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 521 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->are_actions_attached;
#line 521 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_) {
#line 522 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 4779 "Page.c"
	}
#line 525 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_view (self);
#line 525 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_;
#line 525 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = view_collection_get_selected_count (_tmp2_);
#line 525 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = _tmp3_;
#line 525 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp2_);
#line 525 "/home/jens/Source/shotwell/src/Page.vala"
	selected_count = _tmp4_;
#line 526 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = page_get_view (self);
#line 526 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = _tmp5_;
#line 526 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TYPE_DATA_COLLECTION, DataCollection));
#line 526 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = _tmp7_;
#line 526 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp6_);
#line 526 "/home/jens/Source/shotwell/src/Page.vala"
	count = _tmp8_;
#line 527 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = selected_count;
#line 527 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = count;
#line 527 "/home/jens/Source/shotwell/src/Page.vala"
	page_init_actions (self, _tmp9_, _tmp10_);
#line 528 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = selected_count;
#line 528 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = count;
#line 528 "/home/jens/Source/shotwell/src/Page.vala"
	page_update_actions (self, _tmp11_, _tmp12_);
#line 531 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp13_ = page_get_view (self);
#line 531 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp14_ = _tmp13_;
#line 531 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp14_, "items-state-changed", (GCallback) _page_on_update_actions_view_collection_items_state_changed, self, 0);
#line 531 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp14_);
#line 532 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp15_ = page_get_view (self);
#line 532 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp16_ = _tmp15_;
#line 532 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp16_, "selection-group-altered", (GCallback) _page_on_update_actions_view_collection_selection_group_altered, self, 0);
#line 532 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp16_);
#line 533 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp17_ = page_get_view (self);
#line 533 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp18_ = _tmp17_;
#line 533 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp18_, "items-visibility-changed", (GCallback) _page_on_update_actions_view_collection_items_visibility_changed, self, 0);
#line 533 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp18_);
#line 534 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp19_ = page_get_view (self);
#line 534 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp20_ = _tmp19_;
#line 534 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, TYPE_DATA_COLLECTION, DataCollection), "contents-altered", (GCallback) _page_on_update_actions_data_collection_contents_altered, self, 0);
#line 534 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp20_);
#line 536 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->are_actions_attached = TRUE;
#line 4851 "Page.c"
}


static void page_detach_view_signals (Page* self) {
	gboolean _tmp0_;
	ViewCollection* _tmp1_;
	ViewCollection* _tmp2_;
	guint _tmp3_;
	ViewCollection* _tmp4_;
	ViewCollection* _tmp5_;
	guint _tmp6_;
	ViewCollection* _tmp7_;
	ViewCollection* _tmp8_;
	guint _tmp9_;
	ViewCollection* _tmp10_;
	ViewCollection* _tmp11_;
	guint _tmp12_;
#line 540 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 541 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->are_actions_attached;
#line 541 "/home/jens/Source/shotwell/src/Page.vala"
	if (!_tmp0_) {
#line 542 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 4877 "Page.c"
	}
#line 544 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_view (self);
#line 544 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_;
#line 544 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("items-state-changed", TYPE_VIEW_COLLECTION, &_tmp3_, NULL, FALSE);
#line 544 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _page_on_update_actions_view_collection_items_state_changed, self);
#line 544 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp2_);
#line 545 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = page_get_view (self);
#line 545 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _tmp4_;
#line 545 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("selection-group-altered", TYPE_VIEW_COLLECTION, &_tmp6_, NULL, FALSE);
#line 545 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (_tmp5_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp6_, 0, NULL, (GCallback) _page_on_update_actions_view_collection_selection_group_altered, self);
#line 545 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp5_);
#line 546 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = page_get_view (self);
#line 546 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = _tmp7_;
#line 546 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("items-visibility-changed", TYPE_VIEW_COLLECTION, &_tmp9_, NULL, FALSE);
#line 546 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (_tmp8_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp9_, 0, NULL, (GCallback) _page_on_update_actions_view_collection_items_visibility_changed, self);
#line 546 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp8_);
#line 547 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = page_get_view (self);
#line 547 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = _tmp10_;
#line 547 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("contents-altered", TYPE_DATA_COLLECTION, &_tmp12_, NULL, FALSE);
#line 547 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_DATA_COLLECTION, DataCollection), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp12_, 0, NULL, (GCallback) _page_on_update_actions_data_collection_contents_altered, self);
#line 547 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp11_);
#line 549 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->are_actions_attached = FALSE;
#line 4921 "Page.c"
}


static void _page_on_update_actions_on_idle_one_shot_callback (gpointer self) {
#line 554 "/home/jens/Source/shotwell/src/Page.vala"
	page_on_update_actions_on_idle ((Page*) self);
#line 4928 "Page.c"
}


static void page_on_update_actions (Page* self) {
	OneShotScheduler* _tmp0_;
	OneShotScheduler* _tmp6_;
#line 552 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 553 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->update_actions_scheduler;
#line 553 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ == NULL) {
#line 4941 "Page.c"
		gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		OneShotScheduler* _tmp5_;
#line 554 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = page_get_page_name (self);
#line 554 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = _tmp1_;
#line 554 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = g_strdup_printf ("Update actions scheduler for %s", _tmp2_);
#line 554 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = _tmp3_;
#line 554 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = one_shot_scheduler_new (_tmp4_, _page_on_update_actions_on_idle_one_shot_callback, self);
#line 554 "/home/jens/Source/shotwell/src/Page.vala"
		_one_shot_scheduler_unref0 (self->priv->update_actions_scheduler);
#line 554 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->update_actions_scheduler = _tmp5_;
#line 554 "/home/jens/Source/shotwell/src/Page.vala"
		_g_free0 (_tmp4_);
#line 554 "/home/jens/Source/shotwell/src/Page.vala"
		_g_free0 (_tmp2_);
#line 4965 "Page.c"
	}
#line 559 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = self->priv->update_actions_scheduler;
#line 559 "/home/jens/Source/shotwell/src/Page.vala"
	one_shot_scheduler_at_priority_idle (_tmp6_, G_PRIORITY_LOW);
#line 4971 "Page.c"
}


static void page_on_update_actions_on_idle (Page* self) {
	gboolean _tmp0_;
	gboolean _tmp1_;
	ViewCollection* _tmp2_;
	ViewCollection* _tmp3_;
	gint _tmp4_;
	ViewCollection* _tmp5_;
	ViewCollection* _tmp6_;
	gint _tmp7_;
#line 562 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 563 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->is_destroyed;
#line 563 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_) {
#line 564 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 4992 "Page.c"
	}
#line 566 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->in_view;
#line 566 "/home/jens/Source/shotwell/src/Page.vala"
	if (!_tmp1_) {
#line 567 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 5000 "Page.c"
	}
#line 569 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = page_get_view (self);
#line 569 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_;
#line 569 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = view_collection_get_selected_count (_tmp3_);
#line 569 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = page_get_view (self);
#line 569 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = _tmp5_;
#line 569 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TYPE_DATA_COLLECTION, DataCollection));
#line 569 "/home/jens/Source/shotwell/src/Page.vala"
	page_update_actions (self, _tmp4_, _tmp7_);
#line 569 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp6_);
#line 569 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp3_);
#line 5020 "Page.c"
}


static void page_init_load_ui (Page* self, const gchar* ui_filename) {
	gchar* ui_resource = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	GError * _inner_error_ = NULL;
#line 572 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 572 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (ui_filename != NULL);
#line 573 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = ui_filename;
#line 573 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = resources_get_ui (_tmp0_);
#line 573 "/home/jens/Source/shotwell/src/Page.vala"
	ui_resource = _tmp1_;
#line 5039 "Page.c"
	{
		GtkBuilder* _tmp2_;
#line 575 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = self->builder;
#line 575 "/home/jens/Source/shotwell/src/Page.vala"
		gtk_builder_add_from_resource (_tmp2_, ui_resource, &_inner_error_);
#line 575 "/home/jens/Source/shotwell/src/Page.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5048 "Page.c"
			goto __catch255_g_error;
		}
#line 576 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->menubar_injected = FALSE;
#line 5053 "Page.c"
	}
	goto __finally255;
	__catch255_g_error:
	{
		GError* err = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		Application* _tmp7_;
		Application* _tmp8_;
#line 574 "/home/jens/Source/shotwell/src/Page.vala"
		err = _inner_error_;
#line 574 "/home/jens/Source/shotwell/src/Page.vala"
		_inner_error_ = NULL;
#line 578 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = err;
#line 578 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = _tmp3_->message;
#line 578 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = g_strdup_printf ("Error loading UI resource %s: %s", ui_resource, _tmp4_);
#line 578 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = _tmp5_;
#line 578 "/home/jens/Source/shotwell/src/Page.vala"
		app_window_error_message (_tmp6_, NULL);
#line 578 "/home/jens/Source/shotwell/src/Page.vala"
		_g_free0 (_tmp6_);
#line 580 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = application_get_instance ();
#line 580 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = _tmp7_;
#line 580 "/home/jens/Source/shotwell/src/Page.vala"
		application_panic (_tmp8_);
#line 580 "/home/jens/Source/shotwell/src/Page.vala"
		_application_unref0 (_tmp8_);
#line 574 "/home/jens/Source/shotwell/src/Page.vala"
		_g_error_free0 (err);
#line 5091 "Page.c"
	}
	__finally255:
#line 574 "/home/jens/Source/shotwell/src/Page.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 574 "/home/jens/Source/shotwell/src/Page.vala"
		_g_free0 (ui_resource);
#line 574 "/home/jens/Source/shotwell/src/Page.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 574 "/home/jens/Source/shotwell/src/Page.vala"
		g_clear_error (&_inner_error_);
#line 574 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 5104 "Page.c"
	}
#line 572 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (ui_resource);
#line 5108 "Page.c"
}


static void page_real_init_collect_ui_filenames (Page* self, GeeList* ui_filenames) {
#line 587 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GEE_IS_LIST (ui_filenames));
#line 5115 "Page.c"
}


void page_init_collect_ui_filenames (Page* self, GeeList* ui_filenames) {
#line 587 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 587 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->init_collect_ui_filenames (self, ui_filenames);
#line 5124 "Page.c"
}


static InjectionGroup** page_real_init_collect_injection_groups (Page* self, int* result_length1) {
	InjectionGroup** result = NULL;
	InjectionGroup** _tmp0_;
	InjectionGroup** _tmp1_;
	gint _tmp1__length1;
#line 593 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = g_new0 (InjectionGroup*, 0 + 1);
#line 593 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_;
#line 593 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1__length1 = 0;
#line 593 "/home/jens/Source/shotwell/src/Page.vala"
	if (result_length1) {
#line 593 "/home/jens/Source/shotwell/src/Page.vala"
		*result_length1 = _tmp1__length1;
#line 5143 "Page.c"
	}
#line 593 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 593 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 5149 "Page.c"
}


InjectionGroup** page_init_collect_injection_groups (Page* self, int* result_length1) {
#line 592 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 592 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->init_collect_injection_groups (self, result_length1);
#line 5158 "Page.c"
}


static void page_real_init_actions (Page* self, gint selected_count, gint count) {
}


void page_init_actions (Page* self, gint selected_count, gint count) {
#line 598 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 598 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->init_actions (self, selected_count, count);
#line 5171 "Page.c"
}


static void page_real_update_actions (Page* self, gint selected_count, gint count) {
}


void page_update_actions (Page* self, gint selected_count, gint count) {
#line 604 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 604 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->update_actions (self, selected_count, count);
#line 5184 "Page.c"
}


static void _page_on_drag_begin_gtk_widget_drag_begin (GtkWidget* _sender, GdkDragContext* context, gpointer self) {
#line 619 "/home/jens/Source/shotwell/src/Page.vala"
	page_on_drag_begin ((Page*) self, context);
#line 5191 "Page.c"
}


static void _page_on_drag_data_get_gtk_widget_drag_data_get (GtkWidget* _sender, GdkDragContext* context, GtkSelectionData* selection_data, guint info, guint time_, gpointer self) {
#line 620 "/home/jens/Source/shotwell/src/Page.vala"
	page_on_drag_data_get ((Page*) self, context, selection_data, info, time_);
#line 5198 "Page.c"
}


static void _page_on_drag_data_delete_gtk_widget_drag_data_delete (GtkWidget* _sender, GdkDragContext* context, gpointer self) {
#line 621 "/home/jens/Source/shotwell/src/Page.vala"
	page_on_drag_data_delete ((Page*) self, context);
#line 5205 "Page.c"
}


static void _page_on_drag_end_gtk_widget_drag_end (GtkWidget* _sender, GdkDragContext* context, gpointer self) {
#line 622 "/home/jens/Source/shotwell/src/Page.vala"
	page_on_drag_end ((Page*) self, context);
#line 5212 "Page.c"
}


static gboolean _page_on_drag_failed_gtk_widget_drag_failed (GtkWidget* _sender, GdkDragContext* context, GtkDragResult _result_, gpointer self) {
	gboolean result;
	result = page_on_drag_failed ((Page*) self, context, _result_);
#line 623 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 5221 "Page.c"
}


void page_enable_drag_source (Page* self, GdkDragAction actions, GtkTargetEntry* source_target_entries, int source_target_entries_length1) {
	gboolean _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
	GtkTargetEntry* _tmp3_;
	gint _tmp3__length1;
	GdkDragAction _tmp4_;
	GtkWidget* _tmp5_;
	GtkWidget* _tmp6_;
	GtkWidget* _tmp7_;
	GtkWidget* _tmp8_;
	GtkWidget* _tmp9_;
#line 609 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 610 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->dnd_enabled;
#line 610 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_) {
#line 611 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 5245 "Page.c"
	}
#line 613 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->event_source;
#line 613 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp1_ != NULL, "event_source != null");
#line 615 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->priv->event_source;
#line 615 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = source_target_entries;
#line 615 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3__length1 = source_target_entries_length1;
#line 615 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = actions;
#line 615 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_drag_source_set (_tmp2_, GDK_BUTTON1_MASK, _tmp3_, _tmp3__length1, _tmp4_);
#line 619 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = self->priv->event_source;
#line 619 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp5_, "drag-begin", (GCallback) _page_on_drag_begin_gtk_widget_drag_begin, self, 0);
#line 620 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = self->priv->event_source;
#line 620 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp6_, "drag-data-get", (GCallback) _page_on_drag_data_get_gtk_widget_drag_data_get, self, 0);
#line 621 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = self->priv->event_source;
#line 621 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp7_, "drag-data-delete", (GCallback) _page_on_drag_data_delete_gtk_widget_drag_data_delete, self, 0);
#line 622 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = self->priv->event_source;
#line 622 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp8_, "drag-end", (GCallback) _page_on_drag_end_gtk_widget_drag_end, self, 0);
#line 623 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = self->priv->event_source;
#line 623 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp9_, "drag-failed", (GCallback) _page_on_drag_failed_gtk_widget_drag_failed, self, 0);
#line 625 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->dnd_enabled = TRUE;
#line 5283 "Page.c"
}


void page_disable_drag_source (Page* self) {
	gboolean _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
	guint _tmp3_;
	GtkWidget* _tmp4_;
	guint _tmp5_;
	GtkWidget* _tmp6_;
	guint _tmp7_;
	GtkWidget* _tmp8_;
	guint _tmp9_;
	GtkWidget* _tmp10_;
	guint _tmp11_;
	GtkWidget* _tmp12_;
#line 628 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 629 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->dnd_enabled;
#line 629 "/home/jens/Source/shotwell/src/Page.vala"
	if (!_tmp0_) {
#line 630 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 5309 "Page.c"
	}
#line 632 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->event_source;
#line 632 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp1_ != NULL, "event_source != null");
#line 634 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->priv->event_source;
#line 634 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("drag-begin", gtk_widget_get_type (), &_tmp3_, NULL, FALSE);
#line 634 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _page_on_drag_begin_gtk_widget_drag_begin, self);
#line 635 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = self->priv->event_source;
#line 635 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("drag-data-get", gtk_widget_get_type (), &_tmp5_, NULL, FALSE);
#line 635 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (_tmp4_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp5_, 0, NULL, (GCallback) _page_on_drag_data_get_gtk_widget_drag_data_get, self);
#line 636 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = self->priv->event_source;
#line 636 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("drag-data-delete", gtk_widget_get_type (), &_tmp7_, NULL, FALSE);
#line 636 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (_tmp6_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp7_, 0, NULL, (GCallback) _page_on_drag_data_delete_gtk_widget_drag_data_delete, self);
#line 637 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = self->priv->event_source;
#line 637 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("drag-end", gtk_widget_get_type (), &_tmp9_, NULL, FALSE);
#line 637 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (_tmp8_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp9_, 0, NULL, (GCallback) _page_on_drag_end_gtk_widget_drag_end, self);
#line 638 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = self->priv->event_source;
#line 638 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("drag-failed", gtk_widget_get_type (), &_tmp11_, NULL, FALSE);
#line 638 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (_tmp10_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp11_, 0, NULL, (GCallback) _page_on_drag_failed_gtk_widget_drag_failed, self);
#line 639 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = self->priv->event_source;
#line 639 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_drag_source_unset (_tmp12_);
#line 641 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->dnd_enabled = FALSE;
#line 5351 "Page.c"
}


gboolean page_is_dnd_enabled (Page* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 644 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 645 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->dnd_enabled;
#line 645 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp0_;
#line 645 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 5366 "Page.c"
}


static void page_on_drag_begin (Page* self, GdkDragContext* context) {
	GdkDragContext* _tmp0_;
#line 648 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 648 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (context));
#line 649 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = context;
#line 649 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "drag-begin", _tmp0_);
#line 5380 "Page.c"
}


static void page_on_drag_data_get (Page* self, GdkDragContext* context, GtkSelectionData* selection_data, guint info, guint time) {
	GdkDragContext* _tmp0_;
	GtkSelectionData* _tmp1_;
	guint _tmp2_;
	guint _tmp3_;
#line 652 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 652 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (context));
#line 652 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (selection_data != NULL);
#line 654 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = context;
#line 654 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = selection_data;
#line 654 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = info;
#line 654 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = time;
#line 654 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "drag-data-get", _tmp0_, _tmp1_, _tmp2_, _tmp3_);
#line 5405 "Page.c"
}


static void page_on_drag_data_delete (Page* self, GdkDragContext* context) {
	GdkDragContext* _tmp0_;
#line 657 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 657 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (context));
#line 658 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = context;
#line 658 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "drag-data-delete", _tmp0_);
#line 5419 "Page.c"
}


static void page_on_drag_end (Page* self, GdkDragContext* context) {
	GdkDragContext* _tmp0_;
#line 661 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 661 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (context));
#line 662 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = context;
#line 662 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_emit_by_name (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "drag-end", _tmp0_);
#line 5433 "Page.c"
}


static gboolean page_real_source_drag_failed (Page* self, GdkDragContext* context, GtkDragResult drag_result) {
	gboolean result = FALSE;
#line 669 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (GDK_IS_DRAG_CONTEXT (context), FALSE);
#line 670 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 670 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 5445 "Page.c"
}


gboolean page_source_drag_failed (Page* self, GdkDragContext* context, GtkDragResult drag_result) {
#line 669 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 669 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->source_drag_failed (self, context, drag_result);
#line 5454 "Page.c"
}


static gboolean page_on_drag_failed (Page* self, GdkDragContext* context, GtkDragResult drag_result) {
	gboolean result = FALSE;
	GdkDragContext* _tmp0_;
	GtkDragResult _tmp1_;
	gboolean _tmp2_;
#line 673 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 673 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (GDK_IS_DRAG_CONTEXT (context), FALSE);
#line 674 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = context;
#line 674 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = drag_result;
#line 674 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = page_source_drag_failed (self, _tmp0_, _tmp1_);
#line 674 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp2_;
#line 674 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 5477 "Page.c"
}


gboolean page_get_event_source_pointer (Page* self, gint* x, gint* y, GdkModifierType* mask) {
	gint _vala_x = 0;
	gint _vala_y = 0;
	GdkModifierType _vala_mask = 0;
	gboolean result = FALSE;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	GdkWindow* _tmp2_;
	GdkDisplay* _tmp3_;
	GdkDeviceManager* _tmp4_;
	GdkDevice* _tmp5_;
	gint _tmp6_ = 0;
	gint _tmp7_ = 0;
	GdkModifierType _tmp8_ = 0;
	gboolean _tmp9_ = FALSE;
	GdkPoint _tmp10_;
	gint _tmp11_;
	gint _tmp14_;
	GdkPoint _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	gint _tmp19_;
	GdkPoint _tmp20_;
	gint _tmp21_;
	gint _tmp22_;
#line 681 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 682 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->event_source;
#line 682 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ == NULL) {
#line 683 "/home/jens/Source/shotwell/src/Page.vala"
		_vala_x = 0;
#line 684 "/home/jens/Source/shotwell/src/Page.vala"
		_vala_y = 0;
#line 685 "/home/jens/Source/shotwell/src/Page.vala"
		_vala_mask = 0;
#line 687 "/home/jens/Source/shotwell/src/Page.vala"
		result = FALSE;
#line 687 "/home/jens/Source/shotwell/src/Page.vala"
		if (x) {
#line 687 "/home/jens/Source/shotwell/src/Page.vala"
			*x = _vala_x;
#line 5524 "Page.c"
		}
#line 687 "/home/jens/Source/shotwell/src/Page.vala"
		if (y) {
#line 687 "/home/jens/Source/shotwell/src/Page.vala"
			*y = _vala_y;
#line 5530 "Page.c"
		}
#line 687 "/home/jens/Source/shotwell/src/Page.vala"
		if (mask) {
#line 687 "/home/jens/Source/shotwell/src/Page.vala"
			*mask = _vala_mask;
#line 5536 "Page.c"
		}
#line 687 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 5540 "Page.c"
	}
#line 690 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->event_source;
#line 690 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = gtk_widget_get_window (_tmp1_);
#line 690 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = gdk_display_get_default ();
#line 690 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = gdk_display_get_device_manager (_tmp3_);
#line 690 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = gdk_device_manager_get_client_pointer (_tmp4_);
#line 690 "/home/jens/Source/shotwell/src/Page.vala"
	gdk_window_get_device_position (_tmp2_, _tmp5_, &_tmp6_, &_tmp7_, &_tmp8_);
#line 690 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_x = _tmp6_;
#line 690 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_y = _tmp7_;
#line 690 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_mask = _tmp8_;
#line 693 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = self->priv->last_down;
#line 693 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = _tmp10_.x;
#line 693 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp11_ < 0) {
#line 693 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = TRUE;
#line 5568 "Page.c"
	} else {
		GdkPoint _tmp12_;
		gint _tmp13_;
#line 693 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp12_ = self->priv->last_down;
#line 693 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp13_ = _tmp12_.y;
#line 693 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = _tmp13_ < 0;
#line 5578 "Page.c"
	}
#line 693 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp9_) {
#line 694 "/home/jens/Source/shotwell/src/Page.vala"
		result = TRUE;
#line 694 "/home/jens/Source/shotwell/src/Page.vala"
		if (x) {
#line 694 "/home/jens/Source/shotwell/src/Page.vala"
			*x = _vala_x;
#line 5588 "Page.c"
		}
#line 694 "/home/jens/Source/shotwell/src/Page.vala"
		if (y) {
#line 694 "/home/jens/Source/shotwell/src/Page.vala"
			*y = _vala_y;
#line 5594 "Page.c"
		}
#line 694 "/home/jens/Source/shotwell/src/Page.vala"
		if (mask) {
#line 694 "/home/jens/Source/shotwell/src/Page.vala"
			*mask = _vala_mask;
#line 5600 "Page.c"
		}
#line 694 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 5604 "Page.c"
	}
#line 700 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp14_ = _vala_x;
#line 700 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp15_ = self->priv->last_down;
#line 700 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp16_ = _tmp15_.x;
#line 700 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp17_ = abs (_tmp14_ - _tmp16_);
#line 700 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp17_ >= 0x7FFF) {
#line 5616 "Page.c"
		gint _tmp18_;
#line 701 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp18_ = _vala_x;
#line 701 "/home/jens/Source/shotwell/src/Page.vala"
		_vala_x = _tmp18_ + 0xFFFF;
#line 5622 "Page.c"
	}
#line 703 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp19_ = _vala_y;
#line 703 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp20_ = self->priv->last_down;
#line 703 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp21_ = _tmp20_.y;
#line 703 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp22_ = abs (_tmp19_ - _tmp21_);
#line 703 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp22_ >= 0x7FFF) {
#line 5634 "Page.c"
		gint _tmp23_;
#line 704 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp23_ = _vala_y;
#line 704 "/home/jens/Source/shotwell/src/Page.vala"
		_vala_y = _tmp23_ + 0xFFFF;
#line 5640 "Page.c"
	}
#line 706 "/home/jens/Source/shotwell/src/Page.vala"
	result = TRUE;
#line 706 "/home/jens/Source/shotwell/src/Page.vala"
	if (x) {
#line 706 "/home/jens/Source/shotwell/src/Page.vala"
		*x = _vala_x;
#line 5648 "Page.c"
	}
#line 706 "/home/jens/Source/shotwell/src/Page.vala"
	if (y) {
#line 706 "/home/jens/Source/shotwell/src/Page.vala"
		*y = _vala_y;
#line 5654 "Page.c"
	}
#line 706 "/home/jens/Source/shotwell/src/Page.vala"
	if (mask) {
#line 706 "/home/jens/Source/shotwell/src/Page.vala"
		*mask = _vala_mask;
#line 5660 "Page.c"
	}
#line 706 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 5664 "Page.c"
}


static gboolean page_real_on_left_click (Page* self, GdkEventButton* event) {
	gboolean result = FALSE;
#line 709 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 710 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 710 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 5676 "Page.c"
}


gboolean page_on_left_click (Page* self, GdkEventButton* event) {
#line 709 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 709 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_left_click (self, event);
#line 5685 "Page.c"
}


static gboolean page_real_on_middle_click (Page* self, GdkEventButton* event) {
	gboolean result = FALSE;
#line 713 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 714 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 714 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 5697 "Page.c"
}


gboolean page_on_middle_click (Page* self, GdkEventButton* event) {
#line 713 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 713 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_middle_click (self, event);
#line 5706 "Page.c"
}


static gboolean page_real_on_right_click (Page* self, GdkEventButton* event) {
	gboolean result = FALSE;
#line 717 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 718 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 718 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 5718 "Page.c"
}


gboolean page_on_right_click (Page* self, GdkEventButton* event) {
#line 717 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 717 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_right_click (self, event);
#line 5727 "Page.c"
}


static gboolean page_real_on_left_released (Page* self, GdkEventButton* event) {
	gboolean result = FALSE;
#line 721 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 722 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 722 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 5739 "Page.c"
}


gboolean page_on_left_released (Page* self, GdkEventButton* event) {
#line 721 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 721 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_left_released (self, event);
#line 5748 "Page.c"
}


static gboolean page_real_on_middle_released (Page* self, GdkEventButton* event) {
	gboolean result = FALSE;
#line 725 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 726 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 726 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 5760 "Page.c"
}


gboolean page_on_middle_released (Page* self, GdkEventButton* event) {
#line 725 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 725 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_middle_released (self, event);
#line 5769 "Page.c"
}


static gboolean page_real_on_right_released (Page* self, GdkEventButton* event) {
	gboolean result = FALSE;
#line 729 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 730 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 730 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 5781 "Page.c"
}


gboolean page_on_right_released (Page* self, GdkEventButton* event) {
#line 729 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 729 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_right_released (self, event);
#line 5790 "Page.c"
}


static gboolean page_on_button_pressed_internal (Page* self, GdkEventButton* event) {
	gboolean result = FALSE;
	GdkEventButton* _tmp0_;
	guint _tmp1_;
#line 733 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 733 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 734 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = event;
#line 734 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_->button;
#line 734 "/home/jens/Source/shotwell/src/Page.vala"
	switch (_tmp1_) {
#line 734 "/home/jens/Source/shotwell/src/Page.vala"
		case 1:
#line 5810 "Page.c"
		{
			GtkWidget* _tmp2_;
			GdkEventButton* _tmp4_;
			gdouble _tmp5_;
			GdkEventButton* _tmp6_;
			gdouble _tmp7_;
			GdkEventButton* _tmp8_;
			gboolean _tmp9_;
#line 736 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp2_ = self->priv->event_source;
#line 736 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp2_ != NULL) {
#line 5823 "Page.c"
				GtkWidget* _tmp3_;
#line 737 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp3_ = self->priv->event_source;
#line 737 "/home/jens/Source/shotwell/src/Page.vala"
				gtk_widget_grab_focus (_tmp3_);
#line 5829 "Page.c"
			}
#line 740 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp4_ = event;
#line 740 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp5_ = _tmp4_->x;
#line 740 "/home/jens/Source/shotwell/src/Page.vala"
			self->priv->last_down.x = (gint) _tmp5_;
#line 741 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp6_ = event;
#line 741 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp7_ = _tmp6_->y;
#line 741 "/home/jens/Source/shotwell/src/Page.vala"
			self->priv->last_down.y = (gint) _tmp7_;
#line 743 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp8_ = event;
#line 743 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp9_ = page_on_left_click (self, _tmp8_);
#line 743 "/home/jens/Source/shotwell/src/Page.vala"
			result = _tmp9_;
#line 743 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 5851 "Page.c"
		}
#line 734 "/home/jens/Source/shotwell/src/Page.vala"
		case 2:
#line 5855 "Page.c"
		{
			GdkEventButton* _tmp10_;
			gboolean _tmp11_;
#line 746 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp10_ = event;
#line 746 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp11_ = page_on_middle_click (self, _tmp10_);
#line 746 "/home/jens/Source/shotwell/src/Page.vala"
			result = _tmp11_;
#line 746 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 5867 "Page.c"
		}
#line 734 "/home/jens/Source/shotwell/src/Page.vala"
		case 3:
#line 5871 "Page.c"
		{
			GdkEventButton* _tmp12_;
			gboolean _tmp13_;
#line 749 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp12_ = event;
#line 749 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp13_ = page_on_right_click (self, _tmp12_);
#line 749 "/home/jens/Source/shotwell/src/Page.vala"
			result = _tmp13_;
#line 749 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 5883 "Page.c"
		}
		default:
		{
#line 752 "/home/jens/Source/shotwell/src/Page.vala"
			result = FALSE;
#line 752 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 5891 "Page.c"
		}
	}
}


static gboolean page_on_button_released_internal (Page* self, GdkEventButton* event) {
	gboolean result = FALSE;
	GdkEventButton* _tmp0_;
	guint _tmp1_;
#line 756 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 756 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 757 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = event;
#line 757 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_->button;
#line 757 "/home/jens/Source/shotwell/src/Page.vala"
	switch (_tmp1_) {
#line 757 "/home/jens/Source/shotwell/src/Page.vala"
		case 1:
#line 5913 "Page.c"
		{
			GdkPoint _tmp2_ = {0};
			GdkEventButton* _tmp3_;
			gboolean _tmp4_;
#line 760 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp2_.x = -1;
#line 760 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp2_.y = -1;
#line 760 "/home/jens/Source/shotwell/src/Page.vala"
			self->priv->last_down = _tmp2_;
#line 762 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp3_ = event;
#line 762 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp4_ = page_on_left_released (self, _tmp3_);
#line 762 "/home/jens/Source/shotwell/src/Page.vala"
			result = _tmp4_;
#line 762 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 5932 "Page.c"
		}
#line 757 "/home/jens/Source/shotwell/src/Page.vala"
		case 2:
#line 5936 "Page.c"
		{
			GdkEventButton* _tmp5_;
			gboolean _tmp6_;
#line 765 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp5_ = event;
#line 765 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp6_ = page_on_middle_released (self, _tmp5_);
#line 765 "/home/jens/Source/shotwell/src/Page.vala"
			result = _tmp6_;
#line 765 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 5948 "Page.c"
		}
#line 757 "/home/jens/Source/shotwell/src/Page.vala"
		case 3:
#line 5952 "Page.c"
		{
			GdkEventButton* _tmp7_;
			gboolean _tmp8_;
#line 768 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp7_ = event;
#line 768 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp8_ = page_on_right_released (self, _tmp7_);
#line 768 "/home/jens/Source/shotwell/src/Page.vala"
			result = _tmp8_;
#line 768 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 5964 "Page.c"
		}
		default:
		{
#line 771 "/home/jens/Source/shotwell/src/Page.vala"
			result = FALSE;
#line 771 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 5972 "Page.c"
		}
	}
}


static gboolean page_real_on_ctrl_pressed (Page* self, GdkEventKey* event) {
	gboolean result = FALSE;
#line 776 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 776 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 5984 "Page.c"
}


gboolean page_on_ctrl_pressed (Page* self, GdkEventKey* event) {
#line 775 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 775 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_ctrl_pressed (self, event);
#line 5993 "Page.c"
}


static gboolean page_real_on_ctrl_released (Page* self, GdkEventKey* event) {
	gboolean result = FALSE;
#line 780 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 780 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6003 "Page.c"
}


gboolean page_on_ctrl_released (Page* self, GdkEventKey* event) {
#line 779 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 779 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_ctrl_released (self, event);
#line 6012 "Page.c"
}


static gboolean page_real_on_alt_pressed (Page* self, GdkEventKey* event) {
	gboolean result = FALSE;
#line 784 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 784 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6022 "Page.c"
}


gboolean page_on_alt_pressed (Page* self, GdkEventKey* event) {
#line 783 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 783 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_alt_pressed (self, event);
#line 6031 "Page.c"
}


static gboolean page_real_on_alt_released (Page* self, GdkEventKey* event) {
	gboolean result = FALSE;
#line 788 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 788 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6041 "Page.c"
}


gboolean page_on_alt_released (Page* self, GdkEventKey* event) {
#line 787 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 787 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_alt_released (self, event);
#line 6050 "Page.c"
}


static gboolean page_real_on_shift_pressed (Page* self, GdkEventKey* event) {
	gboolean result = FALSE;
#line 792 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 792 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6060 "Page.c"
}


gboolean page_on_shift_pressed (Page* self, GdkEventKey* event) {
#line 791 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 791 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_shift_pressed (self, event);
#line 6069 "Page.c"
}


static gboolean page_real_on_shift_released (Page* self, GdkEventKey* event) {
	gboolean result = FALSE;
#line 796 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 796 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6079 "Page.c"
}


gboolean page_on_shift_released (Page* self, GdkEventKey* event) {
#line 795 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 795 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_shift_released (self, event);
#line 6088 "Page.c"
}


static gboolean page_real_on_super_pressed (Page* self, GdkEventKey* event) {
	gboolean result = FALSE;
#line 800 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 800 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6098 "Page.c"
}


gboolean page_on_super_pressed (Page* self, GdkEventKey* event) {
#line 799 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 799 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_super_pressed (self, event);
#line 6107 "Page.c"
}


static gboolean page_real_on_super_released (Page* self, GdkEventKey* event) {
	gboolean result = FALSE;
#line 804 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 804 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6117 "Page.c"
}


gboolean page_on_super_released (Page* self, GdkEventKey* event) {
#line 803 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 803 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_super_released (self, event);
#line 6126 "Page.c"
}


static gboolean page_real_on_app_key_pressed (Page* self, GdkEventKey* event) {
	gboolean result = FALSE;
#line 807 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 808 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 808 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6138 "Page.c"
}


gboolean page_on_app_key_pressed (Page* self, GdkEventKey* event) {
#line 807 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 807 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_app_key_pressed (self, event);
#line 6147 "Page.c"
}


static gboolean page_real_on_app_key_released (Page* self, GdkEventKey* event) {
	gboolean result = FALSE;
#line 811 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 812 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 812 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6159 "Page.c"
}


gboolean page_on_app_key_released (Page* self, GdkEventKey* event) {
#line 811 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 811 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_app_key_released (self, event);
#line 6168 "Page.c"
}


gboolean page_notify_app_key_pressed (Page* self, GdkEventKey* event) {
	gboolean result = FALSE;
	gboolean ctrl_currently_pressed = FALSE;
	gboolean alt_currently_pressed = FALSE;
	gboolean shift_currently_pressed = FALSE;
	gboolean super_currently_pressed = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GdkEventKey* _tmp4_;
	guint _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	GQuark _tmp9_ = 0U;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label0 = 0;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label1 = 0;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label2 = 0;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label3 = 0;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label4 = 0;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label5 = 0;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label6 = 0;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label7 = 0;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label8 = 0;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label9 = 0;
#line 6207 "Page.c"
	GdkEventKey* _tmp30_;
	gboolean _tmp31_;
#line 815 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 815 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 818 "/home/jens/Source/shotwell/src/Page.vala"
	page_get_modifiers (self, &_tmp0_, &_tmp1_, &_tmp2_, &_tmp3_);
#line 818 "/home/jens/Source/shotwell/src/Page.vala"
	ctrl_currently_pressed = _tmp0_;
#line 818 "/home/jens/Source/shotwell/src/Page.vala"
	alt_currently_pressed = _tmp1_;
#line 818 "/home/jens/Source/shotwell/src/Page.vala"
	shift_currently_pressed = _tmp2_;
#line 818 "/home/jens/Source/shotwell/src/Page.vala"
	super_currently_pressed = _tmp3_;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = event;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _tmp4_->keyval;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = gdk_keyval_name (_tmp5_);
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = _tmp6_;
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = (NULL == _tmp7_) ? 0 : g_quark_from_string (_tmp7_);
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
	if ((_tmp9_ == ((0 != _tmp8_label0) ? _tmp8_label0 : (_tmp8_label0 = g_quark_from_static_string ("Control_L")))) || (_tmp9_ == ((0 != _tmp8_label1) ? _tmp8_label1 : (_tmp8_label1 = g_quark_from_static_string ("Control_R"))))) {
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 6238 "Page.c"
			default:
			{
				gboolean _tmp10_ = FALSE;
				gboolean _tmp11_;
				GdkEventKey* _tmp13_;
				gboolean _tmp14_;
#line 824 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp11_ = ctrl_currently_pressed;
#line 824 "/home/jens/Source/shotwell/src/Page.vala"
				if (!_tmp11_) {
#line 824 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp10_ = TRUE;
#line 6251 "Page.c"
				} else {
					gboolean _tmp12_;
#line 824 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp12_ = self->priv->ctrl_pressed;
#line 824 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp10_ = _tmp12_;
#line 6258 "Page.c"
				}
#line 824 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp10_) {
#line 825 "/home/jens/Source/shotwell/src/Page.vala"
					result = FALSE;
#line 825 "/home/jens/Source/shotwell/src/Page.vala"
					return result;
#line 6266 "Page.c"
				}
#line 827 "/home/jens/Source/shotwell/src/Page.vala"
				self->priv->ctrl_pressed = TRUE;
#line 829 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp13_ = event;
#line 829 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp14_ = page_on_ctrl_pressed (self, _tmp13_);
#line 829 "/home/jens/Source/shotwell/src/Page.vala"
				result = _tmp14_;
#line 829 "/home/jens/Source/shotwell/src/Page.vala"
				return result;
#line 6278 "Page.c"
			}
		}
	} else if ((((_tmp9_ == ((0 != _tmp8_label2) ? _tmp8_label2 : (_tmp8_label2 = g_quark_from_static_string ("Meta_L")))) || (_tmp9_ == ((0 != _tmp8_label3) ? _tmp8_label3 : (_tmp8_label3 = g_quark_from_static_string ("Meta_R"))))) || (_tmp9_ == ((0 != _tmp8_label4) ? _tmp8_label4 : (_tmp8_label4 = g_quark_from_static_string ("Alt_L"))))) || (_tmp9_ == ((0 != _tmp8_label5) ? _tmp8_label5 : (_tmp8_label5 = g_quark_from_static_string ("Alt_R"))))) {
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 6284 "Page.c"
			default:
			{
				gboolean _tmp15_ = FALSE;
				gboolean _tmp16_;
				GdkEventKey* _tmp18_;
				gboolean _tmp19_;
#line 835 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp16_ = alt_currently_pressed;
#line 835 "/home/jens/Source/shotwell/src/Page.vala"
				if (!_tmp16_) {
#line 835 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp15_ = TRUE;
#line 6297 "Page.c"
				} else {
					gboolean _tmp17_;
#line 835 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp17_ = self->priv->alt_pressed;
#line 835 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp15_ = _tmp17_;
#line 6304 "Page.c"
				}
#line 835 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp15_) {
#line 836 "/home/jens/Source/shotwell/src/Page.vala"
					result = FALSE;
#line 836 "/home/jens/Source/shotwell/src/Page.vala"
					return result;
#line 6312 "Page.c"
				}
#line 838 "/home/jens/Source/shotwell/src/Page.vala"
				self->priv->alt_pressed = TRUE;
#line 840 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp18_ = event;
#line 840 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp19_ = page_on_alt_pressed (self, _tmp18_);
#line 840 "/home/jens/Source/shotwell/src/Page.vala"
				result = _tmp19_;
#line 840 "/home/jens/Source/shotwell/src/Page.vala"
				return result;
#line 6324 "Page.c"
			}
		}
	} else if ((_tmp9_ == ((0 != _tmp8_label6) ? _tmp8_label6 : (_tmp8_label6 = g_quark_from_static_string ("Shift_L")))) || (_tmp9_ == ((0 != _tmp8_label7) ? _tmp8_label7 : (_tmp8_label7 = g_quark_from_static_string ("Shift_R"))))) {
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 6330 "Page.c"
			default:
			{
				gboolean _tmp20_ = FALSE;
				gboolean _tmp21_;
				GdkEventKey* _tmp23_;
				gboolean _tmp24_;
#line 844 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp21_ = shift_currently_pressed;
#line 844 "/home/jens/Source/shotwell/src/Page.vala"
				if (!_tmp21_) {
#line 844 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp20_ = TRUE;
#line 6343 "Page.c"
				} else {
					gboolean _tmp22_;
#line 844 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp22_ = self->priv->shift_pressed;
#line 844 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp20_ = _tmp22_;
#line 6350 "Page.c"
				}
#line 844 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp20_) {
#line 845 "/home/jens/Source/shotwell/src/Page.vala"
					result = FALSE;
#line 845 "/home/jens/Source/shotwell/src/Page.vala"
					return result;
#line 6358 "Page.c"
				}
#line 847 "/home/jens/Source/shotwell/src/Page.vala"
				self->priv->shift_pressed = TRUE;
#line 849 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp23_ = event;
#line 849 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp24_ = page_on_shift_pressed (self, _tmp23_);
#line 849 "/home/jens/Source/shotwell/src/Page.vala"
				result = _tmp24_;
#line 849 "/home/jens/Source/shotwell/src/Page.vala"
				return result;
#line 6370 "Page.c"
			}
		}
	} else if ((_tmp9_ == ((0 != _tmp8_label8) ? _tmp8_label8 : (_tmp8_label8 = g_quark_from_static_string ("Super_L")))) || (_tmp9_ == ((0 != _tmp8_label9) ? _tmp8_label9 : (_tmp8_label9 = g_quark_from_static_string ("Super_R"))))) {
#line 821 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 6376 "Page.c"
			default:
			{
				gboolean _tmp25_ = FALSE;
				gboolean _tmp26_;
				GdkEventKey* _tmp28_;
				gboolean _tmp29_;
#line 853 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp26_ = super_currently_pressed;
#line 853 "/home/jens/Source/shotwell/src/Page.vala"
				if (!_tmp26_) {
#line 853 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp25_ = TRUE;
#line 6389 "Page.c"
				} else {
					gboolean _tmp27_;
#line 853 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp27_ = self->priv->super_pressed;
#line 853 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp25_ = _tmp27_;
#line 6396 "Page.c"
				}
#line 853 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp25_) {
#line 854 "/home/jens/Source/shotwell/src/Page.vala"
					result = FALSE;
#line 854 "/home/jens/Source/shotwell/src/Page.vala"
					return result;
#line 6404 "Page.c"
				}
#line 856 "/home/jens/Source/shotwell/src/Page.vala"
				self->priv->super_pressed = TRUE;
#line 858 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp28_ = event;
#line 858 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp29_ = page_on_super_pressed (self, _tmp28_);
#line 858 "/home/jens/Source/shotwell/src/Page.vala"
				result = _tmp29_;
#line 858 "/home/jens/Source/shotwell/src/Page.vala"
				return result;
#line 6416 "Page.c"
			}
		}
	}
#line 861 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp30_ = event;
#line 861 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp31_ = page_on_app_key_pressed (self, _tmp30_);
#line 861 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp31_;
#line 861 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6428 "Page.c"
}


gboolean page_notify_app_key_released (Page* self, GdkEventKey* event) {
	gboolean result = FALSE;
	gboolean ctrl_currently_pressed = FALSE;
	gboolean alt_currently_pressed = FALSE;
	gboolean shift_currently_pressed = FALSE;
	gboolean super_currently_pressed = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	GdkEventKey* _tmp4_;
	guint _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	GQuark _tmp9_ = 0U;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label0 = 0;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label1 = 0;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label2 = 0;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label3 = 0;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label4 = 0;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label5 = 0;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label6 = 0;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label7 = 0;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label8 = 0;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp8_label9 = 0;
#line 6467 "Page.c"
	GdkEventKey* _tmp30_;
	gboolean _tmp31_;
#line 864 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 864 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 867 "/home/jens/Source/shotwell/src/Page.vala"
	page_get_modifiers (self, &_tmp0_, &_tmp1_, &_tmp2_, &_tmp3_);
#line 867 "/home/jens/Source/shotwell/src/Page.vala"
	ctrl_currently_pressed = _tmp0_;
#line 867 "/home/jens/Source/shotwell/src/Page.vala"
	alt_currently_pressed = _tmp1_;
#line 867 "/home/jens/Source/shotwell/src/Page.vala"
	shift_currently_pressed = _tmp2_;
#line 867 "/home/jens/Source/shotwell/src/Page.vala"
	super_currently_pressed = _tmp3_;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = event;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _tmp4_->keyval;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = gdk_keyval_name (_tmp5_);
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = _tmp6_;
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = (NULL == _tmp7_) ? 0 : g_quark_from_string (_tmp7_);
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
	if ((_tmp9_ == ((0 != _tmp8_label0) ? _tmp8_label0 : (_tmp8_label0 = g_quark_from_static_string ("Control_L")))) || (_tmp9_ == ((0 != _tmp8_label1) ? _tmp8_label1 : (_tmp8_label1 = g_quark_from_static_string ("Control_R"))))) {
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 6498 "Page.c"
			default:
			{
				gboolean _tmp10_ = FALSE;
				gboolean _tmp11_;
				GdkEventKey* _tmp13_;
				gboolean _tmp14_;
#line 873 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp11_ = ctrl_currently_pressed;
#line 873 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp11_) {
#line 873 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp10_ = TRUE;
#line 6511 "Page.c"
				} else {
					gboolean _tmp12_;
#line 873 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp12_ = self->priv->ctrl_pressed;
#line 873 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp10_ = !_tmp12_;
#line 6518 "Page.c"
				}
#line 873 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp10_) {
#line 874 "/home/jens/Source/shotwell/src/Page.vala"
					result = FALSE;
#line 874 "/home/jens/Source/shotwell/src/Page.vala"
					return result;
#line 6526 "Page.c"
				}
#line 876 "/home/jens/Source/shotwell/src/Page.vala"
				self->priv->ctrl_pressed = FALSE;
#line 878 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp13_ = event;
#line 878 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp14_ = page_on_ctrl_released (self, _tmp13_);
#line 878 "/home/jens/Source/shotwell/src/Page.vala"
				result = _tmp14_;
#line 878 "/home/jens/Source/shotwell/src/Page.vala"
				return result;
#line 6538 "Page.c"
			}
		}
	} else if ((((_tmp9_ == ((0 != _tmp8_label2) ? _tmp8_label2 : (_tmp8_label2 = g_quark_from_static_string ("Meta_L")))) || (_tmp9_ == ((0 != _tmp8_label3) ? _tmp8_label3 : (_tmp8_label3 = g_quark_from_static_string ("Meta_R"))))) || (_tmp9_ == ((0 != _tmp8_label4) ? _tmp8_label4 : (_tmp8_label4 = g_quark_from_static_string ("Alt_L"))))) || (_tmp9_ == ((0 != _tmp8_label5) ? _tmp8_label5 : (_tmp8_label5 = g_quark_from_static_string ("Alt_R"))))) {
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 6544 "Page.c"
			default:
			{
				gboolean _tmp15_ = FALSE;
				gboolean _tmp16_;
				GdkEventKey* _tmp18_;
				gboolean _tmp19_;
#line 884 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp16_ = alt_currently_pressed;
#line 884 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp16_) {
#line 884 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp15_ = TRUE;
#line 6557 "Page.c"
				} else {
					gboolean _tmp17_;
#line 884 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp17_ = self->priv->alt_pressed;
#line 884 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp15_ = !_tmp17_;
#line 6564 "Page.c"
				}
#line 884 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp15_) {
#line 885 "/home/jens/Source/shotwell/src/Page.vala"
					result = FALSE;
#line 885 "/home/jens/Source/shotwell/src/Page.vala"
					return result;
#line 6572 "Page.c"
				}
#line 887 "/home/jens/Source/shotwell/src/Page.vala"
				self->priv->alt_pressed = FALSE;
#line 889 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp18_ = event;
#line 889 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp19_ = page_on_alt_released (self, _tmp18_);
#line 889 "/home/jens/Source/shotwell/src/Page.vala"
				result = _tmp19_;
#line 889 "/home/jens/Source/shotwell/src/Page.vala"
				return result;
#line 6584 "Page.c"
			}
		}
	} else if ((_tmp9_ == ((0 != _tmp8_label6) ? _tmp8_label6 : (_tmp8_label6 = g_quark_from_static_string ("Shift_L")))) || (_tmp9_ == ((0 != _tmp8_label7) ? _tmp8_label7 : (_tmp8_label7 = g_quark_from_static_string ("Shift_R"))))) {
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 6590 "Page.c"
			default:
			{
				gboolean _tmp20_ = FALSE;
				gboolean _tmp21_;
				GdkEventKey* _tmp23_;
				gboolean _tmp24_;
#line 893 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp21_ = shift_currently_pressed;
#line 893 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp21_) {
#line 893 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp20_ = TRUE;
#line 6603 "Page.c"
				} else {
					gboolean _tmp22_;
#line 893 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp22_ = self->priv->shift_pressed;
#line 893 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp20_ = !_tmp22_;
#line 6610 "Page.c"
				}
#line 893 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp20_) {
#line 894 "/home/jens/Source/shotwell/src/Page.vala"
					result = FALSE;
#line 894 "/home/jens/Source/shotwell/src/Page.vala"
					return result;
#line 6618 "Page.c"
				}
#line 896 "/home/jens/Source/shotwell/src/Page.vala"
				self->priv->shift_pressed = FALSE;
#line 898 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp23_ = event;
#line 898 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp24_ = page_on_shift_released (self, _tmp23_);
#line 898 "/home/jens/Source/shotwell/src/Page.vala"
				result = _tmp24_;
#line 898 "/home/jens/Source/shotwell/src/Page.vala"
				return result;
#line 6630 "Page.c"
			}
		}
	} else if ((_tmp9_ == ((0 != _tmp8_label8) ? _tmp8_label8 : (_tmp8_label8 = g_quark_from_static_string ("Super_L")))) || (_tmp9_ == ((0 != _tmp8_label9) ? _tmp8_label9 : (_tmp8_label9 = g_quark_from_static_string ("Super_R"))))) {
#line 870 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 6636 "Page.c"
			default:
			{
				gboolean _tmp25_ = FALSE;
				gboolean _tmp26_;
				GdkEventKey* _tmp28_;
				gboolean _tmp29_;
#line 902 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp26_ = super_currently_pressed;
#line 902 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp26_) {
#line 902 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp25_ = TRUE;
#line 6649 "Page.c"
				} else {
					gboolean _tmp27_;
#line 902 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp27_ = self->priv->super_pressed;
#line 902 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp25_ = !_tmp27_;
#line 6656 "Page.c"
				}
#line 902 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp25_) {
#line 903 "/home/jens/Source/shotwell/src/Page.vala"
					result = FALSE;
#line 903 "/home/jens/Source/shotwell/src/Page.vala"
					return result;
#line 6664 "Page.c"
				}
#line 905 "/home/jens/Source/shotwell/src/Page.vala"
				self->priv->super_pressed = FALSE;
#line 907 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp28_ = event;
#line 907 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp29_ = page_on_super_released (self, _tmp28_);
#line 907 "/home/jens/Source/shotwell/src/Page.vala"
				result = _tmp29_;
#line 907 "/home/jens/Source/shotwell/src/Page.vala"
				return result;
#line 6676 "Page.c"
			}
		}
	}
#line 910 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp30_ = event;
#line 910 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp31_ = page_on_app_key_released (self, _tmp30_);
#line 910 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp31_;
#line 910 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6688 "Page.c"
}


gboolean page_notify_app_focus_in (Page* self, GdkEventFocus* event) {
	gboolean result = FALSE;
#line 913 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 913 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 914 "/home/jens/Source/shotwell/src/Page.vala"
	page_update_modifiers (self);
#line 916 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 916 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6704 "Page.c"
}


gboolean page_notify_app_focus_out (Page* self, GdkEventFocus* event) {
	gboolean result = FALSE;
#line 919 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 919 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 920 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 920 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6718 "Page.c"
}


static void page_real_on_move (Page* self, GdkRectangle* rect) {
#line 923 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (rect != NULL);
#line 6725 "Page.c"
}


void page_on_move (Page* self, GdkRectangle* rect) {
#line 923 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 923 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->on_move (self, rect);
#line 6734 "Page.c"
}


static void page_real_on_move_start (Page* self, GdkRectangle* rect) {
#line 926 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (rect != NULL);
#line 6741 "Page.c"
}


void page_on_move_start (Page* self, GdkRectangle* rect) {
#line 926 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 926 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->on_move_start (self, rect);
#line 6750 "Page.c"
}


static void page_real_on_move_finished (Page* self, GdkRectangle* rect) {
#line 929 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (rect != NULL);
#line 6757 "Page.c"
}


void page_on_move_finished (Page* self, GdkRectangle* rect) {
#line 929 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 929 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->on_move_finished (self, rect);
#line 6766 "Page.c"
}


static void page_real_on_resize (Page* self, GdkRectangle* rect) {
#line 932 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (rect != NULL);
#line 6773 "Page.c"
}


void page_on_resize (Page* self, GdkRectangle* rect) {
#line 932 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 932 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->on_resize (self, rect);
#line 6782 "Page.c"
}


static void page_real_on_resize_start (Page* self, GdkRectangle* rect) {
#line 935 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (rect != NULL);
#line 6789 "Page.c"
}


void page_on_resize_start (Page* self, GdkRectangle* rect) {
#line 935 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 935 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->on_resize_start (self, rect);
#line 6798 "Page.c"
}


static void page_real_on_resize_finished (Page* self, GdkRectangle* rect) {
#line 938 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (rect != NULL);
#line 6805 "Page.c"
}


void page_on_resize_finished (Page* self, GdkRectangle* rect) {
#line 938 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 938 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->on_resize_finished (self, rect);
#line 6814 "Page.c"
}


static gboolean page_real_on_configure (Page* self, GdkEventConfigure* event, GdkRectangle* rect) {
	gboolean result = FALSE;
#line 941 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 941 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (rect != NULL, FALSE);
#line 942 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 942 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6828 "Page.c"
}


gboolean page_on_configure (Page* self, GdkEventConfigure* event, GdkRectangle* rect) {
#line 941 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 941 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_configure (self, event, rect);
#line 6837 "Page.c"
}


static gboolean _page_check_configure_halted_gsource_func (gpointer self) {
	gboolean result;
	result = page_check_configure_halted ((Page*) self);
#line 966 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 6846 "Page.c"
}


gboolean page_notify_configure_event (Page* self, GdkEventConfigure* event) {
	gboolean result = FALSE;
	GdkRectangle rect = {0};
	GdkEventConfigure* _tmp0_;
	gint _tmp1_;
	GdkEventConfigure* _tmp2_;
	gint _tmp3_;
	GdkEventConfigure* _tmp4_;
	gint _tmp5_;
	GdkEventConfigure* _tmp6_;
	gint _tmp7_;
	gulong _tmp8_;
	gboolean _tmp29_ = FALSE;
	GdkRectangle _tmp30_;
	gint _tmp31_;
	GdkRectangle _tmp32_;
	gint _tmp33_;
	gboolean _tmp39_ = FALSE;
	GdkRectangle _tmp40_;
	gint _tmp41_;
	GdkRectangle _tmp42_;
	gint _tmp43_;
	GdkRectangle _tmp49_;
	gulong _tmp50_;
	GdkEventConfigure* _tmp51_;
	GdkRectangle _tmp52_;
	gboolean _tmp53_;
#line 945 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 945 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 946 "/home/jens/Source/shotwell/src/Page.vala"
	memset (&rect, 0, sizeof (GdkRectangle));
#line 947 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = event;
#line 947 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_->x;
#line 947 "/home/jens/Source/shotwell/src/Page.vala"
	rect.x = _tmp1_;
#line 948 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = event;
#line 948 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_->y;
#line 948 "/home/jens/Source/shotwell/src/Page.vala"
	rect.y = _tmp3_;
#line 949 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = event;
#line 949 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _tmp4_->width;
#line 949 "/home/jens/Source/shotwell/src/Page.vala"
	rect.width = _tmp5_;
#line 950 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = event;
#line 950 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = _tmp6_->height;
#line 950 "/home/jens/Source/shotwell/src/Page.vala"
	rect.height = _tmp7_;
#line 953 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = self->priv->last_configure_ms;
#line 953 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp8_ == ((gulong) 0)) {
#line 6911 "Page.c"
		gboolean _tmp9_ = FALSE;
		GdkRectangle _tmp10_;
		gint _tmp11_;
		GdkRectangle _tmp12_;
		gint _tmp13_;
		gboolean _tmp19_ = FALSE;
		GdkRectangle _tmp20_;
		gint _tmp21_;
		GdkRectangle _tmp22_;
		gint _tmp23_;
#line 954 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = self->priv->last_position;
#line 954 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = _tmp10_.x;
#line 954 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp12_ = rect;
#line 954 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp13_ = _tmp12_.x;
#line 954 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp11_ != _tmp13_) {
#line 954 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp9_ = TRUE;
#line 6934 "Page.c"
		} else {
			GdkRectangle _tmp14_;
			gint _tmp15_;
			GdkRectangle _tmp16_;
			gint _tmp17_;
#line 954 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp14_ = self->priv->last_position;
#line 954 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp15_ = _tmp14_.y;
#line 954 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp16_ = rect;
#line 954 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp17_ = _tmp16_.y;
#line 954 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp9_ = _tmp15_ != _tmp17_;
#line 6950 "Page.c"
		}
#line 954 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp9_) {
#line 6954 "Page.c"
			GdkRectangle _tmp18_;
#line 955 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp18_ = rect;
#line 955 "/home/jens/Source/shotwell/src/Page.vala"
			page_on_move_start (self, &_tmp18_);
#line 956 "/home/jens/Source/shotwell/src/Page.vala"
			self->priv->report_move_finished = TRUE;
#line 6962 "Page.c"
		}
#line 959 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp20_ = self->priv->last_position;
#line 959 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp21_ = _tmp20_.width;
#line 959 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp22_ = rect;
#line 959 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp23_ = _tmp22_.width;
#line 959 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp21_ != _tmp23_) {
#line 959 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp19_ = TRUE;
#line 6976 "Page.c"
		} else {
			GdkRectangle _tmp24_;
			gint _tmp25_;
			GdkRectangle _tmp26_;
			gint _tmp27_;
#line 959 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp24_ = self->priv->last_position;
#line 959 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp25_ = _tmp24_.height;
#line 959 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp26_ = rect;
#line 959 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp27_ = _tmp26_.height;
#line 959 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp19_ = _tmp25_ != _tmp27_;
#line 6992 "Page.c"
		}
#line 959 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp19_) {
#line 6996 "Page.c"
			GdkRectangle _tmp28_;
#line 960 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp28_ = rect;
#line 960 "/home/jens/Source/shotwell/src/Page.vala"
			page_on_resize_start (self, &_tmp28_);
#line 961 "/home/jens/Source/shotwell/src/Page.vala"
			self->priv->report_resize_finished = TRUE;
#line 7004 "Page.c"
		}
#line 966 "/home/jens/Source/shotwell/src/Page.vala"
		g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) (PAGE_CONSIDER_CONFIGURE_HALTED_MSEC / 8), _page_check_configure_halted_gsource_func, g_object_ref (self), g_object_unref);
#line 7008 "Page.c"
	}
#line 969 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp30_ = self->priv->last_position;
#line 969 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp31_ = _tmp30_.x;
#line 969 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp32_ = rect;
#line 969 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp33_ = _tmp32_.x;
#line 969 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp31_ != _tmp33_) {
#line 969 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp29_ = TRUE;
#line 7022 "Page.c"
	} else {
		GdkRectangle _tmp34_;
		gint _tmp35_;
		GdkRectangle _tmp36_;
		gint _tmp37_;
#line 969 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp34_ = self->priv->last_position;
#line 969 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp35_ = _tmp34_.y;
#line 969 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp36_ = rect;
#line 969 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp37_ = _tmp36_.y;
#line 969 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp29_ = _tmp35_ != _tmp37_;
#line 7038 "Page.c"
	}
#line 969 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp29_) {
#line 7042 "Page.c"
		GdkRectangle _tmp38_;
#line 970 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp38_ = rect;
#line 970 "/home/jens/Source/shotwell/src/Page.vala"
		page_on_move (self, &_tmp38_);
#line 7048 "Page.c"
	}
#line 972 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp40_ = self->priv->last_position;
#line 972 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp41_ = _tmp40_.width;
#line 972 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp42_ = rect;
#line 972 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp43_ = _tmp42_.width;
#line 972 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp41_ != _tmp43_) {
#line 972 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp39_ = TRUE;
#line 7062 "Page.c"
	} else {
		GdkRectangle _tmp44_;
		gint _tmp45_;
		GdkRectangle _tmp46_;
		gint _tmp47_;
#line 972 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp44_ = self->priv->last_position;
#line 972 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp45_ = _tmp44_.height;
#line 972 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp46_ = rect;
#line 972 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp47_ = _tmp46_.height;
#line 972 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp39_ = _tmp45_ != _tmp47_;
#line 7078 "Page.c"
	}
#line 972 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp39_) {
#line 7082 "Page.c"
		GdkRectangle _tmp48_;
#line 973 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp48_ = rect;
#line 973 "/home/jens/Source/shotwell/src/Page.vala"
		page_on_resize (self, &_tmp48_);
#line 7088 "Page.c"
	}
#line 975 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp49_ = rect;
#line 975 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->last_position = _tmp49_;
#line 976 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp50_ = now_ms ();
#line 976 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->last_configure_ms = _tmp50_;
#line 978 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp51_ = event;
#line 978 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp52_ = rect;
#line 978 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp53_ = page_on_configure (self, _tmp51_, &_tmp52_);
#line 978 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp53_;
#line 978 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 7108 "Page.c"
}


static gboolean page_check_configure_halted (Page* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
	gulong _tmp1_;
	gulong _tmp2_;
	GtkAllocation allocation = {0};
	GtkAllocation _tmp3_ = {0};
	gboolean _tmp4_;
	gboolean _tmp7_;
#line 981 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 982 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->is_destroyed;
#line 982 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_) {
#line 983 "/home/jens/Source/shotwell/src/Page.vala"
		result = FALSE;
#line 983 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 7131 "Page.c"
	}
#line 985 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = now_ms ();
#line 985 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->priv->last_configure_ms;
#line 985 "/home/jens/Source/shotwell/src/Page.vala"
	if ((_tmp1_ - _tmp2_) < ((gulong) PAGE_CONSIDER_CONFIGURE_HALTED_MSEC)) {
#line 986 "/home/jens/Source/shotwell/src/Page.vala"
		result = TRUE;
#line 986 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 7143 "Page.c"
	}
#line 989 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_widget_get_allocation (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), &_tmp3_);
#line 989 "/home/jens/Source/shotwell/src/Page.vala"
	allocation = _tmp3_;
#line 991 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = self->priv->report_move_finished;
#line 991 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_) {
#line 7153 "Page.c"
		GtkAllocation _tmp5_;
		GdkRectangle _tmp6_;
#line 992 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = allocation;
#line 992 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = (GdkRectangle) _tmp5_;
#line 992 "/home/jens/Source/shotwell/src/Page.vala"
		page_on_move_finished (self, &_tmp6_);
#line 7162 "Page.c"
	}
#line 994 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = self->priv->report_resize_finished;
#line 994 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp7_) {
#line 7168 "Page.c"
		GtkAllocation _tmp8_;
		GdkRectangle _tmp9_;
#line 995 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = allocation;
#line 995 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = (GdkRectangle) _tmp8_;
#line 995 "/home/jens/Source/shotwell/src/Page.vala"
		page_on_resize_finished (self, &_tmp9_);
#line 7177 "Page.c"
	}
#line 997 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->last_configure_ms = (gulong) 0;
#line 998 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->report_move_finished = FALSE;
#line 999 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->report_resize_finished = FALSE;
#line 1001 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 1001 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 7189 "Page.c"
}


static gboolean page_real_on_motion (Page* self, GdkEventMotion* event, gint x, gint y, GdkModifierType mask) {
	gboolean result = FALSE;
#line 1004 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1005 "/home/jens/Source/shotwell/src/Page.vala"
	page_check_cursor_hiding (self);
#line 1007 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 1007 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 7203 "Page.c"
}


gboolean page_on_motion (Page* self, GdkEventMotion* event, gint x, gint y, GdkModifierType mask) {
#line 1004 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 1004 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_motion (self, event, x, y, mask);
#line 7212 "Page.c"
}


static gboolean page_real_on_leave_notify_event (Page* self) {
	gboolean result = FALSE;
#line 1011 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 1011 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 7222 "Page.c"
}


gboolean page_on_leave_notify_event (Page* self) {
#line 1010 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 1010 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_leave_notify_event (self);
#line 7231 "Page.c"
}


static gboolean page_on_motion_internal (Page* self, GdkEventMotion* event) {
	gboolean result = FALSE;
	gint x = 0;
	gint y = 0;
	GdkModifierType mask = 0;
	GdkEventMotion* _tmp0_;
	gint16 _tmp1_;
	GdkEventMotion* _tmp11_;
	gint _tmp12_;
	gint _tmp13_;
	GdkModifierType _tmp14_;
	gboolean _tmp15_;
#line 1014 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 1014 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1017 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = event;
#line 1017 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_->is_hint;
#line 1017 "/home/jens/Source/shotwell/src/Page.vala"
	if (((gint) _tmp1_) == 1) {
#line 7257 "Page.c"
		gint _tmp2_ = 0;
		gint _tmp3_ = 0;
		GdkModifierType _tmp4_ = 0;
#line 1018 "/home/jens/Source/shotwell/src/Page.vala"
		page_get_event_source_pointer (self, &_tmp2_, &_tmp3_, &_tmp4_);
#line 1018 "/home/jens/Source/shotwell/src/Page.vala"
		x = _tmp2_;
#line 1018 "/home/jens/Source/shotwell/src/Page.vala"
		y = _tmp3_;
#line 1018 "/home/jens/Source/shotwell/src/Page.vala"
		mask = _tmp4_;
#line 7269 "Page.c"
	} else {
		GdkEventMotion* _tmp5_;
		gdouble _tmp6_;
		GdkEventMotion* _tmp7_;
		gdouble _tmp8_;
		GdkEventMotion* _tmp9_;
		GdkModifierType _tmp10_;
#line 1020 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = event;
#line 1020 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = _tmp5_->x;
#line 1020 "/home/jens/Source/shotwell/src/Page.vala"
		x = (gint) _tmp6_;
#line 1021 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = event;
#line 1021 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = _tmp7_->y;
#line 1021 "/home/jens/Source/shotwell/src/Page.vala"
		y = (gint) _tmp8_;
#line 1022 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = event;
#line 1022 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = _tmp9_->state;
#line 1022 "/home/jens/Source/shotwell/src/Page.vala"
		mask = _tmp10_;
#line 7295 "Page.c"
	}
#line 1025 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = event;
#line 1025 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = x;
#line 1025 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp13_ = y;
#line 1025 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp14_ = mask;
#line 1025 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp15_ = page_on_motion (self, _tmp11_, _tmp12_, _tmp13_, _tmp14_);
#line 1025 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp15_;
#line 1025 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 7311 "Page.c"
}


static gboolean page_on_mousewheel_internal (Page* self, GdkEventScroll* event) {
	gboolean result = FALSE;
	GdkEventScroll* _tmp0_;
	GdkScrollDirection _tmp1_;
#line 1028 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 1028 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1029 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = event;
#line 1029 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_->direction;
#line 1029 "/home/jens/Source/shotwell/src/Page.vala"
	switch (_tmp1_) {
#line 1029 "/home/jens/Source/shotwell/src/Page.vala"
		case GDK_SCROLL_UP:
#line 7331 "Page.c"
		{
			GdkEventScroll* _tmp2_;
			gboolean _tmp3_;
#line 1031 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp2_ = event;
#line 1031 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp3_ = page_on_mousewheel_up (self, _tmp2_);
#line 1031 "/home/jens/Source/shotwell/src/Page.vala"
			result = _tmp3_;
#line 1031 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 7343 "Page.c"
		}
#line 1029 "/home/jens/Source/shotwell/src/Page.vala"
		case GDK_SCROLL_DOWN:
#line 7347 "Page.c"
		{
			GdkEventScroll* _tmp4_;
			gboolean _tmp5_;
#line 1034 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp4_ = event;
#line 1034 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp5_ = page_on_mousewheel_down (self, _tmp4_);
#line 1034 "/home/jens/Source/shotwell/src/Page.vala"
			result = _tmp5_;
#line 1034 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 7359 "Page.c"
		}
#line 1029 "/home/jens/Source/shotwell/src/Page.vala"
		case GDK_SCROLL_LEFT:
#line 7363 "Page.c"
		{
			GdkEventScroll* _tmp6_;
			gboolean _tmp7_;
#line 1037 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp6_ = event;
#line 1037 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp7_ = page_on_mousewheel_left (self, _tmp6_);
#line 1037 "/home/jens/Source/shotwell/src/Page.vala"
			result = _tmp7_;
#line 1037 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 7375 "Page.c"
		}
#line 1029 "/home/jens/Source/shotwell/src/Page.vala"
		case GDK_SCROLL_RIGHT:
#line 7379 "Page.c"
		{
			GdkEventScroll* _tmp8_;
			gboolean _tmp9_;
#line 1040 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp8_ = event;
#line 1040 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp9_ = page_on_mousewheel_right (self, _tmp8_);
#line 1040 "/home/jens/Source/shotwell/src/Page.vala"
			result = _tmp9_;
#line 1040 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 7391 "Page.c"
		}
#line 1029 "/home/jens/Source/shotwell/src/Page.vala"
		case GDK_SCROLL_SMOOTH:
#line 7395 "Page.c"
		{
			{
				gdouble dx = 0.0;
				gdouble dy = 0.0;
				GdkEventScroll* _tmp10_;
				gdouble _tmp11_ = 0.0;
				gdouble _tmp12_ = 0.0;
				gdouble _tmp13_;
#line 1045 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp10_ = event;
#line 1045 "/home/jens/Source/shotwell/src/Page.vala"
				gdk_event_get_scroll_deltas ((GdkEvent*) _tmp10_, &_tmp11_, &_tmp12_);
#line 1045 "/home/jens/Source/shotwell/src/Page.vala"
				dx = _tmp11_;
#line 1045 "/home/jens/Source/shotwell/src/Page.vala"
				dy = _tmp12_;
#line 1047 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp13_ = dy;
#line 1047 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp13_ < ((gdouble) 0)) {
#line 7416 "Page.c"
					GdkEventScroll* _tmp14_;
					gboolean _tmp15_;
#line 1048 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp14_ = event;
#line 1048 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp15_ = page_on_mousewheel_up (self, _tmp14_);
#line 1048 "/home/jens/Source/shotwell/src/Page.vala"
					result = _tmp15_;
#line 1048 "/home/jens/Source/shotwell/src/Page.vala"
					return result;
#line 7427 "Page.c"
				} else {
					gdouble _tmp16_;
#line 1049 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp16_ = dy;
#line 1049 "/home/jens/Source/shotwell/src/Page.vala"
					if (_tmp16_ > ((gdouble) 0)) {
#line 7434 "Page.c"
						GdkEventScroll* _tmp17_;
						gboolean _tmp18_;
#line 1050 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp17_ = event;
#line 1050 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp18_ = page_on_mousewheel_down (self, _tmp17_);
#line 1050 "/home/jens/Source/shotwell/src/Page.vala"
						result = _tmp18_;
#line 1050 "/home/jens/Source/shotwell/src/Page.vala"
						return result;
#line 7445 "Page.c"
					} else {
						gdouble _tmp19_;
#line 1051 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp19_ = dx;
#line 1051 "/home/jens/Source/shotwell/src/Page.vala"
						if (_tmp19_ < ((gdouble) 0)) {
#line 7452 "Page.c"
							GdkEventScroll* _tmp20_;
							gboolean _tmp21_;
#line 1052 "/home/jens/Source/shotwell/src/Page.vala"
							_tmp20_ = event;
#line 1052 "/home/jens/Source/shotwell/src/Page.vala"
							_tmp21_ = page_on_mousewheel_left (self, _tmp20_);
#line 1052 "/home/jens/Source/shotwell/src/Page.vala"
							result = _tmp21_;
#line 1052 "/home/jens/Source/shotwell/src/Page.vala"
							return result;
#line 7463 "Page.c"
						} else {
							gdouble _tmp22_;
#line 1053 "/home/jens/Source/shotwell/src/Page.vala"
							_tmp22_ = dx;
#line 1053 "/home/jens/Source/shotwell/src/Page.vala"
							if (_tmp22_ > ((gdouble) 0)) {
#line 7470 "Page.c"
								GdkEventScroll* _tmp23_;
								gboolean _tmp24_;
#line 1054 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp23_ = event;
#line 1054 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp24_ = page_on_mousewheel_right (self, _tmp23_);
#line 1054 "/home/jens/Source/shotwell/src/Page.vala"
								result = _tmp24_;
#line 1054 "/home/jens/Source/shotwell/src/Page.vala"
								return result;
#line 7481 "Page.c"
							} else {
#line 1056 "/home/jens/Source/shotwell/src/Page.vala"
								result = FALSE;
#line 1056 "/home/jens/Source/shotwell/src/Page.vala"
								return result;
#line 7487 "Page.c"
							}
						}
					}
				}
			}
		}
		default:
		{
#line 1060 "/home/jens/Source/shotwell/src/Page.vala"
			result = FALSE;
#line 1060 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 7500 "Page.c"
		}
	}
}


static gboolean page_real_on_mousewheel_up (Page* self, GdkEventScroll* event) {
	gboolean result = FALSE;
#line 1064 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1065 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 1065 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 7514 "Page.c"
}


gboolean page_on_mousewheel_up (Page* self, GdkEventScroll* event) {
#line 1064 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 1064 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_mousewheel_up (self, event);
#line 7523 "Page.c"
}


static gboolean page_real_on_mousewheel_down (Page* self, GdkEventScroll* event) {
	gboolean result = FALSE;
#line 1068 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1069 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 1069 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 7535 "Page.c"
}


gboolean page_on_mousewheel_down (Page* self, GdkEventScroll* event) {
#line 1068 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 1068 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_mousewheel_down (self, event);
#line 7544 "Page.c"
}


static gboolean page_real_on_mousewheel_left (Page* self, GdkEventScroll* event) {
	gboolean result = FALSE;
#line 1072 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1073 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 1073 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 7556 "Page.c"
}


gboolean page_on_mousewheel_left (Page* self, GdkEventScroll* event) {
#line 1072 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 1072 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_mousewheel_left (self, event);
#line 7565 "Page.c"
}


static gboolean page_real_on_mousewheel_right (Page* self, GdkEventScroll* event) {
	gboolean result = FALSE;
#line 1076 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1077 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 1077 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 7577 "Page.c"
}


gboolean page_on_mousewheel_right (Page* self, GdkEventScroll* event) {
#line 1076 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 1076 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_mousewheel_right (self, event);
#line 7586 "Page.c"
}


static gboolean page_real_on_context_keypress (Page* self) {
	gboolean result = FALSE;
#line 1081 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 1081 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 7596 "Page.c"
}


gboolean page_on_context_keypress (Page* self) {
#line 1080 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 1080 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_context_keypress (self);
#line 7605 "Page.c"
}


static gboolean page_real_on_context_buttonpress (Page* self, GdkEventButton* event) {
	gboolean result = FALSE;
#line 1084 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1085 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 1085 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 7617 "Page.c"
}


gboolean page_on_context_buttonpress (Page* self, GdkEventButton* event) {
#line 1084 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 1084 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_context_buttonpress (self, event);
#line 7626 "Page.c"
}


static gboolean page_real_on_context_invoked (Page* self) {
	gboolean result = FALSE;
#line 1089 "/home/jens/Source/shotwell/src/Page.vala"
	result = TRUE;
#line 1089 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 7636 "Page.c"
}


gboolean page_on_context_invoked (Page* self) {
#line 1088 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 1088 "/home/jens/Source/shotwell/src/Page.vala"
	return PAGE_GET_CLASS (self)->on_context_invoked (self);
#line 7645 "Page.c"
}


gboolean page_popup_context_menu (Page* self, GtkMenu* context_menu, GdkEventButton* event) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GtkMenu* _tmp1_;
	GdkEventButton* _tmp3_;
#line 1092 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 1092 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail ((context_menu == NULL) || GTK_IS_MENU (context_menu), FALSE);
#line 1095 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = context_menu;
#line 1095 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_ == NULL) {
#line 1095 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = TRUE;
#line 7664 "Page.c"
	} else {
		gboolean _tmp2_;
#line 1095 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = page_on_context_invoked (self);
#line 1095 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = !_tmp2_;
#line 7671 "Page.c"
	}
#line 1095 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_) {
#line 1096 "/home/jens/Source/shotwell/src/Page.vala"
		result = FALSE;
#line 1096 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 7679 "Page.c"
	}
#line 1098 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = event;
#line 1098 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_ == NULL) {
#line 7685 "Page.c"
		GtkMenu* _tmp4_;
		guint32 _tmp5_;
#line 1099 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = context_menu;
#line 1099 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = gtk_get_current_event_time ();
#line 1099 "/home/jens/Source/shotwell/src/Page.vala"
		gtk_menu_popup (_tmp4_, NULL, NULL, NULL, NULL, (guint) 0, _tmp5_);
#line 7694 "Page.c"
	} else {
		GtkMenu* _tmp6_;
		GdkEventButton* _tmp7_;
		guint _tmp8_;
		GdkEventButton* _tmp9_;
		guint32 _tmp10_;
#line 1101 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = context_menu;
#line 1101 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = event;
#line 1101 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = _tmp7_->button;
#line 1101 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = event;
#line 1101 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = _tmp9_->time;
#line 1101 "/home/jens/Source/shotwell/src/Page.vala"
		gtk_menu_popup (_tmp6_, NULL, NULL, NULL, NULL, _tmp8_, _tmp10_);
#line 7713 "Page.c"
	}
#line 1103 "/home/jens/Source/shotwell/src/Page.vala"
	result = TRUE;
#line 1103 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 7719 "Page.c"
}


void page_on_event_source_realize (Page* self) {
	GtkWidget* _tmp0_;
	GdkWindow* _tmp1_;
	GtkWidget* _tmp2_;
	GdkWindow* _tmp3_;
	GdkCursor* _tmp4_;
	GdkWindow* parent_window = NULL;
	GtkWidget* _tmp9_;
	GdkWindow* _tmp10_;
	GdkWindow* _tmp11_;
	GdkWindow* _tmp20_;
#line 1106 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 1107 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->event_source;
#line 1107 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = gtk_widget_get_window (_tmp0_);
#line 1107 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp1_ != NULL, "event_source.get_window() != null");
#line 1109 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->priv->event_source;
#line 1109 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = gtk_widget_get_window (_tmp2_);
#line 1109 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = gdk_window_get_cursor (_tmp3_);
#line 1109 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_ != NULL) {
#line 7750 "Page.c"
		GtkWidget* _tmp5_;
		GdkWindow* _tmp6_;
		GdkCursor* _tmp7_;
		GdkCursorType _tmp8_;
#line 1110 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = self->priv->event_source;
#line 1110 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = gtk_widget_get_window (_tmp5_);
#line 1110 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = gdk_window_get_cursor (_tmp6_);
#line 1110 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = gdk_cursor_get_cursor_type (_tmp7_);
#line 1110 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->last_cursor = _tmp8_;
#line 1111 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 7767 "Page.c"
	}
#line 1115 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = self->priv->event_source;
#line 1115 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = gtk_widget_get_window (_tmp9_);
#line 1115 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = _g_object_ref0 (_tmp10_);
#line 1115 "/home/jens/Source/shotwell/src/Page.vala"
	parent_window = _tmp11_;
#line 7777 "Page.c"
	{
		gboolean _tmp12_ = FALSE;
#line 1116 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp12_ = TRUE;
#line 1116 "/home/jens/Source/shotwell/src/Page.vala"
		while (TRUE) {
#line 7784 "Page.c"
			GdkWindow* _tmp17_;
			GdkWindow* _tmp18_;
			GdkWindow* _tmp19_;
#line 1116 "/home/jens/Source/shotwell/src/Page.vala"
			if (!_tmp12_) {
#line 7790 "Page.c"
				gboolean _tmp13_ = FALSE;
				GdkWindow* _tmp14_;
#line 1118 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp14_ = parent_window;
#line 1118 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp14_ != NULL) {
#line 7797 "Page.c"
					GdkWindow* _tmp15_;
					GdkCursor* _tmp16_;
#line 1118 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp15_ = parent_window;
#line 1118 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp16_ = gdk_window_get_cursor (_tmp15_);
#line 1118 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp13_ = _tmp16_ == NULL;
#line 7806 "Page.c"
				} else {
#line 1118 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp13_ = FALSE;
#line 7810 "Page.c"
				}
#line 1118 "/home/jens/Source/shotwell/src/Page.vala"
				if (!_tmp13_) {
#line 1118 "/home/jens/Source/shotwell/src/Page.vala"
					break;
#line 7816 "Page.c"
				}
			}
#line 1116 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp12_ = FALSE;
#line 1117 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp17_ = parent_window;
#line 1117 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp18_ = gdk_window_get_parent (_tmp17_);
#line 1117 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp19_ = _g_object_ref0 (_tmp18_);
#line 1117 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (parent_window);
#line 1117 "/home/jens/Source/shotwell/src/Page.vala"
			parent_window = _tmp19_;
#line 7831 "Page.c"
		}
	}
#line 1120 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp20_ = parent_window;
#line 1120 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp20_ != NULL) {
#line 7838 "Page.c"
		GdkWindow* _tmp21_;
		GdkCursor* _tmp22_;
		GdkCursorType _tmp23_;
#line 1121 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp21_ = parent_window;
#line 1121 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp22_ = gdk_window_get_cursor (_tmp21_);
#line 1121 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp23_ = gdk_cursor_get_cursor_type (_tmp22_);
#line 1121 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->last_cursor = _tmp23_;
#line 7850 "Page.c"
	}
#line 1106 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (parent_window);
#line 7854 "Page.c"
}


void page_set_cursor_hide_time (Page* self, gint hide_time) {
	gint _tmp0_;
#line 1124 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 1125 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = hide_time;
#line 1125 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->cursor_hide_msec = _tmp0_;
#line 7866 "Page.c"
}


void page_start_cursor_hiding (Page* self) {
#line 1128 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 1129 "/home/jens/Source/shotwell/src/Page.vala"
	page_check_cursor_hiding (self);
#line 7875 "Page.c"
}


void page_stop_cursor_hiding (Page* self) {
	guint _tmp0_;
#line 1132 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 1133 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->last_timeout_id;
#line 1133 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ != ((guint) 0)) {
#line 7887 "Page.c"
		guint _tmp1_;
#line 1134 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = self->priv->last_timeout_id;
#line 1134 "/home/jens/Source/shotwell/src/Page.vala"
		g_source_remove (_tmp1_);
#line 7893 "Page.c"
	}
}


void page_suspend_cursor_hiding (Page* self) {
	gint _tmp0_;
	guint _tmp1_;
#line 1137 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 1138 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->cursor_hide_msec;
#line 1138 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->cursor_hide_time_cached = _tmp0_;
#line 1140 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->last_timeout_id;
#line 1140 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_ != ((guint) 0)) {
#line 7911 "Page.c"
		guint _tmp2_;
#line 1141 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = self->priv->last_timeout_id;
#line 1141 "/home/jens/Source/shotwell/src/Page.vala"
		g_source_remove (_tmp2_);
#line 7917 "Page.c"
	}
#line 1143 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->cursor_hide_msec = 0;
#line 7921 "Page.c"
}


void page_restore_cursor_hiding (Page* self) {
	gint _tmp0_;
#line 1146 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 1147 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->cursor_hide_time_cached;
#line 1147 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->cursor_hide_msec = _tmp0_;
#line 1148 "/home/jens/Source/shotwell/src/Page.vala"
	page_check_cursor_hiding (self);
#line 7935 "Page.c"
}


static void page_real_set_page_cursor (Page* self, GdkCursorType cursor_type) {
	GdkCursorType _tmp0_;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_;
#line 1153 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = cursor_type;
#line 1153 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->last_cursor = _tmp0_;
#line 1155 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->priv->cursor_hidden;
#line 1155 "/home/jens/Source/shotwell/src/Page.vala"
	if (!_tmp2_) {
#line 7951 "Page.c"
		GtkWidget* _tmp3_;
#line 1155 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = self->priv->event_source;
#line 1155 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = _tmp3_ != NULL;
#line 7957 "Page.c"
	} else {
#line 1155 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = FALSE;
#line 7961 "Page.c"
	}
#line 1155 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_) {
#line 7965 "Page.c"
		GdkDisplay* display = NULL;
		GtkWidget* _tmp4_;
		GdkWindow* _tmp5_;
		GdkDisplay* _tmp6_;
		GdkDisplay* _tmp7_;
		GtkWidget* _tmp8_;
		GdkWindow* _tmp9_;
		GdkDisplay* _tmp10_;
		GdkCursorType _tmp11_;
		GdkCursor* _tmp12_;
		GdkCursor* _tmp13_;
#line 1156 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = self->priv->event_source;
#line 1156 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = gtk_widget_get_window (_tmp4_);
#line 1156 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = gdk_window_get_display (_tmp5_);
#line 1156 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = _g_object_ref0 (_tmp6_);
#line 1156 "/home/jens/Source/shotwell/src/Page.vala"
		display = _tmp7_;
#line 1157 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = self->priv->event_source;
#line 1157 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = gtk_widget_get_window (_tmp8_);
#line 1157 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = display;
#line 1157 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = cursor_type;
#line 1157 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp12_ = gdk_cursor_new_for_display (_tmp10_, _tmp11_);
#line 1157 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp13_ = _tmp12_;
#line 1157 "/home/jens/Source/shotwell/src/Page.vala"
		gdk_window_set_cursor (_tmp9_, _tmp13_);
#line 1157 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp13_);
#line 1155 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (display);
#line 8005 "Page.c"
	}
}


void page_set_page_cursor (Page* self, GdkCursorType cursor_type) {
#line 1152 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 1152 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_GET_CLASS (self)->set_page_cursor (self, cursor_type);
#line 8015 "Page.c"
}


static gboolean _page_on_hide_cursor_gsource_func (gpointer self) {
	gboolean result;
	result = page_on_hide_cursor ((Page*) self);
#line 1170 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 8024 "Page.c"
}


static void page_check_cursor_hiding (Page* self) {
	gboolean _tmp0_;
	gint _tmp2_;
#line 1161 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 1162 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->cursor_hidden;
#line 1162 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_) {
#line 8037 "Page.c"
		GdkCursorType _tmp1_;
#line 1163 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->cursor_hidden = FALSE;
#line 1164 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = self->priv->last_cursor;
#line 1164 "/home/jens/Source/shotwell/src/Page.vala"
		page_set_page_cursor (self, _tmp1_);
#line 8045 "Page.c"
	}
#line 1167 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->priv->cursor_hide_msec;
#line 1167 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_ != 0) {
#line 8051 "Page.c"
		guint _tmp3_;
		gint _tmp5_;
		guint _tmp6_;
#line 1168 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = self->priv->last_timeout_id;
#line 1168 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp3_ != ((guint) 0)) {
#line 8059 "Page.c"
			guint _tmp4_;
#line 1169 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp4_ = self->priv->last_timeout_id;
#line 1169 "/home/jens/Source/shotwell/src/Page.vala"
			g_source_remove (_tmp4_);
#line 8065 "Page.c"
		}
#line 1170 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = self->priv->cursor_hide_msec;
#line 1170 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) _tmp5_, _page_on_hide_cursor_gsource_func, g_object_ref (self), g_object_unref);
#line 1170 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->last_timeout_id = _tmp6_;
#line 8073 "Page.c"
	}
}


static gboolean page_on_hide_cursor (Page* self) {
	gboolean result = FALSE;
	GtkWidget* _tmp0_;
#line 1174 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), FALSE);
#line 1175 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->cursor_hidden = TRUE;
#line 1177 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->event_source;
#line 1177 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ != NULL) {
#line 8089 "Page.c"
		GdkDisplay* display = NULL;
		GtkWidget* _tmp1_;
		GdkWindow* _tmp2_;
		GdkDisplay* _tmp3_;
		GdkDisplay* _tmp4_;
		GtkWidget* _tmp5_;
		GdkWindow* _tmp6_;
		GdkDisplay* _tmp7_;
		GdkCursor* _tmp8_;
		GdkCursor* _tmp9_;
#line 1178 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = self->priv->event_source;
#line 1178 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = gtk_widget_get_window (_tmp1_);
#line 1178 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = gdk_window_get_display (_tmp2_);
#line 1178 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = _g_object_ref0 (_tmp3_);
#line 1178 "/home/jens/Source/shotwell/src/Page.vala"
		display = _tmp4_;
#line 1179 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = self->priv->event_source;
#line 1179 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = gtk_widget_get_window (_tmp5_);
#line 1179 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = display;
#line 1179 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = gdk_cursor_new_for_display (_tmp7_, GDK_BLANK_CURSOR);
#line 1179 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = _tmp8_;
#line 1179 "/home/jens/Source/shotwell/src/Page.vala"
		gdk_window_set_cursor (_tmp6_, _tmp9_);
#line 1179 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp9_);
#line 1177 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (display);
#line 8126 "Page.c"
	}
#line 1183 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->last_timeout_id = (guint) 0;
#line 1185 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 1185 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 8134 "Page.c"
}


void page_update_menu_item_label (Page* self, const gchar* id, const gchar* new_label) {
	AppWindow* _tmp0_;
	AppWindow* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
#line 1188 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (self));
#line 1188 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (id != NULL);
#line 1188 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (new_label != NULL);
#line 1190 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = app_window_get_instance ();
#line 1190 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_;
#line 1190 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = id;
#line 1190 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = new_label;
#line 1190 "/home/jens/Source/shotwell/src/Page.vala"
	app_window_update_menu_item_label (_tmp1_, _tmp2_, _tmp3_);
#line 1190 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (_tmp1_);
#line 8161 "Page.c"
}


GMenuModel* page_find_extension_point (Page* self, GMenuModel* model, const gchar* extension_point) {
	GMenuModel* result = NULL;
	gint items = 0;
	GMenuModel* _tmp0_;
	gint _tmp1_;
	GMenuModel* section = NULL;
#line 1193 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (self), NULL);
#line 1193 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (G_IS_MENU_MODEL (model), NULL);
#line 1193 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (extension_point != NULL, NULL);
#line 1195 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = model;
#line 1195 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = g_menu_model_get_n_items (_tmp0_);
#line 1195 "/home/jens/Source/shotwell/src/Page.vala"
	items = _tmp1_;
#line 1196 "/home/jens/Source/shotwell/src/Page.vala"
	section = NULL;
#line 8185 "Page.c"
	{
		gint i = 0;
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
		i = 0;
#line 8190 "Page.c"
		{
			gboolean _tmp2_ = FALSE;
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp2_ = TRUE;
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
			while (TRUE) {
#line 8197 "Page.c"
				gboolean _tmp4_ = FALSE;
				gint _tmp5_;
				gint _tmp6_;
				gchar* name = NULL;
				GMenuModel* _tmp8_;
				gint _tmp9_;
				const gchar* _tmp10_;
				const gchar* _tmp11_;
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
				if (!_tmp2_) {
#line 8208 "Page.c"
					gint _tmp3_;
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp3_ = i;
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
					i = _tmp3_ + 1;
#line 8214 "Page.c"
				}
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp2_ = FALSE;
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp5_ = i;
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp6_ = items;
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp5_ < _tmp6_) {
#line 8224 "Page.c"
					GMenuModel* _tmp7_;
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp7_ = section;
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp4_ = _tmp7_ == NULL;
#line 8230 "Page.c"
				} else {
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp4_ = FALSE;
#line 8234 "Page.c"
				}
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
				if (!_tmp4_) {
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
					break;
#line 8240 "Page.c"
				}
#line 1199 "/home/jens/Source/shotwell/src/Page.vala"
				name = NULL;
#line 1200 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp8_ = model;
#line 1200 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp9_ = i;
#line 1200 "/home/jens/Source/shotwell/src/Page.vala"
				g_menu_model_get_item_attribute (_tmp8_, _tmp9_, "id", "s", &name, NULL);
#line 1201 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp10_ = name;
#line 1201 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp11_ = extension_point;
#line 1201 "/home/jens/Source/shotwell/src/Page.vala"
				if (g_strcmp0 (_tmp10_, _tmp11_) == 0) {
#line 8256 "Page.c"
					GMenuModel* _tmp12_;
					gint _tmp13_;
					GMenuModel* _tmp14_;
#line 1202 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp12_ = model;
#line 1202 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp13_ = i;
#line 1202 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp14_ = g_menu_model_get_item_link (_tmp12_, _tmp13_, G_MENU_LINK_SECTION);
#line 1202 "/home/jens/Source/shotwell/src/Page.vala"
					_g_object_unref0 (section);
#line 1202 "/home/jens/Source/shotwell/src/Page.vala"
					section = _tmp14_;
#line 8270 "Page.c"
				} else {
					GMenuModel* subsection = NULL;
					GMenuModel* _tmp15_;
					gint _tmp16_;
					GMenuModel* _tmp17_;
					GMenuModel* _tmp18_;
					gint sub_items = 0;
					GMenuModel* _tmp19_;
					gint _tmp20_;
#line 1204 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp15_ = model;
#line 1204 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp16_ = i;
#line 1204 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp17_ = g_menu_model_get_item_link (_tmp15_, _tmp16_, G_MENU_LINK_SECTION);
#line 1204 "/home/jens/Source/shotwell/src/Page.vala"
					subsection = _tmp17_;
#line 1206 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp18_ = subsection;
#line 1206 "/home/jens/Source/shotwell/src/Page.vala"
					if (_tmp18_ == NULL) {
#line 1207 "/home/jens/Source/shotwell/src/Page.vala"
						_g_object_unref0 (subsection);
#line 1207 "/home/jens/Source/shotwell/src/Page.vala"
						_g_free0 (name);
#line 1207 "/home/jens/Source/shotwell/src/Page.vala"
						continue;
#line 8298 "Page.c"
					}
#line 1210 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp19_ = subsection;
#line 1210 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp20_ = g_menu_model_get_n_items (_tmp19_);
#line 1210 "/home/jens/Source/shotwell/src/Page.vala"
					sub_items = _tmp20_;
#line 8306 "Page.c"
					{
						gint j = 0;
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
						j = 0;
#line 8311 "Page.c"
						{
							gboolean _tmp21_ = FALSE;
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
							_tmp21_ = TRUE;
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
							while (TRUE) {
#line 8318 "Page.c"
								gboolean _tmp23_ = FALSE;
								gint _tmp24_;
								gint _tmp25_;
								GMenuModel* submenu = NULL;
								GMenuModel* _tmp27_;
								gint _tmp28_;
								GMenuModel* _tmp29_;
								GMenuModel* _tmp30_;
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
								if (!_tmp21_) {
#line 8329 "Page.c"
									gint _tmp22_;
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
									_tmp22_ = j;
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
									j = _tmp22_ + 1;
#line 8335 "Page.c"
								}
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp21_ = FALSE;
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp24_ = j;
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp25_ = sub_items;
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
								if (_tmp24_ < _tmp25_) {
#line 8345 "Page.c"
									GMenuModel* _tmp26_;
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
									_tmp26_ = section;
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
									_tmp23_ = _tmp26_ == NULL;
#line 8351 "Page.c"
								} else {
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
									_tmp23_ = FALSE;
#line 8355 "Page.c"
								}
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
								if (!_tmp23_) {
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
									break;
#line 8361 "Page.c"
								}
#line 1212 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp27_ = subsection;
#line 1212 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp28_ = j;
#line 1212 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp29_ = g_menu_model_get_item_link (_tmp27_, _tmp28_, G_MENU_LINK_SUBMENU);
#line 1212 "/home/jens/Source/shotwell/src/Page.vala"
								submenu = _tmp29_;
#line 1214 "/home/jens/Source/shotwell/src/Page.vala"
								_tmp30_ = submenu;
#line 1214 "/home/jens/Source/shotwell/src/Page.vala"
								if (_tmp30_ != NULL) {
#line 8375 "Page.c"
									GMenuModel* _tmp31_;
									const gchar* _tmp32_;
									GMenuModel* _tmp33_;
#line 1215 "/home/jens/Source/shotwell/src/Page.vala"
									_tmp31_ = submenu;
#line 1215 "/home/jens/Source/shotwell/src/Page.vala"
									_tmp32_ = extension_point;
#line 1215 "/home/jens/Source/shotwell/src/Page.vala"
									_tmp33_ = page_find_extension_point (self, _tmp31_, _tmp32_);
#line 1215 "/home/jens/Source/shotwell/src/Page.vala"
									_g_object_unref0 (section);
#line 1215 "/home/jens/Source/shotwell/src/Page.vala"
									section = _tmp33_;
#line 8389 "Page.c"
								}
#line 1211 "/home/jens/Source/shotwell/src/Page.vala"
								_g_object_unref0 (submenu);
#line 8393 "Page.c"
							}
						}
					}
#line 1201 "/home/jens/Source/shotwell/src/Page.vala"
					_g_object_unref0 (subsection);
#line 8399 "Page.c"
				}
#line 1198 "/home/jens/Source/shotwell/src/Page.vala"
				_g_free0 (name);
#line 8403 "Page.c"
			}
		}
	}
#line 1222 "/home/jens/Source/shotwell/src/Page.vala"
	result = section;
#line 1222 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 8411 "Page.c"
}


static void page_class_init (PageClass * klass) {
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	page_parent_class = g_type_class_peek_parent (klass);
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	g_type_class_add_private (klass, sizeof (PagePrivate));
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((GtkWidgetClass *) klass)->destroy = (void (*) (GtkWidget *)) page_real_destroy;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->set_page_name = (void (*) (Page *, const gchar*)) page_real_set_page_name;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->set_container = (void (*) (Page *, GtkWindow*)) page_real_set_container;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->clear_container = (void (*) (Page *)) page_real_clear_container;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->get_toolbar = (GtkToolbar* (*) (Page *)) page_real_get_toolbar;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->get_page_context_menu = (GtkMenu* (*) (Page *)) page_real_get_page_context_menu;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->switching_from = (void (*) (Page *)) page_real_switching_from;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->switched_to = (void (*) (Page *)) page_real_switched_to;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->ready = (void (*) (Page *)) page_real_ready;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->switching_to_fullscreen = (void (*) (Page *, FullscreenWindow*)) page_real_switching_to_fullscreen;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->returning_from_fullscreen = (void (*) (Page *, FullscreenWindow*)) page_real_returning_from_fullscreen;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->add_actions = (void (*) (Page *, GActionMap*)) page_real_add_actions;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->remove_actions = (void (*) (Page *, GActionMap*)) page_real_remove_actions;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->init_collect_ui_filenames = (void (*) (Page *, GeeList*)) page_real_init_collect_ui_filenames;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->init_collect_injection_groups = (InjectionGroup** (*) (Page *, int*)) page_real_init_collect_injection_groups;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->init_actions = (void (*) (Page *, gint, gint)) page_real_init_actions;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->update_actions = (void (*) (Page *, gint, gint)) page_real_update_actions;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->source_drag_failed = (gboolean (*) (Page *, GdkDragContext*, GtkDragResult)) page_real_source_drag_failed;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_left_click = (gboolean (*) (Page *, GdkEventButton*)) page_real_on_left_click;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_middle_click = (gboolean (*) (Page *, GdkEventButton*)) page_real_on_middle_click;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_right_click = (gboolean (*) (Page *, GdkEventButton*)) page_real_on_right_click;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_left_released = (gboolean (*) (Page *, GdkEventButton*)) page_real_on_left_released;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_middle_released = (gboolean (*) (Page *, GdkEventButton*)) page_real_on_middle_released;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_right_released = (gboolean (*) (Page *, GdkEventButton*)) page_real_on_right_released;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_ctrl_pressed = (gboolean (*) (Page *, GdkEventKey*)) page_real_on_ctrl_pressed;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_ctrl_released = (gboolean (*) (Page *, GdkEventKey*)) page_real_on_ctrl_released;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_alt_pressed = (gboolean (*) (Page *, GdkEventKey*)) page_real_on_alt_pressed;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_alt_released = (gboolean (*) (Page *, GdkEventKey*)) page_real_on_alt_released;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_shift_pressed = (gboolean (*) (Page *, GdkEventKey*)) page_real_on_shift_pressed;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_shift_released = (gboolean (*) (Page *, GdkEventKey*)) page_real_on_shift_released;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_super_pressed = (gboolean (*) (Page *, GdkEventKey*)) page_real_on_super_pressed;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_super_released = (gboolean (*) (Page *, GdkEventKey*)) page_real_on_super_released;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_app_key_pressed = (gboolean (*) (Page *, GdkEventKey*)) page_real_on_app_key_pressed;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_app_key_released = (gboolean (*) (Page *, GdkEventKey*)) page_real_on_app_key_released;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_move = (void (*) (Page *, GdkRectangle*)) page_real_on_move;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_move_start = (void (*) (Page *, GdkRectangle*)) page_real_on_move_start;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_move_finished = (void (*) (Page *, GdkRectangle*)) page_real_on_move_finished;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_resize = (void (*) (Page *, GdkRectangle*)) page_real_on_resize;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_resize_start = (void (*) (Page *, GdkRectangle*)) page_real_on_resize_start;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_resize_finished = (void (*) (Page *, GdkRectangle*)) page_real_on_resize_finished;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_configure = (gboolean (*) (Page *, GdkEventConfigure*, GdkRectangle*)) page_real_on_configure;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_motion = (gboolean (*) (Page *, GdkEventMotion*, gint, gint, GdkModifierType)) page_real_on_motion;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_leave_notify_event = (gboolean (*) (Page *)) page_real_on_leave_notify_event;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_mousewheel_up = (gboolean (*) (Page *, GdkEventScroll*)) page_real_on_mousewheel_up;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_mousewheel_down = (gboolean (*) (Page *, GdkEventScroll*)) page_real_on_mousewheel_down;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_mousewheel_left = (gboolean (*) (Page *, GdkEventScroll*)) page_real_on_mousewheel_left;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_mousewheel_right = (gboolean (*) (Page *, GdkEventScroll*)) page_real_on_mousewheel_right;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_context_keypress = (gboolean (*) (Page *)) page_real_on_context_keypress;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_context_buttonpress = (gboolean (*) (Page *, GdkEventButton*)) page_real_on_context_buttonpress;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_context_invoked = (gboolean (*) (Page *)) page_real_on_context_invoked;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->set_page_cursor = (void (*) (Page *, GdkCursorType)) page_real_set_page_cursor;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	G_OBJECT_CLASS (klass)->finalize = page_finalize;
#line 8524 "Page.c"
}


static void page_instance_init (Page * self) {
	GtkBuilder* _tmp0_;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv = PAGE_GET_PRIVATE (self);
#line 61 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = gtk_builder_new ();
#line 61 "/home/jens/Source/shotwell/src/Page.vala"
	self->builder = _tmp0_;
#line 63 "/home/jens/Source/shotwell/src/Page.vala"
	self->in_view = FALSE;
#line 66 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->view = NULL;
#line 67 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->container = NULL;
#line 69 "/home/jens/Source/shotwell/src/Page.vala"
	memset (&self->priv->last_position, 0, sizeof (GdkRectangle));
#line 70 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->event_source = NULL;
#line 71 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->dnd_enabled = FALSE;
#line 72 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->last_configure_ms = (gulong) 0;
#line 73 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->report_move_finished = FALSE;
#line 74 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->report_resize_finished = FALSE;
#line 75 "/home/jens/Source/shotwell/src/Page.vala"
	memset (&self->priv->last_down, 0, sizeof (GdkPoint));
#line 76 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->is_destroyed = FALSE;
#line 77 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->ctrl_pressed = FALSE;
#line 78 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->alt_pressed = FALSE;
#line 79 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->shift_pressed = FALSE;
#line 80 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->super_pressed = FALSE;
#line 81 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->last_cursor = GDK_LEFT_PTR;
#line 82 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->cursor_hidden = FALSE;
#line 83 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->cursor_hide_msec = 0;
#line 84 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->last_timeout_id = (guint) 0;
#line 85 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->cursor_hide_time_cached = 0;
#line 86 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->are_actions_attached = FALSE;
#line 87 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->update_actions_scheduler = NULL;
#line 205 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->menubar_injected = FALSE;
#line 8582 "Page.c"
}


static void page_finalize (GObject * obj) {
	Page * self;
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PAGE, Page);
#line 61 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->builder);
#line 62 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->toolbar);
#line 65 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->priv->page_name);
#line 66 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (self->priv->view);
#line 67 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->container);
#line 68 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->priv->toolbar_path);
#line 70 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->event_source);
#line 87 "/home/jens/Source/shotwell/src/Page.vala"
	_one_shot_scheduler_unref0 (self->priv->update_actions_scheduler);
#line 58 "/home/jens/Source/shotwell/src/Page.vala"
	G_OBJECT_CLASS (page_parent_class)->finalize (obj);
#line 8608 "Page.c"
}


GType page_get_type (void) {
	static volatile gsize page_type_id__volatile = 0;
	if (g_once_init_enter (&page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Page), 0, (GInstanceInitFunc) page_instance_init, NULL };
		GType page_type_id;
		page_type_id = g_type_register_static (gtk_scrolled_window_get_type (), "Page", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&page_type_id__volatile, page_type_id);
	}
	return page_type_id__volatile;
}


GType checkerboard_page_activator_get_type (void) {
	static volatile gsize checkerboard_page_activator_type_id__volatile = 0;
	if (g_once_init_enter (&checkerboard_page_activator_type_id__volatile)) {
		static const GEnumValue values[] = {{CHECKERBOARD_PAGE_ACTIVATOR_KEYBOARD, "CHECKERBOARD_PAGE_ACTIVATOR_KEYBOARD", "keyboard"}, {CHECKERBOARD_PAGE_ACTIVATOR_MOUSE, "CHECKERBOARD_PAGE_ACTIVATOR_MOUSE", "mouse"}, {0, NULL, NULL}};
		GType checkerboard_page_activator_type_id;
		checkerboard_page_activator_type_id = g_enum_register_static ("CheckerboardPageActivator", values);
		g_once_init_leave (&checkerboard_page_activator_type_id__volatile, checkerboard_page_activator_type_id);
	}
	return checkerboard_page_activator_type_id__volatile;
}


static void _checkerboard_page_on_items_hidden_view_collection_items_hidden (ViewCollection* _sender, GeeCollection* hidden, gpointer self) {
#line 1284 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_page_on_items_hidden ((CheckerboardPage*) self, hidden);
#line 8639 "Page.c"
}


static void _checkerboard_page_on_contents_altered_data_collection_contents_altered (DataCollection* _sender, GeeIterable* added, GeeIterable* removed, gpointer self) {
#line 1285 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_page_on_contents_altered ((CheckerboardPage*) self, added, removed);
#line 8646 "Page.c"
}


static void _checkerboard_page_on_items_state_changed_view_collection_items_state_changed (ViewCollection* _sender, GeeIterable* changed, gpointer self) {
#line 1286 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_page_on_items_state_changed ((CheckerboardPage*) self, changed);
#line 8653 "Page.c"
}


static void _checkerboard_page_on_items_visibility_changed_view_collection_items_visibility_changed (ViewCollection* _sender, GeeCollection* changed, gpointer self) {
#line 1287 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_page_on_items_visibility_changed ((CheckerboardPage*) self, changed);
#line 8660 "Page.c"
}


CheckerboardPage* checkerboard_page_construct (GType object_type, const gchar* page_name) {
	CheckerboardPage * self = NULL;
	const gchar* _tmp0_;
	ViewCollection* _tmp1_;
	ViewCollection* _tmp2_;
	CheckerboardLayout* _tmp3_;
	CheckerboardLayout* _tmp4_;
	const gchar* _tmp5_;
	CheckerboardLayout* _tmp6_;
	GtkViewport* _tmp7_;
	GtkViewport* _tmp8_;
	GtkViewport* _tmp9_;
	CheckerboardLayout* _tmp10_;
	CheckerboardLayout* _tmp11_;
	GtkAdjustment* _tmp12_;
	GtkAdjustment* _tmp13_;
	GtkViewport* _tmp14_;
	ViewCollection* _tmp15_;
	ViewCollection* _tmp16_;
	ViewCollection* _tmp17_;
	ViewCollection* _tmp18_;
	ViewCollection* _tmp19_;
	ViewCollection* _tmp20_;
	ViewCollection* _tmp21_;
	ViewCollection* _tmp22_;
#line 1261 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (page_name != NULL, NULL);
#line 1262 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_name;
#line 1262 "/home/jens/Source/shotwell/src/Page.vala"
	self = (CheckerboardPage*) page_construct (object_type, _tmp0_);
#line 1264 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1264 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_;
#line 1264 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = checkerboard_layout_new (_tmp2_);
#line 1264 "/home/jens/Source/shotwell/src/Page.vala"
	g_object_ref_sink (_tmp3_);
#line 1264 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->layout);
#line 1264 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->layout = _tmp3_;
#line 1264 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp2_);
#line 1265 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = self->priv->layout;
#line 1265 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = page_name;
#line 1265 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_layout_set_name (_tmp4_, _tmp5_);
#line 1267 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = self->priv->layout;
#line 1267 "/home/jens/Source/shotwell/src/Page.vala"
	page_set_event_source (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget));
#line 1269 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_container_get_type (), GtkContainer), (guint) 0);
#line 1270 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_scrolled_window_set_shadow_type (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow), GTK_SHADOW_NONE);
#line 1272 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = self->priv->viewport;
#line 1272 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_container_get_type (), GtkContainer), (guint) 0);
#line 1273 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = self->priv->viewport;
#line 1273 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_viewport_set_shadow_type (_tmp8_, GTK_SHADOW_NONE);
#line 1275 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = self->priv->viewport;
#line 1275 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = self->priv->layout;
#line 1275 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget));
#line 1279 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = self->priv->layout;
#line 1279 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = gtk_scrolled_window_get_hadjustment (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow));
#line 1279 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp13_ = gtk_scrolled_window_get_vadjustment (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow));
#line 1279 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_layout_set_adjustments (_tmp11_, _tmp12_, _tmp13_);
#line 1281 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp14_ = self->priv->viewport;
#line 1281 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_widget_get_type (), GtkWidget));
#line 1284 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp15_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1284 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp16_ = _tmp15_;
#line 1284 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp16_, "items-hidden", (GCallback) _checkerboard_page_on_items_hidden_view_collection_items_hidden, self, 0);
#line 1284 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp16_);
#line 1285 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp17_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1285 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp18_ = _tmp17_;
#line 1285 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, TYPE_DATA_COLLECTION, DataCollection), "contents-altered", (GCallback) _checkerboard_page_on_contents_altered_data_collection_contents_altered, self, 0);
#line 1285 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp18_);
#line 1286 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp19_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1286 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp20_ = _tmp19_;
#line 1286 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp20_, "items-state-changed", (GCallback) _checkerboard_page_on_items_state_changed_view_collection_items_state_changed, self, 0);
#line 1286 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp20_);
#line 1287 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp21_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1287 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp22_ = _tmp21_;
#line 1287 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (_tmp22_, "items-visibility-changed", (GCallback) _checkerboard_page_on_items_visibility_changed_view_collection_items_visibility_changed, self, 0);
#line 1287 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp22_);
#line 1290 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_scrolled_window_set_policy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
#line 1261 "/home/jens/Source/shotwell/src/Page.vala"
	return self;
#line 8785 "Page.c"
}


void checkerboard_page_init_item_context_menu (CheckerboardPage* self, const gchar* path) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1293 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1293 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (path != NULL);
#line 1294 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = path;
#line 1294 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1294 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->priv->item_context_menu_path);
#line 1294 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->item_context_menu_path = _tmp1_;
#line 8804 "Page.c"
}


void checkerboard_page_init_page_context_menu (CheckerboardPage* self, const gchar* path) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1297 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1297 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (path != NULL);
#line 1298 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = path;
#line 1298 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1298 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->priv->page_context_menu_path);
#line 1298 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->page_context_menu_path = _tmp1_;
#line 8823 "Page.c"
}


GtkMenu* checkerboard_page_get_context_menu (CheckerboardPage* self) {
	GtkMenu* result = NULL;
	GtkMenu* _tmp0_ = NULL;
	ViewCollection* _tmp1_;
	ViewCollection* _tmp2_;
	gint _tmp3_;
	gboolean _tmp4_;
#line 1301 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_CHECKERBOARD_PAGE (self), NULL);
#line 1303 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1303 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_;
#line 1303 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = view_collection_get_selected_count (_tmp2_);
#line 1303 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = _tmp3_ != 0;
#line 1303 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp2_);
#line 1303 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_) {
#line 8848 "Page.c"
		GtkMenu* _tmp5_;
#line 1303 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = checkerboard_page_get_item_context_menu (self);
#line 1303 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp0_);
#line 1303 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = _tmp5_;
#line 8856 "Page.c"
	} else {
		GtkMenu* _tmp6_;
#line 1304 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = page_get_page_context_menu (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1304 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp0_);
#line 1304 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = _tmp6_;
#line 8865 "Page.c"
	}
#line 1303 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp0_;
#line 1303 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 8871 "Page.c"
}


static GtkMenu* checkerboard_page_real_get_item_context_menu (CheckerboardPage* self) {
	GtkMenu* result = NULL;
	GtkMenu* _tmp0_;
	GtkMenu* _tmp8_;
	GtkMenu* _tmp9_;
#line 1309 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->item_context_menu;
#line 1309 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ == NULL) {
#line 8884 "Page.c"
		GMenuModel* model = NULL;
		GtkBuilder* _tmp1_;
		const gchar* _tmp2_;
		GObject* _tmp3_;
		GMenuModel* _tmp4_;
		GMenuModel* _tmp5_;
		GtkMenu* _tmp6_;
		GtkMenu* _tmp7_;
#line 1310 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page)->builder;
#line 1310 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = self->priv->item_context_menu_path;
#line 1310 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = gtk_builder_get_object (_tmp1_, _tmp2_);
#line 1310 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, g_menu_model_get_type ()) ? ((GMenuModel*) _tmp3_) : NULL);
#line 1310 "/home/jens/Source/shotwell/src/Page.vala"
		model = _tmp4_;
#line 1312 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = model;
#line 1312 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = (GtkMenu*) gtk_menu_new_from_model (_tmp5_);
#line 1312 "/home/jens/Source/shotwell/src/Page.vala"
		g_object_ref_sink (_tmp6_);
#line 1312 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (self->priv->item_context_menu);
#line 1312 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->item_context_menu = _tmp6_;
#line 1313 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = self->priv->item_context_menu;
#line 1313 "/home/jens/Source/shotwell/src/Page.vala"
		gtk_menu_attach_to_widget (_tmp7_, G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), NULL);
#line 1309 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (model);
#line 8919 "Page.c"
	}
#line 1316 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = self->priv->item_context_menu;
#line 1316 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = _g_object_ref0 (_tmp8_);
#line 1316 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp9_;
#line 1316 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 8929 "Page.c"
}


GtkMenu* checkerboard_page_get_item_context_menu (CheckerboardPage* self) {
#line 1308 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_CHECKERBOARD_PAGE (self), NULL);
#line 1308 "/home/jens/Source/shotwell/src/Page.vala"
	return CHECKERBOARD_PAGE_GET_CLASS (self)->get_item_context_menu (self);
#line 8938 "Page.c"
}


static GtkMenu* checkerboard_page_real_get_page_context_menu (Page* base) {
	CheckerboardPage * self;
	GtkMenu* result = NULL;
	const gchar* _tmp0_;
	GtkMenu* _tmp1_;
	GtkMenu* _tmp9_;
	GtkMenu* _tmp10_;
#line 1320 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_CHECKERBOARD_PAGE, CheckerboardPage);
#line 1321 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->page_context_menu_path;
#line 1321 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ == NULL) {
#line 1322 "/home/jens/Source/shotwell/src/Page.vala"
		result = NULL;
#line 1322 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 8959 "Page.c"
	}
#line 1324 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->page_context_menu;
#line 1324 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_ == NULL) {
#line 8965 "Page.c"
		GMenuModel* model = NULL;
		GtkBuilder* _tmp2_;
		const gchar* _tmp3_;
		GObject* _tmp4_;
		GMenuModel* _tmp5_;
		GMenuModel* _tmp6_;
		GtkMenu* _tmp7_;
		GtkMenu* _tmp8_;
#line 1325 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page)->builder;
#line 1325 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = self->priv->page_context_menu_path;
#line 1325 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = gtk_builder_get_object (_tmp2_, _tmp3_);
#line 1325 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, g_menu_model_get_type ()) ? ((GMenuModel*) _tmp4_) : NULL);
#line 1325 "/home/jens/Source/shotwell/src/Page.vala"
		model = _tmp5_;
#line 1327 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = model;
#line 1327 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = (GtkMenu*) gtk_menu_new_from_model (_tmp6_);
#line 1327 "/home/jens/Source/shotwell/src/Page.vala"
		g_object_ref_sink (_tmp7_);
#line 1327 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (self->priv->page_context_menu);
#line 1327 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->page_context_menu = _tmp7_;
#line 1328 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = self->priv->page_context_menu;
#line 1328 "/home/jens/Source/shotwell/src/Page.vala"
		gtk_menu_attach_to_widget (_tmp8_, G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), NULL);
#line 1324 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (model);
#line 9000 "Page.c"
	}
#line 1331 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = self->priv->page_context_menu;
#line 1331 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = _g_object_ref0 (_tmp9_);
#line 1331 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp10_;
#line 1331 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 9010 "Page.c"
}


static gboolean checkerboard_page_real_on_context_keypress (Page* base) {
	CheckerboardPage * self;
	gboolean result = FALSE;
	GtkMenu* _tmp0_;
	GtkMenu* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
#line 1334 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_CHECKERBOARD_PAGE, CheckerboardPage);
#line 1335 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = checkerboard_page_get_context_menu (self);
#line 1335 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_;
#line 1335 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = page_popup_context_menu (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), _tmp1_, NULL);
#line 1335 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_;
#line 1335 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (_tmp1_);
#line 1335 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp3_;
#line 1335 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 9037 "Page.c"
}


static gchar* checkerboard_page_real_get_view_empty_message (CheckerboardPage* self) {
	gchar* result = NULL;
	gchar* _tmp0_;
#line 1339 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = g_strdup (_ ("No photos/videos"));
#line 1339 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp0_;
#line 1339 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 9050 "Page.c"
}


gchar* checkerboard_page_get_view_empty_message (CheckerboardPage* self) {
#line 1338 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_CHECKERBOARD_PAGE (self), NULL);
#line 1338 "/home/jens/Source/shotwell/src/Page.vala"
	return CHECKERBOARD_PAGE_GET_CLASS (self)->get_view_empty_message (self);
#line 9059 "Page.c"
}


static gchar* checkerboard_page_real_get_filter_no_match_message (CheckerboardPage* self) {
	gchar* result = NULL;
	gchar* _tmp0_;
#line 1343 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = g_strdup (_ ("No photos/videos found which match the current filter"));
#line 1343 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp0_;
#line 1343 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 9072 "Page.c"
}


gchar* checkerboard_page_get_filter_no_match_message (CheckerboardPage* self) {
#line 1342 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_CHECKERBOARD_PAGE (self), NULL);
#line 1342 "/home/jens/Source/shotwell/src/Page.vala"
	return CHECKERBOARD_PAGE_GET_CLASS (self)->get_filter_no_match_message (self);
#line 9081 "Page.c"
}


static void checkerboard_page_real_on_item_activated (CheckerboardPage* self, CheckerboardItem* item, CheckerboardPageActivator activator, CheckerboardPageKeyboardModifiers* modifiers) {
#line 1346 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_ITEM (item));
#line 1346 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (modifiers != NULL);
#line 9090 "Page.c"
}


void checkerboard_page_on_item_activated (CheckerboardPage* self, CheckerboardItem* item, CheckerboardPageActivator activator, CheckerboardPageKeyboardModifiers* modifiers) {
#line 1346 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1346 "/home/jens/Source/shotwell/src/Page.vala"
	CHECKERBOARD_PAGE_GET_CLASS (self)->on_item_activated (self, item, activator, modifiers);
#line 9099 "Page.c"
}


CheckerboardLayout* checkerboard_page_get_checkerboard_layout (CheckerboardPage* self) {
	CheckerboardLayout* result = NULL;
	CheckerboardLayout* _tmp0_;
	CheckerboardLayout* _tmp1_;
#line 1350 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_CHECKERBOARD_PAGE (self), NULL);
#line 1351 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->layout;
#line 1351 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1351 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 1351 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 9117 "Page.c"
}


static SearchViewFilter* checkerboard_page_real_get_search_view_filter (CheckerboardPage* self) {
#line 1355 "/home/jens/Source/shotwell/src/Page.vala"
	g_critical ("Type `%s' does not implement abstract method `checkerboard_page_get_search_view_filter'", g_type_name (G_TYPE_FROM_INSTANCE (self)));
#line 1355 "/home/jens/Source/shotwell/src/Page.vala"
	return NULL;
#line 9126 "Page.c"
}


SearchViewFilter* checkerboard_page_get_search_view_filter (CheckerboardPage* self) {
#line 1355 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_CHECKERBOARD_PAGE (self), NULL);
#line 1355 "/home/jens/Source/shotwell/src/Page.vala"
	return CHECKERBOARD_PAGE_GET_CLASS (self)->get_search_view_filter (self);
#line 9135 "Page.c"
}


static CoreViewTracker* checkerboard_page_real_get_view_tracker (CheckerboardPage* self) {
	CoreViewTracker* result = NULL;
#line 1358 "/home/jens/Source/shotwell/src/Page.vala"
	result = NULL;
#line 1358 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 9145 "Page.c"
}


CoreViewTracker* checkerboard_page_get_view_tracker (CheckerboardPage* self) {
#line 1357 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_CHECKERBOARD_PAGE (self), NULL);
#line 1357 "/home/jens/Source/shotwell/src/Page.vala"
	return CHECKERBOARD_PAGE_GET_CLASS (self)->get_view_tracker (self);
#line 9154 "Page.c"
}


static void _checkerboard_page_on_view_filter_refresh_view_filter_refresh (ViewFilter* _sender, gpointer self) {
#line 1363 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_page_on_view_filter_refresh ((CheckerboardPage*) self);
#line 9161 "Page.c"
}


static void checkerboard_page_real_switching_from (Page* base) {
	CheckerboardPage * self;
	CheckerboardLayout* _tmp0_;
	SearchViewFilter* _tmp1_;
	SearchViewFilter* _tmp2_;
	guint _tmp3_;
	ViewCollection* _tmp4_;
	ViewCollection* _tmp5_;
#line 1361 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_CHECKERBOARD_PAGE, CheckerboardPage);
#line 1362 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->layout;
#line 1362 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_layout_set_in_view (_tmp0_, FALSE);
#line 1363 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = checkerboard_page_get_search_view_filter (self);
#line 1363 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_;
#line 1363 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_parse_name ("refresh", TYPE_VIEW_FILTER, &_tmp3_, NULL, FALSE);
#line 1363 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_VIEW_FILTER, ViewFilter), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _checkerboard_page_on_view_filter_refresh_view_filter_refresh, self);
#line 1363 "/home/jens/Source/shotwell/src/Page.vala"
	_view_filter_unref0 (_tmp2_);
#line 1366 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1366 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _tmp4_;
#line 1366 "/home/jens/Source/shotwell/src/Page.vala"
	view_collection_unselect_all (_tmp5_);
#line 1366 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp5_);
#line 1368 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_CLASS (checkerboard_page_parent_class)->switching_from (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 9199 "Page.c"
}


static void checkerboard_page_real_switched_to (Page* base) {
	CheckerboardPage * self;
	CheckerboardLayout* _tmp0_;
	SearchViewFilter* _tmp1_;
	SearchViewFilter* _tmp2_;
	ViewCollection* _tmp3_;
	ViewCollection* _tmp4_;
	gint _tmp5_;
	gboolean _tmp6_;
#line 1371 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_CHECKERBOARD_PAGE, CheckerboardPage);
#line 1372 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->layout;
#line 1372 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_layout_set_in_view (_tmp0_, TRUE);
#line 1373 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = checkerboard_page_get_search_view_filter (self);
#line 1373 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_;
#line 1373 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_VIEW_FILTER, ViewFilter), "refresh", (GCallback) _checkerboard_page_on_view_filter_refresh_view_filter_refresh, self, 0);
#line 1373 "/home/jens/Source/shotwell/src/Page.vala"
	_view_filter_unref0 (_tmp2_);
#line 1374 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_page_on_view_filter_refresh (self);
#line 1376 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1376 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = _tmp3_;
#line 1376 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = view_collection_get_selected_count (_tmp4_);
#line 1376 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = _tmp5_ > 0;
#line 1376 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp4_);
#line 1376 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp6_) {
#line 9240 "Page.c"
		CheckerboardItem* item = NULL;
		ViewCollection* _tmp7_;
		ViewCollection* _tmp8_;
		DataView* _tmp9_;
		CheckerboardItem* _tmp10_;
		GtkAdjustment* vadj = NULL;
		GtkAdjustment* _tmp11_;
		GtkAdjustment* _tmp12_;
		gboolean _tmp13_ = FALSE;
		GtkAdjustment* _tmp14_;
		CheckerboardItem* _tmp15_;
		GdkRectangle _tmp16_;
		gint _tmp17_;
		AdjustmentRelation _tmp18_;
#line 1377 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1377 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = _tmp7_;
#line 1377 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = view_collection_get_selected_at (_tmp8_, 0);
#line 1377 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_CHECKERBOARD_ITEM, CheckerboardItem);
#line 1377 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp8_);
#line 1377 "/home/jens/Source/shotwell/src/Page.vala"
		item = _tmp10_;
#line 1380 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = gtk_scrolled_window_get_vadjustment (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow));
#line 1380 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp12_ = _g_object_ref0 (_tmp11_);
#line 1380 "/home/jens/Source/shotwell/src/Page.vala"
		vadj = _tmp12_;
#line 1381 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp14_ = vadj;
#line 1381 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp15_ = item;
#line 1381 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp16_ = _tmp15_->allocation;
#line 1381 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp17_ = _tmp16_.y;
#line 1381 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp18_ = get_adjustment_relation (_tmp14_, _tmp17_);
#line 1381 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp18_ == ADJUSTMENT_RELATION_IN_RANGE) {
#line 9285 "Page.c"
			GtkAdjustment* _tmp19_;
			CheckerboardItem* _tmp20_;
			GdkRectangle _tmp21_;
			gint _tmp22_;
			CheckerboardItem* _tmp23_;
			GdkRectangle _tmp24_;
			gint _tmp25_;
			AdjustmentRelation _tmp26_;
#line 1382 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp19_ = vadj;
#line 1382 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp20_ = item;
#line 1382 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp21_ = _tmp20_->allocation;
#line 1382 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp22_ = _tmp21_.y;
#line 1382 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp23_ = item;
#line 1382 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp24_ = _tmp23_->allocation;
#line 1382 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp25_ = _tmp24_.height;
#line 1382 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp26_ = get_adjustment_relation (_tmp19_, _tmp22_ + _tmp25_);
#line 1382 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp13_ = _tmp26_ == ADJUSTMENT_RELATION_IN_RANGE;
#line 9312 "Page.c"
		} else {
#line 1381 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp13_ = FALSE;
#line 9316 "Page.c"
		}
#line 1381 "/home/jens/Source/shotwell/src/Page.vala"
		if (!_tmp13_) {
#line 9320 "Page.c"
			gint top = 0;
			CheckerboardItem* _tmp27_;
			GdkRectangle _tmp28_;
			gint _tmp29_;
			GtkAdjustment* _tmp30_;
			gdouble _tmp31_;
			GtkAdjustment* _tmp45_;
			gint _tmp46_;
#line 1385 "/home/jens/Source/shotwell/src/Page.vala"
			top = 0;
#line 1386 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp27_ = item;
#line 1386 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp28_ = _tmp27_->allocation;
#line 1386 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp29_ = _tmp28_.y;
#line 1386 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp30_ = vadj;
#line 1386 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp31_ = gtk_adjustment_get_value (_tmp30_);
#line 1386 "/home/jens/Source/shotwell/src/Page.vala"
			if (((gdouble) _tmp29_) < _tmp31_) {
#line 9343 "Page.c"
				CheckerboardItem* _tmp32_;
				GdkRectangle _tmp33_;
				gint _tmp34_;
				gint _tmp35_;
#line 1387 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp32_ = item;
#line 1387 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp33_ = _tmp32_->allocation;
#line 1387 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp34_ = _tmp33_.y;
#line 1387 "/home/jens/Source/shotwell/src/Page.vala"
				top = _tmp34_;
#line 1388 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp35_ = top;
#line 1388 "/home/jens/Source/shotwell/src/Page.vala"
				top = _tmp35_ - (CHECKERBOARD_LAYOUT_ROW_GUTTER_PADDING / 2);
#line 9360 "Page.c"
			} else {
				CheckerboardItem* _tmp36_;
				GdkRectangle _tmp37_;
				gint _tmp38_;
				CheckerboardItem* _tmp39_;
				GdkRectangle _tmp40_;
				gint _tmp41_;
				GtkAdjustment* _tmp42_;
				gdouble _tmp43_;
				gint _tmp44_;
#line 1390 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp36_ = item;
#line 1390 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp37_ = _tmp36_->allocation;
#line 1390 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp38_ = _tmp37_.y;
#line 1390 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp39_ = item;
#line 1390 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp40_ = _tmp39_->allocation;
#line 1390 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp41_ = _tmp40_.height;
#line 1390 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp42_ = vadj;
#line 1390 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp43_ = gtk_adjustment_get_page_size (_tmp42_);
#line 1390 "/home/jens/Source/shotwell/src/Page.vala"
				top = (_tmp38_ + _tmp41_) - ((gint) _tmp43_);
#line 1391 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp44_ = top;
#line 1391 "/home/jens/Source/shotwell/src/Page.vala"
				top = _tmp44_ + (CHECKERBOARD_LAYOUT_ROW_GUTTER_PADDING / 2);
#line 9393 "Page.c"
			}
#line 1394 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp45_ = vadj;
#line 1394 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp46_ = top;
#line 1394 "/home/jens/Source/shotwell/src/Page.vala"
			gtk_adjustment_set_value (_tmp45_, (gdouble) _tmp46_);
#line 9401 "Page.c"
		}
#line 1376 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (vadj);
#line 1376 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (item);
#line 9407 "Page.c"
	}
#line 1399 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_CLASS (checkerboard_page_parent_class)->switched_to (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 9411 "Page.c"
}


static void checkerboard_page_on_view_filter_refresh (CheckerboardPage* self) {
#line 1402 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1403 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_page_update_view_filter_message (self);
#line 9420 "Page.c"
}


static void checkerboard_page_on_contents_altered (CheckerboardPage* self, GeeIterable* added, GeeIterable* removed) {
#line 1406 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1406 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail ((added == NULL) || GEE_IS_ITERABLE (added));
#line 1406 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail ((removed == NULL) || GEE_IS_ITERABLE (removed));
#line 1408 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_page_update_view_filter_message (self);
#line 9433 "Page.c"
}


static void checkerboard_page_on_items_state_changed (CheckerboardPage* self, GeeIterable* changed) {
#line 1411 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1411 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GEE_IS_ITERABLE (changed));
#line 1412 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_page_update_view_filter_message (self);
#line 9444 "Page.c"
}


static void checkerboard_page_on_items_visibility_changed (CheckerboardPage* self, GeeCollection* changed) {
#line 1415 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1415 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GEE_IS_COLLECTION (changed));
#line 1416 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_page_update_view_filter_message (self);
#line 9455 "Page.c"
}


static void checkerboard_page_update_view_filter_message (CheckerboardPage* self) {
	gboolean _tmp0_ = FALSE;
	ViewCollection* _tmp1_;
	ViewCollection* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
#line 1419 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1420 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1420 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_;
#line 1420 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = view_collection_are_items_filtered_out (_tmp2_);
#line 1420 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = _tmp3_;
#line 1420 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp2_);
#line 1420 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_) {
#line 9479 "Page.c"
		ViewCollection* _tmp5_;
		ViewCollection* _tmp6_;
		gint _tmp7_;
#line 1420 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1420 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = _tmp5_;
#line 1420 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TYPE_DATA_COLLECTION, DataCollection));
#line 1420 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = _tmp7_ == 0;
#line 1420 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp6_);
#line 9493 "Page.c"
	} else {
#line 1420 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = FALSE;
#line 9497 "Page.c"
	}
#line 1420 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_) {
#line 9501 "Page.c"
		gchar* _tmp8_;
		gchar* _tmp9_;
#line 1421 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = checkerboard_page_get_filter_no_match_message (self);
#line 1421 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = _tmp8_;
#line 1421 "/home/jens/Source/shotwell/src/Page.vala"
		checkerboard_page_set_page_message (self, _tmp9_);
#line 1421 "/home/jens/Source/shotwell/src/Page.vala"
		_g_free0 (_tmp9_);
#line 9512 "Page.c"
	} else {
		ViewCollection* _tmp10_;
		ViewCollection* _tmp11_;
		gint _tmp12_;
		gboolean _tmp13_;
#line 1422 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1422 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = _tmp10_;
#line 1422 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp12_ = data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_DATA_COLLECTION, DataCollection));
#line 1422 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp13_ = _tmp12_ == 0;
#line 1422 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp11_);
#line 1422 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp13_) {
#line 9530 "Page.c"
			gchar* _tmp14_;
			gchar* _tmp15_;
#line 1423 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp14_ = checkerboard_page_get_view_empty_message (self);
#line 1423 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp15_ = _tmp14_;
#line 1423 "/home/jens/Source/shotwell/src/Page.vala"
			checkerboard_page_set_page_message (self, _tmp15_);
#line 1423 "/home/jens/Source/shotwell/src/Page.vala"
			_g_free0 (_tmp15_);
#line 9541 "Page.c"
		} else {
#line 1425 "/home/jens/Source/shotwell/src/Page.vala"
			checkerboard_page_unset_page_message (self);
#line 9545 "Page.c"
		}
	}
}


void checkerboard_page_set_page_message (CheckerboardPage* self, const gchar* message) {
	CheckerboardLayout* _tmp0_;
	const gchar* _tmp1_;
	gboolean _tmp2_;
#line 1429 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1429 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (message != NULL);
#line 1430 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->layout;
#line 1430 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = message;
#line 1430 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_layout_set_message (_tmp0_, _tmp1_);
#line 1431 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = page_is_in_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1431 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_) {
#line 9569 "Page.c"
		CheckerboardLayout* _tmp3_;
#line 1432 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = self->priv->layout;
#line 1432 "/home/jens/Source/shotwell/src/Page.vala"
		gtk_widget_queue_draw (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget));
#line 9575 "Page.c"
	}
}


void checkerboard_page_unset_page_message (CheckerboardPage* self) {
	CheckerboardLayout* _tmp0_;
	gboolean _tmp1_;
#line 1435 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1436 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->layout;
#line 1436 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_layout_unset_message (_tmp0_);
#line 1437 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_is_in_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1437 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_) {
#line 9593 "Page.c"
		CheckerboardLayout* _tmp2_;
#line 1438 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = self->priv->layout;
#line 1438 "/home/jens/Source/shotwell/src/Page.vala"
		gtk_widget_queue_draw (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 9599 "Page.c"
	}
}


static void checkerboard_page_real_set_page_name (Page* base, const gchar* name) {
	CheckerboardPage * self;
	const gchar* _tmp0_;
	CheckerboardLayout* _tmp1_;
	const gchar* _tmp2_;
#line 1441 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_CHECKERBOARD_PAGE, CheckerboardPage);
#line 1441 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (name != NULL);
#line 1442 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = name;
#line 1442 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_CLASS (checkerboard_page_parent_class)->set_page_name (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), _tmp0_);
#line 1444 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->layout;
#line 1444 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = name;
#line 1444 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_layout_set_name (_tmp1_, _tmp2_);
#line 9623 "Page.c"
}


CheckerboardItem* checkerboard_page_get_item_at_pixel (CheckerboardPage* self, gdouble x, gdouble y) {
	CheckerboardItem* result = NULL;
	CheckerboardLayout* _tmp0_;
	gdouble _tmp1_;
	gdouble _tmp2_;
	CheckerboardItem* _tmp3_;
#line 1447 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_CHECKERBOARD_PAGE (self), NULL);
#line 1448 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->layout;
#line 1448 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = x;
#line 1448 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = y;
#line 1448 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = checkerboard_layout_get_item_at_pixel (_tmp0_, _tmp1_, _tmp2_);
#line 1448 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp3_;
#line 1448 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 9647 "Page.c"
}


static void checkerboard_page_on_items_hidden (CheckerboardPage* self, GeeIterable* hidden) {
#line 1451 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1451 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GEE_IS_ITERABLE (hidden));
#line 9656 "Page.c"
	{
		GeeIterator* _view_it = NULL;
		GeeIterable* _tmp0_;
		GeeIterator* _tmp1_;
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = hidden;
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = gee_iterable_iterator (_tmp0_);
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
		_view_it = _tmp1_;
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
		while (TRUE) {
#line 9669 "Page.c"
			GeeIterator* _tmp2_;
			gboolean _tmp3_;
			DataView* view = NULL;
			GeeIterator* _tmp4_;
			gpointer _tmp5_;
			CheckerboardItem* item = NULL;
			DataView* _tmp6_;
			CheckerboardItem* _tmp7_;
			CheckerboardItem* _tmp8_;
			CheckerboardItem* _tmp9_;
			CheckerboardItem* _tmp10_;
			CheckerboardItem* _tmp11_;
			CheckerboardItem* _tmp12_;
			CheckerboardItem* _tmp13_;
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp2_ = _view_it;
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
			if (!_tmp3_) {
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 9692 "Page.c"
			}
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp4_ = _view_it;
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
			view = (DataView*) _tmp5_;
#line 1453 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp6_ = view;
#line 1453 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp7_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TYPE_CHECKERBOARD_ITEM, CheckerboardItem));
#line 1453 "/home/jens/Source/shotwell/src/Page.vala"
			item = _tmp7_;
#line 1455 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp8_ = self->anchor;
#line 1455 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp9_ = item;
#line 1455 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp8_ == _tmp9_) {
#line 1456 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (self->anchor);
#line 1456 "/home/jens/Source/shotwell/src/Page.vala"
				self->anchor = NULL;
#line 9716 "Page.c"
			}
#line 1458 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp10_ = self->cursor;
#line 1458 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp11_ = item;
#line 1458 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp10_ == _tmp11_) {
#line 1459 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (self->cursor);
#line 1459 "/home/jens/Source/shotwell/src/Page.vala"
				self->cursor = NULL;
#line 9728 "Page.c"
			}
#line 1461 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp12_ = self->priv->highlighted;
#line 1461 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp13_ = item;
#line 1461 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp12_ == _tmp13_) {
#line 1462 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (self->priv->highlighted);
#line 1462 "/home/jens/Source/shotwell/src/Page.vala"
				self->priv->highlighted = NULL;
#line 9740 "Page.c"
			}
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (item);
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (view);
#line 9746 "Page.c"
		}
#line 1452 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_view_it);
#line 9750 "Page.c"
	}
}


static gboolean checkerboard_page_real_key_press_event (GtkWidget* base, GdkEventKey* event) {
	CheckerboardPage * self;
	gboolean result = FALSE;
	gboolean handled = FALSE;
	guint state = 0U;
	GdkEventKey* _tmp0_;
	GdkModifierType _tmp1_;
	GdkEventKey* _tmp2_;
	guint _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	GQuark _tmp7_ = 0U;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label0 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label1 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label2 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label3 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label4 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label5 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label6 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label7 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label8 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label9 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label10 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label11 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label12 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label13 = 0;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp6_label14 = 0;
#line 9797 "Page.c"
	gboolean _tmp45_;
	gboolean _tmp46_ = FALSE;
#line 1466 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_CHECKERBOARD_PAGE, CheckerboardPage);
#line 1466 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1467 "/home/jens/Source/shotwell/src/Page.vala"
	handled = TRUE;
#line 1470 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = event;
#line 1470 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_->state;
#line 1470 "/home/jens/Source/shotwell/src/Page.vala"
	state = (guint) (_tmp1_ & GDK_SHIFT_MASK);
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = event;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_->keyval;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = gdk_keyval_name (_tmp3_);
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _tmp4_;
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = (NULL == _tmp5_) ? 0 : g_quark_from_string (_tmp5_);
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
	if ((_tmp7_ == ((0 != _tmp6_label0) ? _tmp6_label0 : (_tmp6_label0 = g_quark_from_static_string ("Up")))) || (_tmp7_ == ((0 != _tmp6_label1) ? _tmp6_label1 : (_tmp6_label1 = g_quark_from_static_string ("KP_Up"))))) {
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 9826 "Page.c"
			default:
			{
				guint _tmp8_;
#line 1475 "/home/jens/Source/shotwell/src/Page.vala"
				checkerboard_page_move_cursor (self, COMPASS_POINT_NORTH);
#line 1476 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp8_ = state;
#line 1476 "/home/jens/Source/shotwell/src/Page.vala"
				checkerboard_page_select_anchor_to_cursor (self, _tmp8_);
#line 1477 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 9838 "Page.c"
			}
		}
	} else if ((_tmp7_ == ((0 != _tmp6_label2) ? _tmp6_label2 : (_tmp6_label2 = g_quark_from_static_string ("Down")))) || (_tmp7_ == ((0 != _tmp6_label3) ? _tmp6_label3 : (_tmp6_label3 = g_quark_from_static_string ("KP_Down"))))) {
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 9844 "Page.c"
			default:
			{
				guint _tmp9_;
#line 1481 "/home/jens/Source/shotwell/src/Page.vala"
				checkerboard_page_move_cursor (self, COMPASS_POINT_SOUTH);
#line 1482 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp9_ = state;
#line 1482 "/home/jens/Source/shotwell/src/Page.vala"
				checkerboard_page_select_anchor_to_cursor (self, _tmp9_);
#line 1483 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 9856 "Page.c"
			}
		}
	} else if ((_tmp7_ == ((0 != _tmp6_label4) ? _tmp6_label4 : (_tmp6_label4 = g_quark_from_static_string ("Left")))) || (_tmp7_ == ((0 != _tmp6_label5) ? _tmp6_label5 : (_tmp6_label5 = g_quark_from_static_string ("KP_Left"))))) {
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 9862 "Page.c"
			default:
			{
				guint _tmp10_;
#line 1487 "/home/jens/Source/shotwell/src/Page.vala"
				checkerboard_page_move_cursor (self, COMPASS_POINT_WEST);
#line 1488 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp10_ = state;
#line 1488 "/home/jens/Source/shotwell/src/Page.vala"
				checkerboard_page_select_anchor_to_cursor (self, _tmp10_);
#line 1489 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 9874 "Page.c"
			}
		}
	} else if ((_tmp7_ == ((0 != _tmp6_label6) ? _tmp6_label6 : (_tmp6_label6 = g_quark_from_static_string ("Right")))) || (_tmp7_ == ((0 != _tmp6_label7) ? _tmp6_label7 : (_tmp6_label7 = g_quark_from_static_string ("KP_Right"))))) {
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 9880 "Page.c"
			default:
			{
				guint _tmp11_;
#line 1493 "/home/jens/Source/shotwell/src/Page.vala"
				checkerboard_page_move_cursor (self, COMPASS_POINT_EAST);
#line 1494 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp11_ = state;
#line 1494 "/home/jens/Source/shotwell/src/Page.vala"
				checkerboard_page_select_anchor_to_cursor (self, _tmp11_);
#line 1495 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 9892 "Page.c"
			}
		}
	} else if ((_tmp7_ == ((0 != _tmp6_label8) ? _tmp6_label8 : (_tmp6_label8 = g_quark_from_static_string ("Home")))) || (_tmp7_ == ((0 != _tmp6_label9) ? _tmp6_label9 : (_tmp6_label9 = g_quark_from_static_string ("KP_Home"))))) {
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 9898 "Page.c"
			default:
			{
				CheckerboardItem* first = NULL;
				ViewCollection* _tmp12_;
				ViewCollection* _tmp13_;
				DataView* _tmp14_;
				CheckerboardItem* _tmp15_;
				CheckerboardItem* _tmp16_;
				guint _tmp18_;
#line 1499 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp12_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1499 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp13_ = _tmp12_;
#line 1499 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp14_ = view_collection_get_first (_tmp13_);
#line 1499 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp15_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_CHECKERBOARD_ITEM, CheckerboardItem);
#line 1499 "/home/jens/Source/shotwell/src/Page.vala"
				_data_collection_unref0 (_tmp13_);
#line 1499 "/home/jens/Source/shotwell/src/Page.vala"
				first = _tmp15_;
#line 1500 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp16_ = first;
#line 1500 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp16_ != NULL) {
#line 9924 "Page.c"
					CheckerboardItem* _tmp17_;
#line 1501 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp17_ = first;
#line 1501 "/home/jens/Source/shotwell/src/Page.vala"
					checkerboard_page_cursor_to_item (self, _tmp17_);
#line 9930 "Page.c"
				}
#line 1502 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp18_ = state;
#line 1502 "/home/jens/Source/shotwell/src/Page.vala"
				checkerboard_page_select_anchor_to_cursor (self, _tmp18_);
#line 1503 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (first);
#line 1503 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 9940 "Page.c"
			}
		}
	} else if ((_tmp7_ == ((0 != _tmp6_label10) ? _tmp6_label10 : (_tmp6_label10 = g_quark_from_static_string ("End")))) || (_tmp7_ == ((0 != _tmp6_label11) ? _tmp6_label11 : (_tmp6_label11 = g_quark_from_static_string ("KP_End"))))) {
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 9946 "Page.c"
			default:
			{
				CheckerboardItem* last = NULL;
				ViewCollection* _tmp19_;
				ViewCollection* _tmp20_;
				DataView* _tmp21_;
				CheckerboardItem* _tmp22_;
				CheckerboardItem* _tmp23_;
				guint _tmp25_;
#line 1507 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp19_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1507 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp20_ = _tmp19_;
#line 1507 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp21_ = view_collection_get_last (_tmp20_);
#line 1507 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp22_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, TYPE_CHECKERBOARD_ITEM, CheckerboardItem);
#line 1507 "/home/jens/Source/shotwell/src/Page.vala"
				_data_collection_unref0 (_tmp20_);
#line 1507 "/home/jens/Source/shotwell/src/Page.vala"
				last = _tmp22_;
#line 1508 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp23_ = last;
#line 1508 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp23_ != NULL) {
#line 9972 "Page.c"
					CheckerboardItem* _tmp24_;
#line 1509 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp24_ = last;
#line 1509 "/home/jens/Source/shotwell/src/Page.vala"
					checkerboard_page_cursor_to_item (self, _tmp24_);
#line 9978 "Page.c"
				}
#line 1510 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp25_ = state;
#line 1510 "/home/jens/Source/shotwell/src/Page.vala"
				checkerboard_page_select_anchor_to_cursor (self, _tmp25_);
#line 1511 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (last);
#line 1511 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 9988 "Page.c"
			}
		}
	} else if ((_tmp7_ == ((0 != _tmp6_label12) ? _tmp6_label12 : (_tmp6_label12 = g_quark_from_static_string ("Return")))) || (_tmp7_ == ((0 != _tmp6_label13) ? _tmp6_label13 : (_tmp6_label13 = g_quark_from_static_string ("KP_Enter"))))) {
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 9994 "Page.c"
			default:
			{
				ViewCollection* _tmp26_;
				ViewCollection* _tmp27_;
				gint _tmp28_;
				gboolean _tmp29_;
#line 1515 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp26_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1515 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp27_ = _tmp26_;
#line 1515 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp28_ = view_collection_get_selected_count (_tmp27_);
#line 1515 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp29_ = _tmp28_ == 1;
#line 1515 "/home/jens/Source/shotwell/src/Page.vala"
				_data_collection_unref0 (_tmp27_);
#line 1515 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp29_) {
#line 10013 "Page.c"
					ViewCollection* _tmp30_;
					ViewCollection* _tmp31_;
					DataView* _tmp32_;
					CheckerboardItem* _tmp33_;
					CheckerboardPageKeyboardModifiers _tmp34_ = {0};
#line 1516 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp30_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1516 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp31_ = _tmp30_;
#line 1516 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp32_ = view_collection_get_selected_at (_tmp31_, 0);
#line 1516 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp33_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, TYPE_CHECKERBOARD_ITEM, CheckerboardItem);
#line 1516 "/home/jens/Source/shotwell/src/Page.vala"
					checkerboard_page_keyboard_modifiers_init (&_tmp34_, G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1516 "/home/jens/Source/shotwell/src/Page.vala"
					checkerboard_page_on_item_activated (self, _tmp33_, CHECKERBOARD_PAGE_ACTIVATOR_KEYBOARD, &_tmp34_);
#line 1516 "/home/jens/Source/shotwell/src/Page.vala"
					_g_object_unref0 (_tmp33_);
#line 1516 "/home/jens/Source/shotwell/src/Page.vala"
					_data_collection_unref0 (_tmp31_);
#line 10035 "Page.c"
				} else {
#line 1519 "/home/jens/Source/shotwell/src/Page.vala"
					handled = FALSE;
#line 10039 "Page.c"
				}
#line 1520 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 10043 "Page.c"
			}
		}
	} else if (_tmp7_ == ((0 != _tmp6_label14) ? _tmp6_label14 : (_tmp6_label14 = g_quark_from_static_string ("space")))) {
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 10049 "Page.c"
			default:
			{
				Marker* marker = NULL;
				ViewCollection* _tmp35_;
				ViewCollection* _tmp36_;
				CheckerboardLayout* _tmp37_;
				CheckerboardItem* _tmp38_;
				CheckerboardItem* _tmp39_;
				Marker* _tmp40_;
				Marker* _tmp41_;
				ViewCollection* _tmp42_;
				ViewCollection* _tmp43_;
				Marker* _tmp44_;
#line 1523 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp35_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1523 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp36_ = _tmp35_;
#line 1523 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp37_ = self->priv->layout;
#line 1523 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp38_ = checkerboard_layout_get_cursor (_tmp37_);
#line 1523 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp39_ = _tmp38_;
#line 1523 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp40_ = data_collection_mark (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, TYPE_DATA_COLLECTION, DataCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, TYPE_DATA_OBJECT, DataObject));
#line 1523 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp41_ = _tmp40_;
#line 1523 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (_tmp39_);
#line 1523 "/home/jens/Source/shotwell/src/Page.vala"
				_data_collection_unref0 (_tmp36_);
#line 1523 "/home/jens/Source/shotwell/src/Page.vala"
				marker = _tmp41_;
#line 1524 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp42_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1524 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp43_ = _tmp42_;
#line 1524 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp44_ = marker;
#line 1524 "/home/jens/Source/shotwell/src/Page.vala"
				view_collection_toggle_marked (_tmp43_, _tmp44_);
#line 1524 "/home/jens/Source/shotwell/src/Page.vala"
				_data_collection_unref0 (_tmp43_);
#line 1525 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (marker);
#line 1525 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 10097 "Page.c"
			}
		}
	} else {
#line 1472 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 10103 "Page.c"
			default:
			{
#line 1528 "/home/jens/Source/shotwell/src/Page.vala"
				handled = FALSE;
#line 1529 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 10110 "Page.c"
			}
		}
	}
#line 1532 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp45_ = handled;
#line 1532 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp45_) {
#line 1533 "/home/jens/Source/shotwell/src/Page.vala"
		result = TRUE;
#line 1533 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 10122 "Page.c"
	}
#line 1535 "/home/jens/Source/shotwell/src/Page.vala"
	if (GTK_WIDGET_CLASS (checkerboard_page_parent_class)->key_press_event != NULL) {
#line 10126 "Page.c"
		GdkEventKey* _tmp47_;
		gboolean _tmp48_;
#line 1535 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp47_ = event;
#line 1535 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp48_ = GTK_WIDGET_CLASS (checkerboard_page_parent_class)->key_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), gtk_widget_get_type (), GtkWidget), _tmp47_);
#line 1535 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp46_ = _tmp48_;
#line 10135 "Page.c"
	} else {
#line 1535 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp46_ = TRUE;
#line 10139 "Page.c"
	}
#line 1535 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp46_;
#line 1535 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 10145 "Page.c"
}


static gboolean checkerboard_page_real_on_left_click (Page* base, GdkEventButton* event) {
	CheckerboardPage * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GdkEventButton* _tmp1_;
	GdkEventType _tmp2_;
	guint state = 0U;
	GdkEventButton* _tmp5_;
	GdkModifierType _tmp6_;
	CheckerboardItem* item = NULL;
	GdkEventButton* _tmp7_;
	gdouble _tmp8_;
	GdkEventButton* _tmp9_;
	gdouble _tmp10_;
	CheckerboardItem* _tmp11_;
	CheckerboardItem* _tmp12_;
	ViewCollection* _tmp106_;
	ViewCollection* _tmp107_;
	gint _tmp108_;
	gboolean _tmp109_;
#line 1538 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_CHECKERBOARD_PAGE, CheckerboardPage);
#line 1538 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1540 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = event;
#line 1540 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_->type;
#line 1540 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_ != GDK_BUTTON_PRESS) {
#line 10179 "Page.c"
		GdkEventButton* _tmp3_;
		GdkEventType _tmp4_;
#line 1540 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = event;
#line 1540 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = _tmp3_->type;
#line 1540 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = _tmp4_ != GDK_2BUTTON_PRESS;
#line 10188 "Page.c"
	} else {
#line 1540 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = FALSE;
#line 10192 "Page.c"
	}
#line 1540 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_) {
#line 1541 "/home/jens/Source/shotwell/src/Page.vala"
		result = FALSE;
#line 1541 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 10200 "Page.c"
	}
#line 1544 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = event;
#line 1544 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = _tmp5_->state;
#line 1544 "/home/jens/Source/shotwell/src/Page.vala"
	state = (guint) (_tmp6_ & (GDK_CONTROL_MASK | GDK_SHIFT_MASK));
#line 1548 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = event;
#line 1548 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = _tmp7_->x;
#line 1548 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = event;
#line 1548 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = _tmp9_->y;
#line 1548 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = checkerboard_page_get_item_at_pixel (self, _tmp8_, _tmp10_);
#line 1548 "/home/jens/Source/shotwell/src/Page.vala"
	item = _tmp11_;
#line 1549 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = item;
#line 1549 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp12_ != NULL) {
#line 10224 "Page.c"
		CheckerboardLayout* _tmp13_;
		CheckerboardItem* _tmp14_;
		GdkEventButton* _tmp15_;
		gdouble _tmp16_;
		GdkEventButton* _tmp17_;
		gdouble _tmp18_;
		GdkEventButton* _tmp19_;
		GdkModifierType _tmp20_;
		gboolean _tmp21_;
		guint _tmp22_;
		CheckerboardLayout* _tmp80_;
		CheckerboardItem* _tmp81_;
#line 1552 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp13_ = self->priv->layout;
#line 1552 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp14_ = item;
#line 1552 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp15_ = event;
#line 1552 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp16_ = _tmp15_->x;
#line 1552 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp17_ = event;
#line 1552 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp18_ = _tmp17_->y;
#line 1552 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp19_ = event;
#line 1552 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp20_ = _tmp19_->state;
#line 1552 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp21_ = checkerboard_layout_handle_left_click (_tmp13_, _tmp14_, _tmp16_, _tmp18_, _tmp20_);
#line 1552 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp21_) {
#line 1553 "/home/jens/Source/shotwell/src/Page.vala"
			result = TRUE;
#line 1553 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (item);
#line 1553 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 10263 "Page.c"
		}
#line 1555 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp22_ = state;
#line 1555 "/home/jens/Source/shotwell/src/Page.vala"
		switch (_tmp22_) {
#line 1555 "/home/jens/Source/shotwell/src/Page.vala"
			case GDK_CONTROL_MASK:
#line 10271 "Page.c"
			{
				Marker* marker = NULL;
				ViewCollection* _tmp23_;
				ViewCollection* _tmp24_;
				CheckerboardItem* _tmp25_;
				Marker* _tmp26_;
				Marker* _tmp27_;
				ViewCollection* _tmp28_;
				ViewCollection* _tmp29_;
				Marker* _tmp30_;
				CheckerboardItem* _tmp31_;
				gboolean _tmp32_;
#line 1559 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp23_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1559 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp24_ = _tmp23_;
#line 1559 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp25_ = item;
#line 1559 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp26_ = data_collection_mark (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, TYPE_DATA_COLLECTION, DataCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, TYPE_DATA_OBJECT, DataObject));
#line 1559 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp27_ = _tmp26_;
#line 1559 "/home/jens/Source/shotwell/src/Page.vala"
				_data_collection_unref0 (_tmp24_);
#line 1559 "/home/jens/Source/shotwell/src/Page.vala"
				marker = _tmp27_;
#line 1560 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp28_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1560 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp29_ = _tmp28_;
#line 1560 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp30_ = marker;
#line 1560 "/home/jens/Source/shotwell/src/Page.vala"
				view_collection_toggle_marked (_tmp29_, _tmp30_);
#line 1560 "/home/jens/Source/shotwell/src/Page.vala"
				_data_collection_unref0 (_tmp29_);
#line 1562 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp31_ = item;
#line 1562 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp32_ = data_view_is_selected (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, TYPE_DATA_VIEW, DataView));
#line 1562 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp32_) {
#line 10314 "Page.c"
					CheckerboardItem* _tmp33_;
					CheckerboardItem* _tmp34_;
					CheckerboardItem* _tmp35_;
					CheckerboardItem* _tmp36_;
#line 1563 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp33_ = item;
#line 1563 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp34_ = _g_object_ref0 (_tmp33_);
#line 1563 "/home/jens/Source/shotwell/src/Page.vala"
					_g_object_unref0 (self->anchor);
#line 1563 "/home/jens/Source/shotwell/src/Page.vala"
					self->anchor = _tmp34_;
#line 1564 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp35_ = item;
#line 1564 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp36_ = _g_object_ref0 (_tmp35_);
#line 1564 "/home/jens/Source/shotwell/src/Page.vala"
					_g_object_unref0 (self->cursor);
#line 1564 "/home/jens/Source/shotwell/src/Page.vala"
					self->cursor = _tmp36_;
#line 10335 "Page.c"
				}
#line 1566 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (marker);
#line 1566 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 10341 "Page.c"
			}
#line 1555 "/home/jens/Source/shotwell/src/Page.vala"
			case GDK_SHIFT_MASK:
#line 10345 "Page.c"
			{
				ViewCollection* _tmp37_;
				ViewCollection* _tmp38_;
				CheckerboardItem* _tmp39_;
				CheckerboardItem* _tmp42_;
				CheckerboardItem* _tmp43_;
				CheckerboardItem* _tmp44_;
				CheckerboardItem* _tmp45_;
#line 1569 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp37_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1569 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp38_ = _tmp37_;
#line 1569 "/home/jens/Source/shotwell/src/Page.vala"
				view_collection_unselect_all (_tmp38_);
#line 1569 "/home/jens/Source/shotwell/src/Page.vala"
				_data_collection_unref0 (_tmp38_);
#line 1571 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp39_ = self->anchor;
#line 1571 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp39_ == NULL) {
#line 10366 "Page.c"
					CheckerboardItem* _tmp40_;
					CheckerboardItem* _tmp41_;
#line 1572 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp40_ = item;
#line 1572 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp41_ = _g_object_ref0 (_tmp40_);
#line 1572 "/home/jens/Source/shotwell/src/Page.vala"
					_g_object_unref0 (self->anchor);
#line 1572 "/home/jens/Source/shotwell/src/Page.vala"
					self->anchor = _tmp41_;
#line 10377 "Page.c"
				}
#line 1574 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp42_ = self->anchor;
#line 1574 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp43_ = item;
#line 1574 "/home/jens/Source/shotwell/src/Page.vala"
				checkerboard_page_select_between_items (self, _tmp42_, _tmp43_);
#line 1576 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp44_ = item;
#line 1576 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp45_ = _g_object_ref0 (_tmp44_);
#line 1576 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (self->cursor);
#line 1576 "/home/jens/Source/shotwell/src/Page.vala"
				self->cursor = _tmp45_;
#line 1577 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 10395 "Page.c"
			}
#line 1555 "/home/jens/Source/shotwell/src/Page.vala"
			case GDK_CONTROL_MASK | GDK_SHIFT_MASK:
#line 10399 "Page.c"
			{
				CheckerboardItem* _tmp46_;
				CheckerboardItem* _tmp49_;
				CheckerboardItem* _tmp50_;
				CheckerboardItem* _tmp51_;
				CheckerboardItem* _tmp52_;
#line 1584 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp46_ = self->anchor;
#line 1584 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp46_ == NULL) {
#line 10410 "Page.c"
					CheckerboardItem* _tmp47_;
					CheckerboardItem* _tmp48_;
#line 1585 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp47_ = item;
#line 1585 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp48_ = _g_object_ref0 (_tmp47_);
#line 1585 "/home/jens/Source/shotwell/src/Page.vala"
					_g_object_unref0 (self->anchor);
#line 1585 "/home/jens/Source/shotwell/src/Page.vala"
					self->anchor = _tmp48_;
#line 10421 "Page.c"
				}
#line 1587 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp49_ = self->anchor;
#line 1587 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp50_ = item;
#line 1587 "/home/jens/Source/shotwell/src/Page.vala"
				checkerboard_page_select_between_items (self, _tmp49_, _tmp50_);
#line 1589 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp51_ = item;
#line 1589 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp52_ = _g_object_ref0 (_tmp51_);
#line 1589 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (self->cursor);
#line 1589 "/home/jens/Source/shotwell/src/Page.vala"
				self->cursor = _tmp52_;
#line 1590 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 10439 "Page.c"
			}
			default:
			{
				GdkEventButton* _tmp53_;
				GdkEventType _tmp54_;
				CheckerboardItem* _tmp76_;
				CheckerboardItem* _tmp77_;
				CheckerboardItem* _tmp78_;
				CheckerboardItem* _tmp79_;
#line 1593 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp53_ = event;
#line 1593 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp54_ = _tmp53_->type;
#line 1593 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp54_ == GDK_2BUTTON_PRESS) {
#line 10455 "Page.c"
					CheckerboardItem* _tmp55_;
					CheckerboardItem* _tmp56_;
#line 1594 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp55_ = item;
#line 1594 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp56_ = _g_object_ref0 (_tmp55_);
#line 1594 "/home/jens/Source/shotwell/src/Page.vala"
					_g_object_unref0 (self->priv->activated_item);
#line 1594 "/home/jens/Source/shotwell/src/Page.vala"
					self->priv->activated_item = _tmp56_;
#line 10466 "Page.c"
				} else {
					CheckerboardItem* _tmp57_;
					gboolean _tmp58_;
#line 1600 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp57_ = item;
#line 1600 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp58_ = data_view_is_selected (G_TYPE_CHECK_INSTANCE_CAST (_tmp57_, TYPE_DATA_VIEW, DataView));
#line 1600 "/home/jens/Source/shotwell/src/Page.vala"
					if (!_tmp58_) {
#line 10476 "Page.c"
						Marker* all = NULL;
						ViewCollection* _tmp59_;
						ViewCollection* _tmp60_;
						Marker* _tmp61_;
						Marker* _tmp62_;
						Marker* _tmp63_;
						ViewCollection* _tmp64_;
						ViewCollection* _tmp65_;
						GeeList* _tmp66_;
						GeeList* _tmp67_;
						ViewCollection* _tmp68_;
						ViewCollection* _tmp69_;
						Marker* _tmp70_;
						ViewCollection* _tmp71_;
						ViewCollection* _tmp72_;
						CheckerboardItem* _tmp73_;
						Marker* _tmp74_;
						Marker* _tmp75_;
#line 1601 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp59_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1601 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp60_ = _tmp59_;
#line 1601 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp61_ = data_collection_start_marking (G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, TYPE_DATA_COLLECTION, DataCollection));
#line 1601 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp62_ = _tmp61_;
#line 1601 "/home/jens/Source/shotwell/src/Page.vala"
						_data_collection_unref0 (_tmp60_);
#line 1601 "/home/jens/Source/shotwell/src/Page.vala"
						all = _tmp62_;
#line 1602 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp63_ = all;
#line 1602 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp64_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1602 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp65_ = _tmp64_;
#line 1602 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp66_ = view_collection_get_selected (_tmp65_);
#line 1602 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp67_ = _tmp66_;
#line 1602 "/home/jens/Source/shotwell/src/Page.vala"
						marker_mark_many (_tmp63_, G_TYPE_CHECK_INSTANCE_CAST (_tmp67_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1602 "/home/jens/Source/shotwell/src/Page.vala"
						_g_object_unref0 (_tmp67_);
#line 1602 "/home/jens/Source/shotwell/src/Page.vala"
						_data_collection_unref0 (_tmp65_);
#line 1604 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp68_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1604 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp69_ = _tmp68_;
#line 1604 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp70_ = all;
#line 1604 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp71_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1604 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp72_ = _tmp71_;
#line 1604 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp73_ = item;
#line 1604 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp74_ = data_collection_mark (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, TYPE_DATA_COLLECTION, DataCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp73_, TYPE_DATA_OBJECT, DataObject));
#line 1604 "/home/jens/Source/shotwell/src/Page.vala"
						_tmp75_ = _tmp74_;
#line 1604 "/home/jens/Source/shotwell/src/Page.vala"
						view_collection_unselect_and_select_marked (_tmp69_, _tmp70_, _tmp75_);
#line 1604 "/home/jens/Source/shotwell/src/Page.vala"
						_g_object_unref0 (_tmp75_);
#line 1604 "/home/jens/Source/shotwell/src/Page.vala"
						_data_collection_unref0 (_tmp72_);
#line 1604 "/home/jens/Source/shotwell/src/Page.vala"
						_data_collection_unref0 (_tmp69_);
#line 1600 "/home/jens/Source/shotwell/src/Page.vala"
						_g_object_unref0 (all);
#line 10549 "Page.c"
					}
				}
#line 1608 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp76_ = item;
#line 1608 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp77_ = _g_object_ref0 (_tmp76_);
#line 1608 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (self->anchor);
#line 1608 "/home/jens/Source/shotwell/src/Page.vala"
				self->anchor = _tmp77_;
#line 1609 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp78_ = item;
#line 1609 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp79_ = _g_object_ref0 (_tmp78_);
#line 1609 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (self->cursor);
#line 1609 "/home/jens/Source/shotwell/src/Page.vala"
				self->cursor = _tmp79_;
#line 1610 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 10570 "Page.c"
			}
		}
#line 1612 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp80_ = self->priv->layout;
#line 1612 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp81_ = item;
#line 1612 "/home/jens/Source/shotwell/src/Page.vala"
		checkerboard_layout_set_cursor (_tmp80_, _tmp81_);
#line 10579 "Page.c"
	} else {
		guint _tmp82_;
		GeeArrayList* _tmp85_;
		CheckerboardLayout* _tmp101_;
		GdkEventButton* _tmp102_;
		gdouble _tmp103_;
		GdkEventButton* _tmp104_;
		gdouble _tmp105_;
#line 1616 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp82_ = state;
#line 1616 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp82_ != ((guint) GDK_CONTROL_MASK)) {
#line 10592 "Page.c"
			ViewCollection* _tmp83_;
			ViewCollection* _tmp84_;
#line 1617 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp83_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1617 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp84_ = _tmp83_;
#line 1617 "/home/jens/Source/shotwell/src/Page.vala"
			view_collection_unselect_all (_tmp84_);
#line 1617 "/home/jens/Source/shotwell/src/Page.vala"
			_data_collection_unref0 (_tmp84_);
#line 10603 "Page.c"
		}
#line 1620 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp85_ = gee_array_list_new (TYPE_CHECKERBOARD_ITEM, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 1620 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (self->priv->previously_selected);
#line 1620 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->previously_selected = _tmp85_;
#line 10611 "Page.c"
		{
			GeeList* _view_list = NULL;
			ViewCollection* _tmp86_;
			ViewCollection* _tmp87_;
			GeeList* _tmp88_;
			GeeList* _tmp89_;
			gint _view_size = 0;
			GeeList* _tmp90_;
			gint _tmp91_;
			gint _tmp92_;
			gint _view_index = 0;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp86_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp87_ = _tmp86_;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp88_ = view_collection_get_selected (_tmp87_);
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp89_ = _tmp88_;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
			_data_collection_unref0 (_tmp87_);
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
			_view_list = _tmp89_;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp90_ = _view_list;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp91_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp90_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp92_ = _tmp91_;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
			_view_size = _tmp92_;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
			_view_index = -1;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
			while (TRUE) {
#line 10647 "Page.c"
				gint _tmp93_;
				gint _tmp94_;
				gint _tmp95_;
				DataView* view = NULL;
				GeeList* _tmp96_;
				gint _tmp97_;
				gpointer _tmp98_;
				GeeArrayList* _tmp99_;
				DataView* _tmp100_;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp93_ = _view_index;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
				_view_index = _tmp93_ + 1;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp94_ = _view_index;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp95_ = _view_size;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
				if (!(_tmp94_ < _tmp95_)) {
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
					break;
#line 10669 "Page.c"
				}
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp96_ = _view_list;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp97_ = _view_index;
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp98_ = gee_list_get (_tmp96_, _tmp97_);
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
				view = (DataView*) _tmp98_;
#line 1622 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp99_ = self->priv->previously_selected;
#line 1622 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp100_ = view;
#line 1622 "/home/jens/Source/shotwell/src/Page.vala"
				gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp99_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp100_, TYPE_CHECKERBOARD_ITEM, CheckerboardItem));
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (view);
#line 10687 "Page.c"
			}
#line 1621 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (_view_list);
#line 10691 "Page.c"
		}
#line 1624 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp101_ = self->priv->layout;
#line 1624 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp102_ = event;
#line 1624 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp103_ = _tmp102_->x;
#line 1624 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp104_ = event;
#line 1624 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp105_ = _tmp104_->y;
#line 1624 "/home/jens/Source/shotwell/src/Page.vala"
		checkerboard_layout_set_drag_select_origin (_tmp101_, (gint) _tmp103_, (gint) _tmp105_);
#line 1626 "/home/jens/Source/shotwell/src/Page.vala"
		result = TRUE;
#line 1626 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (item);
#line 1626 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 10711 "Page.c"
	}
#line 1632 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp106_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1632 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp107_ = _tmp106_;
#line 1632 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp108_ = view_collection_get_selected_count (_tmp107_);
#line 1632 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp109_ = _tmp108_ == 0;
#line 1632 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp107_);
#line 1632 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp109_;
#line 1632 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (item);
#line 1632 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 10729 "Page.c"
}


static gboolean checkerboard_page_real_on_left_released (Page* base, GdkEventButton* event) {
	CheckerboardPage * self;
	gboolean result = FALSE;
	CheckerboardLayout* _tmp0_;
	gboolean _tmp1_;
	GdkEventButton* _tmp5_;
	GdkModifierType _tmp6_;
	CheckerboardItem* _tmp7_;
	CheckerboardItem* item = NULL;
	GdkEventButton* _tmp10_;
	gdouble _tmp11_;
	GdkEventButton* _tmp12_;
	gdouble _tmp13_;
	CheckerboardItem* _tmp14_;
	CheckerboardItem* _tmp15_;
	CheckerboardItem* _tmp16_;
	CheckerboardItem* _tmp17_;
#line 1635 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_CHECKERBOARD_PAGE, CheckerboardPage);
#line 1635 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1636 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->previously_selected);
#line 1636 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->previously_selected = NULL;
#line 1639 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->layout;
#line 1639 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = checkerboard_layout_is_drag_select_active (_tmp0_);
#line 1639 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_) {
#line 10764 "Page.c"
		CheckerboardLayout* _tmp2_;
		CheckerboardItem* _tmp3_;
		CheckerboardItem* _tmp4_;
#line 1640 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = self->priv->layout;
#line 1640 "/home/jens/Source/shotwell/src/Page.vala"
		checkerboard_layout_clear_drag_select (_tmp2_);
#line 1641 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = self->cursor;
#line 1641 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = _g_object_ref0 (_tmp3_);
#line 1641 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (self->anchor);
#line 1641 "/home/jens/Source/shotwell/src/Page.vala"
		self->anchor = _tmp4_;
#line 1643 "/home/jens/Source/shotwell/src/Page.vala"
		result = TRUE;
#line 1643 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 10784 "Page.c"
	}
#line 1647 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = event;
#line 1647 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = _tmp5_->state;
#line 1647 "/home/jens/Source/shotwell/src/Page.vala"
	if ((_tmp6_ & (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) != 0) {
#line 1648 "/home/jens/Source/shotwell/src/Page.vala"
		result = FALSE;
#line 1648 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 10796 "Page.c"
	}
#line 1651 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = self->priv->activated_item;
#line 1651 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp7_ != NULL) {
#line 10802 "Page.c"
		CheckerboardItem* _tmp8_;
		CheckerboardPageKeyboardModifiers _tmp9_ = {0};
#line 1652 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = self->priv->activated_item;
#line 1652 "/home/jens/Source/shotwell/src/Page.vala"
		checkerboard_page_keyboard_modifiers_init (&_tmp9_, G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1652 "/home/jens/Source/shotwell/src/Page.vala"
		checkerboard_page_on_item_activated (self, _tmp8_, CHECKERBOARD_PAGE_ACTIVATOR_MOUSE, &_tmp9_);
#line 1653 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (self->priv->activated_item);
#line 1653 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->activated_item = NULL;
#line 1655 "/home/jens/Source/shotwell/src/Page.vala"
		result = TRUE;
#line 1655 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 10819 "Page.c"
	}
#line 1658 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = event;
#line 1658 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = _tmp10_->x;
#line 1658 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = event;
#line 1658 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp13_ = _tmp12_->y;
#line 1658 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp14_ = checkerboard_page_get_item_at_pixel (self, _tmp11_, _tmp13_);
#line 1658 "/home/jens/Source/shotwell/src/Page.vala"
	item = _tmp14_;
#line 1659 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp15_ = item;
#line 1659 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp15_ == NULL) {
#line 1661 "/home/jens/Source/shotwell/src/Page.vala"
		result = TRUE;
#line 1661 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (item);
#line 1661 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 10843 "Page.c"
	}
#line 1664 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp16_ = self->cursor;
#line 1664 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp17_ = item;
#line 1664 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp16_ != _tmp17_) {
#line 10851 "Page.c"
		ViewCollection* _tmp18_;
		ViewCollection* _tmp19_;
#line 1667 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp18_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1667 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp19_ = _tmp18_;
#line 1667 "/home/jens/Source/shotwell/src/Page.vala"
		view_collection_unselect_all (_tmp19_);
#line 1667 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp19_);
#line 10862 "Page.c"
	} else {
		CheckerboardItem* _tmp20_;
		gboolean _tmp21_;
#line 1673 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp20_ = item;
#line 1673 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp21_ = data_view_is_selected (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, TYPE_DATA_VIEW, DataView));
#line 1673 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp21_) {
#line 10872 "Page.c"
			ViewCollection* _tmp22_;
			ViewCollection* _tmp23_;
			CheckerboardItem* _tmp24_;
#line 1674 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp22_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1674 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp23_ = _tmp22_;
#line 1674 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp24_ = item;
#line 1674 "/home/jens/Source/shotwell/src/Page.vala"
			view_collection_unselect_all_but (_tmp23_, G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, TYPE_DATA_VIEW, DataView));
#line 1674 "/home/jens/Source/shotwell/src/Page.vala"
			_data_collection_unref0 (_tmp23_);
#line 10886 "Page.c"
		}
	}
#line 1677 "/home/jens/Source/shotwell/src/Page.vala"
	result = TRUE;
#line 1677 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (item);
#line 1677 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 10895 "Page.c"
}


static gboolean checkerboard_page_real_on_right_click (Page* base, GdkEventButton* event) {
	CheckerboardPage * self;
	gboolean result = FALSE;
	GdkEventButton* _tmp0_;
	GdkEventType _tmp1_;
	CheckerboardItem* item = NULL;
	GdkEventButton* _tmp2_;
	gdouble _tmp3_;
	GdkEventButton* _tmp4_;
	gdouble _tmp5_;
	CheckerboardItem* _tmp6_;
	CheckerboardItem* _tmp7_;
	GtkMenu* context_menu = NULL;
	GtkMenu* _tmp39_;
	GtkMenu* _tmp40_;
	GdkEventButton* _tmp41_;
	gboolean _tmp42_;
#line 1680 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_CHECKERBOARD_PAGE, CheckerboardPage);
#line 1680 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1682 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = event;
#line 1682 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_->type;
#line 1682 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_ != GDK_BUTTON_PRESS) {
#line 1683 "/home/jens/Source/shotwell/src/Page.vala"
		result = FALSE;
#line 1683 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 10930 "Page.c"
	}
#line 1686 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = event;
#line 1686 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_->x;
#line 1686 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = event;
#line 1686 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _tmp4_->y;
#line 1686 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = checkerboard_page_get_item_at_pixel (self, _tmp3_, _tmp5_);
#line 1686 "/home/jens/Source/shotwell/src/Page.vala"
	item = _tmp6_;
#line 1687 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = item;
#line 1687 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp7_ != NULL) {
#line 10948 "Page.c"
		GdkEventButton* _tmp8_;
		GdkModifierType _tmp9_;
#line 1689 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = event;
#line 1689 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = _tmp8_->state;
#line 1689 "/home/jens/Source/shotwell/src/Page.vala"
		switch (_tmp9_ & (GDK_CONTROL_MASK | GDK_SHIFT_MASK)) {
#line 1689 "/home/jens/Source/shotwell/src/Page.vala"
			case GDK_CONTROL_MASK:
#line 10959 "Page.c"
			{
				Marker* marker = NULL;
				ViewCollection* _tmp10_;
				ViewCollection* _tmp11_;
				CheckerboardItem* _tmp12_;
				Marker* _tmp13_;
				Marker* _tmp14_;
				ViewCollection* _tmp15_;
				ViewCollection* _tmp16_;
				Marker* _tmp17_;
#line 1692 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp10_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1692 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp11_ = _tmp10_;
#line 1692 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp12_ = item;
#line 1692 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp13_ = data_collection_mark (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_DATA_COLLECTION, DataCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TYPE_DATA_OBJECT, DataObject));
#line 1692 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp14_ = _tmp13_;
#line 1692 "/home/jens/Source/shotwell/src/Page.vala"
				_data_collection_unref0 (_tmp11_);
#line 1692 "/home/jens/Source/shotwell/src/Page.vala"
				marker = _tmp14_;
#line 1693 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp15_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1693 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp16_ = _tmp15_;
#line 1693 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp17_ = marker;
#line 1693 "/home/jens/Source/shotwell/src/Page.vala"
				view_collection_toggle_marked (_tmp16_, _tmp17_);
#line 1693 "/home/jens/Source/shotwell/src/Page.vala"
				_data_collection_unref0 (_tmp16_);
#line 1694 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (marker);
#line 1694 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 10998 "Page.c"
			}
#line 1689 "/home/jens/Source/shotwell/src/Page.vala"
			case GDK_SHIFT_MASK:
#line 11002 "Page.c"
			{
#line 1698 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 11006 "Page.c"
			}
#line 1689 "/home/jens/Source/shotwell/src/Page.vala"
			case GDK_CONTROL_MASK | GDK_SHIFT_MASK:
#line 11010 "Page.c"
			{
#line 1702 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 11014 "Page.c"
			}
			default:
			{
				CheckerboardItem* _tmp18_;
				gboolean _tmp19_;
#line 1707 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp18_ = item;
#line 1707 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp19_ = data_view_is_selected (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, TYPE_DATA_VIEW, DataView));
#line 1707 "/home/jens/Source/shotwell/src/Page.vala"
				if (!_tmp19_) {
#line 11026 "Page.c"
					Marker* all = NULL;
					ViewCollection* _tmp20_;
					ViewCollection* _tmp21_;
					Marker* _tmp22_;
					Marker* _tmp23_;
					Marker* _tmp24_;
					ViewCollection* _tmp25_;
					ViewCollection* _tmp26_;
					GeeList* _tmp27_;
					GeeList* _tmp28_;
					ViewCollection* _tmp29_;
					ViewCollection* _tmp30_;
					Marker* _tmp31_;
					ViewCollection* _tmp32_;
					ViewCollection* _tmp33_;
					CheckerboardItem* _tmp34_;
					Marker* _tmp35_;
					Marker* _tmp36_;
#line 1708 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp20_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1708 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp21_ = _tmp20_;
#line 1708 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp22_ = data_collection_start_marking (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, TYPE_DATA_COLLECTION, DataCollection));
#line 1708 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp23_ = _tmp22_;
#line 1708 "/home/jens/Source/shotwell/src/Page.vala"
					_data_collection_unref0 (_tmp21_);
#line 1708 "/home/jens/Source/shotwell/src/Page.vala"
					all = _tmp23_;
#line 1709 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp24_ = all;
#line 1709 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp25_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1709 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp26_ = _tmp25_;
#line 1709 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp27_ = view_collection_get_selected (_tmp26_);
#line 1709 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp28_ = _tmp27_;
#line 1709 "/home/jens/Source/shotwell/src/Page.vala"
					marker_mark_many (_tmp24_, G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1709 "/home/jens/Source/shotwell/src/Page.vala"
					_g_object_unref0 (_tmp28_);
#line 1709 "/home/jens/Source/shotwell/src/Page.vala"
					_data_collection_unref0 (_tmp26_);
#line 1711 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp29_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1711 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp30_ = _tmp29_;
#line 1711 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp31_ = all;
#line 1711 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp32_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1711 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp33_ = _tmp32_;
#line 1711 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp34_ = item;
#line 1711 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp35_ = data_collection_mark (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, TYPE_DATA_COLLECTION, DataCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, TYPE_DATA_OBJECT, DataObject));
#line 1711 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp36_ = _tmp35_;
#line 1711 "/home/jens/Source/shotwell/src/Page.vala"
					view_collection_unselect_and_select_marked (_tmp30_, _tmp31_, _tmp36_);
#line 1711 "/home/jens/Source/shotwell/src/Page.vala"
					_g_object_unref0 (_tmp36_);
#line 1711 "/home/jens/Source/shotwell/src/Page.vala"
					_data_collection_unref0 (_tmp33_);
#line 1711 "/home/jens/Source/shotwell/src/Page.vala"
					_data_collection_unref0 (_tmp30_);
#line 1707 "/home/jens/Source/shotwell/src/Page.vala"
					_g_object_unref0 (all);
#line 11099 "Page.c"
				}
#line 1713 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 11103 "Page.c"
			}
		}
	} else {
		ViewCollection* _tmp37_;
		ViewCollection* _tmp38_;
#line 1717 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp37_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1717 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp38_ = _tmp37_;
#line 1717 "/home/jens/Source/shotwell/src/Page.vala"
		view_collection_unselect_all (_tmp38_);
#line 1717 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp38_);
#line 11117 "Page.c"
	}
#line 1720 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp39_ = checkerboard_page_get_context_menu (self);
#line 1720 "/home/jens/Source/shotwell/src/Page.vala"
	context_menu = _tmp39_;
#line 1721 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp40_ = context_menu;
#line 1721 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp41_ = event;
#line 1721 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp42_ = page_popup_context_menu (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), _tmp40_, _tmp41_);
#line 1721 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp42_;
#line 1721 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (context_menu);
#line 1721 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (item);
#line 1721 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 11137 "Page.c"
}


static gboolean checkerboard_page_real_on_mouse_over (CheckerboardPage* self, CheckerboardItem* item, gint x, gint y, GdkModifierType mask) {
	gboolean result = FALSE;
	CheckerboardItem* _tmp0_;
	CheckerboardItem* _tmp6_;
	CheckerboardItem* _tmp7_;
	CheckerboardItem* _tmp8_;
	CheckerboardItem* _tmp10_;
	CheckerboardItem* _tmp11_;
	CheckerboardItem* _tmp12_;
	CheckerboardItem* _tmp13_;
#line 1724 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail ((item == NULL) || IS_CHECKERBOARD_ITEM (item), FALSE);
#line 1725 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = item;
#line 1725 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ != NULL) {
#line 11157 "Page.c"
		CheckerboardLayout* _tmp1_;
		CheckerboardItem* _tmp2_;
		gint _tmp3_;
		gint _tmp4_;
		GdkModifierType _tmp5_;
#line 1726 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = self->priv->layout;
#line 1726 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = item;
#line 1726 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = x;
#line 1726 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = y;
#line 1726 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = mask;
#line 1726 "/home/jens/Source/shotwell/src/Page.vala"
		checkerboard_layout_handle_mouse_motion (_tmp1_, _tmp2_, _tmp3_, _tmp4_, _tmp5_);
#line 11175 "Page.c"
	}
#line 1730 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = item;
#line 1730 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = self->priv->highlighted;
#line 1730 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp6_ == _tmp7_) {
#line 1731 "/home/jens/Source/shotwell/src/Page.vala"
		result = TRUE;
#line 1731 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 11187 "Page.c"
	}
#line 1734 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = self->priv->highlighted;
#line 1734 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp8_ != NULL) {
#line 11193 "Page.c"
		CheckerboardItem* _tmp9_;
#line 1735 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = self->priv->highlighted;
#line 1735 "/home/jens/Source/shotwell/src/Page.vala"
		checkerboard_item_unbrighten (_tmp9_);
#line 1736 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (self->priv->highlighted);
#line 1736 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->highlighted = NULL;
#line 11203 "Page.c"
	}
#line 1740 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = item;
#line 1740 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp10_ == NULL) {
#line 1741 "/home/jens/Source/shotwell/src/Page.vala"
		result = TRUE;
#line 1741 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 11213 "Page.c"
	}
#line 1744 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = item;
#line 1744 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_item_brighten (_tmp11_);
#line 1745 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = item;
#line 1745 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp13_ = _g_object_ref0 (_tmp12_);
#line 1745 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->highlighted);
#line 1745 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->highlighted = _tmp13_;
#line 1747 "/home/jens/Source/shotwell/src/Page.vala"
	result = TRUE;
#line 1747 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 11231 "Page.c"
}


gboolean checkerboard_page_on_mouse_over (CheckerboardPage* self, CheckerboardItem* item, gint x, gint y, GdkModifierType mask) {
#line 1724 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_CHECKERBOARD_PAGE (self), FALSE);
#line 1724 "/home/jens/Source/shotwell/src/Page.vala"
	return CHECKERBOARD_PAGE_GET_CLASS (self)->on_mouse_over (self, item, x, y, mask);
#line 11240 "Page.c"
}


static gboolean _checkerboard_page_selection_autoscroll_gsource_func (gpointer self) {
	gboolean result;
	result = checkerboard_page_selection_autoscroll ((CheckerboardPage*) self);
#line 1767 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 11249 "Page.c"
}


static gboolean checkerboard_page_real_on_motion (Page* base, GdkEventMotion* event, gint x, gint y, GdkModifierType mask) {
	CheckerboardPage * self;
	gboolean result = FALSE;
	gint _tmp0_;
	gint _tmp1_;
	CheckerboardItem* _tmp2_;
	CheckerboardItem* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	GdkModifierType _tmp6_;
	gboolean _tmp7_;
	gboolean _tmp8_;
	CheckerboardLayout* _tmp9_;
	gboolean _tmp10_;
	CheckerboardLayout* _tmp11_;
	gint _tmp12_;
	gint _tmp13_;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_;
#line 1750 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_CHECKERBOARD_PAGE, CheckerboardPage);
#line 1750 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1752 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = x;
#line 1752 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = y;
#line 1752 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = checkerboard_page_get_item_at_pixel (self, (gdouble) _tmp0_, (gdouble) _tmp1_);
#line 1752 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_;
#line 1752 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = x;
#line 1752 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = y;
#line 1752 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = mask;
#line 1752 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = checkerboard_page_on_mouse_over (self, _tmp3_, _tmp4_, _tmp5_, _tmp6_);
#line 1752 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = !_tmp7_;
#line 1752 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (_tmp3_);
#line 1752 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp8_) {
#line 1753 "/home/jens/Source/shotwell/src/Page.vala"
		result = FALSE;
#line 1753 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 11302 "Page.c"
	}
#line 1756 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = self->priv->layout;
#line 1756 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = checkerboard_layout_is_drag_select_active (_tmp9_);
#line 1756 "/home/jens/Source/shotwell/src/Page.vala"
	if (!_tmp10_) {
#line 1757 "/home/jens/Source/shotwell/src/Page.vala"
		result = FALSE;
#line 1757 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 11314 "Page.c"
	}
#line 1760 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = self->priv->layout;
#line 1760 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = x;
#line 1760 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp13_ = y;
#line 1760 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_layout_set_drag_select_endpoint (_tmp11_, _tmp12_, _tmp13_);
#line 1762 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_page_updated_selection_band (self);
#line 1765 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp15_ = self->priv->autoscroll_scheduled;
#line 1765 "/home/jens/Source/shotwell/src/Page.vala"
	if (!_tmp15_) {
#line 11330 "Page.c"
		GtkAdjustment* _tmp16_;
		gint _tmp17_;
		AdjustmentRelation _tmp18_;
#line 1766 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp16_ = gtk_scrolled_window_get_vadjustment (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow));
#line 1766 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp17_ = y;
#line 1766 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp18_ = get_adjustment_relation (_tmp16_, _tmp17_);
#line 1766 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp14_ = _tmp18_ != ADJUSTMENT_RELATION_IN_RANGE;
#line 11342 "Page.c"
	} else {
#line 1765 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp14_ = FALSE;
#line 11346 "Page.c"
	}
#line 1765 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp14_) {
#line 1767 "/home/jens/Source/shotwell/src/Page.vala"
		g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) CHECKERBOARD_PAGE_AUTOSCROLL_TICKS_MSEC, _checkerboard_page_selection_autoscroll_gsource_func, g_object_ref (self), g_object_unref);
#line 1768 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->autoscroll_scheduled = TRUE;
#line 11354 "Page.c"
	}
#line 1772 "/home/jens/Source/shotwell/src/Page.vala"
	result = TRUE;
#line 1772 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 11360 "Page.c"
}


static void checkerboard_page_updated_selection_band (CheckerboardPage* self) {
	CheckerboardLayout* _tmp0_;
	gboolean _tmp1_;
	GeeList* intersection = NULL;
	CheckerboardLayout* _tmp2_;
	GeeList* _tmp3_;
	GeeList* _tmp4_;
	Marker* to_unselect = NULL;
	ViewCollection* _tmp5_;
	ViewCollection* _tmp6_;
	Marker* _tmp7_;
	Marker* _tmp8_;
	Marker* to_select = NULL;
	ViewCollection* _tmp9_;
	ViewCollection* _tmp10_;
	Marker* _tmp11_;
	Marker* _tmp12_;
	Marker* _tmp13_;
	ViewCollection* _tmp14_;
	ViewCollection* _tmp15_;
	GeeList* _tmp16_;
	GeeList* _tmp17_;
	GeeArrayList* _tmp18_;
	Marker* _tmp19_;
	GeeArrayList* _tmp20_;
	Marker* _tmp21_;
	GeeArrayList* _tmp22_;
	ViewCollection* _tmp44_;
	ViewCollection* _tmp45_;
	Marker* _tmp46_;
	ViewCollection* _tmp47_;
	ViewCollection* _tmp48_;
	Marker* _tmp49_;
#line 1775 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1776 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->layout;
#line 1776 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = checkerboard_layout_is_drag_select_active (_tmp0_);
#line 1776 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp1_, "layout.is_drag_select_active()");
#line 1779 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->priv->layout;
#line 1779 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = checkerboard_layout_items_in_selection_band (_tmp2_);
#line 1779 "/home/jens/Source/shotwell/src/Page.vala"
	intersection = _tmp3_;
#line 1780 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = intersection;
#line 1780 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_ == NULL) {
#line 1781 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (intersection);
#line 1781 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 11419 "Page.c"
	}
#line 1783 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1783 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = _tmp5_;
#line 1783 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = data_collection_start_marking (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, TYPE_DATA_COLLECTION, DataCollection));
#line 1783 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = _tmp7_;
#line 1783 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp6_);
#line 1783 "/home/jens/Source/shotwell/src/Page.vala"
	to_unselect = _tmp8_;
#line 1784 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1784 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = _tmp9_;
#line 1784 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = data_collection_start_marking (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, TYPE_DATA_COLLECTION, DataCollection));
#line 1784 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = _tmp11_;
#line 1784 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp10_);
#line 1784 "/home/jens/Source/shotwell/src/Page.vala"
	to_select = _tmp12_;
#line 1787 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp13_ = to_unselect;
#line 1787 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp14_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1787 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp15_ = _tmp14_;
#line 1787 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp16_ = view_collection_get_selected (_tmp15_);
#line 1787 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp17_ = _tmp16_;
#line 1787 "/home/jens/Source/shotwell/src/Page.vala"
	marker_mark_many (_tmp13_, G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1787 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (_tmp17_);
#line 1787 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp15_);
#line 1790 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp18_ = self->priv->previously_selected;
#line 1790 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp18_ != NULL, "previously_selected != null");
#line 1791 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp19_ = to_unselect;
#line 1791 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp20_ = self->priv->previously_selected;
#line 1791 "/home/jens/Source/shotwell/src/Page.vala"
	marker_unmark_many (_tmp19_, G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1792 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp21_ = to_select;
#line 1792 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp22_ = self->priv->previously_selected;
#line 1792 "/home/jens/Source/shotwell/src/Page.vala"
	marker_mark_many (_tmp21_, G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1795 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->cursor);
#line 1795 "/home/jens/Source/shotwell/src/Page.vala"
	self->cursor = NULL;
#line 11481 "Page.c"
	{
		GeeList* _item_list = NULL;
		GeeList* _tmp23_;
		GeeList* _tmp24_;
		gint _item_size = 0;
		GeeList* _tmp25_;
		gint _tmp26_;
		gint _tmp27_;
		gint _item_index = 0;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp23_ = intersection;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp24_ = _g_object_ref0 (_tmp23_);
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
		_item_list = _tmp24_;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp25_ = _item_list;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp26_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp27_ = _tmp26_;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
		_item_size = _tmp27_;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
		_item_index = -1;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
		while (TRUE) {
#line 11509 "Page.c"
			gint _tmp28_;
			gint _tmp29_;
			gint _tmp30_;
			CheckerboardItem* item = NULL;
			GeeList* _tmp31_;
			gint _tmp32_;
			gpointer _tmp33_;
			Marker* _tmp34_;
			CheckerboardItem* _tmp35_;
			gboolean _tmp36_;
			CheckerboardItem* _tmp41_;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp28_ = _item_index;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
			_item_index = _tmp28_ + 1;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp29_ = _item_index;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp30_ = _item_size;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
			if (!(_tmp29_ < _tmp30_)) {
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 11533 "Page.c"
			}
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp31_ = _item_list;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp32_ = _item_index;
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp33_ = gee_list_get (_tmp31_, _tmp32_);
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
			item = (CheckerboardItem*) _tmp33_;
#line 1798 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp34_ = to_select;
#line 1798 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp35_ = item;
#line 1798 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp36_ = marker_toggle (_tmp34_, G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, TYPE_DATA_OBJECT, DataObject));
#line 1798 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp36_) {
#line 11551 "Page.c"
				Marker* _tmp37_;
				CheckerboardItem* _tmp38_;
#line 1799 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp37_ = to_unselect;
#line 1799 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp38_ = item;
#line 1799 "/home/jens/Source/shotwell/src/Page.vala"
				marker_unmark (_tmp37_, G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, TYPE_DATA_OBJECT, DataObject));
#line 11560 "Page.c"
			} else {
				Marker* _tmp39_;
				CheckerboardItem* _tmp40_;
#line 1801 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp39_ = to_unselect;
#line 1801 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp40_ = item;
#line 1801 "/home/jens/Source/shotwell/src/Page.vala"
				marker_mark (_tmp39_, G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, TYPE_DATA_OBJECT, DataObject));
#line 11570 "Page.c"
			}
#line 1803 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp41_ = self->cursor;
#line 1803 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp41_ == NULL) {
#line 11576 "Page.c"
				CheckerboardItem* _tmp42_;
				CheckerboardItem* _tmp43_;
#line 1804 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp42_ = item;
#line 1804 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp43_ = _g_object_ref0 (_tmp42_);
#line 1804 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (self->cursor);
#line 1804 "/home/jens/Source/shotwell/src/Page.vala"
				self->cursor = _tmp43_;
#line 11587 "Page.c"
			}
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (item);
#line 11591 "Page.c"
		}
#line 1797 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_item_list);
#line 11595 "Page.c"
	}
#line 1807 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp44_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1807 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp45_ = _tmp44_;
#line 1807 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp46_ = to_select;
#line 1807 "/home/jens/Source/shotwell/src/Page.vala"
	view_collection_select_marked (_tmp45_, _tmp46_);
#line 1807 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp45_);
#line 1808 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp47_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1808 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp48_ = _tmp47_;
#line 1808 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp49_ = to_unselect;
#line 1808 "/home/jens/Source/shotwell/src/Page.vala"
	view_collection_unselect_marked (_tmp48_, _tmp49_);
#line 1808 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp48_);
#line 1775 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (to_select);
#line 1775 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (to_unselect);
#line 1775 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (intersection);
#line 11623 "Page.c"
}


static gboolean checkerboard_page_selection_autoscroll (CheckerboardPage* self) {
	gboolean result = FALSE;
	CheckerboardLayout* _tmp0_;
	gboolean _tmp1_;
	GtkAdjustment* vadj = NULL;
	GtkAdjustment* _tmp2_;
	GtkAdjustment* _tmp3_;
	gint x = 0;
	gint y = 0;
	GdkModifierType mask = 0;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	GdkModifierType _tmp6_ = 0;
	gint new_value = 0;
	GtkAdjustment* _tmp7_;
	gdouble _tmp8_;
	GtkAdjustment* _tmp9_;
	gint _tmp10_;
	AdjustmentRelation _tmp11_;
	GtkAdjustment* _tmp22_;
	gint _tmp23_;
	GtkAdjustment* _tmp24_;
	gdouble _tmp25_;
	GtkAdjustment* _tmp26_;
	gdouble _tmp27_;
	GtkAdjustment* _tmp28_;
	gdouble _tmp29_;
	gint _tmp30_;
#line 1811 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_CHECKERBOARD_PAGE (self), FALSE);
#line 1812 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->layout;
#line 1812 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = checkerboard_layout_is_drag_select_active (_tmp0_);
#line 1812 "/home/jens/Source/shotwell/src/Page.vala"
	if (!_tmp1_) {
#line 1813 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->autoscroll_scheduled = FALSE;
#line 1815 "/home/jens/Source/shotwell/src/Page.vala"
		result = FALSE;
#line 1815 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 11669 "Page.c"
	}
#line 1819 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = gtk_scrolled_window_get_vadjustment (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow));
#line 1819 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 1819 "/home/jens/Source/shotwell/src/Page.vala"
	vadj = _tmp3_;
#line 1823 "/home/jens/Source/shotwell/src/Page.vala"
	page_get_event_source_pointer (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), &_tmp4_, &_tmp5_, &_tmp6_);
#line 1823 "/home/jens/Source/shotwell/src/Page.vala"
	x = _tmp4_;
#line 1823 "/home/jens/Source/shotwell/src/Page.vala"
	y = _tmp5_;
#line 1823 "/home/jens/Source/shotwell/src/Page.vala"
	mask = _tmp6_;
#line 1825 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = vadj;
#line 1825 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = gtk_adjustment_get_value (_tmp7_);
#line 1825 "/home/jens/Source/shotwell/src/Page.vala"
	new_value = (gint) _tmp8_;
#line 1826 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = vadj;
#line 1826 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = y;
#line 1826 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = get_adjustment_relation (_tmp9_, _tmp10_);
#line 1826 "/home/jens/Source/shotwell/src/Page.vala"
	switch (_tmp11_) {
#line 1826 "/home/jens/Source/shotwell/src/Page.vala"
		case ADJUSTMENT_RELATION_BELOW:
#line 11701 "Page.c"
		{
			gint _tmp12_;
			CheckerboardLayout* _tmp13_;
			gint _tmp14_;
			gint _tmp15_;
#line 1829 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp12_ = new_value;
#line 1829 "/home/jens/Source/shotwell/src/Page.vala"
			new_value = _tmp12_ - CHECKERBOARD_PAGE_AUTOSCROLL_PIXELS;
#line 1830 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp13_ = self->priv->layout;
#line 1830 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp14_ = x;
#line 1830 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp15_ = new_value;
#line 1830 "/home/jens/Source/shotwell/src/Page.vala"
			checkerboard_layout_set_drag_select_endpoint (_tmp13_, _tmp14_, _tmp15_);
#line 1831 "/home/jens/Source/shotwell/src/Page.vala"
			break;
#line 11721 "Page.c"
		}
#line 1826 "/home/jens/Source/shotwell/src/Page.vala"
		case ADJUSTMENT_RELATION_ABOVE:
#line 11725 "Page.c"
		{
			gint _tmp16_;
			CheckerboardLayout* _tmp17_;
			gint _tmp18_;
			gint _tmp19_;
			GtkAdjustment* _tmp20_;
			gdouble _tmp21_;
#line 1835 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp16_ = new_value;
#line 1835 "/home/jens/Source/shotwell/src/Page.vala"
			new_value = _tmp16_ + CHECKERBOARD_PAGE_AUTOSCROLL_PIXELS;
#line 1836 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp17_ = self->priv->layout;
#line 1836 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp18_ = x;
#line 1836 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp19_ = new_value;
#line 1836 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp20_ = vadj;
#line 1836 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp21_ = gtk_adjustment_get_page_size (_tmp20_);
#line 1836 "/home/jens/Source/shotwell/src/Page.vala"
			checkerboard_layout_set_drag_select_endpoint (_tmp17_, _tmp18_, _tmp19_ + ((gint) _tmp21_));
#line 1837 "/home/jens/Source/shotwell/src/Page.vala"
			break;
#line 11751 "Page.c"
		}
#line 1826 "/home/jens/Source/shotwell/src/Page.vala"
		case ADJUSTMENT_RELATION_IN_RANGE:
#line 11755 "Page.c"
		{
#line 1840 "/home/jens/Source/shotwell/src/Page.vala"
			self->priv->autoscroll_scheduled = FALSE;
#line 1842 "/home/jens/Source/shotwell/src/Page.vala"
			result = FALSE;
#line 1842 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (vadj);
#line 1842 "/home/jens/Source/shotwell/src/Page.vala"
			return result;
#line 11765 "Page.c"
		}
		default:
		{
#line 1845 "/home/jens/Source/shotwell/src/Page.vala"
			g_warn_if_reached ();
#line 1846 "/home/jens/Source/shotwell/src/Page.vala"
			break;
#line 11773 "Page.c"
		}
	}
#line 1852 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp22_ = vadj;
#line 1852 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp23_ = new_value;
#line 1852 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp24_ = vadj;
#line 1852 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp25_ = gtk_adjustment_get_lower (_tmp24_);
#line 1852 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp26_ = vadj;
#line 1852 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp27_ = gtk_adjustment_get_upper (_tmp26_);
#line 1852 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp28_ = vadj;
#line 1852 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp29_ = gtk_adjustment_get_page_size (_tmp28_);
#line 1852 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp30_ = CLAMP (_tmp23_, (gint) _tmp25_, ((gint) _tmp27_) - ((gint) _tmp29_));
#line 1852 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_adjustment_set_value (_tmp22_, (gdouble) _tmp30_);
#line 1855 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_page_updated_selection_band (self);
#line 1857 "/home/jens/Source/shotwell/src/Page.vala"
	result = TRUE;
#line 1857 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (vadj);
#line 1857 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 11804 "Page.c"
}


void checkerboard_page_cursor_to_item (CheckerboardPage* self, CheckerboardItem* item) {
	ViewCollection* _tmp0_;
	ViewCollection* _tmp1_;
	CheckerboardItem* _tmp2_;
	gboolean _tmp3_;
	CheckerboardItem* _tmp4_;
	CheckerboardItem* _tmp5_;
	gboolean _tmp6_;
	CheckerboardLayout* _tmp17_;
	CheckerboardItem* _tmp18_;
	GtkAdjustment* vadj = NULL;
	GtkAdjustment* _tmp19_;
	GtkAdjustment* _tmp20_;
	gboolean _tmp21_ = FALSE;
	GtkAdjustment* _tmp22_;
	CheckerboardItem* _tmp23_;
	GdkRectangle _tmp24_;
	gint _tmp25_;
	AdjustmentRelation _tmp26_;
	gint top = 0;
	CheckerboardItem* _tmp35_;
	GdkRectangle _tmp36_;
	gint _tmp37_;
	GtkAdjustment* _tmp38_;
	gdouble _tmp39_;
	GtkAdjustment* _tmp53_;
	gint _tmp54_;
#line 1860 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1860 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_ITEM (item));
#line 1861 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1861 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_;
#line 1861 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = item;
#line 1861 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = data_collection_contains (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DATA_COLLECTION, DataCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_DATA_OBJECT, DataObject));
#line 1861 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp3_, "get_view().contains(item)");
#line 1861 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp1_);
#line 1863 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = item;
#line 1863 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 1863 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->cursor);
#line 1863 "/home/jens/Source/shotwell/src/Page.vala"
	self->cursor = _tmp5_;
#line 1865 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = page_get_ctrl_pressed (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1865 "/home/jens/Source/shotwell/src/Page.vala"
	if (!_tmp6_) {
#line 11863 "Page.c"
		ViewCollection* _tmp7_;
		ViewCollection* _tmp8_;
		Marker* marker = NULL;
		ViewCollection* _tmp9_;
		ViewCollection* _tmp10_;
		CheckerboardItem* _tmp11_;
		Marker* _tmp12_;
		Marker* _tmp13_;
		ViewCollection* _tmp14_;
		ViewCollection* _tmp15_;
		Marker* _tmp16_;
#line 1866 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1866 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = _tmp7_;
#line 1866 "/home/jens/Source/shotwell/src/Page.vala"
		view_collection_unselect_all (_tmp8_);
#line 1866 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp8_);
#line 1867 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1867 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = _tmp9_;
#line 1867 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = item;
#line 1867 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp12_ = data_collection_mark (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, TYPE_DATA_COLLECTION, DataCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_DATA_OBJECT, DataObject));
#line 1867 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp13_ = _tmp12_;
#line 1867 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp10_);
#line 1867 "/home/jens/Source/shotwell/src/Page.vala"
		marker = _tmp13_;
#line 1868 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp14_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1868 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp15_ = _tmp14_;
#line 1868 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp16_ = marker;
#line 1868 "/home/jens/Source/shotwell/src/Page.vala"
		view_collection_select_marked (_tmp15_, _tmp16_);
#line 1868 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp15_);
#line 1865 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (marker);
#line 11909 "Page.c"
	}
#line 1870 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp17_ = self->priv->layout;
#line 1870 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp18_ = item;
#line 1870 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_layout_set_cursor (_tmp17_, _tmp18_);
#line 1873 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp19_ = gtk_scrolled_window_get_vadjustment (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow));
#line 1873 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp20_ = _g_object_ref0 (_tmp19_);
#line 1873 "/home/jens/Source/shotwell/src/Page.vala"
	vadj = _tmp20_;
#line 1874 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp22_ = vadj;
#line 1874 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp23_ = item;
#line 1874 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp24_ = _tmp23_->allocation;
#line 1874 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp25_ = _tmp24_.y;
#line 1874 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp26_ = get_adjustment_relation (_tmp22_, _tmp25_);
#line 1874 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp26_ == ADJUSTMENT_RELATION_IN_RANGE) {
#line 11935 "Page.c"
		GtkAdjustment* _tmp27_;
		CheckerboardItem* _tmp28_;
		GdkRectangle _tmp29_;
		gint _tmp30_;
		CheckerboardItem* _tmp31_;
		GdkRectangle _tmp32_;
		gint _tmp33_;
		AdjustmentRelation _tmp34_;
#line 1875 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp27_ = vadj;
#line 1875 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp28_ = item;
#line 1875 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp29_ = _tmp28_->allocation;
#line 1875 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp30_ = _tmp29_.y;
#line 1875 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp31_ = item;
#line 1875 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp32_ = _tmp31_->allocation;
#line 1875 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp33_ = _tmp32_.height;
#line 1875 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp34_ = get_adjustment_relation (_tmp27_, _tmp30_ + _tmp33_);
#line 1875 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp21_ = _tmp34_ == ADJUSTMENT_RELATION_IN_RANGE;
#line 11962 "Page.c"
	} else {
#line 1874 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp21_ = FALSE;
#line 11966 "Page.c"
	}
#line 1874 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp21_) {
#line 1876 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (vadj);
#line 1876 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 11974 "Page.c"
	}
#line 1879 "/home/jens/Source/shotwell/src/Page.vala"
	top = 0;
#line 1880 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp35_ = item;
#line 1880 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp36_ = _tmp35_->allocation;
#line 1880 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp37_ = _tmp36_.y;
#line 1880 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp38_ = vadj;
#line 1880 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp39_ = gtk_adjustment_get_value (_tmp38_);
#line 1880 "/home/jens/Source/shotwell/src/Page.vala"
	if (((gdouble) _tmp37_) < _tmp39_) {
#line 11990 "Page.c"
		CheckerboardItem* _tmp40_;
		GdkRectangle _tmp41_;
		gint _tmp42_;
		gint _tmp43_;
#line 1881 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp40_ = item;
#line 1881 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp41_ = _tmp40_->allocation;
#line 1881 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp42_ = _tmp41_.y;
#line 1881 "/home/jens/Source/shotwell/src/Page.vala"
		top = _tmp42_;
#line 1882 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp43_ = top;
#line 1882 "/home/jens/Source/shotwell/src/Page.vala"
		top = _tmp43_ - (CHECKERBOARD_LAYOUT_ROW_GUTTER_PADDING / 2);
#line 12007 "Page.c"
	} else {
		CheckerboardItem* _tmp44_;
		GdkRectangle _tmp45_;
		gint _tmp46_;
		CheckerboardItem* _tmp47_;
		GdkRectangle _tmp48_;
		gint _tmp49_;
		GtkAdjustment* _tmp50_;
		gdouble _tmp51_;
		gint _tmp52_;
#line 1884 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp44_ = item;
#line 1884 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp45_ = _tmp44_->allocation;
#line 1884 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp46_ = _tmp45_.y;
#line 1884 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp47_ = item;
#line 1884 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp48_ = _tmp47_->allocation;
#line 1884 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp49_ = _tmp48_.height;
#line 1884 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp50_ = vadj;
#line 1884 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp51_ = gtk_adjustment_get_page_size (_tmp50_);
#line 1884 "/home/jens/Source/shotwell/src/Page.vala"
		top = (_tmp46_ + _tmp49_) - ((gint) _tmp51_);
#line 1885 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp52_ = top;
#line 1885 "/home/jens/Source/shotwell/src/Page.vala"
		top = _tmp52_ + (CHECKERBOARD_LAYOUT_ROW_GUTTER_PADDING / 2);
#line 12040 "Page.c"
	}
#line 1888 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp53_ = vadj;
#line 1888 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp54_ = top;
#line 1888 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_adjustment_set_value (_tmp53_, (gdouble) _tmp54_);
#line 1860 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (vadj);
#line 12050 "Page.c"
}


void checkerboard_page_move_cursor (CheckerboardPage* self, CompassPoint point) {
	ViewCollection* _tmp0_;
	ViewCollection* _tmp1_;
	gint _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	CheckerboardItem* _tmp6_;
	CheckerboardItem* _tmp21_;
	CheckerboardItem* item = NULL;
	CheckerboardLayout* _tmp25_;
	CheckerboardItem* _tmp26_;
	CompassPoint _tmp27_;
	CheckerboardItem* _tmp28_;
	CheckerboardItem* _tmp29_;
#line 1891 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1893 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1893 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_;
#line 1893 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = data_collection_get_count (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DATA_COLLECTION, DataCollection));
#line 1893 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_ == 0;
#line 1893 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp1_);
#line 1893 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_) {
#line 1894 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 12085 "Page.c"
	}
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = self->cursor;
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp6_ == NULL) {
#line 12091 "Page.c"
		CheckerboardLayout* _tmp7_;
		CheckerboardItem* _tmp8_;
		CheckerboardItem* _tmp9_;
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = self->priv->layout;
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = checkerboard_layout_get_cursor (_tmp7_);
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = _tmp8_;
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = _tmp9_ == NULL;
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp9_);
#line 12105 "Page.c"
	} else {
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = FALSE;
#line 12109 "Page.c"
	}
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp5_) {
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = TRUE;
#line 12115 "Page.c"
	} else {
		gboolean _tmp10_ = FALSE;
		CheckerboardItem* _tmp11_;
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = self->cursor;
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp11_ != NULL) {
#line 12123 "Page.c"
			ViewCollection* _tmp12_;
			ViewCollection* _tmp13_;
			CheckerboardItem* _tmp14_;
			gboolean _tmp15_;
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp12_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp13_ = _tmp12_;
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp14_ = self->cursor;
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp15_ = data_collection_contains (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, TYPE_DATA_COLLECTION, DataCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_DATA_OBJECT, DataObject));
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp10_ = !_tmp15_;
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
			_data_collection_unref0 (_tmp13_);
#line 12140 "Page.c"
		} else {
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp10_ = FALSE;
#line 12144 "Page.c"
		}
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = _tmp10_;
#line 12148 "Page.c"
	}
#line 1899 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_) {
#line 12152 "Page.c"
		CheckerboardItem* item = NULL;
		CheckerboardLayout* _tmp16_;
		CheckerboardItem* _tmp17_;
		CheckerboardItem* _tmp18_;
		CheckerboardItem* _tmp19_;
		CheckerboardItem* _tmp20_;
#line 1900 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp16_ = self->priv->layout;
#line 1900 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp17_ = checkerboard_layout_get_item_at_coordinate (_tmp16_, 0, 0);
#line 1900 "/home/jens/Source/shotwell/src/Page.vala"
		item = _tmp17_;
#line 1901 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp18_ = item;
#line 1901 "/home/jens/Source/shotwell/src/Page.vala"
		checkerboard_page_cursor_to_item (self, _tmp18_);
#line 1902 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp19_ = item;
#line 1902 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp20_ = _g_object_ref0 (_tmp19_);
#line 1902 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (self->anchor);
#line 1902 "/home/jens/Source/shotwell/src/Page.vala"
		self->anchor = _tmp20_;
#line 1904 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (item);
#line 1904 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 12181 "Page.c"
	}
#line 1907 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp21_ = self->cursor;
#line 1907 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp21_ == NULL) {
#line 12187 "Page.c"
		CheckerboardLayout* _tmp22_;
		CheckerboardItem* _tmp23_;
		CheckerboardItem* _tmp24_;
#line 1908 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp22_ = self->priv->layout;
#line 1908 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp23_ = checkerboard_layout_get_cursor (_tmp22_);
#line 1908 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp24_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, TYPE_CHECKERBOARD_ITEM) ? ((CheckerboardItem*) _tmp23_) : NULL;
#line 1908 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp24_ == NULL) {
#line 1908 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (_tmp23_);
#line 12201 "Page.c"
		}
#line 1908 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (self->cursor);
#line 1908 "/home/jens/Source/shotwell/src/Page.vala"
		self->cursor = _tmp24_;
#line 12207 "Page.c"
	}
#line 1912 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp25_ = self->priv->layout;
#line 1912 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp26_ = self->cursor;
#line 1912 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp27_ = point;
#line 1912 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp28_ = checkerboard_layout_get_item_relative_to (_tmp25_, _tmp26_, _tmp27_);
#line 1912 "/home/jens/Source/shotwell/src/Page.vala"
	item = _tmp28_;
#line 1913 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp29_ = item;
#line 1913 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp29_ != NULL) {
#line 12223 "Page.c"
		CheckerboardItem* _tmp30_;
#line 1914 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp30_ = item;
#line 1914 "/home/jens/Source/shotwell/src/Page.vala"
		checkerboard_page_cursor_to_item (self, _tmp30_);
#line 12229 "Page.c"
	}
#line 1891 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (item);
#line 12233 "Page.c"
}


void checkerboard_page_set_cursor (CheckerboardPage* self, CheckerboardItem* item) {
	Marker* marker = NULL;
	ViewCollection* _tmp0_;
	ViewCollection* _tmp1_;
	CheckerboardItem* _tmp2_;
	Marker* _tmp3_;
	Marker* _tmp4_;
	ViewCollection* _tmp5_;
	ViewCollection* _tmp6_;
	CheckerboardItem* _tmp7_;
	CheckerboardItem* _tmp8_;
	CheckerboardItem* _tmp9_;
	CheckerboardItem* _tmp10_;
#line 1917 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1917 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_ITEM (item));
#line 1918 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1918 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_;
#line 1918 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = item;
#line 1918 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = data_collection_mark (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DATA_COLLECTION, DataCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, TYPE_DATA_OBJECT, DataObject));
#line 1918 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = _tmp3_;
#line 1918 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp1_);
#line 1918 "/home/jens/Source/shotwell/src/Page.vala"
	marker = _tmp4_;
#line 1919 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1919 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = _tmp5_;
#line 1919 "/home/jens/Source/shotwell/src/Page.vala"
	view_collection_select_marked (_tmp6_, marker);
#line 1919 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp6_);
#line 1921 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = item;
#line 1921 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 1921 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->cursor);
#line 1921 "/home/jens/Source/shotwell/src/Page.vala"
	self->cursor = _tmp8_;
#line 1922 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = item;
#line 1922 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = _g_object_ref0 (_tmp9_);
#line 1922 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->anchor);
#line 1922 "/home/jens/Source/shotwell/src/Page.vala"
	self->anchor = _tmp10_;
#line 1917 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (marker);
#line 12294 "Page.c"
}


void checkerboard_page_select_between_items (CheckerboardPage* self, CheckerboardItem* item_start, CheckerboardItem* item_end) {
	Marker* marker = NULL;
	ViewCollection* _tmp0_;
	ViewCollection* _tmp1_;
	Marker* _tmp2_;
	Marker* _tmp3_;
	gboolean passed_start = FALSE;
	gboolean passed_end = FALSE;
	ViewCollection* _tmp28_;
	ViewCollection* _tmp29_;
	Marker* _tmp30_;
#line 1925 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1925 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_ITEM (item_start));
#line 1925 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_ITEM (item_end));
#line 1926 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1926 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_;
#line 1926 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = data_collection_start_marking (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DATA_COLLECTION, DataCollection));
#line 1926 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_;
#line 1926 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp1_);
#line 1926 "/home/jens/Source/shotwell/src/Page.vala"
	marker = _tmp3_;
#line 1928 "/home/jens/Source/shotwell/src/Page.vala"
	passed_start = FALSE;
#line 1929 "/home/jens/Source/shotwell/src/Page.vala"
	passed_end = FALSE;
#line 12331 "Page.c"
	{
		GeeIterator* _object_it = NULL;
		ViewCollection* _tmp4_;
		ViewCollection* _tmp5_;
		GeeCollection* _tmp6_;
		GeeCollection* _tmp7_;
		GeeIterator* _tmp8_;
		GeeIterator* _tmp9_;
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = _tmp4_;
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = data_collection_get_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_DATA_COLLECTION, DataCollection));
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = _tmp6_;
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_ITERABLE, GeeIterable));
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = _tmp8_;
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp7_);
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp5_);
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
		_object_it = _tmp9_;
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
		while (TRUE) {
#line 12360 "Page.c"
			GeeIterator* _tmp10_;
			gboolean _tmp11_;
			DataObject* object = NULL;
			GeeIterator* _tmp12_;
			gpointer _tmp13_;
			CheckerboardItem* item = NULL;
			DataObject* _tmp14_;
			CheckerboardItem* _tmp15_;
			CheckerboardItem* _tmp16_;
			CheckerboardItem* _tmp17_;
			CheckerboardItem* _tmp18_;
			CheckerboardItem* _tmp19_;
			gboolean _tmp20_ = FALSE;
			gboolean _tmp21_;
			gboolean _tmp25_ = FALSE;
			gboolean _tmp26_;
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp10_ = _object_it;
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp11_ = gee_iterator_next (_tmp10_);
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
			if (!_tmp11_) {
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 12385 "Page.c"
			}
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp12_ = _object_it;
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp13_ = gee_iterator_get (_tmp12_);
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
			object = (DataObject*) _tmp13_;
#line 1932 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp14_ = object;
#line 1932 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp15_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_CHECKERBOARD_ITEM, CheckerboardItem));
#line 1932 "/home/jens/Source/shotwell/src/Page.vala"
			item = _tmp15_;
#line 1934 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp16_ = item_start;
#line 1934 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp17_ = item;
#line 1934 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp16_ == _tmp17_) {
#line 1935 "/home/jens/Source/shotwell/src/Page.vala"
				passed_start = TRUE;
#line 12407 "Page.c"
			}
#line 1937 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp18_ = item_end;
#line 1937 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp19_ = item;
#line 1937 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp18_ == _tmp19_) {
#line 1938 "/home/jens/Source/shotwell/src/Page.vala"
				passed_end = TRUE;
#line 12417 "Page.c"
			}
#line 1940 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp21_ = passed_start;
#line 1940 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp21_) {
#line 1940 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp20_ = TRUE;
#line 12425 "Page.c"
			} else {
				gboolean _tmp22_;
#line 1940 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp22_ = passed_end;
#line 1940 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp20_ = _tmp22_;
#line 12432 "Page.c"
			}
#line 1940 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp20_) {
#line 12436 "Page.c"
				Marker* _tmp23_;
				DataObject* _tmp24_;
#line 1941 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp23_ = marker;
#line 1941 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp24_ = object;
#line 1941 "/home/jens/Source/shotwell/src/Page.vala"
				marker_mark (_tmp23_, G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, TYPE_DATA_VIEW, DataView), TYPE_DATA_OBJECT, DataObject));
#line 12445 "Page.c"
			}
#line 1943 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp26_ = passed_start;
#line 1943 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp26_) {
#line 12451 "Page.c"
				gboolean _tmp27_;
#line 1943 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp27_ = passed_end;
#line 1943 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp25_ = _tmp27_;
#line 12457 "Page.c"
			} else {
#line 1943 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp25_ = FALSE;
#line 12461 "Page.c"
			}
#line 1943 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp25_) {
#line 1944 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (item);
#line 1944 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (object);
#line 1944 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 12471 "Page.c"
			}
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (item);
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (object);
#line 12477 "Page.c"
		}
#line 1931 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_object_it);
#line 12481 "Page.c"
	}
#line 1947 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp28_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1947 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp29_ = _tmp28_;
#line 1947 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp30_ = marker;
#line 1947 "/home/jens/Source/shotwell/src/Page.vala"
	view_collection_select_marked (_tmp29_, _tmp30_);
#line 1947 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp29_);
#line 1925 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (marker);
#line 12495 "Page.c"
}


void checkerboard_page_select_anchor_to_cursor (CheckerboardPage* self, guint state) {
	gboolean _tmp0_ = FALSE;
	CheckerboardItem* _tmp1_;
	guint _tmp3_;
#line 1950 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1951 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->cursor;
#line 1951 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_ == NULL) {
#line 1951 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = TRUE;
#line 12511 "Page.c"
	} else {
		CheckerboardItem* _tmp2_;
#line 1951 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = self->anchor;
#line 1951 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = _tmp2_ == NULL;
#line 12518 "Page.c"
	}
#line 1951 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_) {
#line 1952 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 12524 "Page.c"
	}
#line 1954 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = state;
#line 1954 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_ == ((guint) GDK_SHIFT_MASK)) {
#line 12530 "Page.c"
		ViewCollection* _tmp4_;
		ViewCollection* _tmp5_;
		CheckerboardItem* _tmp6_;
		CheckerboardItem* _tmp7_;
#line 1955 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1955 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = _tmp4_;
#line 1955 "/home/jens/Source/shotwell/src/Page.vala"
		view_collection_unselect_all (_tmp5_);
#line 1955 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp5_);
#line 1956 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = self->anchor;
#line 1956 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = self->cursor;
#line 1956 "/home/jens/Source/shotwell/src/Page.vala"
		checkerboard_page_select_between_items (self, _tmp6_, _tmp7_);
#line 12549 "Page.c"
	} else {
		CheckerboardItem* _tmp8_;
		CheckerboardItem* _tmp9_;
#line 1958 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = self->cursor;
#line 1958 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = _g_object_ref0 (_tmp8_);
#line 1958 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (self->anchor);
#line 1958 "/home/jens/Source/shotwell/src/Page.vala"
		self->anchor = _tmp9_;
#line 12561 "Page.c"
	}
}


static void checkerboard_page_real_set_display_titles (CheckerboardPage* self, gboolean display) {
	ViewCollection* _tmp0_;
	ViewCollection* _tmp1_;
	ViewCollection* _tmp2_;
	ViewCollection* _tmp3_;
	gboolean _tmp4_;
	GValue _tmp5_ = {0};
	ViewCollection* _tmp6_;
	ViewCollection* _tmp7_;
#line 1963 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1963 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_;
#line 1963 "/home/jens/Source/shotwell/src/Page.vala"
	data_collection_freeze_notifications (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DATA_COLLECTION, DataCollection));
#line 1963 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp1_);
#line 1964 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1964 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_;
#line 1964 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = display;
#line 1964 "/home/jens/Source/shotwell/src/Page.vala"
	g_value_init (&_tmp5_, G_TYPE_BOOLEAN);
#line 1964 "/home/jens/Source/shotwell/src/Page.vala"
	g_value_set_boolean (&_tmp5_, _tmp4_);
#line 1964 "/home/jens/Source/shotwell/src/Page.vala"
	data_collection_set_property (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_DATA_COLLECTION, DataCollection), CHECKERBOARD_ITEM_PROP_SHOW_TITLES, &_tmp5_, NULL, NULL);
#line 1964 "/home/jens/Source/shotwell/src/Page.vala"
	G_IS_VALUE (&_tmp5_) ? (g_value_unset (&_tmp5_), NULL) : NULL;
#line 1964 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp3_);
#line 1965 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1965 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = _tmp6_;
#line 1965 "/home/jens/Source/shotwell/src/Page.vala"
	data_collection_thaw_notifications (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_DATA_COLLECTION, DataCollection));
#line 1965 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp7_);
#line 12607 "Page.c"
}


void checkerboard_page_set_display_titles (CheckerboardPage* self, gboolean display) {
#line 1962 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1962 "/home/jens/Source/shotwell/src/Page.vala"
	CHECKERBOARD_PAGE_GET_CLASS (self)->set_display_titles (self, display);
#line 12616 "Page.c"
}


static void checkerboard_page_real_set_display_comments (CheckerboardPage* self, gboolean display) {
	ViewCollection* _tmp0_;
	ViewCollection* _tmp1_;
	ViewCollection* _tmp2_;
	ViewCollection* _tmp3_;
	gboolean _tmp4_;
	GValue _tmp5_ = {0};
	ViewCollection* _tmp6_;
	ViewCollection* _tmp7_;
#line 1969 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1969 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_;
#line 1969 "/home/jens/Source/shotwell/src/Page.vala"
	data_collection_freeze_notifications (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DATA_COLLECTION, DataCollection));
#line 1969 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp1_);
#line 1970 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1970 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_;
#line 1970 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = display;
#line 1970 "/home/jens/Source/shotwell/src/Page.vala"
	g_value_init (&_tmp5_, G_TYPE_BOOLEAN);
#line 1970 "/home/jens/Source/shotwell/src/Page.vala"
	g_value_set_boolean (&_tmp5_, _tmp4_);
#line 1970 "/home/jens/Source/shotwell/src/Page.vala"
	data_collection_set_property (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_DATA_COLLECTION, DataCollection), CHECKERBOARD_ITEM_PROP_SHOW_COMMENTS, &_tmp5_, NULL, NULL);
#line 1970 "/home/jens/Source/shotwell/src/Page.vala"
	G_IS_VALUE (&_tmp5_) ? (g_value_unset (&_tmp5_), NULL) : NULL;
#line 1970 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp3_);
#line 1971 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = page_get_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 1971 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = _tmp6_;
#line 1971 "/home/jens/Source/shotwell/src/Page.vala"
	data_collection_thaw_notifications (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_DATA_COLLECTION, DataCollection));
#line 1971 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp7_);
#line 12661 "Page.c"
}


void checkerboard_page_set_display_comments (CheckerboardPage* self, gboolean display) {
#line 1968 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_CHECKERBOARD_PAGE (self));
#line 1968 "/home/jens/Source/shotwell/src/Page.vala"
	CHECKERBOARD_PAGE_GET_CLASS (self)->set_display_comments (self, display);
#line 12670 "Page.c"
}


void checkerboard_page_keyboard_modifiers_init (CheckerboardPageKeyboardModifiers *self, Page* page) {
	Page* _tmp0_;
	gboolean _tmp1_;
	Page* _tmp2_;
	gboolean _tmp3_;
	Page* _tmp4_;
	gboolean _tmp5_;
	Page* _tmp6_;
	gboolean _tmp7_;
#line 1248 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_PAGE (page));
#line 1248 "/home/jens/Source/shotwell/src/Page.vala"
	memset (self, 0, sizeof (CheckerboardPageKeyboardModifiers));
#line 1249 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page;
#line 1249 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_ctrl_pressed (_tmp0_);
#line 1249 "/home/jens/Source/shotwell/src/Page.vala"
	(*self).ctrl_pressed = _tmp1_;
#line 1250 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = page;
#line 1250 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = page_get_alt_pressed (_tmp2_);
#line 1250 "/home/jens/Source/shotwell/src/Page.vala"
	(*self).alt_pressed = _tmp3_;
#line 1251 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = page;
#line 1251 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = page_get_shift_pressed (_tmp4_);
#line 1251 "/home/jens/Source/shotwell/src/Page.vala"
	(*self).shift_pressed = _tmp5_;
#line 1252 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = page;
#line 1252 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = page_get_super_pressed (_tmp6_);
#line 1252 "/home/jens/Source/shotwell/src/Page.vala"
	(*self).super_pressed = _tmp7_;
#line 12711 "Page.c"
}


CheckerboardPageKeyboardModifiers* checkerboard_page_keyboard_modifiers_dup (const CheckerboardPageKeyboardModifiers* self) {
	CheckerboardPageKeyboardModifiers* dup;
#line 1247 "/home/jens/Source/shotwell/src/Page.vala"
	dup = g_new0 (CheckerboardPageKeyboardModifiers, 1);
#line 1247 "/home/jens/Source/shotwell/src/Page.vala"
	memcpy (dup, self, sizeof (CheckerboardPageKeyboardModifiers));
#line 1247 "/home/jens/Source/shotwell/src/Page.vala"
	return dup;
#line 12723 "Page.c"
}


void checkerboard_page_keyboard_modifiers_free (CheckerboardPageKeyboardModifiers* self) {
#line 1247 "/home/jens/Source/shotwell/src/Page.vala"
	g_free (self);
#line 12730 "Page.c"
}


GType checkerboard_page_keyboard_modifiers_get_type (void) {
	static volatile gsize checkerboard_page_keyboard_modifiers_type_id__volatile = 0;
	if (g_once_init_enter (&checkerboard_page_keyboard_modifiers_type_id__volatile)) {
		GType checkerboard_page_keyboard_modifiers_type_id;
		checkerboard_page_keyboard_modifiers_type_id = g_boxed_type_register_static ("CheckerboardPageKeyboardModifiers", (GBoxedCopyFunc) checkerboard_page_keyboard_modifiers_dup, (GBoxedFreeFunc) checkerboard_page_keyboard_modifiers_free);
		g_once_init_leave (&checkerboard_page_keyboard_modifiers_type_id__volatile, checkerboard_page_keyboard_modifiers_type_id);
	}
	return checkerboard_page_keyboard_modifiers_type_id__volatile;
}


static void checkerboard_page_class_init (CheckerboardPageClass * klass) {
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	checkerboard_page_parent_class = g_type_class_peek_parent (klass);
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	g_type_class_add_private (klass, sizeof (CheckerboardPagePrivate));
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((CheckerboardPageClass *) klass)->get_item_context_menu = (GtkMenu* (*) (CheckerboardPage *)) checkerboard_page_real_get_item_context_menu;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->get_page_context_menu = (GtkMenu* (*) (Page *)) checkerboard_page_real_get_page_context_menu;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_context_keypress = (gboolean (*) (Page *)) checkerboard_page_real_on_context_keypress;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((CheckerboardPageClass *) klass)->get_view_empty_message = (gchar* (*) (CheckerboardPage *)) checkerboard_page_real_get_view_empty_message;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((CheckerboardPageClass *) klass)->get_filter_no_match_message = (gchar* (*) (CheckerboardPage *)) checkerboard_page_real_get_filter_no_match_message;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((CheckerboardPageClass *) klass)->on_item_activated = (void (*) (CheckerboardPage *, CheckerboardItem*, CheckerboardPageActivator, CheckerboardPageKeyboardModifiers*)) checkerboard_page_real_on_item_activated;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((CheckerboardPageClass *) klass)->get_search_view_filter = (SearchViewFilter* (*) (CheckerboardPage *)) checkerboard_page_real_get_search_view_filter;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((CheckerboardPageClass *) klass)->get_view_tracker = (CoreViewTracker* (*) (CheckerboardPage *)) checkerboard_page_real_get_view_tracker;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->switching_from = (void (*) (Page *)) checkerboard_page_real_switching_from;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->switched_to = (void (*) (Page *)) checkerboard_page_real_switched_to;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->set_page_name = (void (*) (Page *, const gchar*)) checkerboard_page_real_set_page_name;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((GtkWidgetClass *) klass)->key_press_event = (gboolean (*) (GtkWidget *, GdkEventKey*)) checkerboard_page_real_key_press_event;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_left_click = (gboolean (*) (Page *, GdkEventButton*)) checkerboard_page_real_on_left_click;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_left_released = (gboolean (*) (Page *, GdkEventButton*)) checkerboard_page_real_on_left_released;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_right_click = (gboolean (*) (Page *, GdkEventButton*)) checkerboard_page_real_on_right_click;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((CheckerboardPageClass *) klass)->on_mouse_over = (gboolean (*) (CheckerboardPage *, CheckerboardItem*, gint, gint, GdkModifierType)) checkerboard_page_real_on_mouse_over;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_motion = (gboolean (*) (Page *, GdkEventMotion*, gint, gint, GdkModifierType)) checkerboard_page_real_on_motion;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((CheckerboardPageClass *) klass)->set_display_titles = (void (*) (CheckerboardPage *, gboolean)) checkerboard_page_real_set_display_titles;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	((CheckerboardPageClass *) klass)->set_display_comments = (void (*) (CheckerboardPage *, gboolean)) checkerboard_page_real_set_display_comments;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	G_OBJECT_CLASS (klass)->finalize = checkerboard_page_finalize;
#line 12790 "Page.c"
}


static void checkerboard_page_instance_init (CheckerboardPage * self) {
	GtkViewport* _tmp0_;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv = CHECKERBOARD_PAGE_GET_PRIVATE (self);
#line 1232 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->item_context_menu_path = NULL;
#line 1233 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->page_context_menu_path = NULL;
#line 1234 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = (GtkViewport*) gtk_viewport_new (NULL, NULL);
#line 1234 "/home/jens/Source/shotwell/src/Page.vala"
	g_object_ref_sink (_tmp0_);
#line 1234 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->viewport = _tmp0_;
#line 1235 "/home/jens/Source/shotwell/src/Page.vala"
	self->anchor = NULL;
#line 1236 "/home/jens/Source/shotwell/src/Page.vala"
	self->cursor = NULL;
#line 1237 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->highlighted = NULL;
#line 1238 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->autoscroll_scheduled = FALSE;
#line 1239 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->activated_item = NULL;
#line 1240 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->previously_selected = NULL;
#line 12820 "Page.c"
}


static void checkerboard_page_finalize (GObject * obj) {
	CheckerboardPage * self;
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_CHECKERBOARD_PAGE, CheckerboardPage);
#line 1231 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->layout);
#line 1232 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->priv->item_context_menu_path);
#line 1233 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (self->priv->page_context_menu_path);
#line 1234 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->viewport);
#line 1235 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->anchor);
#line 1236 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->cursor);
#line 1237 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->highlighted);
#line 1239 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->activated_item);
#line 1240 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->previously_selected);
#line 1307 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->item_context_menu);
#line 1319 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->page_context_menu);
#line 1227 "/home/jens/Source/shotwell/src/Page.vala"
	G_OBJECT_CLASS (checkerboard_page_parent_class)->finalize (obj);
#line 12852 "Page.c"
}


GType checkerboard_page_get_type (void) {
	static volatile gsize checkerboard_page_type_id__volatile = 0;
	if (g_once_init_enter (&checkerboard_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (CheckerboardPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) checkerboard_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (CheckerboardPage), 0, (GInstanceInitFunc) checkerboard_page_instance_init, NULL };
		GType checkerboard_page_type_id;
		checkerboard_page_type_id = g_type_register_static (TYPE_PAGE, "CheckerboardPage", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&checkerboard_page_type_id__volatile, checkerboard_page_type_id);
	}
	return checkerboard_page_type_id__volatile;
}


GType single_photo_page_update_reason_get_type (void) {
	static volatile gsize single_photo_page_update_reason_type_id__volatile = 0;
	if (g_once_init_enter (&single_photo_page_update_reason_type_id__volatile)) {
		static const GEnumValue values[] = {{SINGLE_PHOTO_PAGE_UPDATE_REASON_NEW_PIXBUF, "SINGLE_PHOTO_PAGE_UPDATE_REASON_NEW_PIXBUF", "new-pixbuf"}, {SINGLE_PHOTO_PAGE_UPDATE_REASON_QUALITY_IMPROVEMENT, "SINGLE_PHOTO_PAGE_UPDATE_REASON_QUALITY_IMPROVEMENT", "quality-improvement"}, {SINGLE_PHOTO_PAGE_UPDATE_REASON_RESIZED_CANVAS, "SINGLE_PHOTO_PAGE_UPDATE_REASON_RESIZED_CANVAS", "resized-canvas"}, {0, NULL, NULL}};
		GType single_photo_page_update_reason_type_id;
		single_photo_page_update_reason_type_id = g_enum_register_static ("SinglePhotoPageUpdateReason", values);
		g_once_init_leave (&single_photo_page_update_reason_type_id__volatile, single_photo_page_update_reason_type_id);
	}
	return single_photo_page_update_reason_type_id__volatile;
}


static void _single_photo_page_on_viewport_resize_gtk_widget_size_allocate (GtkWidget* _sender, GtkAllocation* allocation, gpointer self) {
#line 2030 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_on_viewport_resize ((SinglePhotoPage*) self);
#line 12883 "Page.c"
}


static gboolean _single_photo_page_on_canvas_exposed_gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self) {
	gboolean result;
	result = single_photo_page_on_canvas_exposed ((SinglePhotoPage*) self, cr);
#line 2031 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 12892 "Page.c"
}


SinglePhotoPage* single_photo_page_construct (GType object_type, const gchar* page_name, gboolean scale_up_to_viewport) {
	SinglePhotoPage * self = NULL;
	const gchar* _tmp0_;
	gboolean _tmp1_;
	TransitionEffectsManager* _tmp2_;
	TransitionEffectsManager* _tmp3_;
	TransitionClock* _tmp4_;
	GtkViewport* _tmp5_;
	GtkViewport* _tmp6_;
	GtkViewport* _tmp7_;
	GtkDrawingArea* _tmp8_;
	GtkViewport* _tmp9_;
	GtkDrawingArea* _tmp10_;
	GtkViewport* _tmp11_;
	GtkDrawingArea* _tmp12_;
	GtkDrawingArea* _tmp13_;
#line 2007 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (page_name != NULL, NULL);
#line 2008 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_name;
#line 2008 "/home/jens/Source/shotwell/src/Page.vala"
	self = (SinglePhotoPage*) page_construct (object_type, _tmp0_);
#line 2010 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = scale_up_to_viewport;
#line 2010 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->scale_up_to_viewport = _tmp1_;
#line 2012 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = transition_effects_manager_get_instance ();
#line 2012 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_;
#line 2012 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = transition_effects_manager_create_null_transition_clock (_tmp3_);
#line 2012 "/home/jens/Source/shotwell/src/Page.vala"
	_transition_clock_unref0 (self->priv->transition_clock);
#line 2012 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->transition_clock = _tmp4_;
#line 2012 "/home/jens/Source/shotwell/src/Page.vala"
	_transition_effects_manager_unref0 (_tmp3_);
#line 2016 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_scrolled_window_set_policy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
#line 2018 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_container_get_type (), GtkContainer), (guint) 0);
#line 2019 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_scrolled_window_set_shadow_type (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow), GTK_SHADOW_NONE);
#line 2021 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = self->viewport;
#line 2021 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_viewport_set_shadow_type (_tmp5_, GTK_SHADOW_NONE);
#line 2022 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = self->viewport;
#line 2022 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_container_get_type (), GtkContainer), (guint) 0);
#line 2023 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = self->viewport;
#line 2023 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = self->canvas;
#line 2023 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget));
#line 2025 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = self->viewport;
#line 2025 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget));
#line 2027 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = self->canvas;
#line 2027 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_widget_add_events (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget), (gint) ((GDK_EXPOSURE_MASK | GDK_STRUCTURE_MASK) | GDK_SUBSTRUCTURE_MASK));
#line 2030 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = self->viewport;
#line 2030 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_widget_get_type (), GtkWidget), "size-allocate", (GCallback) _single_photo_page_on_viewport_resize_gtk_widget_size_allocate, self, 0);
#line 2031 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = self->canvas;
#line 2031 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_widget_get_type (), GtkWidget), "draw", (GCallback) _single_photo_page_on_canvas_exposed_gtk_widget_draw, self, 0);
#line 2033 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp13_ = self->canvas;
#line 2033 "/home/jens/Source/shotwell/src/Page.vala"
	page_set_event_source (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_widget_get_type (), GtkWidget));
#line 2007 "/home/jens/Source/shotwell/src/Page.vala"
	return self;
#line 12976 "Page.c"
}


gboolean single_photo_page_is_transition_in_progress (SinglePhotoPage* self) {
	gboolean result = FALSE;
	TransitionClock* _tmp0_;
	gboolean _tmp1_;
#line 2036 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_SINGLE_PHOTO_PAGE (self), FALSE);
#line 2037 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->transition_clock;
#line 2037 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = transition_clock_is_in_progress (_tmp0_);
#line 2037 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 2037 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 12994 "Page.c"
}


void single_photo_page_cancel_transition (SinglePhotoPage* self) {
	TransitionClock* _tmp0_;
	gboolean _tmp1_;
#line 2040 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2041 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->transition_clock;
#line 2041 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = transition_clock_is_in_progress (_tmp0_);
#line 2041 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_) {
#line 13009 "Page.c"
		TransitionClock* _tmp2_;
#line 2042 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = self->priv->transition_clock;
#line 2042 "/home/jens/Source/shotwell/src/Page.vala"
		transition_clock_cancel (_tmp2_);
#line 13015 "Page.c"
	}
}


void single_photo_page_set_transition (SinglePhotoPage* self, const gchar* effect_id, gint duration_msec) {
	TransitionEffectsManager* _tmp0_;
	TransitionEffectsManager* _tmp1_;
	const gchar* _tmp2_;
	TransitionClock* _tmp3_;
	TransitionClock* _tmp4_;
	gint _tmp8_;
#line 2045 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2045 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (effect_id != NULL);
#line 2046 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_cancel_transition (self);
#line 2048 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = transition_effects_manager_get_instance ();
#line 2048 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_;
#line 2048 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = effect_id;
#line 2048 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = transition_effects_manager_create_transition_clock (_tmp1_, _tmp2_);
#line 2048 "/home/jens/Source/shotwell/src/Page.vala"
	_transition_clock_unref0 (self->priv->transition_clock);
#line 2048 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->transition_clock = _tmp3_;
#line 2048 "/home/jens/Source/shotwell/src/Page.vala"
	_transition_effects_manager_unref0 (_tmp1_);
#line 2049 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = self->priv->transition_clock;
#line 2049 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_ == NULL) {
#line 13051 "Page.c"
		TransitionEffectsManager* _tmp5_;
		TransitionEffectsManager* _tmp6_;
		TransitionClock* _tmp7_;
#line 2050 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = transition_effects_manager_get_instance ();
#line 2050 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = _tmp5_;
#line 2050 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = transition_effects_manager_create_null_transition_clock (_tmp6_);
#line 2050 "/home/jens/Source/shotwell/src/Page.vala"
		_transition_clock_unref0 (self->priv->transition_clock);
#line 2050 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->transition_clock = _tmp7_;
#line 2050 "/home/jens/Source/shotwell/src/Page.vala"
		_transition_effects_manager_unref0 (_tmp6_);
#line 13067 "Page.c"
	}
#line 2052 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = duration_msec;
#line 2052 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->transition_duration_msec = _tmp8_;
#line 13073 "Page.c"
}


static void single_photo_page_render_zoomed_to_pixmap (SinglePhotoPage* self, ZoomState* zoom_state) {
	gboolean _tmp0_;
	GdkRectangle view_rect = {0};
	GdkRectangle _tmp1_ = {0};
	GdkPixbuf* zoomed = NULL;
	ZoomBuffer* _tmp2_;
	ZoomBuffer* _tmp3_;
	gboolean _tmp4_;
	GdkPixbuf* _tmp34_;
	gint draw_x = 0;
	Dimensions _tmp35_;
	gint _tmp36_;
	GdkRectangle _tmp37_;
	gint _tmp38_;
	gint _tmp39_;
	gint _tmp40_;
	gint draw_y = 0;
	Dimensions _tmp41_;
	gint _tmp42_;
	GdkRectangle _tmp43_;
	gint _tmp44_;
	gint _tmp45_;
	gint _tmp46_;
	cairo_t* _tmp47_;
	GdkPixbuf* _tmp48_;
	gint _tmp49_;
	gint _tmp50_;
	cairo_t* _tmp51_;
#line 2056 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2056 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (zoom_state != NULL);
#line 2057 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = single_photo_page_is_zoom_supported (self);
#line 2057 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp0_, "is_zoom_supported()");
#line 2059 "/home/jens/Source/shotwell/src/Page.vala"
	zoom_state_get_viewing_rectangle_wrt_content (zoom_state, &_tmp1_);
#line 2059 "/home/jens/Source/shotwell/src/Page.vala"
	view_rect = _tmp1_;
#line 2062 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = single_photo_page_get_zoom_buffer (self);
#line 2062 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_;
#line 2062 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = _tmp3_ != NULL;
#line 2062 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (_tmp3_);
#line 2062 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_) {
#line 13127 "Page.c"
		GdkPixbuf* _tmp5_ = NULL;
		gboolean _tmp6_;
		GdkPixbuf* _tmp15_;
#line 2063 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = self->priv->zoom_high_quality;
#line 2063 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp6_) {
#line 13135 "Page.c"
			ZoomBuffer* _tmp7_;
			ZoomBuffer* _tmp8_;
			ZoomState _tmp9_;
			GdkPixbuf* _tmp10_;
#line 2063 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp7_ = single_photo_page_get_zoom_buffer (self);
#line 2063 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp8_ = _tmp7_;
#line 2063 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp9_ = *zoom_state;
#line 2063 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp10_ = zoom_buffer_get_zoomed_image (_tmp8_, &_tmp9_);
#line 2063 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (_tmp5_);
#line 2063 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp5_ = _tmp10_;
#line 2063 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (_tmp8_);
#line 13154 "Page.c"
		} else {
			ZoomBuffer* _tmp11_;
			ZoomBuffer* _tmp12_;
			ZoomState _tmp13_;
			GdkPixbuf* _tmp14_;
#line 2064 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp11_ = single_photo_page_get_zoom_buffer (self);
#line 2064 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp12_ = _tmp11_;
#line 2064 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp13_ = *zoom_state;
#line 2064 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp14_ = zoom_buffer_get_zoom_preview_image (_tmp12_, &_tmp13_);
#line 2064 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (_tmp5_);
#line 2064 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp5_ = _tmp14_;
#line 2064 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (_tmp12_);
#line 13174 "Page.c"
		}
#line 2063 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp15_ = _g_object_ref0 (_tmp5_);
#line 2063 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (zoomed);
#line 2063 "/home/jens/Source/shotwell/src/Page.vala"
		zoomed = _tmp15_;
#line 2062 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp5_);
#line 13184 "Page.c"
	} else {
		GdkRectangle view_rect_proj = {0};
		GdkPixbuf* _tmp16_;
		GdkRectangle _tmp17_ = {0};
		GdkPixbuf* proj_subpixbuf = NULL;
		GdkPixbuf* _tmp18_;
		GdkRectangle _tmp19_;
		gint _tmp20_;
		GdkRectangle _tmp21_;
		gint _tmp22_;
		GdkRectangle _tmp23_;
		gint _tmp24_;
		GdkRectangle _tmp25_;
		gint _tmp26_;
		GdkPixbuf* _tmp27_;
		GdkPixbuf* _tmp28_;
		GdkRectangle _tmp29_;
		gint _tmp30_;
		GdkRectangle _tmp31_;
		gint _tmp32_;
		GdkPixbuf* _tmp33_;
#line 2066 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp16_ = self->priv->unscaled;
#line 2066 "/home/jens/Source/shotwell/src/Page.vala"
		zoom_state_get_viewing_rectangle_projection (zoom_state, _tmp16_, &_tmp17_);
#line 2066 "/home/jens/Source/shotwell/src/Page.vala"
		view_rect_proj = _tmp17_;
#line 2068 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp18_ = self->priv->unscaled;
#line 2068 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp19_ = view_rect_proj;
#line 2068 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp20_ = _tmp19_.x;
#line 2068 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp21_ = view_rect_proj;
#line 2068 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp22_ = _tmp21_.y;
#line 2068 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp23_ = view_rect_proj;
#line 2068 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp24_ = _tmp23_.width;
#line 2068 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp25_ = view_rect_proj;
#line 2068 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp26_ = _tmp25_.height;
#line 2068 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp27_ = gdk_pixbuf_new_subpixbuf (_tmp18_, _tmp20_, _tmp22_, _tmp24_, _tmp26_);
#line 2068 "/home/jens/Source/shotwell/src/Page.vala"
		proj_subpixbuf = _tmp27_;
#line 2071 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp28_ = proj_subpixbuf;
#line 2071 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp29_ = view_rect;
#line 2071 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp30_ = _tmp29_.width;
#line 2071 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp31_ = view_rect;
#line 2071 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp32_ = _tmp31_.height;
#line 2071 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp33_ = gdk_pixbuf_scale_simple (_tmp28_, _tmp30_, _tmp32_, GDK_INTERP_BILINEAR);
#line 2071 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (zoomed);
#line 2071 "/home/jens/Source/shotwell/src/Page.vala"
		zoomed = _tmp33_;
#line 2062 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (proj_subpixbuf);
#line 13252 "Page.c"
	}
#line 2075 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp34_ = zoomed;
#line 2075 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp34_ == NULL) {
#line 2076 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (zoomed);
#line 2076 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 13262 "Page.c"
	}
#line 2079 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp35_ = self->priv->pixmap_dim;
#line 2079 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp36_ = _tmp35_.width;
#line 2079 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp37_ = view_rect;
#line 2079 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp38_ = _tmp37_.width;
#line 2079 "/home/jens/Source/shotwell/src/Page.vala"
	draw_x = (_tmp36_ - _tmp38_) / 2;
#line 2080 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp39_ = draw_x;
#line 2080 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp40_ = CLAMP (_tmp39_, 0, G_MAXINT);
#line 2080 "/home/jens/Source/shotwell/src/Page.vala"
	draw_x = _tmp40_;
#line 2082 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp41_ = self->priv->pixmap_dim;
#line 2082 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp42_ = _tmp41_.height;
#line 2082 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp43_ = view_rect;
#line 2082 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp44_ = _tmp43_.height;
#line 2082 "/home/jens/Source/shotwell/src/Page.vala"
	draw_y = (_tmp42_ - _tmp44_) / 2;
#line 2083 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp45_ = draw_y;
#line 2083 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp46_ = CLAMP (_tmp45_, 0, G_MAXINT);
#line 2083 "/home/jens/Source/shotwell/src/Page.vala"
	draw_y = _tmp46_;
#line 2085 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp47_ = self->priv->pixmap_ctx;
#line 2085 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp48_ = zoomed;
#line 2085 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp49_ = draw_x;
#line 2085 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp50_ = draw_y;
#line 2085 "/home/jens/Source/shotwell/src/Page.vala"
	gdk_cairo_set_source_pixbuf (_tmp47_, _tmp48_, (gdouble) _tmp49_, (gdouble) _tmp50_);
#line 2086 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp51_ = self->priv->pixmap_ctx;
#line 2086 "/home/jens/Source/shotwell/src/Page.vala"
	cairo_paint (_tmp51_);
#line 2056 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (zoomed);
#line 13312 "Page.c"
}


void single_photo_page_on_interactive_zoom (SinglePhotoPage* self, ZoomState* interactive_zoom_state) {
	gboolean _tmp0_;
	cairo_t* _tmp1_;
	cairo_t* _tmp2_;
	gboolean old_quality_setting = FALSE;
	gboolean _tmp3_;
	ZoomState _tmp4_;
	GtkDrawingArea* _tmp5_;
#line 2089 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2089 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (interactive_zoom_state != NULL);
#line 2090 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = single_photo_page_is_zoom_supported (self);
#line 2090 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp0_, "is_zoom_supported()");
#line 2092 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->pixmap_ctx;
#line 2092 "/home/jens/Source/shotwell/src/Page.vala"
	set_source_color_from_string (_tmp1_, "#000");
#line 2093 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->priv->pixmap_ctx;
#line 2093 "/home/jens/Source/shotwell/src/Page.vala"
	cairo_paint (_tmp2_);
#line 2095 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = self->priv->zoom_high_quality;
#line 2095 "/home/jens/Source/shotwell/src/Page.vala"
	old_quality_setting = _tmp3_;
#line 2096 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->zoom_high_quality = FALSE;
#line 2097 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = *interactive_zoom_state;
#line 2097 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_render_zoomed_to_pixmap (self, &_tmp4_);
#line 2098 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->zoom_high_quality = old_quality_setting;
#line 2100 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = self->canvas;
#line 2100 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_widget_queue_draw (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget));
#line 13356 "Page.c"
}


void single_photo_page_on_interactive_pan (SinglePhotoPage* self, ZoomState* interactive_zoom_state) {
	gboolean _tmp0_;
	cairo_t* _tmp1_;
	cairo_t* _tmp2_;
	gboolean old_quality_setting = FALSE;
	gboolean _tmp3_;
	ZoomState _tmp4_;
	GtkDrawingArea* _tmp5_;
#line 2103 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2103 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (interactive_zoom_state != NULL);
#line 2104 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = single_photo_page_is_zoom_supported (self);
#line 2104 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp0_, "is_zoom_supported()");
#line 2106 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->pixmap_ctx;
#line 2106 "/home/jens/Source/shotwell/src/Page.vala"
	set_source_color_from_string (_tmp1_, "#000");
#line 2107 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->priv->pixmap_ctx;
#line 2107 "/home/jens/Source/shotwell/src/Page.vala"
	cairo_paint (_tmp2_);
#line 2109 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = self->priv->zoom_high_quality;
#line 2109 "/home/jens/Source/shotwell/src/Page.vala"
	old_quality_setting = _tmp3_;
#line 2110 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->zoom_high_quality = TRUE;
#line 2111 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = *interactive_zoom_state;
#line 2111 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_render_zoomed_to_pixmap (self, &_tmp4_);
#line 2112 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->zoom_high_quality = old_quality_setting;
#line 2114 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = self->canvas;
#line 2114 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_widget_queue_draw (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget));
#line 13400 "Page.c"
}


static gboolean single_photo_page_real_is_zoom_supported (SinglePhotoPage* self) {
	gboolean result = FALSE;
#line 2118 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 2118 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 13410 "Page.c"
}


gboolean single_photo_page_is_zoom_supported (SinglePhotoPage* self) {
#line 2117 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_SINGLE_PHOTO_PAGE (self), FALSE);
#line 2117 "/home/jens/Source/shotwell/src/Page.vala"
	return SINGLE_PHOTO_PAGE_GET_CLASS (self)->is_zoom_supported (self);
#line 13419 "Page.c"
}


static void single_photo_page_real_cancel_zoom (SinglePhotoPage* self) {
	cairo_surface_t* _tmp0_;
#line 2122 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->pixmap;
#line 2122 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ != NULL) {
#line 13429 "Page.c"
		cairo_t* _tmp1_;
		cairo_t* _tmp2_;
#line 2123 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = self->priv->pixmap_ctx;
#line 2123 "/home/jens/Source/shotwell/src/Page.vala"
		set_source_color_from_string (_tmp1_, "#000");
#line 2124 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = self->priv->pixmap_ctx;
#line 2124 "/home/jens/Source/shotwell/src/Page.vala"
		cairo_paint (_tmp2_);
#line 13440 "Page.c"
	}
}


void single_photo_page_cancel_zoom (SinglePhotoPage* self) {
#line 2121 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2121 "/home/jens/Source/shotwell/src/Page.vala"
	SINGLE_PHOTO_PAGE_GET_CLASS (self)->cancel_zoom (self);
#line 13450 "Page.c"
}


static void single_photo_page_real_save_zoom_state (SinglePhotoPage* self) {
	ZoomState _tmp0_;
#line 2129 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->static_zoom_state;
#line 2129 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->saved_zoom_state = _tmp0_;
#line 2130 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->has_saved_zoom_state = TRUE;
#line 13462 "Page.c"
}


void single_photo_page_save_zoom_state (SinglePhotoPage* self) {
#line 2128 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2128 "/home/jens/Source/shotwell/src/Page.vala"
	SINGLE_PHOTO_PAGE_GET_CLASS (self)->save_zoom_state (self);
#line 13471 "Page.c"
}


static void single_photo_page_real_restore_zoom_state (SinglePhotoPage* self) {
	gboolean _tmp0_;
	ZoomState _tmp1_;
#line 2134 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->has_saved_zoom_state;
#line 2134 "/home/jens/Source/shotwell/src/Page.vala"
	if (!_tmp0_) {
#line 2135 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 13484 "Page.c"
	}
#line 2137 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->saved_zoom_state;
#line 2137 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->static_zoom_state = _tmp1_;
#line 2138 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_repaint (self, NULL);
#line 2139 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->has_saved_zoom_state = FALSE;
#line 13494 "Page.c"
}


void single_photo_page_restore_zoom_state (SinglePhotoPage* self) {
#line 2133 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2133 "/home/jens/Source/shotwell/src/Page.vala"
	SINGLE_PHOTO_PAGE_GET_CLASS (self)->restore_zoom_state (self);
#line 13503 "Page.c"
}


static ZoomBuffer* single_photo_page_real_get_zoom_buffer (SinglePhotoPage* self) {
	ZoomBuffer* result = NULL;
#line 2143 "/home/jens/Source/shotwell/src/Page.vala"
	result = NULL;
#line 2143 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 13513 "Page.c"
}


ZoomBuffer* single_photo_page_get_zoom_buffer (SinglePhotoPage* self) {
#line 2142 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_SINGLE_PHOTO_PAGE (self), NULL);
#line 2142 "/home/jens/Source/shotwell/src/Page.vala"
	return SINGLE_PHOTO_PAGE_GET_CLASS (self)->get_zoom_buffer (self);
#line 13522 "Page.c"
}


void single_photo_page_get_saved_zoom_state (SinglePhotoPage* self, ZoomState* result) {
	ZoomState _tmp0_;
#line 2146 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2147 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->saved_zoom_state;
#line 2147 "/home/jens/Source/shotwell/src/Page.vala"
	*result = _tmp0_;
#line 2147 "/home/jens/Source/shotwell/src/Page.vala"
	return;
#line 13536 "Page.c"
}


void single_photo_page_set_zoom_state (SinglePhotoPage* self, ZoomState* zoom_state) {
	gboolean _tmp0_;
	ZoomState _tmp1_;
#line 2150 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2150 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (zoom_state != NULL);
#line 2151 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = single_photo_page_is_zoom_supported (self);
#line 2151 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp0_, "is_zoom_supported()");
#line 2153 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = *zoom_state;
#line 2153 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->static_zoom_state = _tmp1_;
#line 13555 "Page.c"
}


void single_photo_page_get_zoom_state (SinglePhotoPage* self, ZoomState* result) {
	gboolean _tmp0_;
	ZoomState _tmp1_;
#line 2156 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2157 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = single_photo_page_is_zoom_supported (self);
#line 2157 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp0_, "is_zoom_supported()");
#line 2159 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->static_zoom_state;
#line 2159 "/home/jens/Source/shotwell/src/Page.vala"
	*result = _tmp1_;
#line 2159 "/home/jens/Source/shotwell/src/Page.vala"
	return;
#line 13574 "Page.c"
}


static void single_photo_page_real_switched_to (Page* base) {
	SinglePhotoPage * self;
	GdkPixbuf* _tmp0_;
#line 2162 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPage);
#line 2163 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_CLASS (single_photo_page_parent_class)->switched_to (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 2165 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->unscaled;
#line 2165 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ != NULL) {
#line 2166 "/home/jens/Source/shotwell/src/Page.vala"
		single_photo_page_repaint (self, NULL);
#line 13591 "Page.c"
	}
}


static void single_photo_page_real_set_container (Page* base, GtkWindow* container) {
	SinglePhotoPage * self;
	GtkWindow* _tmp0_;
	GtkWindow* _tmp1_;
#line 2169 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPage);
#line 2169 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GTK_IS_WINDOW (container));
#line 2170 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = container;
#line 2170 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_CLASS (single_photo_page_parent_class)->set_container (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), _tmp0_);
#line 2174 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = container;
#line 2174 "/home/jens/Source/shotwell/src/Page.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, TYPE_FULLSCREEN_WINDOW)) {
#line 2175 "/home/jens/Source/shotwell/src/Page.vala"
		gtk_scrolled_window_set_policy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_scrolled_window_get_type (), GtkScrolledWindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
#line 13614 "Page.c"
	}
}


void single_photo_page_set_pixbuf (SinglePhotoPage* self, GdkPixbuf* unscaled, Dimensions* max_dim, Direction* direction) {
	Dimensions _tmp0_;
	Dimensions _tmp1_;
	gdouble _tmp2_;
	GdkPoint _tmp3_ = {0};
	GdkPixbuf* _tmp4_;
	GdkPixbuf* _tmp5_;
	Dimensions _tmp6_;
	GdkPixbuf* _tmp7_;
	GdkPixbuf* _tmp8_;
	GtkDrawingArea* _tmp9_;
	Direction* _tmp10_;
#line 2182 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2182 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GDK_IS_PIXBUF (unscaled));
#line 2182 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (max_dim != NULL);
#line 2183 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = *max_dim;
#line 2183 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->pixmap_dim;
#line 2183 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = zoom_state_get_interpolation_factor (&self->priv->static_zoom_state);
#line 2183 "/home/jens/Source/shotwell/src/Page.vala"
	zoom_state_get_viewport_center (&self->priv->static_zoom_state, &_tmp3_);
#line 2183 "/home/jens/Source/shotwell/src/Page.vala"
	zoom_state_init (&self->priv->static_zoom_state, &_tmp0_, &_tmp1_, _tmp2_, &_tmp3_);
#line 2187 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_cancel_transition (self);
#line 2189 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = unscaled;
#line 2189 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 2189 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->unscaled);
#line 2189 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->unscaled = _tmp5_;
#line 2190 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = *max_dim;
#line 2190 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->max_dim = _tmp6_;
#line 2191 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = self->priv->scaled;
#line 2191 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 2191 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->old_scaled);
#line 2191 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->old_scaled = _tmp8_;
#line 2192 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->scaled);
#line 2192 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->scaled = NULL;
#line 2195 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = self->canvas;
#line 2195 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_widget_realize (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget));
#line 2197 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = direction;
#line 2197 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_repaint (self, _tmp10_);
#line 13681 "Page.c"
}


void single_photo_page_blank_display (SinglePhotoPage* self) {
	GtkDrawingArea* _tmp0_;
#line 2200 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2201 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->unscaled);
#line 2201 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->unscaled = NULL;
#line 2202 "/home/jens/Source/shotwell/src/Page.vala"
	dimensions_init (&self->priv->max_dim, 0, 0);
#line 2203 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->scaled);
#line 2203 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->scaled = NULL;
#line 2204 "/home/jens/Source/shotwell/src/Page.vala"
	_cairo_surface_destroy0 (self->priv->pixmap);
#line 2204 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->pixmap = NULL;
#line 2207 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->canvas;
#line 2207 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_widget_realize (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 2210 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_invalidate_all (self);
#line 13709 "Page.c"
}


static gpointer _cairo_surface_reference0 (gpointer self) {
#line 2214 "/home/jens/Source/shotwell/src/Page.vala"
	return self ? cairo_surface_reference (self) : NULL;
#line 13716 "Page.c"
}


cairo_surface_t* single_photo_page_get_surface (SinglePhotoPage* self) {
	cairo_surface_t* result = NULL;
	cairo_surface_t* _tmp0_;
	cairo_surface_t* _tmp1_;
#line 2213 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_SINGLE_PHOTO_PAGE (self), NULL);
#line 2214 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->pixmap;
#line 2214 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _cairo_surface_reference0 (_tmp0_);
#line 2214 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 2214 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 13734 "Page.c"
}


void single_photo_page_get_surface_dim (SinglePhotoPage* self, Dimensions* result) {
	Dimensions _tmp0_;
#line 2217 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2218 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->pixmap_dim;
#line 2218 "/home/jens/Source/shotwell/src/Page.vala"
	*result = _tmp0_;
#line 2218 "/home/jens/Source/shotwell/src/Page.vala"
	return;
#line 13748 "Page.c"
}


static gpointer _cairo_reference0 (gpointer self) {
#line 2222 "/home/jens/Source/shotwell/src/Page.vala"
	return self ? cairo_reference (self) : NULL;
#line 13755 "Page.c"
}


cairo_t* single_photo_page_get_cairo_context (SinglePhotoPage* self) {
	cairo_t* result = NULL;
	cairo_t* _tmp0_;
	cairo_t* _tmp1_;
#line 2221 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_SINGLE_PHOTO_PAGE (self), NULL);
#line 2222 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->pixmap_ctx;
#line 2222 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _cairo_reference0 (_tmp0_);
#line 2222 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 2222 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 13773 "Page.c"
}


void single_photo_page_paint_text (SinglePhotoPage* self, PangoLayout* pango_layout, gint x, gint y) {
	cairo_t* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	cairo_t* _tmp3_;
	PangoLayout* _tmp4_;
#line 2225 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2225 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (PANGO_IS_LAYOUT (pango_layout));
#line 2226 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->text_ctx;
#line 2226 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = x;
#line 2226 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = y;
#line 2226 "/home/jens/Source/shotwell/src/Page.vala"
	cairo_move_to (_tmp0_, (gdouble) _tmp1_, (gdouble) _tmp2_);
#line 2227 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = self->priv->text_ctx;
#line 2227 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = pango_layout;
#line 2227 "/home/jens/Source/shotwell/src/Page.vala"
	pango_cairo_show_layout (_tmp3_, _tmp4_);
#line 13801 "Page.c"
}


void single_photo_page_get_canvas_scaling (SinglePhotoPage* self, Scaling* result) {
	Scaling _tmp0_ = {0};
	GtkWindow* _tmp1_;
	GtkWindow* _tmp2_;
	gboolean _tmp3_;
#line 2230 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2231 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_container (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 2231 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_;
#line 2231 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, TYPE_FULLSCREEN_WINDOW);
#line 2231 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (_tmp2_);
#line 2231 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_) {
#line 13822 "Page.c"
		GtkWindow* _tmp4_;
		GtkWindow* _tmp5_;
		gboolean _tmp6_;
		Scaling _tmp7_ = {0};
#line 2231 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = page_get_container (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 2231 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = _tmp4_;
#line 2231 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = self->priv->scale_up_to_viewport;
#line 2231 "/home/jens/Source/shotwell/src/Page.vala"
		scaling_for_screen (_tmp5_, _tmp6_, &_tmp7_);
#line 2231 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = _tmp7_;
#line 2231 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp5_);
#line 13839 "Page.c"
	} else {
		GtkViewport* _tmp8_;
		gboolean _tmp9_;
		Scaling _tmp10_ = {0};
#line 2232 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = self->viewport;
#line 2232 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = self->priv->scale_up_to_viewport;
#line 2232 "/home/jens/Source/shotwell/src/Page.vala"
		scaling_for_widget (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget), _tmp9_, &_tmp10_);
#line 2232 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = _tmp10_;
#line 13852 "Page.c"
	}
#line 2231 "/home/jens/Source/shotwell/src/Page.vala"
	*result = _tmp0_;
#line 2231 "/home/jens/Source/shotwell/src/Page.vala"
	return;
#line 13858 "Page.c"
}


GdkPixbuf* single_photo_page_get_unscaled_pixbuf (SinglePhotoPage* self) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_;
	GdkPixbuf* _tmp1_;
#line 2235 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_SINGLE_PHOTO_PAGE (self), NULL);
#line 2236 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->unscaled;
#line 2236 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 2236 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 2236 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 13876 "Page.c"
}


GdkPixbuf* single_photo_page_get_scaled_pixbuf (SinglePhotoPage* self) {
	GdkPixbuf* result = NULL;
	GdkPixbuf* _tmp0_;
	GdkPixbuf* _tmp1_;
#line 2239 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_SINGLE_PHOTO_PAGE (self), NULL);
#line 2240 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->scaled;
#line 2240 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 2240 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp1_;
#line 2240 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 13894 "Page.c"
}


void single_photo_page_get_scaled_pixbuf_position (SinglePhotoPage* self, GdkRectangle* result) {
	GdkRectangle _tmp0_;
#line 2244 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2245 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->scaled_pos;
#line 2245 "/home/jens/Source/shotwell/src/Page.vala"
	*result = _tmp0_;
#line 2245 "/home/jens/Source/shotwell/src/Page.vala"
	return;
#line 13908 "Page.c"
}


gboolean single_photo_page_is_inside_pixbuf (SinglePhotoPage* self, gint x, gint y) {
	gboolean result = FALSE;
	gint _tmp0_;
	gint _tmp1_;
	GdkRectangle _tmp2_;
	gboolean _tmp3_;
#line 2248 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_SINGLE_PHOTO_PAGE (self), FALSE);
#line 2249 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = x;
#line 2249 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = y;
#line 2249 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->priv->scaled_pos;
#line 2249 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = coord_in_rectangle (_tmp0_, _tmp1_, &_tmp2_);
#line 2249 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp3_;
#line 2249 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 13932 "Page.c"
}


void single_photo_page_invalidate (SinglePhotoPage* self, GdkRectangle* rect) {
	GtkDrawingArea* _tmp0_;
	GdkWindow* _tmp1_;
#line 2252 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2252 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (rect != NULL);
#line 2253 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->canvas;
#line 2253 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 2253 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_ != NULL) {
#line 13949 "Page.c"
		GtkDrawingArea* _tmp2_;
		GdkWindow* _tmp3_;
		GdkRectangle _tmp4_;
#line 2254 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = self->canvas;
#line 2254 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 2254 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = *rect;
#line 2254 "/home/jens/Source/shotwell/src/Page.vala"
		gdk_window_invalidate_rect (_tmp3_, &_tmp4_, FALSE);
#line 13961 "Page.c"
	}
}


void single_photo_page_invalidate_all (SinglePhotoPage* self) {
	GtkDrawingArea* _tmp0_;
	GdkWindow* _tmp1_;
#line 2257 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2258 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->canvas;
#line 2258 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 2258 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_ != NULL) {
#line 13977 "Page.c"
		GtkDrawingArea* _tmp2_;
		GdkWindow* _tmp3_;
#line 2259 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = self->canvas;
#line 2259 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 2259 "/home/jens/Source/shotwell/src/Page.vala"
		gdk_window_invalidate_rect (_tmp3_, NULL, FALSE);
#line 13986 "Page.c"
	}
}


static void single_photo_page_on_viewport_resize (SinglePhotoPage* self) {
#line 2262 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2264 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_internal_repaint (self, TRUE, NULL);
#line 13996 "Page.c"
}


static void single_photo_page_real_on_resize_finished (Page* base, GdkRectangle* rect) {
	SinglePhotoPage * self;
	GdkRectangle _tmp0_;
#line 2267 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPage);
#line 2267 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (rect != NULL);
#line 2268 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = *rect;
#line 2268 "/home/jens/Source/shotwell/src/Page.vala"
	PAGE_CLASS (single_photo_page_parent_class)->on_resize_finished (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), &_tmp0_);
#line 2271 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_repaint (self, NULL);
#line 14013 "Page.c"
}


static gboolean single_photo_page_on_canvas_exposed (SinglePhotoPage* self, cairo_t* exposed_ctx) {
	gboolean result = FALSE;
	cairo_surface_t* _tmp0_;
	cairo_t* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	cairo_t* _tmp7_;
#line 2274 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_SINGLE_PHOTO_PAGE (self), FALSE);
#line 2274 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (exposed_ctx != NULL, FALSE);
#line 2277 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->pixmap;
#line 2277 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ != NULL) {
#line 14032 "Page.c"
		cairo_t* _tmp1_;
		cairo_surface_t* _tmp2_;
#line 2278 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = exposed_ctx;
#line 2278 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = self->priv->pixmap;
#line 2278 "/home/jens/Source/shotwell/src/Page.vala"
		cairo_set_source_surface (_tmp1_, _tmp2_, (gdouble) 0, (gdouble) 0);
#line 14041 "Page.c"
	} else {
		cairo_t* _tmp3_;
#line 2280 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = exposed_ctx;
#line 2280 "/home/jens/Source/shotwell/src/Page.vala"
		set_source_color_from_string (_tmp3_, "#000");
#line 14048 "Page.c"
	}
#line 2282 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = exposed_ctx;
#line 2282 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = gtk_widget_get_allocated_width (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 2282 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = gtk_widget_get_allocated_height (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 2282 "/home/jens/Source/shotwell/src/Page.vala"
	cairo_rectangle (_tmp4_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp5_, (gdouble) _tmp6_);
#line 2283 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = exposed_ctx;
#line 2283 "/home/jens/Source/shotwell/src/Page.vala"
	cairo_paint (_tmp7_);
#line 2285 "/home/jens/Source/shotwell/src/Page.vala"
	result = TRUE;
#line 2285 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 14066 "Page.c"
}


static void single_photo_page_real_new_surface (SinglePhotoPage* self, cairo_t* ctx, Dimensions* ctx_dim) {
#line 2288 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (ctx != NULL);
#line 2288 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (ctx_dim != NULL);
#line 14075 "Page.c"
}


void single_photo_page_new_surface (SinglePhotoPage* self, cairo_t* ctx, Dimensions* ctx_dim) {
#line 2288 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2288 "/home/jens/Source/shotwell/src/Page.vala"
	SINGLE_PHOTO_PAGE_GET_CLASS (self)->new_surface (self, ctx, ctx_dim);
#line 14084 "Page.c"
}


static void single_photo_page_real_updated_pixbuf (SinglePhotoPage* self, GdkPixbuf* pixbuf, SinglePhotoPageUpdateReason reason, Dimensions* old_dim) {
#line 2291 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GDK_IS_PIXBUF (pixbuf));
#line 2291 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (old_dim != NULL);
#line 14093 "Page.c"
}


void single_photo_page_updated_pixbuf (SinglePhotoPage* self, GdkPixbuf* pixbuf, SinglePhotoPageUpdateReason reason, Dimensions* old_dim) {
#line 2291 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2291 "/home/jens/Source/shotwell/src/Page.vala"
	SINGLE_PHOTO_PAGE_GET_CLASS (self)->updated_pixbuf (self, pixbuf, reason, old_dim);
#line 14102 "Page.c"
}


static void single_photo_page_real_paint (SinglePhotoPage* self, cairo_t* ctx, Dimensions* ctx_dim) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
#line 2294 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (ctx != NULL);
#line 2294 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (ctx_dim != NULL);
#line 2295 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = single_photo_page_is_zoom_supported (self);
#line 2295 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_) {
#line 14117 "Page.c"
		gboolean _tmp2_;
#line 2295 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp2_ = zoom_state_is_default (&self->priv->static_zoom_state);
#line 2295 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = !_tmp2_;
#line 14123 "Page.c"
	} else {
#line 2295 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp0_ = FALSE;
#line 14127 "Page.c"
	}
#line 2295 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_) {
#line 14131 "Page.c"
		cairo_t* _tmp3_;
		cairo_t* _tmp4_;
		Dimensions _tmp5_;
		gint _tmp6_;
		Dimensions _tmp7_;
		gint _tmp8_;
		cairo_t* _tmp9_;
		ZoomState _tmp10_;
#line 2296 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = ctx;
#line 2296 "/home/jens/Source/shotwell/src/Page.vala"
		set_source_color_from_string (_tmp3_, "#000");
#line 2297 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = ctx;
#line 2297 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = self->priv->pixmap_dim;
#line 2297 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = _tmp5_.width;
#line 2297 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = self->priv->pixmap_dim;
#line 2297 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = _tmp7_.height;
#line 2297 "/home/jens/Source/shotwell/src/Page.vala"
		cairo_rectangle (_tmp4_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp6_, (gdouble) _tmp8_);
#line 2298 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = ctx;
#line 2298 "/home/jens/Source/shotwell/src/Page.vala"
		cairo_fill (_tmp9_);
#line 2300 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = self->priv->static_zoom_state;
#line 2300 "/home/jens/Source/shotwell/src/Page.vala"
		single_photo_page_render_zoomed_to_pixmap (self, &_tmp10_);
#line 14164 "Page.c"
	} else {
		TransitionClock* _tmp11_;
		cairo_t* _tmp12_;
		Dimensions _tmp13_;
		gint _tmp14_;
		Dimensions _tmp15_;
		gint _tmp16_;
		gboolean _tmp17_;
#line 2301 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = self->priv->transition_clock;
#line 2301 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp12_ = ctx;
#line 2301 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp13_ = *ctx_dim;
#line 2301 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp14_ = _tmp13_.width;
#line 2301 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp15_ = *ctx_dim;
#line 2301 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp16_ = _tmp15_.height;
#line 2301 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp17_ = transition_clock_paint (_tmp11_, _tmp12_, _tmp14_, _tmp16_);
#line 2301 "/home/jens/Source/shotwell/src/Page.vala"
		if (!_tmp17_) {
#line 14189 "Page.c"
			cairo_t* _tmp18_;
			cairo_t* _tmp19_;
			Dimensions _tmp20_;
			gint _tmp21_;
			Dimensions _tmp22_;
			gint _tmp23_;
			cairo_t* _tmp24_;
			cairo_t* _tmp25_;
			GdkPixbuf* _tmp26_;
			GdkRectangle _tmp27_;
			gint _tmp28_;
			GdkRectangle _tmp29_;
			gint _tmp30_;
			cairo_t* _tmp31_;
#line 2303 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp18_ = ctx;
#line 2303 "/home/jens/Source/shotwell/src/Page.vala"
			set_source_color_from_string (_tmp18_, "#000");
#line 2305 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp19_ = ctx;
#line 2305 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp20_ = self->priv->pixmap_dim;
#line 2305 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp21_ = _tmp20_.width;
#line 2305 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp22_ = self->priv->pixmap_dim;
#line 2305 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp23_ = _tmp22_.height;
#line 2305 "/home/jens/Source/shotwell/src/Page.vala"
			cairo_rectangle (_tmp19_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp21_, (gdouble) _tmp23_);
#line 2306 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp24_ = ctx;
#line 2306 "/home/jens/Source/shotwell/src/Page.vala"
			cairo_fill (_tmp24_);
#line 2308 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp25_ = ctx;
#line 2308 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp26_ = self->priv->scaled;
#line 2308 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp27_ = self->priv->scaled_pos;
#line 2308 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp28_ = _tmp27_.x;
#line 2308 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp29_ = self->priv->scaled_pos;
#line 2308 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp30_ = _tmp29_.y;
#line 2308 "/home/jens/Source/shotwell/src/Page.vala"
			gdk_cairo_set_source_pixbuf (_tmp25_, _tmp26_, (gdouble) _tmp28_, (gdouble) _tmp30_);
#line 2309 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp31_ = ctx;
#line 2309 "/home/jens/Source/shotwell/src/Page.vala"
			cairo_paint (_tmp31_);
#line 14242 "Page.c"
		}
	}
}


void single_photo_page_paint (SinglePhotoPage* self, cairo_t* ctx, Dimensions* ctx_dim) {
#line 2294 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2294 "/home/jens/Source/shotwell/src/Page.vala"
	SINGLE_PHOTO_PAGE_GET_CLASS (self)->paint (self, ctx, ctx_dim);
#line 14253 "Page.c"
}


static void single_photo_page_repaint_pixmap (SinglePhotoPage* self) {
	cairo_t* _tmp0_;
	cairo_t* _tmp1_;
	Dimensions _tmp2_;
#line 2313 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2314 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->pixmap_ctx;
#line 2314 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ == NULL) {
#line 2315 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 14269 "Page.c"
	}
#line 2317 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->priv->pixmap_ctx;
#line 2317 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->priv->pixmap_dim;
#line 2317 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_paint (self, _tmp1_, &_tmp2_);
#line 2318 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_invalidate_all (self);
#line 14279 "Page.c"
}


void single_photo_page_repaint (SinglePhotoPage* self, Direction* direction) {
	Direction* _tmp0_;
#line 2321 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2322 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = direction;
#line 2322 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_internal_repaint (self, FALSE, _tmp0_);
#line 14291 "Page.c"
}


static void _single_photo_page_repaint_pixmap_transition_clock_repaint_callback (gpointer self) {
#line 2410 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_repaint_pixmap ((SinglePhotoPage*) self);
#line 14298 "Page.c"
}


static void single_photo_page_internal_repaint (SinglePhotoPage* self, gboolean fast, Direction* direction) {
	gboolean _tmp0_;
	gboolean _tmp1_ = FALSE;
	GdkPixbuf* _tmp2_;
	GtkAllocation allocation = {0};
	GtkViewport* _tmp5_;
	GtkAllocation _tmp6_ = {0};
	gint width = 0;
	GtkAllocation _tmp7_;
	gint _tmp8_;
	gint height = 0;
	GtkAllocation _tmp9_;
	gint _tmp10_;
	gboolean _tmp11_ = FALSE;
	gint _tmp12_;
	gboolean new_pixbuf = FALSE;
	GdkPixbuf* _tmp14_;
	Dimensions old_scaled_dim = {0};
	GdkRectangle _tmp15_;
	Dimensions _tmp16_ = {0};
	GdkRectangle old_scaled_pos = {0};
	GdkRectangle _tmp17_;
	gboolean _tmp18_ = FALSE;
	Dimensions _tmp19_;
	gint _tmp20_;
	gint _tmp21_;
	gboolean new_pixmap = FALSE;
	cairo_surface_t* _tmp25_;
	gboolean _tmp28_ = FALSE;
	gboolean _tmp29_;
	GdkInterpType _tmp63_ = 0;
	gboolean _tmp64_;
	GdkInterpType interp = 0;
	GdkPixbuf* _tmp65_;
	gboolean _tmp82_;
	gboolean _tmp83_ = FALSE;
	Direction* _tmp84_;
	TransitionClock* _tmp98_;
	gboolean _tmp99_;
#line 2325 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2327 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_is_in_view (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 2327 "/home/jens/Source/shotwell/src/Page.vala"
	if (!_tmp0_) {
#line 2328 "/home/jens/Source/shotwell/src/Page.vala"
		_cairo_surface_destroy0 (self->priv->pixmap);
#line 2328 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->pixmap = NULL;
#line 2329 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (self->priv->scaled);
#line 2329 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->scaled = NULL;
#line 2331 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 14357 "Page.c"
	}
#line 2335 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->priv->unscaled;
#line 2335 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp2_ == NULL) {
#line 2335 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = TRUE;
#line 14365 "Page.c"
	} else {
		GtkDrawingArea* _tmp3_;
		GdkWindow* _tmp4_;
#line 2335 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = self->canvas;
#line 2335 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget));
#line 2335 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = _tmp4_ == NULL;
#line 14375 "Page.c"
	}
#line 2335 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp1_) {
#line 2336 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 14381 "Page.c"
	}
#line 2339 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = self->viewport;
#line 2339 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_widget_get_allocation (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), &_tmp6_);
#line 2339 "/home/jens/Source/shotwell/src/Page.vala"
	allocation = _tmp6_;
#line 2341 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = allocation;
#line 2341 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = _tmp7_.width;
#line 2341 "/home/jens/Source/shotwell/src/Page.vala"
	width = _tmp8_;
#line 2342 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = allocation;
#line 2342 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = _tmp9_.height;
#line 2342 "/home/jens/Source/shotwell/src/Page.vala"
	height = _tmp10_;
#line 2344 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = width;
#line 2344 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp12_ <= 0) {
#line 2344 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = TRUE;
#line 14407 "Page.c"
	} else {
		gint _tmp13_;
#line 2344 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp13_ = height;
#line 2344 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = _tmp13_ <= 0;
#line 14414 "Page.c"
	}
#line 2344 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp11_) {
#line 2345 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 14420 "Page.c"
	}
#line 2347 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp14_ = self->priv->scaled;
#line 2347 "/home/jens/Source/shotwell/src/Page.vala"
	new_pixbuf = _tmp14_ == NULL;
#line 2350 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp15_ = self->priv->scaled_pos;
#line 2350 "/home/jens/Source/shotwell/src/Page.vala"
	dimensions_for_rectangle (&_tmp15_, &_tmp16_);
#line 2350 "/home/jens/Source/shotwell/src/Page.vala"
	old_scaled_dim = _tmp16_;
#line 2351 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp17_ = self->priv->scaled_pos;
#line 2351 "/home/jens/Source/shotwell/src/Page.vala"
	old_scaled_pos = _tmp17_;
#line 2354 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp19_ = self->priv->pixmap_dim;
#line 2354 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp20_ = _tmp19_.width;
#line 2354 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp21_ = width;
#line 2354 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp20_ != _tmp21_) {
#line 2354 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp18_ = TRUE;
#line 14446 "Page.c"
	} else {
		Dimensions _tmp22_;
		gint _tmp23_;
		gint _tmp24_;
#line 2354 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp22_ = self->priv->pixmap_dim;
#line 2354 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp23_ = _tmp22_.height;
#line 2354 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp24_ = height;
#line 2354 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp18_ = _tmp23_ != _tmp24_;
#line 14459 "Page.c"
	}
#line 2354 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp18_) {
#line 2355 "/home/jens/Source/shotwell/src/Page.vala"
		_cairo_surface_destroy0 (self->priv->pixmap);
#line 2355 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->pixmap = NULL;
#line 14467 "Page.c"
	}
#line 2358 "/home/jens/Source/shotwell/src/Page.vala"
	new_pixmap = FALSE;
#line 2359 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp25_ = self->priv->pixmap;
#line 2359 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp25_ == NULL) {
#line 14475 "Page.c"
		gint _tmp26_;
		gint _tmp27_;
#line 2360 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp26_ = width;
#line 2360 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp27_ = height;
#line 2360 "/home/jens/Source/shotwell/src/Page.vala"
		single_photo_page_init_pixmap (self, _tmp26_, _tmp27_);
#line 2361 "/home/jens/Source/shotwell/src/Page.vala"
		new_pixmap = TRUE;
#line 14486 "Page.c"
	}
#line 2364 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp29_ = new_pixbuf;
#line 2364 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp29_) {
#line 2364 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp28_ = TRUE;
#line 14494 "Page.c"
	} else {
		gboolean _tmp30_;
#line 2364 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp30_ = new_pixmap;
#line 2364 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp28_ = _tmp30_;
#line 14501 "Page.c"
	}
#line 2364 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp28_) {
#line 14505 "Page.c"
		Dimensions unscaled_dim = {0};
		GdkPixbuf* _tmp31_;
		Dimensions _tmp32_ = {0};
		Dimensions scaled_dim = {0};
		gboolean _tmp33_ = FALSE;
		gboolean _tmp34_ = FALSE;
		gboolean _tmp35_ = FALSE;
		gboolean _tmp36_;
		gint _tmp47_;
		Dimensions _tmp48_;
		gint _tmp49_;
		gint _tmp50_;
		Dimensions _tmp51_;
		gint _tmp52_;
		gint _tmp53_;
		Dimensions _tmp54_;
		gint _tmp55_;
		gint _tmp56_;
		Dimensions _tmp57_;
		gint _tmp58_;
		Dimensions _tmp59_;
		gint _tmp60_;
		Dimensions _tmp61_;
		gint _tmp62_;
#line 2365 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp31_ = self->priv->unscaled;
#line 2365 "/home/jens/Source/shotwell/src/Page.vala"
		dimensions_for_pixbuf (_tmp31_, &_tmp32_);
#line 2365 "/home/jens/Source/shotwell/src/Page.vala"
		unscaled_dim = _tmp32_;
#line 2369 "/home/jens/Source/shotwell/src/Page.vala"
		dimensions_init (&scaled_dim, 0, 0);
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp36_ = self->priv->scale_up_to_viewport;
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
		if (!_tmp36_) {
#line 14542 "Page.c"
			gboolean _tmp37_;
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp37_ = dimensions_has_area (&self->priv->max_dim);
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp35_ = _tmp37_;
#line 14548 "Page.c"
		} else {
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp35_ = FALSE;
#line 14552 "Page.c"
		}
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp35_) {
#line 14556 "Page.c"
			Dimensions _tmp38_;
			gint _tmp39_;
			gint _tmp40_;
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp38_ = self->priv->max_dim;
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp39_ = _tmp38_.width;
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp40_ = width;
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp34_ = _tmp39_ < _tmp40_;
#line 14568 "Page.c"
		} else {
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp34_ = FALSE;
#line 14572 "Page.c"
		}
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp34_) {
#line 14576 "Page.c"
			Dimensions _tmp41_;
			gint _tmp42_;
			gint _tmp43_;
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp41_ = self->priv->max_dim;
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp42_ = _tmp41_.height;
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp43_ = height;
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp33_ = _tmp42_ < _tmp43_;
#line 14588 "Page.c"
		} else {
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp33_ = FALSE;
#line 14592 "Page.c"
		}
#line 2370 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp33_) {
#line 14596 "Page.c"
			Dimensions _tmp44_;
#line 2371 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp44_ = self->priv->max_dim;
#line 2371 "/home/jens/Source/shotwell/src/Page.vala"
			scaled_dim = _tmp44_;
#line 14602 "Page.c"
		} else {
			Dimensions _tmp45_;
			Dimensions _tmp46_ = {0};
#line 2373 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp45_ = self->priv->pixmap_dim;
#line 2373 "/home/jens/Source/shotwell/src/Page.vala"
			dimensions_get_scaled_proportional (&unscaled_dim, &_tmp45_, &_tmp46_);
#line 2373 "/home/jens/Source/shotwell/src/Page.vala"
			scaled_dim = _tmp46_;
#line 14612 "Page.c"
		}
#line 2375 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp47_ = width;
#line 2375 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp48_ = scaled_dim;
#line 2375 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp49_ = _tmp48_.width;
#line 2375 "/home/jens/Source/shotwell/src/Page.vala"
		_vala_assert (_tmp47_ >= _tmp49_, "width >= scaled_dim.width");
#line 2376 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp50_ = height;
#line 2376 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp51_ = scaled_dim;
#line 2376 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp52_ = _tmp51_.height;
#line 2376 "/home/jens/Source/shotwell/src/Page.vala"
		_vala_assert (_tmp50_ >= _tmp52_, "height >= scaled_dim.height");
#line 2379 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp53_ = width;
#line 2379 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp54_ = scaled_dim;
#line 2379 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp55_ = _tmp54_.width;
#line 2379 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->scaled_pos.x = (_tmp53_ - _tmp55_) / 2;
#line 2380 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp56_ = height;
#line 2380 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp57_ = scaled_dim;
#line 2380 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp58_ = _tmp57_.height;
#line 2380 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->scaled_pos.y = (_tmp56_ - _tmp58_) / 2;
#line 2381 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp59_ = scaled_dim;
#line 2381 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp60_ = _tmp59_.width;
#line 2381 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->scaled_pos.width = _tmp60_;
#line 2382 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp61_ = scaled_dim;
#line 2382 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp62_ = _tmp61_.height;
#line 2382 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->scaled_pos.height = _tmp62_;
#line 14658 "Page.c"
	}
#line 2385 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp64_ = fast;
#line 2385 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp64_) {
#line 2385 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp63_ = SINGLE_PHOTO_PAGE_FAST_INTERP;
#line 14666 "Page.c"
	} else {
#line 2385 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp63_ = SINGLE_PHOTO_PAGE_QUALITY_INTERP;
#line 14670 "Page.c"
	}
#line 2385 "/home/jens/Source/shotwell/src/Page.vala"
	interp = _tmp63_;
#line 2388 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp65_ = self->priv->scaled;
#line 2388 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp65_ == NULL) {
#line 14678 "Page.c"
		GdkPixbuf* _tmp66_;
		GdkRectangle _tmp67_;
		Dimensions _tmp68_ = {0};
		GdkInterpType _tmp69_;
		GdkPixbuf* _tmp70_;
		SinglePhotoPageUpdateReason reason = 0;
		gboolean _tmp71_;
		Dimensions _tmp75_;
		Dimensions _tmp76_;
		gdouble _tmp77_;
		GdkPoint _tmp78_ = {0};
		GdkPixbuf* _tmp79_;
		SinglePhotoPageUpdateReason _tmp80_;
		Dimensions _tmp81_;
#line 2389 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp66_ = self->priv->unscaled;
#line 2389 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp67_ = self->priv->scaled_pos;
#line 2389 "/home/jens/Source/shotwell/src/Page.vala"
		dimensions_for_rectangle (&_tmp67_, &_tmp68_);
#line 2389 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp69_ = interp;
#line 2389 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp70_ = resize_pixbuf (_tmp66_, &_tmp68_, _tmp69_);
#line 2389 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (self->priv->scaled);
#line 2389 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->scaled = _tmp70_;
#line 2391 "/home/jens/Source/shotwell/src/Page.vala"
		reason = SINGLE_PHOTO_PAGE_UPDATE_REASON_RESIZED_CANVAS;
#line 2392 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp71_ = new_pixbuf;
#line 2392 "/home/jens/Source/shotwell/src/Page.vala"
		if (_tmp71_) {
#line 2393 "/home/jens/Source/shotwell/src/Page.vala"
			reason = SINGLE_PHOTO_PAGE_UPDATE_REASON_NEW_PIXBUF;
#line 14715 "Page.c"
		} else {
			gboolean _tmp72_ = FALSE;
			gboolean _tmp73_;
#line 2394 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp73_ = new_pixmap;
#line 2394 "/home/jens/Source/shotwell/src/Page.vala"
			if (!_tmp73_) {
#line 14723 "Page.c"
				GdkInterpType _tmp74_;
#line 2394 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp74_ = interp;
#line 2394 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp72_ = _tmp74_ == SINGLE_PHOTO_PAGE_QUALITY_INTERP;
#line 14729 "Page.c"
			} else {
#line 2394 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp72_ = FALSE;
#line 14733 "Page.c"
			}
#line 2394 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp72_) {
#line 2395 "/home/jens/Source/shotwell/src/Page.vala"
				reason = SINGLE_PHOTO_PAGE_UPDATE_REASON_QUALITY_IMPROVEMENT;
#line 14739 "Page.c"
			}
		}
#line 2397 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp75_ = self->priv->max_dim;
#line 2397 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp76_ = self->priv->pixmap_dim;
#line 2397 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp77_ = zoom_state_get_interpolation_factor (&self->priv->static_zoom_state);
#line 2397 "/home/jens/Source/shotwell/src/Page.vala"
		zoom_state_get_viewport_center (&self->priv->static_zoom_state, &_tmp78_);
#line 2397 "/home/jens/Source/shotwell/src/Page.vala"
		zoom_state_init (&self->priv->static_zoom_state, &_tmp75_, &_tmp76_, _tmp77_, &_tmp78_);
#line 2401 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp79_ = self->priv->scaled;
#line 2401 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp80_ = reason;
#line 2401 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp81_ = old_scaled_dim;
#line 2401 "/home/jens/Source/shotwell/src/Page.vala"
		single_photo_page_updated_pixbuf (self, _tmp79_, _tmp80_, &_tmp81_);
#line 14760 "Page.c"
	}
#line 2404 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp82_ = fast;
#line 2404 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->zoom_high_quality = !_tmp82_;
#line 2406 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp84_ = direction;
#line 2406 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp84_ != NULL) {
#line 14770 "Page.c"
		TransitionClock* _tmp85_;
		gboolean _tmp86_;
#line 2406 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp85_ = self->priv->transition_clock;
#line 2406 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp86_ = transition_clock_is_in_progress (_tmp85_);
#line 2406 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp83_ = !_tmp86_;
#line 14779 "Page.c"
	} else {
#line 2406 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp83_ = FALSE;
#line 14783 "Page.c"
	}
#line 2406 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp83_) {
#line 14787 "Page.c"
		SpitTransitionsVisuals* visuals = NULL;
		GdkPixbuf* _tmp87_;
		GdkRectangle _tmp88_;
		GdkPixbuf* _tmp89_;
		GdkRectangle _tmp90_;
		GdkRGBA _tmp91_ = {0};
		SpitTransitionsVisuals* _tmp92_;
		TransitionClock* _tmp93_;
		SpitTransitionsVisuals* _tmp94_;
		Direction* _tmp95_;
		SpitTransitionsDirection _tmp96_;
		gint _tmp97_;
#line 2407 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp87_ = self->priv->old_scaled;
#line 2407 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp88_ = old_scaled_pos;
#line 2407 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp89_ = self->priv->scaled;
#line 2407 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp90_ = self->priv->scaled_pos;
#line 2407 "/home/jens/Source/shotwell/src/Page.vala"
		parse_color ("#000", &_tmp91_);
#line 2407 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp92_ = spit_transitions_visuals_new (_tmp87_, &_tmp88_, _tmp89_, &_tmp90_, &_tmp91_);
#line 2407 "/home/jens/Source/shotwell/src/Page.vala"
		visuals = _tmp92_;
#line 2410 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp93_ = self->priv->transition_clock;
#line 2410 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp94_ = visuals;
#line 2410 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp95_ = direction;
#line 2410 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp96_ = direction_to_transition_direction (*_tmp95_);
#line 2410 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp97_ = self->priv->transition_duration_msec;
#line 2410 "/home/jens/Source/shotwell/src/Page.vala"
		transition_clock_start (_tmp93_, _tmp94_, _tmp96_, _tmp97_, _single_photo_page_repaint_pixmap_transition_clock_repaint_callback, self);
#line 2406 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (visuals);
#line 14828 "Page.c"
	}
#line 2414 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp98_ = self->priv->transition_clock;
#line 2414 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp99_ = transition_clock_is_in_progress (_tmp98_);
#line 2414 "/home/jens/Source/shotwell/src/Page.vala"
	if (!_tmp99_) {
#line 2415 "/home/jens/Source/shotwell/src/Page.vala"
		single_photo_page_repaint_pixmap (self);
#line 14838 "Page.c"
	}
}


static void single_photo_page_init_pixmap (SinglePhotoPage* self, gint width, gint height) {
	GdkPixbuf* _tmp0_;
	GtkDrawingArea* _tmp1_;
	GdkWindow* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	cairo_surface_t* _tmp5_;
	gint _tmp6_;
	gint _tmp7_;
	cairo_surface_t* _tmp8_;
	cairo_t* _tmp9_;
	cairo_surface_t* _tmp10_;
	cairo_t* _tmp11_;
	cairo_t* _tmp12_;
	cairo_t* _tmp13_;
	Dimensions _tmp14_;
#line 2418 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2419 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->unscaled;
#line 2419 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp0_ != NULL, "unscaled != null");
#line 2420 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = self->canvas;
#line 2420 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 2420 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp2_ != NULL, "canvas.get_window() != null");
#line 2423 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = width;
#line 2423 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = height;
#line 2423 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = cairo_image_surface_create (CAIRO_FORMAT_ARGB32, _tmp3_, _tmp4_);
#line 2423 "/home/jens/Source/shotwell/src/Page.vala"
	_cairo_surface_destroy0 (self->priv->pixmap);
#line 2423 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->pixmap = _tmp5_;
#line 2424 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = width;
#line 2424 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp7_ = height;
#line 2424 "/home/jens/Source/shotwell/src/Page.vala"
	dimensions_init (&self->priv->pixmap_dim, _tmp6_, _tmp7_);
#line 2427 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = self->priv->pixmap;
#line 2427 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = cairo_create (_tmp8_);
#line 2427 "/home/jens/Source/shotwell/src/Page.vala"
	_cairo_destroy0 (self->priv->pixmap_ctx);
#line 2427 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->pixmap_ctx = _tmp9_;
#line 2430 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->scaled);
#line 2430 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->scaled = NULL;
#line 2433 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp10_ = self->priv->pixmap;
#line 2433 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = cairo_create (_tmp10_);
#line 2433 "/home/jens/Source/shotwell/src/Page.vala"
	_cairo_destroy0 (self->priv->text_ctx);
#line 2433 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->text_ctx = _tmp11_;
#line 2434 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = self->priv->text_ctx;
#line 2434 "/home/jens/Source/shotwell/src/Page.vala"
	set_source_color_from_string (_tmp12_, "#fff");
#line 2439 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp13_ = self->priv->pixmap_ctx;
#line 2439 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp14_ = self->priv->pixmap_dim;
#line 2439 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_new_surface (self, _tmp13_, &_tmp14_);
#line 14917 "Page.c"
}


static gboolean single_photo_page_real_on_context_keypress (Page* base) {
	SinglePhotoPage * self;
	gboolean result = FALSE;
	GtkMenu* _tmp0_;
	GtkMenu* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
#line 2442 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPage);
#line 2443 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page_get_page_context_menu (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page));
#line 2443 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_;
#line 2443 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = page_popup_context_menu (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), _tmp1_, NULL);
#line 2443 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = _tmp2_;
#line 2443 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (_tmp1_);
#line 2443 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp3_;
#line 2443 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 14944 "Page.c"
}


static void single_photo_page_real_on_previous_photo (SinglePhotoPage* self) {
}


void single_photo_page_on_previous_photo (SinglePhotoPage* self) {
#line 2446 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2446 "/home/jens/Source/shotwell/src/Page.vala"
	SINGLE_PHOTO_PAGE_GET_CLASS (self)->on_previous_photo (self);
#line 14957 "Page.c"
}


static void single_photo_page_real_on_next_photo (SinglePhotoPage* self) {
}


void single_photo_page_on_next_photo (SinglePhotoPage* self) {
#line 2449 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_SINGLE_PHOTO_PAGE (self));
#line 2449 "/home/jens/Source/shotwell/src/Page.vala"
	SINGLE_PHOTO_PAGE_GET_CLASS (self)->on_next_photo (self);
#line 14970 "Page.c"
}


static gboolean single_photo_page_real_key_press_event (GtkWidget* base, GdkEventKey* event) {
	SinglePhotoPage * self;
	gboolean result = FALSE;
	gboolean nav_ok = FALSE;
	GdkEventKey* _tmp0_;
	guint32 _tmp1_;
	guint32 _tmp2_;
	gboolean handled = FALSE;
	GdkEventKey* _tmp3_;
	guint _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	GQuark _tmp8_ = 0U;
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp7_label0 = 0;
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp7_label1 = 0;
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp7_label2 = 0;
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp7_label3 = 0;
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp7_label4 = 0;
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
	static GQuark _tmp7_label5 = 0;
#line 14999 "Page.c"
	gboolean _tmp15_;
	gboolean _tmp16_ = FALSE;
#line 2452 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPage);
#line 2452 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 2456 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = event;
#line 2456 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = _tmp0_->time;
#line 2456 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = self->priv->last_nav_key;
#line 2456 "/home/jens/Source/shotwell/src/Page.vala"
	nav_ok = (_tmp1_ - _tmp2_) > ((guint32) SINGLE_PHOTO_PAGE_KEY_REPEAT_INTERVAL_MSEC);
#line 2458 "/home/jens/Source/shotwell/src/Page.vala"
	handled = TRUE;
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = event;
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = _tmp3_->keyval;
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = gdk_keyval_name (_tmp4_);
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = _tmp5_;
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp8_ = (NULL == _tmp6_) ? 0 : g_quark_from_string (_tmp6_);
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
	if (((_tmp8_ == ((0 != _tmp7_label0) ? _tmp7_label0 : (_tmp7_label0 = g_quark_from_static_string ("Left")))) || (_tmp8_ == ((0 != _tmp7_label1) ? _tmp7_label1 : (_tmp7_label1 = g_quark_from_static_string ("KP_Left"))))) || (_tmp8_ == ((0 != _tmp7_label2) ? _tmp7_label2 : (_tmp7_label2 = g_quark_from_static_string ("BackSpace"))))) {
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 15030 "Page.c"
			default:
			{
				gboolean _tmp9_;
#line 2463 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp9_ = nav_ok;
#line 2463 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp9_) {
#line 15038 "Page.c"
					GdkEventKey* _tmp10_;
					guint32 _tmp11_;
#line 2464 "/home/jens/Source/shotwell/src/Page.vala"
					single_photo_page_on_previous_photo (self);
#line 2465 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp10_ = event;
#line 2465 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp11_ = _tmp10_->time;
#line 2465 "/home/jens/Source/shotwell/src/Page.vala"
					self->priv->last_nav_key = _tmp11_;
#line 15049 "Page.c"
				}
#line 2467 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 15053 "Page.c"
			}
		}
	} else if (((_tmp8_ == ((0 != _tmp7_label3) ? _tmp7_label3 : (_tmp7_label3 = g_quark_from_static_string ("Right")))) || (_tmp8_ == ((0 != _tmp7_label4) ? _tmp7_label4 : (_tmp7_label4 = g_quark_from_static_string ("KP_Right"))))) || (_tmp8_ == ((0 != _tmp7_label5) ? _tmp7_label5 : (_tmp7_label5 = g_quark_from_static_string ("space"))))) {
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 15059 "Page.c"
			default:
			{
				gboolean _tmp12_;
#line 2472 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp12_ = nav_ok;
#line 2472 "/home/jens/Source/shotwell/src/Page.vala"
				if (_tmp12_) {
#line 15067 "Page.c"
					GdkEventKey* _tmp13_;
					guint32 _tmp14_;
#line 2473 "/home/jens/Source/shotwell/src/Page.vala"
					single_photo_page_on_next_photo (self);
#line 2474 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp13_ = event;
#line 2474 "/home/jens/Source/shotwell/src/Page.vala"
					_tmp14_ = _tmp13_->time;
#line 2474 "/home/jens/Source/shotwell/src/Page.vala"
					self->priv->last_nav_key = _tmp14_;
#line 15078 "Page.c"
				}
#line 2476 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 15082 "Page.c"
			}
		}
	} else {
#line 2459 "/home/jens/Source/shotwell/src/Page.vala"
		switch (0) {
#line 15088 "Page.c"
			default:
			{
#line 2479 "/home/jens/Source/shotwell/src/Page.vala"
				handled = FALSE;
#line 2480 "/home/jens/Source/shotwell/src/Page.vala"
				break;
#line 15095 "Page.c"
			}
		}
	}
#line 2483 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp15_ = handled;
#line 2483 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp15_) {
#line 2484 "/home/jens/Source/shotwell/src/Page.vala"
		result = TRUE;
#line 2484 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 15107 "Page.c"
	}
#line 2486 "/home/jens/Source/shotwell/src/Page.vala"
	if (GTK_WIDGET_CLASS (single_photo_page_parent_class)->key_press_event != NULL) {
#line 15111 "Page.c"
		GdkEventKey* _tmp17_;
		gboolean _tmp18_;
#line 2486 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp17_ = event;
#line 2486 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp18_ = GTK_WIDGET_CLASS (single_photo_page_parent_class)->key_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_PAGE, Page), gtk_widget_get_type (), GtkWidget), _tmp17_);
#line 2486 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp16_ = _tmp18_;
#line 15120 "Page.c"
	} else {
#line 2486 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp16_ = TRUE;
#line 15124 "Page.c"
	}
#line 2486 "/home/jens/Source/shotwell/src/Page.vala"
	result = _tmp16_;
#line 2486 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 15130 "Page.c"
}


static void single_photo_page_class_init (SinglePhotoPageClass * klass) {
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	single_photo_page_parent_class = g_type_class_peek_parent (klass);
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	g_type_class_add_private (klass, sizeof (SinglePhotoPagePrivate));
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((SinglePhotoPageClass *) klass)->is_zoom_supported = (gboolean (*) (SinglePhotoPage *)) single_photo_page_real_is_zoom_supported;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((SinglePhotoPageClass *) klass)->cancel_zoom = (void (*) (SinglePhotoPage *)) single_photo_page_real_cancel_zoom;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((SinglePhotoPageClass *) klass)->save_zoom_state = (void (*) (SinglePhotoPage *)) single_photo_page_real_save_zoom_state;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((SinglePhotoPageClass *) klass)->restore_zoom_state = (void (*) (SinglePhotoPage *)) single_photo_page_real_restore_zoom_state;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((SinglePhotoPageClass *) klass)->get_zoom_buffer = (ZoomBuffer* (*) (SinglePhotoPage *)) single_photo_page_real_get_zoom_buffer;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->switched_to = (void (*) (Page *)) single_photo_page_real_switched_to;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->set_container = (void (*) (Page *, GtkWindow*)) single_photo_page_real_set_container;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_resize_finished = (void (*) (Page *, GdkRectangle*)) single_photo_page_real_on_resize_finished;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((SinglePhotoPageClass *) klass)->new_surface = (void (*) (SinglePhotoPage *, cairo_t*, Dimensions*)) single_photo_page_real_new_surface;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((SinglePhotoPageClass *) klass)->updated_pixbuf = (void (*) (SinglePhotoPage *, GdkPixbuf*, SinglePhotoPageUpdateReason, Dimensions*)) single_photo_page_real_updated_pixbuf;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((SinglePhotoPageClass *) klass)->paint = (void (*) (SinglePhotoPage *, cairo_t*, Dimensions*)) single_photo_page_real_paint;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((PageClass *) klass)->on_context_keypress = (gboolean (*) (Page *)) single_photo_page_real_on_context_keypress;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((SinglePhotoPageClass *) klass)->on_previous_photo = (void (*) (SinglePhotoPage *)) single_photo_page_real_on_previous_photo;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((SinglePhotoPageClass *) klass)->on_next_photo = (void (*) (SinglePhotoPage *)) single_photo_page_real_on_next_photo;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	((GtkWidgetClass *) klass)->key_press_event = (gboolean (*) (GtkWidget *, GdkEventKey*)) single_photo_page_real_key_press_event;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	G_OBJECT_CLASS (klass)->finalize = single_photo_page_finalize;
#line 15171 "Page.c"
}


static void single_photo_page_instance_init (SinglePhotoPage * self) {
	GtkDrawingArea* _tmp0_;
	GtkViewport* _tmp1_;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv = SINGLE_PHOTO_PAGE_GET_PRIVATE (self);
#line 1986 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = (GtkDrawingArea*) gtk_drawing_area_new ();
#line 1986 "/home/jens/Source/shotwell/src/Page.vala"
	g_object_ref_sink (_tmp0_);
#line 1986 "/home/jens/Source/shotwell/src/Page.vala"
	self->canvas = _tmp0_;
#line 1987 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = (GtkViewport*) gtk_viewport_new (NULL, NULL);
#line 1987 "/home/jens/Source/shotwell/src/Page.vala"
	g_object_ref_sink (_tmp1_);
#line 1987 "/home/jens/Source/shotwell/src/Page.vala"
	self->viewport = _tmp1_;
#line 1991 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->transition_duration_msec = 0;
#line 1992 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->pixmap = NULL;
#line 1993 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->pixmap_ctx = NULL;
#line 1994 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->text_ctx = NULL;
#line 1995 "/home/jens/Source/shotwell/src/Page.vala"
	dimensions_init (&self->priv->pixmap_dim, 0, 0);
#line 1996 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->unscaled = NULL;
#line 1997 "/home/jens/Source/shotwell/src/Page.vala"
	dimensions_init (&self->priv->max_dim, 0, 0);
#line 1998 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->scaled = NULL;
#line 1999 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->old_scaled = NULL;
#line 2000 "/home/jens/Source/shotwell/src/Page.vala"
	memset (&self->priv->scaled_pos, 0, sizeof (GdkRectangle));
#line 2002 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->zoom_high_quality = TRUE;
#line 2004 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->has_saved_zoom_state = FALSE;
#line 2005 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->last_nav_key = (guint32) 0;
#line 15218 "Page.c"
}


static void single_photo_page_finalize (GObject * obj) {
	SinglePhotoPage * self;
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SINGLE_PHOTO_PAGE, SinglePhotoPage);
#line 1986 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->canvas);
#line 1987 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->viewport);
#line 1990 "/home/jens/Source/shotwell/src/Page.vala"
	_transition_clock_unref0 (self->priv->transition_clock);
#line 1992 "/home/jens/Source/shotwell/src/Page.vala"
	_cairo_surface_destroy0 (self->priv->pixmap);
#line 1993 "/home/jens/Source/shotwell/src/Page.vala"
	_cairo_destroy0 (self->priv->pixmap_ctx);
#line 1994 "/home/jens/Source/shotwell/src/Page.vala"
	_cairo_destroy0 (self->priv->text_ctx);
#line 1996 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->unscaled);
#line 1998 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->scaled);
#line 1999 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->old_scaled);
#line 1975 "/home/jens/Source/shotwell/src/Page.vala"
	G_OBJECT_CLASS (single_photo_page_parent_class)->finalize (obj);
#line 15246 "Page.c"
}


GType single_photo_page_get_type (void) {
	static volatile gsize single_photo_page_type_id__volatile = 0;
	if (g_once_init_enter (&single_photo_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SinglePhotoPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) single_photo_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SinglePhotoPage), 0, (GInstanceInitFunc) single_photo_page_instance_init, NULL };
		GType single_photo_page_type_id;
		single_photo_page_type_id = g_type_register_static (TYPE_PAGE, "SinglePhotoPage", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&single_photo_page_type_id__volatile, single_photo_page_type_id);
	}
	return single_photo_page_type_id__volatile;
}


static void _drag_and_drop_handler_on_drag_begin_gtk_widget_drag_begin (GtkWidget* _sender, GdkDragContext* context, gpointer self) {
#line 2545 "/home/jens/Source/shotwell/src/Page.vala"
	drag_and_drop_handler_on_drag_begin ((DragAndDropHandler*) self, context);
#line 15265 "Page.c"
}


static void _drag_and_drop_handler_on_drag_data_get_gtk_widget_drag_data_get (GtkWidget* _sender, GdkDragContext* context, GtkSelectionData* selection_data, guint info, guint time_, gpointer self) {
#line 2546 "/home/jens/Source/shotwell/src/Page.vala"
	drag_and_drop_handler_on_drag_data_get ((DragAndDropHandler*) self, context, selection_data, info, time_);
#line 15272 "Page.c"
}


static void _drag_and_drop_handler_on_drag_end_gtk_widget_drag_end (GtkWidget* _sender, GdkDragContext* context, gpointer self) {
#line 2547 "/home/jens/Source/shotwell/src/Page.vala"
	drag_and_drop_handler_on_drag_end ((DragAndDropHandler*) self);
#line 15279 "Page.c"
}


static gboolean _drag_and_drop_handler_on_drag_failed_gtk_widget_drag_failed (GtkWidget* _sender, GdkDragContext* context, GtkDragResult _result_, gpointer self) {
	gboolean result;
	result = drag_and_drop_handler_on_drag_failed ((DragAndDropHandler*) self, context, _result_);
#line 2548 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 15288 "Page.c"
}


static GType drag_and_drop_handler_target_type_get_type (void) {
	static volatile gsize drag_and_drop_handler_target_type_type_id__volatile = 0;
	if (g_once_init_enter (&drag_and_drop_handler_target_type_type_id__volatile)) {
		static const GEnumValue values[] = {{DRAG_AND_DROP_HANDLER_TARGET_TYPE_XDS, "DRAG_AND_DROP_HANDLER_TARGET_TYPE_XDS", "xds"}, {DRAG_AND_DROP_HANDLER_TARGET_TYPE_MEDIA_LIST, "DRAG_AND_DROP_HANDLER_TARGET_TYPE_MEDIA_LIST", "media-list"}, {0, NULL, NULL}};
		GType drag_and_drop_handler_target_type_type_id;
		drag_and_drop_handler_target_type_type_id = g_enum_register_static ("DragAndDropHandlerTargetType", values);
		g_once_init_leave (&drag_and_drop_handler_target_type_type_id__volatile, drag_and_drop_handler_target_type_type_id);
	}
	return drag_and_drop_handler_target_type_type_id__volatile;
}


static GdkAtom* _gdk_atom_dup (GdkAtom* self) {
	GdkAtom* dup;
#line 2523 "/home/jens/Source/shotwell/src/Page.vala"
	dup = g_new0 (GdkAtom, 1);
#line 2523 "/home/jens/Source/shotwell/src/Page.vala"
	memcpy (dup, self, sizeof (GdkAtom));
#line 2523 "/home/jens/Source/shotwell/src/Page.vala"
	return dup;
#line 15312 "Page.c"
}


static gpointer __gdk_atom_dup0 (gpointer self) {
#line 2523 "/home/jens/Source/shotwell/src/Page.vala"
	return self ? _gdk_atom_dup (self) : NULL;
#line 15319 "Page.c"
}


DragAndDropHandler* drag_and_drop_handler_construct (GType object_type, Page* page) {
	DragAndDropHandler* self = NULL;
	Page* _tmp0_;
	Page* _tmp1_;
	GtkWidget* _tmp2_;
	GtkWidget* _tmp3_;
	GtkWidget* _tmp4_;
	gboolean _tmp5_;
	GdkAtom* _tmp6_;
	GdkAtom* _tmp9_;
	guint8* _tmp12_;
	gint _tmp12__length1;
	GtkWidget* _tmp15_;
	GtkWidget* _tmp16_;
	GtkWidget* _tmp17_;
	GtkWidget* _tmp18_;
	GtkWidget* _tmp19_;
#line 2515 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_PAGE (page), NULL);
#line 2515 "/home/jens/Source/shotwell/src/Page.vala"
	self = (DragAndDropHandler*) g_type_create_instance (object_type);
#line 2516 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = page;
#line 2516 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->page = _tmp0_;
#line 2517 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page;
#line 2517 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = page_get_event_source (_tmp1_);
#line 2517 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->event_source);
#line 2517 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->event_source = _tmp2_;
#line 2518 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = self->priv->event_source;
#line 2518 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp3_ != NULL, "event_source != null");
#line 2519 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = self->priv->event_source;
#line 2519 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = gtk_widget_get_has_window (_tmp4_);
#line 2519 "/home/jens/Source/shotwell/src/Page.vala"
	_vala_assert (_tmp5_, "event_source.get_has_window()");
#line 2522 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = drag_and_drop_handler_XDS_ATOM;
#line 2522 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp6_ == NULL) {
#line 15370 "Page.c"
		GdkAtom _tmp7_;
		GdkAtom* _tmp8_;
#line 2523 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = gdk_atom_intern_static_string ("XdndDirectSave0");
#line 2523 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = __gdk_atom_dup0 (&_tmp7_);
#line 2523 "/home/jens/Source/shotwell/src/Page.vala"
		_g_free0 (drag_and_drop_handler_XDS_ATOM);
#line 2523 "/home/jens/Source/shotwell/src/Page.vala"
		drag_and_drop_handler_XDS_ATOM = _tmp8_;
#line 15381 "Page.c"
	}
#line 2525 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = drag_and_drop_handler_TEXT_ATOM;
#line 2525 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp9_ == NULL) {
#line 15387 "Page.c"
		GdkAtom _tmp10_;
		GdkAtom* _tmp11_;
#line 2526 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = gdk_atom_intern_static_string ("text/plain");
#line 2526 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = __gdk_atom_dup0 (&_tmp10_);
#line 2526 "/home/jens/Source/shotwell/src/Page.vala"
		_g_free0 (drag_and_drop_handler_TEXT_ATOM);
#line 2526 "/home/jens/Source/shotwell/src/Page.vala"
		drag_and_drop_handler_TEXT_ATOM = _tmp11_;
#line 15398 "Page.c"
	}
#line 2528 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = drag_and_drop_handler_XDS_FAKE_TARGET;
#line 2528 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12__length1 = drag_and_drop_handler_XDS_FAKE_TARGET_length1;
#line 2528 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp12_ == NULL) {
#line 15406 "Page.c"
		gint _tmp13_;
		guchar* _tmp14_;
#line 2529 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp14_ = string_to_uchar_array ("shotwell.txt", &_tmp13_);
#line 2529 "/home/jens/Source/shotwell/src/Page.vala"
		drag_and_drop_handler_XDS_FAKE_TARGET = (g_free (drag_and_drop_handler_XDS_FAKE_TARGET), NULL);
#line 2529 "/home/jens/Source/shotwell/src/Page.vala"
		drag_and_drop_handler_XDS_FAKE_TARGET = _tmp14_;
#line 2529 "/home/jens/Source/shotwell/src/Page.vala"
		drag_and_drop_handler_XDS_FAKE_TARGET_length1 = _tmp13_;
#line 2529 "/home/jens/Source/shotwell/src/Page.vala"
		_drag_and_drop_handler_XDS_FAKE_TARGET_size_ = drag_and_drop_handler_XDS_FAKE_TARGET_length1;
#line 15419 "Page.c"
	}
#line 2532 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp15_ = self->priv->event_source;
#line 2532 "/home/jens/Source/shotwell/src/Page.vala"
	gtk_drag_source_set (_tmp15_, GDK_BUTTON1_MASK, DRAG_AND_DROP_HANDLER_SOURCE_TARGET_ENTRIES, G_N_ELEMENTS (DRAG_AND_DROP_HANDLER_SOURCE_TARGET_ENTRIES), GDK_ACTION_COPY);
#line 2537 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp16_ = self->priv->event_source;
#line 2537 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect (_tmp16_, "drag-begin", (GCallback) _drag_and_drop_handler_on_drag_begin_gtk_widget_drag_begin, self);
#line 2538 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp17_ = self->priv->event_source;
#line 2538 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect (_tmp17_, "drag-data-get", (GCallback) _drag_and_drop_handler_on_drag_data_get_gtk_widget_drag_data_get, self);
#line 2539 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp18_ = self->priv->event_source;
#line 2539 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect (_tmp18_, "drag-end", (GCallback) _drag_and_drop_handler_on_drag_end_gtk_widget_drag_end, self);
#line 2540 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp19_ = self->priv->event_source;
#line 2540 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_connect (_tmp19_, "drag-failed", (GCallback) _drag_and_drop_handler_on_drag_failed_gtk_widget_drag_failed, self);
#line 2515 "/home/jens/Source/shotwell/src/Page.vala"
	return self;
#line 15443 "Page.c"
}


DragAndDropHandler* drag_and_drop_handler_new (Page* page) {
#line 2515 "/home/jens/Source/shotwell/src/Page.vala"
	return drag_and_drop_handler_construct (TYPE_DRAG_AND_DROP_HANDLER, page);
#line 15450 "Page.c"
}


static void drag_and_drop_handler_on_drag_begin (DragAndDropHandler* self, GdkDragContext* context) {
	Page* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	Page* _tmp5_;
	ThumbnailSource* thumb = NULL;
	Page* _tmp11_;
	ViewCollection* _tmp12_;
	ViewCollection* _tmp13_;
	DataView* _tmp14_;
	DataView* _tmp15_;
	DataSource* _tmp16_;
	ThumbnailSource* _tmp17_;
	GdkDragContext* _tmp27_;
	GdkWindow* _tmp28_;
	GdkAtom* _tmp29_;
	GdkAtom* _tmp30_;
	guint8* _tmp31_;
	gint _tmp31__length1;
	GError * _inner_error_ = NULL;
#line 2555 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_DRAG_AND_DROP_HANDLER (self));
#line 2555 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (context));
#line 2556 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->page;
#line 2556 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_page_name (_tmp0_);
#line 2556 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_;
#line 2556 "/home/jens/Source/shotwell/src/Page.vala"
	g_debug ("Page.vala:2556: on_drag_begin (%s)", _tmp2_);
#line 2556 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (_tmp2_);
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp5_ = self->priv->page;
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp5_ == NULL) {
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = TRUE;
#line 15496 "Page.c"
	} else {
		Page* _tmp6_;
		ViewCollection* _tmp7_;
		ViewCollection* _tmp8_;
		gint _tmp9_;
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = self->priv->page;
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = page_get_view (_tmp6_);
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = _tmp7_;
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = view_collection_get_selected_count (_tmp8_);
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = _tmp9_ == 0;
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp8_);
#line 15514 "Page.c"
	}
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_) {
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = TRUE;
#line 15520 "Page.c"
	} else {
		ExporterUI* _tmp10_;
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = self->priv->exporter;
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = _tmp10_ != NULL;
#line 15527 "Page.c"
	}
#line 2558 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_) {
#line 2559 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 15533 "Page.c"
	}
#line 2561 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->drag_destination);
#line 2561 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->drag_destination = NULL;
#line 2564 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp11_ = self->priv->page;
#line 2564 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp12_ = page_get_view (_tmp11_);
#line 2564 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp13_ = _tmp12_;
#line 2564 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp14_ = view_collection_get_selected_at (_tmp13_, 0);
#line 2564 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp15_ = _tmp14_;
#line 2564 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp16_ = data_view_get_source (_tmp15_);
#line 2564 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp17_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_THUMBNAIL_SOURCE, ThumbnailSource);
#line 2564 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (_tmp15_);
#line 2564 "/home/jens/Source/shotwell/src/Page.vala"
	_data_collection_unref0 (_tmp13_);
#line 2564 "/home/jens/Source/shotwell/src/Page.vala"
	thumb = _tmp17_;
#line 15559 "Page.c"
	{
		GdkPixbuf* icon = NULL;
		ThumbnailSource* _tmp18_;
		GdkPixbuf* _tmp19_;
		GtkWidget* _tmp20_;
		GdkPixbuf* _tmp21_;
#line 2567 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp18_ = thumb;
#line 2567 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp19_ = thumbnail_source_get_thumbnail (_tmp18_, APP_WINDOW_DND_ICON_SCALE, &_inner_error_);
#line 2567 "/home/jens/Source/shotwell/src/Page.vala"
		icon = _tmp19_;
#line 2567 "/home/jens/Source/shotwell/src/Page.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 15574 "Page.c"
			goto __catch256_g_error;
		}
#line 2568 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp20_ = self->priv->event_source;
#line 2568 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp21_ = icon;
#line 2568 "/home/jens/Source/shotwell/src/Page.vala"
		gtk_drag_source_set_icon_pixbuf (_tmp20_, _tmp21_);
#line 2566 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (icon);
#line 15585 "Page.c"
	}
	goto __finally256;
	__catch256_g_error:
	{
		GError* err = NULL;
		ThumbnailSource* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		GError* _tmp25_;
		const gchar* _tmp26_;
#line 2566 "/home/jens/Source/shotwell/src/Page.vala"
		err = _inner_error_;
#line 2566 "/home/jens/Source/shotwell/src/Page.vala"
		_inner_error_ = NULL;
#line 2570 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp22_ = thumb;
#line 2570 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp23_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, TYPE_DATA_OBJECT, DataObject));
#line 2570 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp24_ = _tmp23_;
#line 2570 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp25_ = err;
#line 2570 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp26_ = _tmp25_->message;
#line 2570 "/home/jens/Source/shotwell/src/Page.vala"
		g_warning ("Page.vala:2570: Unable to fetch icon for drag-and-drop from %s: %s", _tmp24_, _tmp26_);
#line 2570 "/home/jens/Source/shotwell/src/Page.vala"
		_g_free0 (_tmp24_);
#line 2566 "/home/jens/Source/shotwell/src/Page.vala"
		_g_error_free0 (err);
#line 15616 "Page.c"
	}
	__finally256:
#line 2566 "/home/jens/Source/shotwell/src/Page.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2566 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (thumb);
#line 2566 "/home/jens/Source/shotwell/src/Page.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2566 "/home/jens/Source/shotwell/src/Page.vala"
		g_clear_error (&_inner_error_);
#line 2566 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 15629 "Page.c"
	}
#line 2576 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp27_ = context;
#line 2576 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp28_ = gdk_drag_context_get_source_window (_tmp27_);
#line 2576 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp29_ = drag_and_drop_handler_XDS_ATOM;
#line 2576 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp30_ = drag_and_drop_handler_TEXT_ATOM;
#line 2576 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp31_ = drag_and_drop_handler_XDS_FAKE_TARGET;
#line 2576 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp31__length1 = drag_and_drop_handler_XDS_FAKE_TARGET_length1;
#line 2576 "/home/jens/Source/shotwell/src/Page.vala"
	gdk_property_change (_tmp28_, *_tmp29_, *_tmp30_, 8, GDK_PROP_MODE_REPLACE, (const guchar*) _tmp31_, 1);
#line 2555 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (thumb);
#line 15647 "Page.c"
}


static void drag_and_drop_handler_on_drag_data_get (DragAndDropHandler* self, GdkDragContext* context, GtkSelectionData* selection_data, guint target_type, guint time) {
	Page* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gboolean _tmp3_ = FALSE;
	Page* _tmp4_;
	guint _tmp9_;
#line 2584 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_DRAG_AND_DROP_HANDLER (self));
#line 2584 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (context));
#line 2584 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (selection_data != NULL);
#line 2586 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->page;
#line 2586 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_page_name (_tmp0_);
#line 2586 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_;
#line 2586 "/home/jens/Source/shotwell/src/Page.vala"
	g_debug ("Page.vala:2586: on_drag_data_get (%s)", _tmp2_);
#line 2586 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (_tmp2_);
#line 2588 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = self->priv->page;
#line 2588 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_ == NULL) {
#line 2588 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = TRUE;
#line 15680 "Page.c"
	} else {
		Page* _tmp5_;
		ViewCollection* _tmp6_;
		ViewCollection* _tmp7_;
		gint _tmp8_;
#line 2588 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = self->priv->page;
#line 2588 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp6_ = page_get_view (_tmp5_);
#line 2588 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = _tmp6_;
#line 2588 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = view_collection_get_selected_count (_tmp7_);
#line 2588 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = _tmp8_ == 0;
#line 2588 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp7_);
#line 15698 "Page.c"
	}
#line 2588 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_) {
#line 2589 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 15704 "Page.c"
	}
#line 2591 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp9_ = target_type;
#line 2591 "/home/jens/Source/shotwell/src/Page.vala"
	switch (_tmp9_) {
#line 2591 "/home/jens/Source/shotwell/src/Page.vala"
		case DRAG_AND_DROP_HANDLER_TARGET_TYPE_XDS:
#line 15712 "Page.c"
		{
			guchar* data = NULL;
			guchar* _tmp10_;
			gint data_length1;
			gint _data_size_;
			GdkAtom actual_type = 0U;
			gint actual_format = 0;
			gboolean fetched = FALSE;
			GdkDragContext* _tmp11_;
			GdkWindow* _tmp12_;
			GdkAtom* _tmp13_;
			GdkAtom* _tmp14_;
			guchar* _tmp15_;
			gint _tmp15__length1;
			GdkAtom _tmp16_ = 0U;
			gint _tmp17_ = 0;
			guint8* _tmp18_ = NULL;
			gint _tmp19_;
			gboolean _tmp20_;
			gboolean _tmp21_ = FALSE;
			gboolean _tmp22_ = FALSE;
			gboolean _tmp23_;
			gchar* _tmp32_ = NULL;
			GFile* _tmp33_;
			Page* _tmp37_;
			gchar* _tmp38_;
			gchar* _tmp39_;
			const gchar* _tmp40_ = NULL;
			GFile* _tmp41_;
			GtkSelectionData* _tmp42_;
			GdkAtom* _tmp43_;
			gint _tmp44_;
			guchar* _tmp45_;
			guchar* _tmp46_;
			gint _tmp46__length1;
#line 2594 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp10_ = g_new0 (guchar, 4096);
#line 2594 "/home/jens/Source/shotwell/src/Page.vala"
			data = _tmp10_;
#line 2594 "/home/jens/Source/shotwell/src/Page.vala"
			data_length1 = 4096;
#line 2594 "/home/jens/Source/shotwell/src/Page.vala"
			_data_size_ = data_length1;
#line 2596 "/home/jens/Source/shotwell/src/Page.vala"
			actual_format = 0;
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp11_ = context;
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp12_ = gdk_drag_context_get_source_window (_tmp11_);
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp13_ = drag_and_drop_handler_XDS_ATOM;
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp14_ = drag_and_drop_handler_TEXT_ATOM;
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp15_ = data;
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp15__length1 = data_length1;
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp20_ = gdk_property_get (_tmp12_, *_tmp13_, *_tmp14_, (gulong) 0, (gulong) _tmp15__length1, 0, &_tmp16_, &_tmp17_, &_tmp19_, &_tmp18_);
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			actual_type = _tmp16_;
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			actual_format = _tmp17_;
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			data = (g_free (data), NULL);
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			data = _tmp18_;
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			data_length1 = _tmp19_;
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			_data_size_ = data_length1;
#line 2597 "/home/jens/Source/shotwell/src/Page.vala"
			fetched = _tmp20_;
#line 2602 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp23_ = fetched;
#line 2602 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp23_) {
#line 15790 "Page.c"
				guchar* _tmp24_;
				gint _tmp24__length1;
#line 2602 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp24_ = data;
#line 2602 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp24__length1 = data_length1;
#line 2602 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp22_ = _tmp24_ != NULL;
#line 15799 "Page.c"
			} else {
#line 2602 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp22_ = FALSE;
#line 15803 "Page.c"
			}
#line 2602 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp22_) {
#line 15807 "Page.c"
				guchar* _tmp25_;
				gint _tmp25__length1;
#line 2602 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp25_ = data;
#line 2602 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp25__length1 = data_length1;
#line 2602 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp21_ = _tmp25__length1 > 0;
#line 15816 "Page.c"
			} else {
#line 2602 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp21_ = FALSE;
#line 15820 "Page.c"
			}
#line 2602 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp21_) {
#line 15824 "Page.c"
				guchar* _tmp26_;
				gint _tmp26__length1;
				gchar* _tmp27_;
				gchar* _tmp28_;
				GFile* _tmp29_;
				GFile* _tmp30_;
				GFile* _tmp31_;
#line 2603 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp26_ = data;
#line 2603 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp26__length1 = data_length1;
#line 2603 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp27_ = uchar_array_to_string (_tmp26_, _tmp26__length1, -1);
#line 2603 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp28_ = _tmp27_;
#line 2603 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp29_ = g_file_new_for_uri (_tmp28_);
#line 2603 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp30_ = _tmp29_;
#line 2603 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp31_ = g_file_get_parent (_tmp30_);
#line 2603 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (self->priv->drag_destination);
#line 2603 "/home/jens/Source/shotwell/src/Page.vala"
				self->priv->drag_destination = _tmp31_;
#line 2603 "/home/jens/Source/shotwell/src/Page.vala"
				_g_object_unref0 (_tmp30_);
#line 2603 "/home/jens/Source/shotwell/src/Page.vala"
				_g_free0 (_tmp28_);
#line 15854 "Page.c"
			}
#line 2606 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp33_ = self->priv->drag_destination;
#line 2606 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp33_ != NULL) {
#line 15860 "Page.c"
				GFile* _tmp34_;
				gchar* _tmp35_;
#line 2606 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp34_ = self->priv->drag_destination;
#line 2606 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp35_ = g_file_get_path (_tmp34_);
#line 2606 "/home/jens/Source/shotwell/src/Page.vala"
				_g_free0 (_tmp32_);
#line 2606 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp32_ = _tmp35_;
#line 15871 "Page.c"
			} else {
				gchar* _tmp36_;
#line 2606 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp36_ = g_strdup ("(no path)");
#line 2606 "/home/jens/Source/shotwell/src/Page.vala"
				_g_free0 (_tmp32_);
#line 2606 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp32_ = _tmp36_;
#line 15880 "Page.c"
			}
#line 2605 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp37_ = self->priv->page;
#line 2605 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp38_ = page_get_page_name (_tmp37_);
#line 2605 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp39_ = _tmp38_;
#line 2605 "/home/jens/Source/shotwell/src/Page.vala"
			g_debug ("Page.vala:2605: on_drag_data_get (%s): %s", _tmp39_, _tmp32_);
#line 2605 "/home/jens/Source/shotwell/src/Page.vala"
			_g_free0 (_tmp39_);
#line 2610 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp41_ = self->priv->drag_destination;
#line 2610 "/home/jens/Source/shotwell/src/Page.vala"
			if (_tmp41_ != NULL) {
#line 2610 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp40_ = "S";
#line 15898 "Page.c"
			} else {
#line 2610 "/home/jens/Source/shotwell/src/Page.vala"
				_tmp40_ = "E";
#line 15902 "Page.c"
			}
#line 2609 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp42_ = selection_data;
#line 2609 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp43_ = drag_and_drop_handler_XDS_ATOM;
#line 2609 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp45_ = string_to_uchar_array (_tmp40_, &_tmp44_);
#line 2609 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp46_ = _tmp45_;
#line 2609 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp46__length1 = _tmp44_;
#line 2609 "/home/jens/Source/shotwell/src/Page.vala"
			gtk_selection_data_set (_tmp42_, *_tmp43_, 8, _tmp46_, _tmp44_);
#line 2609 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp46_ = (g_free (_tmp46_), NULL);
#line 2611 "/home/jens/Source/shotwell/src/Page.vala"
			_g_free0 (_tmp32_);
#line 2611 "/home/jens/Source/shotwell/src/Page.vala"
			data = (g_free (data), NULL);
#line 2611 "/home/jens/Source/shotwell/src/Page.vala"
			break;
#line 15924 "Page.c"
		}
#line 2591 "/home/jens/Source/shotwell/src/Page.vala"
		case DRAG_AND_DROP_HANDLER_TARGET_TYPE_MEDIA_LIST:
#line 15928 "Page.c"
		{
			GeeCollection* sources = NULL;
			Page* _tmp47_;
			ViewCollection* _tmp48_;
			ViewCollection* _tmp49_;
			GeeList* _tmp50_;
			GeeCollection* _tmp51_;
			GtkSelectionData* _tmp52_;
			GdkAtom _tmp53_;
			GeeCollection* _tmp54_;
			gint _tmp55_;
			guchar* _tmp56_;
			guchar* _tmp57_;
			gint _tmp57__length1;
#line 2614 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp47_ = self->priv->page;
#line 2614 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp48_ = page_get_view (_tmp47_);
#line 2614 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp49_ = _tmp48_;
#line 2614 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp50_ = view_collection_get_selected_sources (_tmp49_);
#line 2614 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp51_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, GEE_TYPE_COLLECTION, GeeCollection);
#line 2614 "/home/jens/Source/shotwell/src/Page.vala"
			_data_collection_unref0 (_tmp49_);
#line 2614 "/home/jens/Source/shotwell/src/Page.vala"
			sources = _tmp51_;
#line 2619 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp52_ = selection_data;
#line 2619 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp53_ = gdk_atom_intern_static_string ("SourceIDAtom");
#line 2619 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp54_ = sources;
#line 2619 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp56_ = serialize_media_sources (_tmp54_, &_tmp55_);
#line 2619 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp57_ = _tmp56_;
#line 2619 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp57__length1 = _tmp55_;
#line 2619 "/home/jens/Source/shotwell/src/Page.vala"
			gtk_selection_data_set (_tmp52_, _tmp53_, (gint) sizeof (GdkAtom), _tmp57_, _tmp55_);
#line 2619 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp57_ = (g_free (_tmp57_), NULL);
#line 2621 "/home/jens/Source/shotwell/src/Page.vala"
			_g_object_unref0 (sources);
#line 2621 "/home/jens/Source/shotwell/src/Page.vala"
			break;
#line 15977 "Page.c"
		}
		default:
		{
			Page* _tmp58_;
			gchar* _tmp59_;
			gchar* _tmp60_;
			guint _tmp61_;
#line 2624 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp58_ = self->priv->page;
#line 2624 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp59_ = page_get_page_name (_tmp58_);
#line 2624 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp60_ = _tmp59_;
#line 2624 "/home/jens/Source/shotwell/src/Page.vala"
			_tmp61_ = target_type;
#line 2624 "/home/jens/Source/shotwell/src/Page.vala"
			g_warning ("Page.vala:2624: on_drag_data_get (%s): unknown target type %u", _tmp60_, _tmp61_);
#line 2624 "/home/jens/Source/shotwell/src/Page.vala"
			_g_free0 (_tmp60_);
#line 2626 "/home/jens/Source/shotwell/src/Page.vala"
			break;
#line 15999 "Page.c"
		}
	}
}


static void _drag_and_drop_handler_on_export_completed_exporter_completion_callback (Exporter* exporter, gboolean is_cancelled, gpointer self) {
#line 2647 "/home/jens/Source/shotwell/src/Page.vala"
	drag_and_drop_handler_on_export_completed ((DragAndDropHandler*) self);
#line 16008 "Page.c"
}


static void drag_and_drop_handler_on_drag_end (DragAndDropHandler* self) {
	Page* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	Page* _tmp6_;
	GFile* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	GFile* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gboolean _tmp19_;
#line 2630 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_DRAG_AND_DROP_HANDLER (self));
#line 2631 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->page;
#line 2631 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_page_name (_tmp0_);
#line 2631 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_;
#line 2631 "/home/jens/Source/shotwell/src/Page.vala"
	g_debug ("Page.vala:2631: on_drag_end (%s)", _tmp2_);
#line 2631 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (_tmp2_);
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp6_ = self->priv->page;
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp6_ == NULL) {
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = TRUE;
#line 16045 "Page.c"
	} else {
		Page* _tmp7_;
		ViewCollection* _tmp8_;
		ViewCollection* _tmp9_;
		gint _tmp10_;
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = self->priv->page;
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp8_ = page_get_view (_tmp7_);
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp9_ = _tmp8_;
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp10_ = view_collection_get_selected_count (_tmp9_);
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = _tmp10_ == 0;
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp9_);
#line 16063 "Page.c"
	}
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp5_) {
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = TRUE;
#line 16069 "Page.c"
	} else {
		GFile* _tmp11_;
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp11_ = self->priv->drag_destination;
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp4_ = _tmp11_ == NULL;
#line 16076 "Page.c"
	}
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_) {
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = TRUE;
#line 16082 "Page.c"
	} else {
		ExporterUI* _tmp12_;
#line 2634 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp12_ = self->priv->exporter;
#line 2634 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = _tmp12_ != NULL;
#line 16089 "Page.c"
	}
#line 2633 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp3_) {
#line 2635 "/home/jens/Source/shotwell/src/Page.vala"
		return;
#line 16095 "Page.c"
	}
#line 2638 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp13_ = self->priv->drag_destination;
#line 2638 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp14_ = g_file_get_path (_tmp13_);
#line 2638 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp15_ = _tmp14_;
#line 2638 "/home/jens/Source/shotwell/src/Page.vala"
	g_debug ("Page.vala:2638: Exporting to %s", _tmp15_);
#line 2638 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (_tmp15_);
#line 2643 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp16_ = self->priv->drag_destination;
#line 2643 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp17_ = g_file_get_path (_tmp16_);
#line 2643 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp18_ = _tmp17_;
#line 2643 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp19_ = _tmp18_ != NULL;
#line 2643 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (_tmp18_);
#line 2643 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp19_) {
#line 16119 "Page.c"
		Page* _tmp20_;
		ViewCollection* _tmp21_;
		ViewCollection* _tmp22_;
		GeeList* _tmp23_;
		GeeCollection* _tmp24_;
		GFile* _tmp25_;
		Scaling _tmp26_ = {0};
		ExportFormatParameters _tmp27_ = {0};
		Exporter* _tmp28_;
		Exporter* _tmp29_;
		ExporterUI* _tmp30_;
		ExporterUI* _tmp31_;
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp20_ = self->priv->page;
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp21_ = page_get_view (_tmp20_);
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp22_ = _tmp21_;
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp23_ = view_collection_get_selected_sources (_tmp22_);
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp24_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GEE_TYPE_COLLECTION, GeeCollection);
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp25_ = self->priv->drag_destination;
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		scaling_for_original (&_tmp26_);
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		export_format_parameters_current (&_tmp27_);
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp28_ = exporter_new (_tmp24_, _tmp25_, &_tmp26_, &_tmp27_, FALSE);
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp29_ = _tmp28_;
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp30_ = exporter_ui_new (_tmp29_);
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		_exporter_ui_unref0 (self->priv->exporter);
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		self->priv->exporter = _tmp30_;
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp29_);
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		_g_object_unref0 (_tmp24_);
#line 2644 "/home/jens/Source/shotwell/src/Page.vala"
		_data_collection_unref0 (_tmp22_);
#line 2647 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp31_ = self->priv->exporter;
#line 2647 "/home/jens/Source/shotwell/src/Page.vala"
		exporter_ui_export (_tmp31_, _drag_and_drop_handler_on_export_completed_exporter_completion_callback, self);
#line 16168 "Page.c"
	} else {
#line 2649 "/home/jens/Source/shotwell/src/Page.vala"
		app_window_error_message (_ ("Photos cannot be exported to this directory."), NULL);
#line 16172 "Page.c"
	}
#line 2652 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->drag_destination);
#line 2652 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->drag_destination = NULL;
#line 16178 "Page.c"
}


static gboolean drag_and_drop_handler_on_drag_failed (DragAndDropHandler* self, GdkDragContext* context, GtkDragResult drag_result) {
	gboolean result = FALSE;
	Page* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	GtkDragResult _tmp3_;
	Page* _tmp4_;
#line 2655 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (IS_DRAG_AND_DROP_HANDLER (self), FALSE);
#line 2655 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (GDK_IS_DRAG_CONTEXT (context), FALSE);
#line 2656 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->page;
#line 2656 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp1_ = page_get_page_name (_tmp0_);
#line 2656 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp2_ = _tmp1_;
#line 2656 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp3_ = drag_result;
#line 2656 "/home/jens/Source/shotwell/src/Page.vala"
	g_debug ("Page.vala:2656: on_drag_failed (%s): %d", _tmp2_, (gint) _tmp3_);
#line 2656 "/home/jens/Source/shotwell/src/Page.vala"
	_g_free0 (_tmp2_);
#line 2658 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp4_ = self->priv->page;
#line 2658 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp4_ == NULL) {
#line 2659 "/home/jens/Source/shotwell/src/Page.vala"
		result = FALSE;
#line 2659 "/home/jens/Source/shotwell/src/Page.vala"
		return result;
#line 16213 "Page.c"
	}
#line 2661 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->drag_destination);
#line 2661 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->drag_destination = NULL;
#line 2663 "/home/jens/Source/shotwell/src/Page.vala"
	result = FALSE;
#line 2663 "/home/jens/Source/shotwell/src/Page.vala"
	return result;
#line 16223 "Page.c"
}


static void drag_and_drop_handler_on_export_completed (DragAndDropHandler* self) {
#line 2666 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (IS_DRAG_AND_DROP_HANDLER (self));
#line 2667 "/home/jens/Source/shotwell/src/Page.vala"
	_exporter_ui_unref0 (self->priv->exporter);
#line 2667 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->exporter = NULL;
#line 16234 "Page.c"
}


static void value_drag_and_drop_handler_init (GValue* value) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	value->data[0].v_pointer = NULL;
#line 16241 "Page.c"
}


static void value_drag_and_drop_handler_free_value (GValue* value) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	if (value->data[0].v_pointer) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		drag_and_drop_handler_unref (value->data[0].v_pointer);
#line 16250 "Page.c"
	}
}


static void value_drag_and_drop_handler_copy_value (const GValue* src_value, GValue* dest_value) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	if (src_value->data[0].v_pointer) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		dest_value->data[0].v_pointer = drag_and_drop_handler_ref (src_value->data[0].v_pointer);
#line 16260 "Page.c"
	} else {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		dest_value->data[0].v_pointer = NULL;
#line 16264 "Page.c"
	}
}


static gpointer value_drag_and_drop_handler_peek_pointer (const GValue* value) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	return value->data[0].v_pointer;
#line 16272 "Page.c"
}


static gchar* value_drag_and_drop_handler_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	if (collect_values[0].v_pointer) {
#line 16279 "Page.c"
		DragAndDropHandler * object;
		object = collect_values[0].v_pointer;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		if (object->parent_instance.g_class == NULL) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 16286 "Page.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 16290 "Page.c"
		}
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = drag_and_drop_handler_ref (object);
#line 16294 "Page.c"
	} else {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = NULL;
#line 16298 "Page.c"
	}
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	return NULL;
#line 16302 "Page.c"
}


static gchar* value_drag_and_drop_handler_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	DragAndDropHandler ** object_p;
	object_p = collect_values[0].v_pointer;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	if (!object_p) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 16313 "Page.c"
	}
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	if (!value->data[0].v_pointer) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		*object_p = NULL;
#line 16319 "Page.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		*object_p = value->data[0].v_pointer;
#line 16323 "Page.c"
	} else {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		*object_p = drag_and_drop_handler_ref (value->data[0].v_pointer);
#line 16327 "Page.c"
	}
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	return NULL;
#line 16331 "Page.c"
}


GParamSpec* param_spec_drag_and_drop_handler (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecDragAndDropHandler* spec;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_DRAG_AND_DROP_HANDLER), NULL);
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	return G_PARAM_SPEC (spec);
#line 16345 "Page.c"
}


gpointer value_get_drag_and_drop_handler (const GValue* value) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_DRAG_AND_DROP_HANDLER), NULL);
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	return value->data[0].v_pointer;
#line 16354 "Page.c"
}


void value_set_drag_and_drop_handler (GValue* value, gpointer v_object) {
	DragAndDropHandler * old;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_DRAG_AND_DROP_HANDLER));
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	old = value->data[0].v_pointer;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	if (v_object) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_DRAG_AND_DROP_HANDLER));
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = v_object;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		drag_and_drop_handler_ref (value->data[0].v_pointer);
#line 16374 "Page.c"
	} else {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = NULL;
#line 16378 "Page.c"
	}
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	if (old) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		drag_and_drop_handler_unref (old);
#line 16384 "Page.c"
	}
}


void value_take_drag_and_drop_handler (GValue* value, gpointer v_object) {
	DragAndDropHandler * old;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_DRAG_AND_DROP_HANDLER));
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	old = value->data[0].v_pointer;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	if (v_object) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_DRAG_AND_DROP_HANDLER));
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = v_object;
#line 16403 "Page.c"
	} else {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		value->data[0].v_pointer = NULL;
#line 16407 "Page.c"
	}
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	if (old) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		drag_and_drop_handler_unref (old);
#line 16413 "Page.c"
	}
}


static void drag_and_drop_handler_class_init (DragAndDropHandlerClass * klass) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	drag_and_drop_handler_parent_class = g_type_class_peek_parent (klass);
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	((DragAndDropHandlerClass *) klass)->finalize = drag_and_drop_handler_finalize;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	g_type_class_add_private (klass, sizeof (DragAndDropHandlerPrivate));
#line 16425 "Page.c"
}


static void drag_and_drop_handler_instance_init (DragAndDropHandler * self) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv = DRAG_AND_DROP_HANDLER_GET_PRIVATE (self);
#line 2512 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->drag_destination = NULL;
#line 2513 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->exporter = NULL;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	self->ref_count = 1;
#line 16438 "Page.c"
}


static void drag_and_drop_handler_finalize (DragAndDropHandler * obj) {
	DragAndDropHandler * self;
	GtkWidget* _tmp0_;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_DRAG_AND_DROP_HANDLER, DragAndDropHandler);
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	g_signal_handlers_destroy (self);
#line 2544 "/home/jens/Source/shotwell/src/Page.vala"
	_tmp0_ = self->priv->event_source;
#line 2544 "/home/jens/Source/shotwell/src/Page.vala"
	if (_tmp0_ != NULL) {
#line 16453 "Page.c"
		GtkWidget* _tmp1_;
		guint _tmp2_;
		GtkWidget* _tmp3_;
		guint _tmp4_;
		GtkWidget* _tmp5_;
		guint _tmp6_;
		GtkWidget* _tmp7_;
		guint _tmp8_;
#line 2545 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp1_ = self->priv->event_source;
#line 2545 "/home/jens/Source/shotwell/src/Page.vala"
		g_signal_parse_name ("drag-begin", gtk_widget_get_type (), &_tmp2_, NULL, FALSE);
#line 2545 "/home/jens/Source/shotwell/src/Page.vala"
		g_signal_handlers_disconnect_matched (_tmp1_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp2_, 0, NULL, (GCallback) _drag_and_drop_handler_on_drag_begin_gtk_widget_drag_begin, self);
#line 2546 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp3_ = self->priv->event_source;
#line 2546 "/home/jens/Source/shotwell/src/Page.vala"
		g_signal_parse_name ("drag-data-get", gtk_widget_get_type (), &_tmp4_, NULL, FALSE);
#line 2546 "/home/jens/Source/shotwell/src/Page.vala"
		g_signal_handlers_disconnect_matched (_tmp3_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp4_, 0, NULL, (GCallback) _drag_and_drop_handler_on_drag_data_get_gtk_widget_drag_data_get, self);
#line 2547 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp5_ = self->priv->event_source;
#line 2547 "/home/jens/Source/shotwell/src/Page.vala"
		g_signal_parse_name ("drag-end", gtk_widget_get_type (), &_tmp6_, NULL, FALSE);
#line 2547 "/home/jens/Source/shotwell/src/Page.vala"
		g_signal_handlers_disconnect_matched (_tmp5_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp6_, 0, NULL, (GCallback) _drag_and_drop_handler_on_drag_end_gtk_widget_drag_end, self);
#line 2548 "/home/jens/Source/shotwell/src/Page.vala"
		_tmp7_ = self->priv->event_source;
#line 2548 "/home/jens/Source/shotwell/src/Page.vala"
		g_signal_parse_name ("drag-failed", gtk_widget_get_type (), &_tmp8_, NULL, FALSE);
#line 2548 "/home/jens/Source/shotwell/src/Page.vala"
		g_signal_handlers_disconnect_matched (_tmp7_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp8_, 0, NULL, (GCallback) _drag_and_drop_handler_on_drag_failed_gtk_widget_drag_failed, self);
#line 16486 "Page.c"
	}
#line 2551 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->page = NULL;
#line 2552 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->event_source);
#line 2552 "/home/jens/Source/shotwell/src/Page.vala"
	self->priv->event_source = NULL;
#line 2511 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->event_source);
#line 2512 "/home/jens/Source/shotwell/src/Page.vala"
	_g_object_unref0 (self->priv->drag_destination);
#line 2513 "/home/jens/Source/shotwell/src/Page.vala"
	_exporter_ui_unref0 (self->priv->exporter);
#line 16500 "Page.c"
}


GType drag_and_drop_handler_get_type (void) {
	static volatile gsize drag_and_drop_handler_type_id__volatile = 0;
	if (g_once_init_enter (&drag_and_drop_handler_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_drag_and_drop_handler_init, value_drag_and_drop_handler_free_value, value_drag_and_drop_handler_copy_value, value_drag_and_drop_handler_peek_pointer, "p", value_drag_and_drop_handler_collect_value, "p", value_drag_and_drop_handler_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (DragAndDropHandlerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) drag_and_drop_handler_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DragAndDropHandler), 0, (GInstanceInitFunc) drag_and_drop_handler_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType drag_and_drop_handler_type_id;
		drag_and_drop_handler_type_id = g_type_register_fundamental (g_type_fundamental_next (), "DragAndDropHandler", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&drag_and_drop_handler_type_id__volatile, drag_and_drop_handler_type_id);
	}
	return drag_and_drop_handler_type_id__volatile;
}


gpointer drag_and_drop_handler_ref (gpointer instance) {
	DragAndDropHandler * self;
	self = instance;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	g_atomic_int_inc (&self->ref_count);
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	return instance;
#line 16525 "Page.c"
}


void drag_and_drop_handler_unref (gpointer instance) {
	DragAndDropHandler * self;
	self = instance;
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		DRAG_AND_DROP_HANDLER_GET_CLASS (self)->finalize (self);
#line 2495 "/home/jens/Source/shotwell/src/Page.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 16538 "Page.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



