/* Tree.c generated by valac 0.36.6, the Vala compiler
 * generated from Tree.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>
#include <pango/pango.h>
#include <float.h>
#include <math.h>


#define SIDEBAR_TYPE_TREE (sidebar_tree_get_type ())
#define SIDEBAR_TREE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_TREE, SidebarTree))
#define SIDEBAR_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_TREE, SidebarTreeClass))
#define SIDEBAR_IS_TREE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_TREE))
#define SIDEBAR_IS_TREE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_TREE))
#define SIDEBAR_TREE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_TREE, SidebarTreeClass))

typedef struct _SidebarTree SidebarTree;
typedef struct _SidebarTreeClass SidebarTreeClass;
typedef struct _SidebarTreePrivate SidebarTreePrivate;

#define SIDEBAR_TYPE_ENTRY (sidebar_entry_get_type ())
#define SIDEBAR_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntry))
#define SIDEBAR_IS_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_ENTRY))
#define SIDEBAR_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_ENTRY, SidebarEntryIface))

typedef struct _SidebarEntry SidebarEntry;
typedef struct _SidebarEntryIface SidebarEntryIface;

#define SIDEBAR_TREE_TYPE_ENTRY_WRAPPER (sidebar_tree_entry_wrapper_get_type ())
#define SIDEBAR_TREE_ENTRY_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, SidebarTreeEntryWrapper))
#define SIDEBAR_TREE_ENTRY_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, SidebarTreeEntryWrapperClass))
#define SIDEBAR_TREE_IS_ENTRY_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TREE_TYPE_ENTRY_WRAPPER))
#define SIDEBAR_TREE_IS_ENTRY_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TREE_TYPE_ENTRY_WRAPPER))
#define SIDEBAR_TREE_ENTRY_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, SidebarTreeEntryWrapperClass))

typedef struct _SidebarTreeEntryWrapper SidebarTreeEntryWrapper;
typedef struct _SidebarTreeEntryWrapperClass SidebarTreeEntryWrapperClass;

#define SIDEBAR_TYPE_BRANCH (sidebar_branch_get_type ())
#define SIDEBAR_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranch))
#define SIDEBAR_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))
#define SIDEBAR_IS_BRANCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_IS_BRANCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_BRANCH))
#define SIDEBAR_BRANCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_BRANCH, SidebarBranchClass))

typedef struct _SidebarBranch SidebarBranch;
typedef struct _SidebarBranchClass SidebarBranchClass;

#define SIDEBAR_TREE_TYPE_COLUMNS (sidebar_tree_columns_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _gtk_tree_row_reference_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_row_reference_free (var), NULL)))

#define LIBRARY_WINDOW_TYPE_TARGET_TYPE (library_window_target_type_get_type ())
typedef struct _SidebarTreeEntryWrapperPrivate SidebarTreeEntryWrapperPrivate;

#define SIDEBAR_TYPE_GROUPING (sidebar_grouping_get_type ())
#define SIDEBAR_GROUPING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_GROUPING, SidebarGrouping))
#define SIDEBAR_GROUPING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_GROUPING, SidebarGroupingClass))
#define SIDEBAR_IS_GROUPING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_GROUPING))
#define SIDEBAR_IS_GROUPING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_GROUPING))
#define SIDEBAR_GROUPING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_GROUPING, SidebarGroupingClass))

typedef struct _SidebarGrouping SidebarGrouping;
typedef struct _SidebarGroupingClass SidebarGroupingClass;

#define SIDEBAR_TYPE_HEADER (sidebar_header_get_type ())
#define SIDEBAR_HEADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_HEADER, SidebarHeader))
#define SIDEBAR_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TYPE_HEADER, SidebarHeaderClass))
#define SIDEBAR_IS_HEADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_HEADER))
#define SIDEBAR_IS_HEADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TYPE_HEADER))
#define SIDEBAR_HEADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TYPE_HEADER, SidebarHeaderClass))

typedef struct _SidebarHeader SidebarHeader;
typedef struct _SidebarHeaderClass SidebarHeaderClass;
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_APPLICATION (application_get_type ())
#define APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APPLICATION, Application))
#define APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APPLICATION, ApplicationClass))
#define IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APPLICATION))
#define IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APPLICATION))
#define APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APPLICATION, ApplicationClass))

typedef struct _Application Application;
typedef struct _ApplicationClass ApplicationClass;
#define _application_unref0(var) ((var == NULL) ? NULL : (var = (application_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define __g_list_free__gtk_tree_path_free0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__gtk_tree_path_free0_ (var), NULL)))

#define SIDEBAR_TYPE_EMPHASIZABLE_ENTRY (sidebar_emphasizable_entry_get_type ())
#define SIDEBAR_EMPHASIZABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY, SidebarEmphasizableEntry))
#define SIDEBAR_IS_EMPHASIZABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY))
#define SIDEBAR_EMPHASIZABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_EMPHASIZABLE_ENTRY, SidebarEmphasizableEntryIface))

typedef struct _SidebarEmphasizableEntry SidebarEmphasizableEntry;
typedef struct _SidebarEmphasizableEntryIface SidebarEmphasizableEntryIface;

#define SIDEBAR_TYPE_RENAMEABLE_ENTRY (sidebar_renameable_entry_get_type ())
#define SIDEBAR_RENAMEABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntry))
#define SIDEBAR_IS_RENAMEABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY))
#define SIDEBAR_RENAMEABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntryIface))

typedef struct _SidebarRenameableEntry SidebarRenameableEntry;
typedef struct _SidebarRenameableEntryIface SidebarRenameableEntryIface;

#define SIDEBAR_TYPE_SELECTABLE_ENTRY (sidebar_selectable_entry_get_type ())
#define SIDEBAR_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntry))
#define SIDEBAR_IS_SELECTABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY))
#define SIDEBAR_SELECTABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_SELECTABLE_ENTRY, SidebarSelectableEntryIface))

typedef struct _SidebarSelectableEntry SidebarSelectableEntry;
typedef struct _SidebarSelectableEntryIface SidebarSelectableEntryIface;

#define SIDEBAR_TREE_TYPE_ROOT_WRAPPER (sidebar_tree_root_wrapper_get_type ())
#define SIDEBAR_TREE_ROOT_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TREE_TYPE_ROOT_WRAPPER, SidebarTreeRootWrapper))
#define SIDEBAR_TREE_ROOT_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SIDEBAR_TREE_TYPE_ROOT_WRAPPER, SidebarTreeRootWrapperClass))
#define SIDEBAR_TREE_IS_ROOT_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TREE_TYPE_ROOT_WRAPPER))
#define SIDEBAR_TREE_IS_ROOT_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SIDEBAR_TREE_TYPE_ROOT_WRAPPER))
#define SIDEBAR_TREE_ROOT_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SIDEBAR_TREE_TYPE_ROOT_WRAPPER, SidebarTreeRootWrapperClass))

typedef struct _SidebarTreeRootWrapper SidebarTreeRootWrapper;
typedef struct _SidebarTreeRootWrapperClass SidebarTreeRootWrapperClass;
typedef struct _SidebarTreeRootWrapperPrivate SidebarTreeRootWrapperPrivate;

#define SIDEBAR_TYPE_PAGE_REPRESENTATIVE (sidebar_page_representative_get_type ())
#define SIDEBAR_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentative))
#define SIDEBAR_IS_PAGE_REPRESENTATIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE))
#define SIDEBAR_PAGE_REPRESENTATIVE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_PAGE_REPRESENTATIVE, SidebarPageRepresentativeIface))

typedef struct _SidebarPageRepresentative SidebarPageRepresentative;
typedef struct _SidebarPageRepresentativeIface SidebarPageRepresentativeIface;

#define TYPE_PAGE (page_get_type ())
#define PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE, Page))
#define PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE, PageClass))
#define IS_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE))
#define IS_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE))
#define PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE, PageClass))

typedef struct _Page Page;
typedef struct _PageClass PageClass;

#define SIDEBAR_TYPE_CONTEXTABLE (sidebar_contextable_get_type ())
#define SIDEBAR_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextable))
#define SIDEBAR_IS_CONTEXTABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_CONTEXTABLE))
#define SIDEBAR_CONTEXTABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_CONTEXTABLE, SidebarContextableIface))

typedef struct _SidebarContextable SidebarContextable;
typedef struct _SidebarContextableIface SidebarContextableIface;

#define SIDEBAR_TYPE_EXPANDABLE_ENTRY (sidebar_expandable_entry_get_type ())
#define SIDEBAR_EXPANDABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY, SidebarExpandableEntry))
#define SIDEBAR_IS_EXPANDABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY))
#define SIDEBAR_EXPANDABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_EXPANDABLE_ENTRY, SidebarExpandableEntryIface))

typedef struct _SidebarExpandableEntry SidebarExpandableEntry;
typedef struct _SidebarExpandableEntryIface SidebarExpandableEntryIface;

#define SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY (sidebar_internal_drop_target_entry_get_type ())
#define SIDEBAR_INTERNAL_DROP_TARGET_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY, SidebarInternalDropTargetEntry))
#define SIDEBAR_IS_INTERNAL_DROP_TARGET_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY))
#define SIDEBAR_INTERNAL_DROP_TARGET_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY, SidebarInternalDropTargetEntryIface))

typedef struct _SidebarInternalDropTargetEntry SidebarInternalDropTargetEntry;
typedef struct _SidebarInternalDropTargetEntryIface SidebarInternalDropTargetEntryIface;

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY (sidebar_internal_drag_source_entry_get_type ())
#define SIDEBAR_INTERNAL_DRAG_SOURCE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY, SidebarInternalDragSourceEntry))
#define SIDEBAR_IS_INTERNAL_DRAG_SOURCE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY))
#define SIDEBAR_INTERNAL_DRAG_SOURCE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY, SidebarInternalDragSourceEntryIface))

typedef struct _SidebarInternalDragSourceEntry SidebarInternalDragSourceEntry;
typedef struct _SidebarInternalDragSourceEntryIface SidebarInternalDragSourceEntryIface;

#define SIDEBAR_TYPE_DESTROYABLE_ENTRY (sidebar_destroyable_entry_get_type ())
#define SIDEBAR_DESTROYABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SIDEBAR_TYPE_DESTROYABLE_ENTRY, SidebarDestroyableEntry))
#define SIDEBAR_IS_DESTROYABLE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SIDEBAR_TYPE_DESTROYABLE_ENTRY))
#define SIDEBAR_DESTROYABLE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), SIDEBAR_TYPE_DESTROYABLE_ENTRY, SidebarDestroyableEntryIface))

typedef struct _SidebarDestroyableEntry SidebarDestroyableEntry;
typedef struct _SidebarDestroyableEntryIface SidebarDestroyableEntryIface;

#define TYPE_SAVED_SEARCH_DIALOG (saved_search_dialog_get_type ())
#define SAVED_SEARCH_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SAVED_SEARCH_DIALOG, SavedSearchDialog))
#define SAVED_SEARCH_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SAVED_SEARCH_DIALOG, SavedSearchDialogClass))
#define IS_SAVED_SEARCH_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SAVED_SEARCH_DIALOG))
#define IS_SAVED_SEARCH_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SAVED_SEARCH_DIALOG))
#define SAVED_SEARCH_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SAVED_SEARCH_DIALOG, SavedSearchDialogClass))

typedef struct _SavedSearchDialog SavedSearchDialog;
typedef struct _SavedSearchDialogClass SavedSearchDialogClass;
#define _saved_search_dialog_unref0(var) ((var == NULL) ? NULL : (var = (saved_search_dialog_unref (var), NULL)))

#define TYPE_COMMAND (command_get_type ())
#define COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND, Command))
#define COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND, CommandClass))
#define IS_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND))
#define IS_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND))
#define COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND, CommandClass))

typedef struct _Command Command;
typedef struct _CommandClass CommandClass;

#define TYPE_PAGE_COMMAND (page_command_get_type ())
#define PAGE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_COMMAND, PageCommand))
#define PAGE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_COMMAND, PageCommandClass))
#define IS_PAGE_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_COMMAND))
#define IS_PAGE_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_COMMAND))
#define PAGE_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_COMMAND, PageCommandClass))

typedef struct _PageCommand PageCommand;
typedef struct _PageCommandClass PageCommandClass;

#define TYPE_NEW_ROOT_TAG_COMMAND (new_root_tag_command_get_type ())
#define NEW_ROOT_TAG_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NEW_ROOT_TAG_COMMAND, NewRootTagCommand))
#define NEW_ROOT_TAG_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NEW_ROOT_TAG_COMMAND, NewRootTagCommandClass))
#define IS_NEW_ROOT_TAG_COMMAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NEW_ROOT_TAG_COMMAND))
#define IS_NEW_ROOT_TAG_COMMAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NEW_ROOT_TAG_COMMAND))
#define NEW_ROOT_TAG_COMMAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NEW_ROOT_TAG_COMMAND, NewRootTagCommandClass))

typedef struct _NewRootTagCommand NewRootTagCommand;
typedef struct _NewRootTagCommandClass NewRootTagCommandClass;

#define TYPE_COMMAND_MANAGER (command_manager_get_type ())
#define COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMMAND_MANAGER, CommandManager))
#define COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMMAND_MANAGER, CommandManagerClass))
#define IS_COMMAND_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMMAND_MANAGER))
#define IS_COMMAND_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMMAND_MANAGER))
#define COMMAND_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMMAND_MANAGER, CommandManagerClass))

typedef struct _CommandManager CommandManager;
typedef struct _CommandManagerClass CommandManagerClass;
#define _command_manager_unref0(var) ((var == NULL) ? NULL : (var = (command_manager_unref (var), NULL)))

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;

#define TYPE_LIBRARY_WINDOW (library_window_get_type ())
#define LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_WINDOW, LibraryWindow))
#define LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_WINDOW, LibraryWindowClass))
#define IS_LIBRARY_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_WINDOW))
#define IS_LIBRARY_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_WINDOW))
#define LIBRARY_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_WINDOW, LibraryWindowClass))

typedef struct _LibraryWindow LibraryWindow;
typedef struct _LibraryWindowClass LibraryWindowClass;

#define TYPE_TAG (tag_get_type ())
#define TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG, Tag))
#define TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG, TagClass))
#define IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG))
#define IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG))
#define TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG, TagClass))

typedef struct _Tag Tag;
typedef struct _TagClass TagClass;
enum  {
	SIDEBAR_TREE_ENTRY_SELECTED_SIGNAL,
	SIDEBAR_TREE_SELECTED_ENTRY_REMOVED_SIGNAL,
	SIDEBAR_TREE_BRANCH_ADDED_SIGNAL,
	SIDEBAR_TREE_BRANCH_REMOVED_SIGNAL,
	SIDEBAR_TREE_BRANCH_SHOWN_SIGNAL,
	SIDEBAR_TREE_PAGE_CREATED_SIGNAL,
	SIDEBAR_TREE_DESTROYING_PAGE_SIGNAL,
	SIDEBAR_TREE_LAST_SIGNAL
};
static guint sidebar_tree_signals[SIDEBAR_TREE_LAST_SIGNAL] = {0};
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _SidebarTree {
	GtkTreeView parent_instance;
	SidebarTreePrivate * priv;
};

struct _SidebarTreeClass {
	GtkTreeViewClass parent_class;
	gboolean (*accept_cursor_changed) (SidebarTree* self);
};

struct _SidebarEntryIface {
	GTypeInterface parent_iface;
	gchar* (*get_sidebar_name) (SidebarEntry* self);
	gchar* (*get_sidebar_tooltip) (SidebarEntry* self);
	gchar* (*get_sidebar_icon) (SidebarEntry* self);
	gchar* (*to_string) (SidebarEntry* self);
	void (*grafted) (SidebarEntry* self, SidebarTree* tree);
	void (*pruned) (SidebarEntry* self, SidebarTree* tree);
};

typedef void (*SidebarTreeExternalDropHandler) (GdkDragContext* context, SidebarEntry* entry, GtkSelectionData* data, guint info, guint time, void* user_data);
struct _SidebarTreePrivate {
	GtkTreeStore* store;
	GtkBuilder* builder;
	GtkCellRendererText* text_renderer;
	SidebarTreeExternalDropHandler drop_handler;
	gpointer drop_handler_target;
	GtkEntry* text_entry;
	GeeHashMap* entry_map;
	GeeHashMap* branches;
	gint editing_disabled;
	gboolean mask_entry_selected_signal;
	SidebarTreeEntryWrapper* selected_wrapper;
	GtkMenu* default_context_menu;
	gboolean expander_called_manually;
	gint expander_special_count;
	gboolean is_internal_drag_in_progress;
	SidebarEntry* internal_drag_source_entry;
	GtkTreeRowReference* old_path_ref;
};

typedef enum  {
	SIDEBAR_TREE_COLUMNS_NAME,
	SIDEBAR_TREE_COLUMNS_TOOLTIP,
	SIDEBAR_TREE_COLUMNS_WRAPPER,
	SIDEBAR_TREE_COLUMNS_ICON,
	SIDEBAR_TREE_COLUMNS_N_COLUMNS
} SidebarTreeColumns;

typedef enum  {
	LIBRARY_WINDOW_TARGET_TYPE_URI_LIST,
	LIBRARY_WINDOW_TARGET_TYPE_MEDIA_LIST,
	LIBRARY_WINDOW_TARGET_TYPE_TAG_PATH
} LibraryWindowTargetType;

struct _SidebarTreeEntryWrapper {
	GObject parent_instance;
	SidebarTreeEntryWrapperPrivate * priv;
	SidebarEntry* entry;
	GtkTreeRowReference* row;
};

struct _SidebarTreeEntryWrapperClass {
	GObjectClass parent_class;
};

struct _SidebarEmphasizableEntryIface {
	GTypeInterface parent_iface;
	gboolean (*is_emphasized) (SidebarEmphasizableEntry* self);
};

struct _SidebarRenameableEntryIface {
	GTypeInterface parent_iface;
	void (*rename) (SidebarRenameableEntry* self, const gchar* new_name);
	gboolean (*is_user_renameable) (SidebarRenameableEntry* self);
};

struct _SidebarSelectableEntryIface {
	GTypeInterface parent_iface;
};

struct _SidebarTreeRootWrapper {
	SidebarTreeEntryWrapper parent_instance;
	SidebarTreeRootWrapperPrivate * priv;
	gint root_position;
};

struct _SidebarTreeRootWrapperClass {
	SidebarTreeEntryWrapperClass parent_class;
};

struct _SidebarPageRepresentativeIface {
	GTypeInterface parent_iface;
	gboolean (*has_page) (SidebarPageRepresentative* self);
	Page* (*get_page) (SidebarPageRepresentative* self);
};

struct _SidebarContextableIface {
	GTypeInterface parent_iface;
	GtkMenu* (*get_sidebar_context_menu) (SidebarContextable* self, GdkEventButton* event);
};

struct _SidebarExpandableEntryIface {
	GTypeInterface parent_iface;
	gboolean (*expand_on_select) (SidebarExpandableEntry* self);
};

struct _SidebarInternalDropTargetEntryIface {
	GTypeInterface parent_iface;
	gboolean (*internal_drop_received) (SidebarInternalDropTargetEntry* self, GeeList* sources);
	gboolean (*internal_drop_received_arbitrary) (SidebarInternalDropTargetEntry* self, GtkSelectionData* data);
};

struct _SidebarInternalDragSourceEntryIface {
	GTypeInterface parent_iface;
	void (*prepare_selection_data) (SidebarInternalDragSourceEntry* self, GtkSelectionData* data);
};

struct _SidebarDestroyableEntryIface {
	GTypeInterface parent_iface;
	void (*destroy_source) (SidebarDestroyableEntry* self);
};


static gpointer sidebar_tree_parent_class = NULL;
static gpointer sidebar_tree_entry_wrapper_parent_class = NULL;
static gpointer sidebar_tree_root_wrapper_parent_class = NULL;

GType sidebar_tree_get_type (void) G_GNUC_CONST;
GType sidebar_entry_get_type (void) G_GNUC_CONST;
static GType sidebar_tree_entry_wrapper_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
GType sidebar_branch_get_type (void) G_GNUC_CONST;
#define SIDEBAR_TREE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SIDEBAR_TYPE_TREE, SidebarTreePrivate))
enum  {
	SIDEBAR_TREE_DUMMY_PROPERTY
};
static void sidebar_tree_on_editing_canceled (SidebarTree* self);
static void _sidebar_tree_on_editing_canceled_gtk_cell_renderer_editing_canceled (GtkCellRenderer* _sender, gpointer self);
static void sidebar_tree_on_editing_started (SidebarTree* self, GtkCellEditable* editable, const gchar* path);
static void _sidebar_tree_on_editing_started_gtk_cell_renderer_editing_started (GtkCellRenderer* _sender, GtkCellEditable* editable, const gchar* path, gpointer self);
static GType sidebar_tree_columns_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define SIDEBAR_TREE_ICON_SIZE 16
static void sidebar_tree_on_new_tag (SidebarTree* self);
static void _sidebar_tree_on_new_tag_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void sidebar_tree_on_new_search (SidebarTree* self);
static void _sidebar_tree_on_new_search_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
SidebarTree* sidebar_tree_new (GtkTargetEntry* target_entries, int target_entries_length1, GdkDragAction actions, SidebarTreeExternalDropHandler drop_handler, void* drop_handler_target);
SidebarTree* sidebar_tree_construct (GType object_type, GtkTargetEntry* target_entries, int target_entries_length1, GdkDragAction actions, SidebarTreeExternalDropHandler drop_handler, void* drop_handler_target);
void sidebar_tree_icon_renderer_function (SidebarTree* self, GtkCellLayout* layout, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter);
static void _sidebar_tree_icon_renderer_function_gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self);
static gboolean sidebar_tree_on_selection (SidebarTree* self, GtkTreeSelection* selection, GtkTreeModel* model, GtkTreePath* path, gboolean path_currently_selected);
static gboolean _sidebar_tree_on_selection_gtk_tree_selection_func (GtkTreeSelection* selection, GtkTreeModel* model, GtkTreePath* path, gboolean path_currently_selected, gpointer self);
gboolean sidebar_tree_on_toggle_row (SidebarTree* self, GtkTreeIter* iter, GtkTreePath* path);
static gboolean _sidebar_tree_on_toggle_row_gtk_tree_view_test_expand_row (GtkTreeView* _sender, GtkTreeIter* iter, GtkTreePath* path, gpointer self);
static gboolean _sidebar_tree_on_toggle_row_gtk_tree_view_test_collapse_row (GtkTreeView* _sender, GtkTreeIter* iter, GtkTreePath* path, gpointer self);
GType library_window_target_type_get_type (void) G_GNUC_CONST;
static void _vala_array_add64 (GtkTargetEntry* * array, int* length, int* size, const GtkTargetEntry* value);
static gboolean sidebar_tree_on_context_menu_keypress (SidebarTree* self);
static gboolean _sidebar_tree_on_context_menu_keypress_gtk_widget_popup_menu (GtkWidget* _sender, gpointer self);
static void sidebar_tree_setup_default_context_menu (SidebarTree* self);
static void sidebar_tree_on_drag_begin (SidebarTree* self, GdkDragContext* ctx);
static void _sidebar_tree_on_drag_begin_gtk_widget_drag_begin (GtkWidget* _sender, GdkDragContext* context, gpointer self);
static void sidebar_tree_on_drag_end (SidebarTree* self, GdkDragContext* ctx);
static void _sidebar_tree_on_drag_end_gtk_widget_drag_end (GtkWidget* _sender, GdkDragContext* context, gpointer self);
static gboolean sidebar_tree_on_drag_motion (SidebarTree* self, GdkDragContext* context, gint x, gint y, guint time_);
static gboolean _sidebar_tree_on_drag_motion_gtk_widget_drag_motion (GtkWidget* _sender, GdkDragContext* context, gint x, gint y, guint time_, gpointer self);
static SidebarTreeEntryWrapper* sidebar_tree_get_wrapper_at_iter (SidebarTree* self, GtkTreeIter* iter);
GType sidebar_grouping_get_type (void) G_GNUC_CONST;
GType sidebar_header_get_type (void) G_GNUC_CONST;
static SidebarTreeEntryWrapper* sidebar_tree_get_wrapper_at_path (SidebarTree* self, GtkTreePath* path);
gchar* resources_get_ui (const gchar* filename);
void app_window_error_message (const gchar* message, GtkWindow* parent);
gpointer application_ref (gpointer instance);
void application_unref (gpointer instance);
GParamSpec* param_spec_application (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_application (GValue* value, gpointer v_object);
void value_take_application (GValue* value, gpointer v_object);
gpointer value_get_application (const GValue* value);
GType application_get_type (void) G_GNUC_CONST;
Application* application_get_instance (void);
void application_panic (Application* self);
static gboolean sidebar_tree_has_wrapper (SidebarTree* self, SidebarEntry* entry);
static SidebarTreeEntryWrapper* sidebar_tree_get_wrapper (SidebarTree* self, SidebarEntry* entry);
gchar* sidebar_entry_to_string (SidebarEntry* self);
gboolean sidebar_tree_place_cursor (SidebarTree* self, SidebarEntry* entry, gboolean mask_signal);
gboolean sidebar_tree_expand_to_entry (SidebarTree* self, SidebarEntry* entry);
static GtkTreePath* sidebar_tree_entry_wrapper_get_path (SidebarTreeEntryWrapper* self);
gboolean sidebar_tree_scroll_to_entry (SidebarTree* self, SidebarEntry* entry);
gboolean sidebar_tree_is_selected (SidebarTree* self, SidebarEntry* entry);
gboolean sidebar_tree_is_any_selected (SidebarTree* self);
static GtkTreePath* sidebar_tree_get_selected_path (SidebarTree* self);
static void _gtk_tree_path_free0_ (gpointer var);
static void _g_list_free__gtk_tree_path_free0_ (GList* self);
static gchar* sidebar_tree_get_name_for_entry (SidebarTree* self, SidebarEntry* entry);
gchar* guarded_markup_escape_text (const gchar* plain);
gchar* sidebar_entry_get_sidebar_name (SidebarEntry* self);
GType sidebar_emphasizable_entry_get_type (void) G_GNUC_CONST;
gboolean sidebar_emphasizable_entry_is_emphasized (SidebarEmphasizableEntry* self);
gboolean sidebar_tree_accept_cursor_changed (SidebarTree* self);
static gboolean sidebar_tree_real_accept_cursor_changed (SidebarTree* self);
static void sidebar_tree_real_cursor_changed (GtkTreeView* base);
GType sidebar_renameable_entry_get_type (void) G_GNUC_CONST;
gboolean sidebar_renameable_entry_is_user_renameable (SidebarRenameableEntry* self);
GType sidebar_selectable_entry_get_type (void) G_GNUC_CONST;
void sidebar_tree_disable_editing (SidebarTree* self);
void sidebar_tree_enable_editing (SidebarTree* self);
void sidebar_tree_toggle_branch_expansion (SidebarTree* self, GtkTreePath* path, gboolean expand_all);
void sidebar_tree_expand_to_first_child (SidebarTree* self, SidebarEntry* entry);
void sidebar_tree_graft (SidebarTree* self, SidebarBranch* branch, gint position);
gboolean sidebar_branch_get_show_branch (SidebarBranch* self);
static void sidebar_tree_associate_branch (SidebarTree* self, SidebarBranch* branch);
gboolean sidebar_branch_is_startup_expand_to_first_child (SidebarBranch* self);
SidebarEntry* sidebar_branch_get_root (SidebarBranch* self);
gboolean sidebar_branch_is_startup_open_grouping (SidebarBranch* self);
static void sidebar_tree_on_branch_entry_added (SidebarTree* self, SidebarBranch* branch, SidebarEntry* entry);
static void _sidebar_tree_on_branch_entry_added_sidebar_branch_entry_added (SidebarBranch* _sender, SidebarEntry* entry, gpointer self);
static void sidebar_tree_on_branch_entry_removed (SidebarTree* self, SidebarBranch* branch, SidebarEntry* entry);
static void _sidebar_tree_on_branch_entry_removed_sidebar_branch_entry_removed (SidebarBranch* _sender, SidebarEntry* entry, gpointer self);
static void sidebar_tree_on_branch_entry_moved (SidebarTree* self, SidebarBranch* branch, SidebarEntry* entry);
static void _sidebar_tree_on_branch_entry_moved_sidebar_branch_entry_moved (SidebarBranch* _sender, SidebarEntry* entry, gpointer self);
static void sidebar_tree_on_branch_entry_reparented (SidebarTree* self, SidebarBranch* branch, SidebarEntry* entry, SidebarEntry* old_parent);
static void _sidebar_tree_on_branch_entry_reparented_sidebar_branch_entry_reparented (SidebarBranch* _sender, SidebarEntry* entry, SidebarEntry* old_parent, gpointer self);
static void sidebar_tree_on_branch_children_reordered (SidebarTree* self, SidebarBranch* branch, SidebarEntry* entry);
static void _sidebar_tree_on_branch_children_reordered_sidebar_branch_children_reordered (SidebarBranch* _sender, SidebarEntry* entry, gpointer self);
static void sidebar_tree_on_show_branch (SidebarTree* self, SidebarBranch* branch, gboolean shown);
static void _sidebar_tree_on_show_branch_sidebar_branch_show_branch (SidebarBranch* _sender, gboolean show, gpointer self);
static GType sidebar_tree_root_wrapper_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self);
static void sidebar_tree_associate_wrapper (SidebarTree* self, GtkTreeIter* assoc_iter, SidebarTreeEntryWrapper* wrapper);
static SidebarTreeRootWrapper* sidebar_tree_root_wrapper_new (GtkTreeModel* model, SidebarEntry* entry, GtkTreePath* path, gint root_position);
static SidebarTreeRootWrapper* sidebar_tree_root_wrapper_construct (GType object_type, GtkTreeModel* model, SidebarEntry* entry, GtkTreePath* path, gint root_position);
static void sidebar_tree_associate_children (SidebarTree* self, SidebarBranch* branch, SidebarEntry* parent, GtkTreeIter* parent_iter);
GeeList* sidebar_branch_get_children (SidebarBranch* self, SidebarEntry* parent);
static void sidebar_tree_associate_entry (SidebarTree* self, GtkTreeIter* assoc_iter, SidebarEntry* entry);
static SidebarTreeEntryWrapper* sidebar_tree_entry_wrapper_new (GtkTreeModel* model, SidebarEntry* entry, GtkTreePath* path);
static SidebarTreeEntryWrapper* sidebar_tree_entry_wrapper_construct (GType object_type, GtkTreeModel* model, SidebarEntry* entry, GtkTreePath* path);
gchar* sidebar_entry_get_sidebar_tooltip (SidebarEntry* self);
static void sidebar_tree_load_entry_icons (SidebarTree* self, GtkTreeIter* iter);
static void sidebar_tree_on_sidebar_tooltip_changed (SidebarTree* self, SidebarEntry* entry, const gchar* tooltip);
static void _sidebar_tree_on_sidebar_tooltip_changed_sidebar_entry_sidebar_tooltip_changed (SidebarEntry* _sender, const gchar* tooltip, gpointer self);
static void sidebar_tree_on_sidebar_icon_changed (SidebarTree* self, SidebarEntry* entry, const gchar* icon);
static void _sidebar_tree_on_sidebar_icon_changed_sidebar_entry_sidebar_icon_changed (SidebarEntry* _sender, const gchar* icon, gpointer self);
GType page_get_type (void) G_GNUC_CONST;
GType sidebar_page_representative_get_type (void) G_GNUC_CONST;
static void sidebar_tree_on_sidebar_page_created (SidebarTree* self, SidebarPageRepresentative* entry, Page* page);
static void _sidebar_tree_on_sidebar_page_created_sidebar_page_representative_page_created (SidebarPageRepresentative* _sender, Page* page, gpointer self);
static void sidebar_tree_on_sidebar_destroying_page (SidebarTree* self, SidebarPageRepresentative* entry, Page* page);
static void _sidebar_tree_on_sidebar_destroying_page_sidebar_page_representative_destroying_page (SidebarPageRepresentative* _sender, Page* page, gpointer self);
static void sidebar_tree_on_is_emphasized_changed (SidebarTree* self, SidebarEmphasizableEntry* entry, gboolean is_emphasized);
static void _sidebar_tree_on_is_emphasized_changed_sidebar_emphasizable_entry_is_emphasized_changed (SidebarEmphasizableEntry* _sender, gboolean emphasized, gpointer self);
static void sidebar_tree_on_sidebar_name_changed (SidebarTree* self, SidebarEntry* entry, const gchar* name);
static void _sidebar_tree_on_sidebar_name_changed_sidebar_renameable_entry_sidebar_name_changed (SidebarRenameableEntry* _sender, const gchar* name, gpointer self);
void sidebar_entry_grafted (SidebarEntry* self, SidebarTree* tree);
static SidebarTreeEntryWrapper* sidebar_tree_reparent_wrapper (SidebarTree* self, GtkTreeIter* new_iter, SidebarTreeEntryWrapper* current_wrapper);
void sidebar_tree_prune (SidebarTree* self, SidebarBranch* branch);
static void sidebar_tree_disassociate_branch (SidebarTree* self, SidebarBranch* branch);
static void sidebar_tree_disassociate_wrapper_and_signal (SidebarTree* self, SidebarTreeEntryWrapper* wrapper, gboolean only_children);
static void sidebar_tree_disassociate_wrapper (SidebarTree* self, SidebarTreeEntryWrapper* wrapper, gboolean only_children);
static void sidebar_tree_entry_wrapper_get_iter (SidebarTreeEntryWrapper* self, GtkTreeIter* result);
void sidebar_entry_pruned (SidebarEntry* self, SidebarTree* tree);
SidebarEntry* sidebar_branch_get_parent (SidebarBranch* self, SidebarEntry* entry);
SidebarEntry* sidebar_branch_get_next_sibling (SidebarBranch* self, SidebarEntry* entry);
gboolean sidebar_branch_is_auto_open_on_new_child (SidebarBranch* self);
SidebarEntry* sidebar_branch_get_previous_sibling (SidebarBranch* self, SidebarEntry* entry);
static GtkTreePath* sidebar_tree_get_current_path (SidebarTree* self);
static void sidebar_tree_rename_entry (SidebarTree* self, SidebarEntry* entry);
gchar* sidebar_entry_get_sidebar_icon (SidebarEntry* self);
static void sidebar_tree_load_branch_icons (SidebarTree* self, GtkTreeIter* iter);
static GtkTreePath* sidebar_tree_get_path_from_event (SidebarTree* self, GdkEventButton* event);
static gboolean sidebar_tree_popup_context_menu (SidebarTree* self, GtkTreePath* path, GdkEventButton* event);
GType sidebar_contextable_get_type (void) G_GNUC_CONST;
GtkMenu* sidebar_contextable_get_sidebar_context_menu (SidebarContextable* self, GdkEventButton* event);
static gboolean sidebar_tree_popup_default_context_menu (SidebarTree* self, GdkEventButton* event);
static gboolean sidebar_tree_real_button_press_event (GtkWidget* base, GdkEventButton* event);
GType sidebar_expandable_entry_get_type (void) G_GNUC_CONST;
GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
GType sidebar_internal_drop_target_entry_get_type (void) G_GNUC_CONST;
gboolean sidebar_tree_is_keypress_interpreted (SidebarTree* self, GdkEventKey* event);
static gboolean sidebar_tree_real_key_press_event (GtkWidget* base, GdkEventKey* event);
static gboolean sidebar_tree_rename_in_place (SidebarTree* self);
static gboolean sidebar_tree_destroy_path (SidebarTree* self, GtkTreePath* path);
gboolean sidebar_tree_rename_entry_in_place (SidebarTree* self, SidebarEntry* entry);
static gboolean sidebar_tree_can_rename_path (SidebarTree* self, GtkTreePath* path);
static void sidebar_tree_real_drag_data_get (GtkWidget* base, GdkDragContext* context, GtkSelectionData* selection_data, guint info, guint time);
GType sidebar_internal_drag_source_entry_get_type (void) G_GNUC_CONST;
void sidebar_internal_drag_source_entry_prepare_selection_data (SidebarInternalDragSourceEntry* self, GtkSelectionData* data);
static void sidebar_tree_real_drag_data_received (GtkWidget* base, GdkDragContext* context, gint x, gint y, GtkSelectionData* selection_data, guint info, guint time);
#define LIBRARY_WINDOW_TAG_PATH_MIME_TYPE "shotwell/tag-path"
gboolean sidebar_internal_drop_target_entry_internal_drop_received_arbitrary (SidebarInternalDropTargetEntry* self, GtkSelectionData* data);
GeeList* unserialize_media_sources (guchar* serialized, gint size);
gboolean sidebar_internal_drop_target_entry_internal_drop_received (SidebarInternalDropTargetEntry* self, GeeList* sources);
static gboolean sidebar_tree_real_drag_motion (GtkWidget* base, GdkDragContext* context, gint x, gint y, guint time);
GType sidebar_destroyable_entry_get_type (void) G_GNUC_CONST;
void sidebar_destroyable_entry_destroy_source (SidebarDestroyableEntry* self);
static void sidebar_tree_on_editing_done (SidebarTree* self);
static void _sidebar_tree_on_editing_done_gtk_cell_editable_editing_done (GtkCellEditable* _sender, gpointer self);
static gboolean sidebar_tree_on_editing_focus_out (SidebarTree* self, GdkEventFocus* event);
static gboolean _sidebar_tree_on_editing_focus_out_gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self);
void sidebar_renameable_entry_rename (SidebarRenameableEntry* self, const gchar* new_name);
SavedSearchDialog* saved_search_dialog_new (void);
SavedSearchDialog* saved_search_dialog_construct (GType object_type);
gpointer saved_search_dialog_ref (gpointer instance);
void saved_search_dialog_unref (gpointer instance);
GParamSpec* param_spec_saved_search_dialog (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_saved_search_dialog (GValue* value, gpointer v_object);
void value_take_saved_search_dialog (GValue* value, gpointer v_object);
gpointer value_get_saved_search_dialog (const GValue* value);
GType saved_search_dialog_get_type (void) G_GNUC_CONST;
void saved_search_dialog_show (SavedSearchDialog* self);
GType command_get_type (void) G_GNUC_CONST;
GType page_command_get_type (void) G_GNUC_CONST;
GType new_root_tag_command_get_type (void) G_GNUC_CONST;
NewRootTagCommand* new_root_tag_command_new (void);
NewRootTagCommand* new_root_tag_command_construct (GType object_type);
gpointer command_manager_ref (gpointer instance);
void command_manager_unref (gpointer instance);
GParamSpec* param_spec_command_manager (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_command_manager (GValue* value, gpointer v_object);
void value_take_command_manager (GValue* value, gpointer v_object);
gpointer value_get_command_manager (const GValue* value);
GType command_manager_get_type (void) G_GNUC_CONST;
CommandManager* app_window_get_command_manager (void);
void command_manager_execute (CommandManager* self, Command* command);
GType page_window_get_type (void) G_GNUC_CONST;
GType app_window_get_type (void) G_GNUC_CONST;
GType library_window_get_type (void) G_GNUC_CONST;
LibraryWindow* library_window_get_app (void);
GType tag_get_type (void) G_GNUC_CONST;
void library_window_rename_tag_in_sidebar (LibraryWindow* self, Tag* tag);
Tag* new_root_tag_command_get_created_tag (NewRootTagCommand* self);
static void g_cclosure_user_marshal_VOID__OBJECT_BOOLEAN (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__OBJECT_OBJECT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
enum  {
	SIDEBAR_TREE_ENTRY_WRAPPER_DUMMY_PROPERTY
};
static void sidebar_tree_entry_wrapper_finalize (GObject * obj);
enum  {
	SIDEBAR_TREE_ROOT_WRAPPER_DUMMY_PROPERTY
};
static void sidebar_tree_root_wrapper_finalize (GObject * obj);
static void sidebar_tree_finalize (GObject * obj);

static const GActionEntry SIDEBAR_TREE_entries[2] = {{"tag.new", _sidebar_tree_on_new_tag_gsimple_action_activate_callback}, {"search.new", _sidebar_tree_on_new_search_gsimple_action_activate_callback}};

static void _sidebar_tree_on_editing_canceled_gtk_cell_renderer_editing_canceled (GtkCellRenderer* _sender, gpointer self) {
#line 156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_editing_canceled ((SidebarTree*) self);
#line 695 "Tree.c"
}


static void _sidebar_tree_on_editing_started_gtk_cell_renderer_editing_started (GtkCellRenderer* _sender, GtkCellEditable* editable, const gchar* path, gpointer self) {
#line 157 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_editing_started ((SidebarTree*) self, editable, path);
#line 702 "Tree.c"
}


static GType sidebar_tree_columns_get_type (void) {
	static volatile gsize sidebar_tree_columns_type_id__volatile = 0;
	if (g_once_init_enter (&sidebar_tree_columns_type_id__volatile)) {
		static const GEnumValue values[] = {{SIDEBAR_TREE_COLUMNS_NAME, "SIDEBAR_TREE_COLUMNS_NAME", "name"}, {SIDEBAR_TREE_COLUMNS_TOOLTIP, "SIDEBAR_TREE_COLUMNS_TOOLTIP", "tooltip"}, {SIDEBAR_TREE_COLUMNS_WRAPPER, "SIDEBAR_TREE_COLUMNS_WRAPPER", "wrapper"}, {SIDEBAR_TREE_COLUMNS_ICON, "SIDEBAR_TREE_COLUMNS_ICON", "icon"}, {SIDEBAR_TREE_COLUMNS_N_COLUMNS, "SIDEBAR_TREE_COLUMNS_N_COLUMNS", "n-columns"}, {0, NULL, NULL}};
		GType sidebar_tree_columns_type_id;
		sidebar_tree_columns_type_id = g_enum_register_static ("SidebarTreeColumns", values);
		g_once_init_leave (&sidebar_tree_columns_type_id__volatile, sidebar_tree_columns_type_id);
	}
	return sidebar_tree_columns_type_id__volatile;
}


static void _sidebar_tree_on_new_tag_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 193 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_new_tag ((SidebarTree*) self);
#line 721 "Tree.c"
}


static void _sidebar_tree_on_new_search_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 193 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_new_search ((SidebarTree*) self);
#line 728 "Tree.c"
}


static void _sidebar_tree_icon_renderer_function_gtk_cell_layout_data_func (GtkCellLayout* cell_layout, GtkCellRenderer* cell, GtkTreeModel* tree_model, GtkTreeIter* iter, gpointer self) {
#line 104 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_icon_renderer_function ((SidebarTree*) self, cell_layout, cell, tree_model, iter);
#line 735 "Tree.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 127 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return self ? g_object_ref (self) : NULL;
#line 742 "Tree.c"
}


static gboolean _sidebar_tree_on_selection_gtk_tree_selection_func (GtkTreeSelection* selection, GtkTreeModel* model, GtkTreePath* path, gboolean path_currently_selected, gpointer self) {
	gboolean result;
	result = sidebar_tree_on_selection ((SidebarTree*) self, selection, model, path, path_currently_selected);
#line 129 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 751 "Tree.c"
}


static gboolean _sidebar_tree_on_toggle_row_gtk_tree_view_test_expand_row (GtkTreeView* _sender, GtkTreeIter* iter, GtkTreePath* path, gpointer self) {
	gboolean result;
	result = sidebar_tree_on_toggle_row ((SidebarTree*) self, iter, path);
#line 131 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 760 "Tree.c"
}


static gboolean _sidebar_tree_on_toggle_row_gtk_tree_view_test_collapse_row (GtkTreeView* _sender, GtkTreeIter* iter, GtkTreePath* path, gpointer self) {
	gboolean result;
	result = sidebar_tree_on_toggle_row ((SidebarTree*) self, iter, path);
#line 132 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 769 "Tree.c"
}


static void _vala_array_add64 (GtkTargetEntry* * array, int* length, int* size, const GtkTargetEntry* value) {
#line 140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if ((*length) == (*size)) {
#line 140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		*array = g_renew (GtkTargetEntry, *array, *size);
#line 780 "Tree.c"
	}
#line 140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	(*array)[(*length)++] = *value;
#line 784 "Tree.c"
}


static gboolean _sidebar_tree_on_context_menu_keypress_gtk_widget_popup_menu (GtkWidget* _sender, gpointer self) {
	gboolean result;
	result = sidebar_tree_on_context_menu_keypress ((SidebarTree*) self);
#line 146 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 793 "Tree.c"
}


static void _sidebar_tree_on_drag_begin_gtk_widget_drag_begin (GtkWidget* _sender, GdkDragContext* context, gpointer self) {
#line 150 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_drag_begin ((SidebarTree*) self, context);
#line 800 "Tree.c"
}


static void _sidebar_tree_on_drag_end_gtk_widget_drag_end (GtkWidget* _sender, GdkDragContext* context, gpointer self) {
#line 151 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_drag_end ((SidebarTree*) self, context);
#line 807 "Tree.c"
}


static gboolean _sidebar_tree_on_drag_motion_gtk_widget_drag_motion (GtkWidget* _sender, GdkDragContext* context, gint x, gint y, guint time_, gpointer self) {
	gboolean result;
	result = sidebar_tree_on_drag_motion ((SidebarTree*) self, context, x, y, time_);
#line 152 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 816 "Tree.c"
}


SidebarTree* sidebar_tree_construct (GType object_type, GtkTargetEntry* target_entries, int target_entries_length1, GdkDragAction actions, SidebarTreeExternalDropHandler drop_handler, void* drop_handler_target) {
	SidebarTree * self = NULL;
	GtkTreeStore* _tmp0_;
	GtkStyleContext* _tmp1_;
	GtkTreeViewColumn* text_column = NULL;
	GtkTreeViewColumn* _tmp2_;
	GtkCellRendererPixbuf* icon_renderer = NULL;
	GtkCellRendererPixbuf* _tmp3_;
	GtkCellRendererText* _tmp4_;
	GtkCellRendererText* _tmp5_;
	GtkCellRendererText* _tmp6_;
	GtkCellRendererText* _tmp7_;
	GtkCellRendererText* _tmp8_;
	GtkCellRendererText* _tmp9_;
	GtkCellRendererText* invisitext = NULL;
	GtkCellRendererText* _tmp10_;
	GtkTreeViewColumn* page_holder = NULL;
	GtkTreeViewColumn* _tmp11_;
	GtkTreeSelection* selection = NULL;
	GtkTreeSelection* _tmp12_;
	GtkTreeSelection* _tmp13_;
	GtkTargetEntry* _tmp14_;
	gint _tmp14__length1;
	GdkDragAction _tmp15_;
	GtkTargetEntry* source_entries = NULL;
	GtkTargetEntry* _tmp16_;
	gint source_entries_length1;
	gint _source_entries_size_;
	GtkTargetEntry* _tmp17_;
	gint _tmp17__length1;
	GtkTargetEntry* _tmp18_;
	gint _tmp18__length1;
	GtkTargetEntry _tmp19_;
	GtkTargetEntry* _tmp20_;
	gint _tmp20__length1;
	SidebarTreeExternalDropHandler _tmp21_;
	void* _tmp21__target;
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = (SidebarTree*) g_object_new (object_type, NULL);
#line 95 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->store;
#line 95 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_model (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GTK_TYPE_TREE_MODEL, GtkTreeModel));
#line 96 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_widget_get_style_context (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 96 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_style_context_add_class (_tmp1_, "sidebar");
#line 98 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gtk_tree_view_column_new ();
#line 98 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_ref_sink (_tmp2_);
#line 98 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	text_column = _tmp2_;
#line 99 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_column_set_expand (text_column, TRUE);
#line 100 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = (GtkCellRendererPixbuf*) gtk_cell_renderer_pixbuf_new ();
#line 100 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_ref_sink (_tmp3_);
#line 100 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	icon_renderer = _tmp3_;
#line 101 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_set (icon_renderer, "follow-state", TRUE, NULL);
#line 102 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (text_column, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (icon_renderer, gtk_cell_renderer_get_type (), GtkCellRenderer), FALSE);
#line 103 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (text_column, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (icon_renderer, gtk_cell_renderer_get_type (), GtkCellRenderer), "icon_name", (gint) SIDEBAR_TREE_COLUMNS_ICON);
#line 104 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_layout_set_cell_data_func (G_TYPE_CHECK_INSTANCE_CAST (text_column, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (icon_renderer, gtk_cell_renderer_get_type (), GtkCellRenderer), _sidebar_tree_icon_renderer_function_gtk_cell_layout_data_func, g_object_ref (self), g_object_unref);
#line 105 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
#line 105 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_ref_sink (_tmp4_);
#line 105 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->text_renderer);
#line 105 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->text_renderer = _tmp4_;
#line 106 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = self->priv->text_renderer;
#line 106 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_set (_tmp5_, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
#line 107 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = self->priv->text_renderer;
#line 107 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_cell_renderer_get_type (), GtkCellRenderer), "editing-canceled", (GCallback) _sidebar_tree_on_editing_canceled_gtk_cell_renderer_editing_canceled, self, 0);
#line 108 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = self->priv->text_renderer;
#line 108 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_cell_renderer_get_type (), GtkCellRenderer), "editing-started", (GCallback) _sidebar_tree_on_editing_started_gtk_cell_renderer_editing_started, self, 0);
#line 109 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = self->priv->text_renderer;
#line 109 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (text_column, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_cell_renderer_get_type (), GtkCellRenderer), TRUE);
#line 110 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = self->priv->text_renderer;
#line 110 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (text_column, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_cell_renderer_get_type (), GtkCellRenderer), "markup", (gint) SIDEBAR_TREE_COLUMNS_NAME);
#line 111 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_append_column (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), text_column);
#line 113 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
#line 113 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_ref_sink (_tmp10_);
#line 113 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	invisitext = _tmp10_;
#line 114 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = gtk_tree_view_column_new ();
#line 114 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_ref_sink (_tmp11_);
#line 114 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	page_holder = _tmp11_;
#line 115 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (page_holder, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (invisitext, gtk_cell_renderer_get_type (), GtkCellRenderer), TRUE);
#line 116 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_column_set_visible (page_holder, FALSE);
#line 117 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_append_column (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), page_holder);
#line 119 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_headers_visible (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), FALSE);
#line 120 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_enable_search (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), FALSE);
#line 121 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_show_expanders (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), TRUE);
#line 122 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_reorderable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), FALSE);
#line 123 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_enable_tree_lines (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), FALSE);
#line 124 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_grid_lines (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), GTK_TREE_VIEW_GRID_LINES_NONE);
#line 125 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_tooltip_column (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), (gint) SIDEBAR_TREE_COLUMNS_TOOLTIP);
#line 127 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp12_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 127 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = _g_object_ref0 (_tmp12_);
#line 127 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	selection = _tmp13_;
#line 128 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
#line 129 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_selection_set_select_function (selection, _sidebar_tree_on_selection_gtk_tree_selection_func, g_object_ref (self), g_object_unref);
#line 131 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), "test-expand-row", (GCallback) _sidebar_tree_on_toggle_row_gtk_tree_view_test_expand_row, self, 0);
#line 132 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), "test-collapse-row", (GCallback) _sidebar_tree_on_toggle_row_gtk_tree_view_test_collapse_row, self, 0);
#line 137 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = target_entries;
#line 137 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14__length1 = target_entries_length1;
#line 137 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = actions;
#line 137 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_enable_model_drag_dest (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp14_, _tmp14__length1, _tmp15_);
#line 139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = g_new0 (GtkTargetEntry, 0);
#line 139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	source_entries = _tmp16_;
#line 139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	source_entries_length1 = 0;
#line 139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_source_entries_size_ = source_entries_length1;
#line 140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = source_entries;
#line 140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17__length1 = source_entries_length1;
#line 140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp18_ = target_entries;
#line 140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp18__length1 = target_entries_length1;
#line 140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp19_ = _tmp18_[LIBRARY_WINDOW_TARGET_TYPE_TAG_PATH];
#line 140 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_array_add64 (&source_entries, &source_entries_length1, &_source_entries_size_, &_tmp19_);
#line 141 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp20_ = source_entries;
#line 141 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp20__length1 = source_entries_length1;
#line 141 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_enable_model_drag_source (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), GDK_BUTTON1_MASK, _tmp20_, _tmp20__length1, GDK_ACTION_COPY);
#line 144 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp21_ = drop_handler;
#line 144 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp21__target = drop_handler_target;
#line 144 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->drop_handler = _tmp21_;
#line 144 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->drop_handler_target = _tmp21__target;
#line 146 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "popup-menu", (GCallback) _sidebar_tree_on_context_menu_keypress_gtk_widget_popup_menu, self, 0);
#line 148 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_setup_default_context_menu (self);
#line 150 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "drag-begin", (GCallback) _sidebar_tree_on_drag_begin_gtk_widget_drag_begin, self, 0);
#line 151 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "drag-end", (GCallback) _sidebar_tree_on_drag_end_gtk_widget_drag_end, self, 0);
#line 152 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "drag-motion", (GCallback) _sidebar_tree_on_drag_motion_gtk_widget_drag_motion, self, 0);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	source_entries = (g_free (source_entries), NULL);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (selection);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (page_holder);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (invisitext);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (icon_renderer);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (text_column);
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return self;
#line 1031 "Tree.c"
}


SidebarTree* sidebar_tree_new (GtkTargetEntry* target_entries, int target_entries_length1, GdkDragAction actions, SidebarTreeExternalDropHandler drop_handler, void* drop_handler_target) {
#line 93 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return sidebar_tree_construct (SIDEBAR_TYPE_TREE, target_entries, target_entries_length1, actions, drop_handler, drop_handler_target);
#line 1038 "Tree.c"
}


void sidebar_tree_icon_renderer_function (SidebarTree* self, GtkCellLayout* layout, GtkCellRenderer* renderer, GtkTreeModel* model, GtkTreeIter* iter) {
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreeIter _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	GtkCellRenderer* _tmp3_;
	SidebarTreeEntryWrapper* _tmp4_;
	SidebarEntry* _tmp5_;
#line 160 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 160 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GTK_IS_CELL_LAYOUT (layout));
#line 160 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GTK_IS_CELL_RENDERER (renderer));
#line 160 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GTK_IS_TREE_MODEL (model));
#line 160 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (iter != NULL);
#line 161 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = *iter;
#line 161 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper_at_iter (self, &_tmp0_);
#line 161 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 162 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 162 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 163 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 163 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 1074 "Tree.c"
	}
#line 165 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = renderer;
#line 165 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = wrapper;
#line 165 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = _tmp4_->entry;
#line 165 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_cell_renderer_set_visible (_tmp3_, !G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, SIDEBAR_TYPE_HEADER));
#line 160 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 1086 "Tree.c"
}


static void sidebar_tree_on_drag_begin (SidebarTree* self, GdkDragContext* ctx) {
#line 168 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 168 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (ctx));
#line 169 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->is_internal_drag_in_progress = TRUE;
#line 1097 "Tree.c"
}


static void sidebar_tree_on_drag_end (SidebarTree* self, GdkDragContext* ctx) {
#line 172 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 172 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (ctx));
#line 173 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->is_internal_drag_in_progress = FALSE;
#line 174 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->internal_drag_source_entry);
#line 174 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->internal_drag_source_entry = NULL;
#line 1112 "Tree.c"
}


static gboolean sidebar_tree_on_drag_motion (SidebarTree* self, GdkDragContext* context, gint x, gint y, guint time_) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
#line 177 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 177 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (GDK_IS_DRAG_CONTEXT (context), FALSE);
#line 178 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->is_internal_drag_in_progress;
#line 178 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_) {
#line 1128 "Tree.c"
		SidebarEntry* _tmp2_;
#line 178 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = self->priv->internal_drag_source_entry;
#line 178 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp0_ = _tmp2_ == NULL;
#line 1134 "Tree.c"
	} else {
#line 178 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp0_ = FALSE;
#line 1138 "Tree.c"
	}
#line 178 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp0_) {
#line 1142 "Tree.c"
		GtkTreePath* path = NULL;
		GtkTreeViewDropPosition position = 0;
		gint _tmp3_;
		gint _tmp4_;
		GtkTreePath* _tmp5_ = NULL;
		GtkTreeViewDropPosition _tmp6_ = 0;
		GtkTreePath* _tmp7_;
#line 181 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = x;
#line 181 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = y;
#line 181 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_view_get_dest_row_at_pos (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp3_, _tmp4_, &_tmp5_, &_tmp6_);
#line 181 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_gtk_tree_path_free0 (path);
#line 181 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		path = _tmp5_;
#line 181 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		position = _tmp6_;
#line 183 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = path;
#line 183 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp7_ != NULL) {
#line 1166 "Tree.c"
			SidebarTreeEntryWrapper* wrapper = NULL;
			GtkTreePath* _tmp8_;
			SidebarTreeEntryWrapper* _tmp9_;
			SidebarTreeEntryWrapper* _tmp10_;
#line 184 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp8_ = path;
#line 184 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = sidebar_tree_get_wrapper_at_path (self, _tmp8_);
#line 184 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			wrapper = _tmp9_;
#line 185 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = wrapper;
#line 185 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp10_ != NULL) {
#line 1181 "Tree.c"
				SidebarTreeEntryWrapper* _tmp11_;
				SidebarEntry* _tmp12_;
				SidebarEntry* _tmp13_;
#line 186 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp11_ = wrapper;
#line 186 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp12_ = _tmp11_->entry;
#line 186 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp13_ = _g_object_ref0 (_tmp12_);
#line 186 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_g_object_unref0 (self->priv->internal_drag_source_entry);
#line 186 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				self->priv->internal_drag_source_entry = _tmp13_;
#line 1195 "Tree.c"
			}
#line 183 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (wrapper);
#line 1199 "Tree.c"
		}
#line 178 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_gtk_tree_path_free0 (path);
#line 1203 "Tree.c"
	}
#line 190 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = FALSE;
#line 190 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1209 "Tree.c"
}


static void sidebar_tree_setup_default_context_menu (SidebarTree* self) {
	GError * _inner_error_ = NULL;
#line 198 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 1217 "Tree.c"
	{
		GtkBuilder* _tmp0_;
		gchar* _tmp1_;
		gchar* _tmp2_;
		GMenuModel* model = NULL;
		GtkBuilder* _tmp3_;
		GObject* _tmp4_;
		GMenuModel* _tmp5_;
		GMenuModel* _tmp6_;
		GtkMenu* _tmp7_;
		GSimpleActionGroup* group = NULL;
		GSimpleActionGroup* _tmp8_;
		GSimpleActionGroup* _tmp9_;
		GSimpleActionGroup* _tmp10_;
		GtkMenu* _tmp11_;
#line 200 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp0_ = self->priv->builder;
#line 200 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = resources_get_ui ("sidebar_default_context.ui");
#line 200 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = _tmp1_;
#line 200 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_builder_add_from_resource (_tmp0_, _tmp2_, &_inner_error_);
#line 200 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (_tmp2_);
#line 200 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1245 "Tree.c"
			goto __catch51_g_error;
		}
#line 201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = self->priv->builder;
#line 201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = gtk_builder_get_object (_tmp3_, "popup-menu");
#line 201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, g_menu_model_get_type ()) ? ((GMenuModel*) _tmp4_) : NULL);
#line 201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		model = _tmp5_;
#line 202 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = model;
#line 202 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = (GtkMenu*) gtk_menu_new_from_model (_tmp6_);
#line 202 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_object_ref_sink (_tmp7_);
#line 202 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (self->priv->default_context_menu);
#line 202 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->default_context_menu = _tmp7_;
#line 203 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = g_simple_action_group_new ();
#line 203 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		group = _tmp8_;
#line 204 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = group;
#line 204 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_action_map_add_action_entries (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, g_action_map_get_type (), GActionMap), SIDEBAR_TREE_entries, G_N_ELEMENTS (SIDEBAR_TREE_entries), self);
#line 205 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = group;
#line 205 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_widget_insert_action_group (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "sidebar", G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, g_action_group_get_type (), GActionGroup));
#line 206 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = self->priv->default_context_menu;
#line 206 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_menu_attach_to_widget (_tmp11_, G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), NULL);
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (group);
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (model);
#line 1286 "Tree.c"
	}
	goto __finally51;
	__catch51_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		Application* _tmp16_;
		Application* _tmp17_;
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_error_ = _inner_error_;
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_inner_error_ = NULL;
#line 208 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = _error_;
#line 208 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = _tmp12_->message;
#line 208 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp14_ = g_strdup_printf ("Error loading UI resource: %s", _tmp13_);
#line 208 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp15_ = _tmp14_;
#line 208 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		app_window_error_message (_tmp15_, NULL);
#line 208 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (_tmp15_);
#line 210 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp16_ = application_get_instance ();
#line 210 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp17_ = _tmp16_;
#line 210 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		application_panic (_tmp17_);
#line 210 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_application_unref0 (_tmp17_);
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_error_free0 (_error_);
#line 1324 "Tree.c"
	}
	__finally51:
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_clear_error (&_inner_error_);
#line 199 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 1335 "Tree.c"
	}
}


static gboolean sidebar_tree_has_wrapper (SidebarTree* self, SidebarEntry* entry) {
	gboolean result = FALSE;
	GeeHashMap* _tmp0_;
	SidebarEntry* _tmp1_;
	gboolean _tmp2_;
#line 214 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 214 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), FALSE);
#line 215 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->entry_map;
#line 215 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = entry;
#line 215 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp1_);
#line 215 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp2_;
#line 215 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1359 "Tree.c"
}


static SidebarTreeEntryWrapper* sidebar_tree_get_wrapper (SidebarTree* self, SidebarEntry* entry) {
	SidebarTreeEntryWrapper* result = NULL;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GeeHashMap* _tmp0_;
	SidebarEntry* _tmp1_;
	gpointer _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
#line 218 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 218 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), NULL);
#line 219 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->entry_map;
#line 219 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = entry;
#line 219 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp1_);
#line 219 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = (SidebarTreeEntryWrapper*) _tmp2_;
#line 220 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 220 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp3_ == NULL) {
#line 1386 "Tree.c"
		SidebarEntry* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
#line 221 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = entry;
#line 221 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = sidebar_entry_to_string (_tmp4_);
#line 221 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = _tmp5_;
#line 221 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_warning ("Tree.vala:221: Entry %s not found in sidebar", _tmp6_);
#line 221 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (_tmp6_);
#line 1400 "Tree.c"
	}
#line 223 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = wrapper;
#line 223 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1406 "Tree.c"
}


static SidebarTreeEntryWrapper* sidebar_tree_get_wrapper_at_iter (SidebarTree* self, GtkTreeIter* iter) {
	SidebarTreeEntryWrapper* result = NULL;
	GValue val = {0};
	GtkTreeStore* _tmp0_;
	GtkTreeIter _tmp1_;
	GValue _tmp2_ = {0};
	SidebarTreeEntryWrapper* wrapper = NULL;
	GValue _tmp3_;
	SidebarTreeEntryWrapper* _tmp4_;
	SidebarTreeEntryWrapper* _tmp5_;
#line 226 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 226 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (iter != NULL, NULL);
#line 228 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->store;
#line 228 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = *iter;
#line 228 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_model_get_value (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &_tmp1_, (gint) SIDEBAR_TREE_COLUMNS_WRAPPER, &_tmp2_);
#line 228 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_IS_VALUE (&val) ? (g_value_unset (&val), NULL) : NULL;
#line 228 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	val = _tmp2_;
#line 230 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = val;
#line 230 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _g_object_ref0 (g_value_get_object (&_tmp3_));
#line 230 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp4_;
#line 231 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = wrapper;
#line 231 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp5_ == NULL) {
#line 1444 "Tree.c"
		GtkTreeStore* _tmp6_;
		GtkTreeIter _tmp7_;
		GtkTreePath* _tmp8_;
		GtkTreePath* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
#line 232 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = self->priv->store;
#line 232 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = *iter;
#line 232 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = gtk_tree_model_get_path (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &_tmp7_);
#line 232 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = _tmp8_;
#line 232 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = gtk_tree_path_to_string (_tmp9_);
#line 232 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = _tmp10_;
#line 232 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_message ("Tree.vala:232: No entry found in sidebar at %s", _tmp11_);
#line 232 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (_tmp11_);
#line 232 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_gtk_tree_path_free0 (_tmp9_);
#line 1469 "Tree.c"
	}
#line 234 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = wrapper;
#line 234 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_IS_VALUE (&val) ? (g_value_unset (&val), NULL) : NULL;
#line 234 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1477 "Tree.c"
}


static SidebarTreeEntryWrapper* sidebar_tree_get_wrapper_at_path (SidebarTree* self, GtkTreePath* path) {
	SidebarTreeEntryWrapper* result = NULL;
	GtkTreeIter iter = {0};
	GtkTreeStore* _tmp0_;
	GtkTreePath* _tmp1_;
	GtkTreeIter _tmp2_ = {0};
	gboolean _tmp3_;
	GtkTreeIter _tmp7_;
	SidebarTreeEntryWrapper* _tmp8_;
#line 237 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 237 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 239 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->store;
#line 239 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = path;
#line 239 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = gtk_tree_model_get_iter (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &_tmp2_, _tmp1_);
#line 239 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	iter = _tmp2_;
#line 239 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (!_tmp3_) {
#line 1504 "Tree.c"
		GtkTreePath* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
#line 240 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = path;
#line 240 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = gtk_tree_path_to_string (_tmp4_);
#line 240 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = _tmp5_;
#line 240 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_message ("Tree.vala:240: No entry found in sidebar at %s", _tmp6_);
#line 240 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (_tmp6_);
#line 242 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = NULL;
#line 242 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 1522 "Tree.c"
	}
#line 245 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = iter;
#line 245 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = sidebar_tree_get_wrapper_at_iter (self, &_tmp7_);
#line 245 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp8_;
#line 245 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1532 "Tree.c"
}


gboolean sidebar_tree_place_cursor (SidebarTree* self, SidebarEntry* entry, gboolean mask_signal) {
	gboolean result = FALSE;
	SidebarEntry* _tmp0_;
	gboolean _tmp1_;
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarEntry* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	SidebarTreeEntryWrapper* _tmp4_;
	GtkTreeSelection* _tmp5_;
	SidebarTreeEntryWrapper* _tmp6_;
	GtkTreePath* _tmp7_;
	GtkTreePath* _tmp8_;
	gboolean _tmp9_;
	SidebarTreeEntryWrapper* _tmp10_;
	GtkTreePath* _tmp11_;
	GtkTreePath* _tmp12_;
	SidebarEntry* _tmp13_;
	gboolean _tmp14_;
#line 250 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 250 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), FALSE);
#line 251 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 251 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_expand_to_entry (self, _tmp0_);
#line 251 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (!_tmp1_) {
#line 252 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 252 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 1568 "Tree.c"
	}
#line 254 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = entry;
#line 254 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_get_wrapper (self, _tmp2_);
#line 254 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp3_;
#line 255 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = wrapper;
#line 255 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp4_ == NULL) {
#line 256 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 256 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 256 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 1586 "Tree.c"
	}
#line 258 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 258 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = wrapper;
#line 258 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = sidebar_tree_entry_wrapper_get_path (_tmp6_);
#line 258 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = _tmp7_;
#line 258 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_selection_select_path (_tmp5_, _tmp8_);
#line 258 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (_tmp8_);
#line 260 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = mask_signal;
#line 260 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->mask_entry_selected_signal = _tmp9_;
#line 261 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = wrapper;
#line 261 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = sidebar_tree_entry_wrapper_get_path (_tmp10_);
#line 261 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp12_ = _tmp11_;
#line 261 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_set_cursor (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp12_, NULL, FALSE);
#line 261 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (_tmp12_);
#line 262 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->mask_entry_selected_signal = FALSE;
#line 264 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = entry;
#line 264 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = sidebar_tree_scroll_to_entry (self, _tmp13_);
#line 264 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp14_;
#line 264 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 264 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1626 "Tree.c"
}


gboolean sidebar_tree_is_selected (SidebarTree* self, SidebarEntry* entry) {
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarEntry* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	GtkTreeSelection* selection = NULL;
	GtkTreeSelection* _tmp2_;
	GtkTreeSelection* _tmp3_;
	GtkTreeSelection* _tmp4_;
	gboolean _tmp5_ = FALSE;
	SidebarTreeEntryWrapper* _tmp6_;
#line 267 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 267 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), FALSE);
#line 268 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 268 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper (self, _tmp0_);
#line 268 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 272 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 272 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 272 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	selection = _tmp3_;
#line 273 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = selection;
#line 273 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp4_ == NULL) {
#line 274 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 274 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (selection);
#line 274 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 274 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 1669 "Tree.c"
	}
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = wrapper;
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp6_ != NULL) {
#line 1675 "Tree.c"
		GtkTreeSelection* _tmp7_;
		SidebarTreeEntryWrapper* _tmp8_;
		GtkTreePath* _tmp9_;
		GtkTreePath* _tmp10_;
		gboolean _tmp11_;
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = selection;
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = wrapper;
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = sidebar_tree_entry_wrapper_get_path (_tmp8_);
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = _tmp9_;
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = gtk_tree_selection_path_is_selected (_tmp7_, _tmp10_);
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = _tmp11_;
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_gtk_tree_path_free0 (_tmp10_);
#line 1695 "Tree.c"
	} else {
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = FALSE;
#line 1699 "Tree.c"
	}
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp5_;
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (selection);
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 276 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1709 "Tree.c"
}


gboolean sidebar_tree_is_any_selected (SidebarTree* self) {
	gboolean result = FALSE;
	GtkTreeSelection* _tmp0_;
	gint _tmp1_;
#line 279 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 280 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 280 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_tree_selection_count_selected_rows (_tmp0_);
#line 280 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp1_ != 0;
#line 280 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1727 "Tree.c"
}


static gpointer _gtk_tree_path_copy0 (gpointer self) {
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return self ? gtk_tree_path_copy (self) : NULL;
#line 1734 "Tree.c"
}


static void _gtk_tree_path_free0_ (gpointer var) {
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	(var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL));
#line 1741 "Tree.c"
}


static void _g_list_free__gtk_tree_path_free0_ (GList* self) {
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_list_foreach (self, (GFunc) _gtk_tree_path_free0_, NULL);
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_list_free (self);
#line 1750 "Tree.c"
}


static GtkTreePath* sidebar_tree_get_selected_path (SidebarTree* self) {
	GtkTreePath* result = NULL;
	GtkTreeModel* model = NULL;
	GtkTreeSelection* selection = NULL;
	GtkTreeSelection* _tmp0_;
	GtkTreeSelection* _tmp1_;
	GtkTreeSelection* _tmp2_;
	GList* rows = NULL;
	GtkTreeSelection* _tmp3_;
	GtkTreeModel* _tmp4_ = NULL;
	GList* _tmp5_;
	GtkTreeModel* _tmp6_;
	gboolean _tmp7_ = FALSE;
	GList* _tmp8_;
	guint _tmp9_;
	GtkTreePath* _tmp12_ = NULL;
	GList* _tmp13_;
	guint _tmp14_;
	GtkTreePath* _tmp17_;
#line 283 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 285 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 285 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 285 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	selection = _tmp1_;
#line 286 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = selection;
#line 286 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 287 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = NULL;
#line 287 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (selection);
#line 287 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (model);
#line 287 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 1793 "Tree.c"
	}
#line 289 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = selection;
#line 289 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = gtk_tree_selection_get_selected_rows (_tmp3_, &_tmp4_);
#line 289 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (model);
#line 289 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = _g_object_ref0 (_tmp4_);
#line 289 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	model = _tmp6_;
#line 289 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	rows = _tmp5_;
#line 290 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = rows;
#line 290 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = g_list_length (_tmp8_);
#line 290 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp9_ == ((guint) 0)) {
#line 290 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = TRUE;
#line 1815 "Tree.c"
	} else {
		GList* _tmp10_;
		guint _tmp11_;
#line 290 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = rows;
#line 290 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = g_list_length (_tmp10_);
#line 290 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = _tmp11_ == ((guint) 1);
#line 1825 "Tree.c"
	}
#line 290 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp7_, "rows.length() == 0 || rows.length() == 1");
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = rows;
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = g_list_length (_tmp13_);
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp14_ != ((guint) 0)) {
#line 1835 "Tree.c"
		GList* _tmp15_;
		gconstpointer _tmp16_;
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp15_ = rows;
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp16_ = g_list_nth_data (_tmp15_, (guint) 0);
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = (GtkTreePath*) _tmp16_;
#line 1844 "Tree.c"
	} else {
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = NULL;
#line 1848 "Tree.c"
	}
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = _gtk_tree_path_copy0 (_tmp12_);
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp17_;
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__g_list_free__gtk_tree_path_free0_0 (rows);
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (selection);
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (model);
#line 292 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1862 "Tree.c"
}


static gchar* sidebar_tree_get_name_for_entry (SidebarTree* self, SidebarEntry* entry) {
	gchar* result = NULL;
	gchar* name = NULL;
	SidebarEntry* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	SidebarEmphasizableEntry* emphasizable_entry = NULL;
	SidebarEntry* _tmp5_;
	SidebarEmphasizableEntry* _tmp6_;
	gboolean _tmp7_ = FALSE;
	SidebarEmphasizableEntry* _tmp8_;
#line 295 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 295 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), NULL);
#line 296 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 296 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_entry_get_sidebar_name (_tmp0_);
#line 296 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _tmp1_;
#line 296 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = guarded_markup_escape_text (_tmp2_);
#line 296 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_;
#line 296 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp2_);
#line 296 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	name = _tmp4_;
#line 298 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = entry;
#line 298 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, SIDEBAR_TYPE_EMPHASIZABLE_ENTRY) ? ((SidebarEmphasizableEntry*) _tmp5_) : NULL);
#line 298 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	emphasizable_entry = _tmp6_;
#line 299 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = emphasizable_entry;
#line 299 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp8_ != NULL) {
#line 1907 "Tree.c"
		SidebarEmphasizableEntry* _tmp9_;
		gboolean _tmp10_;
#line 299 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = emphasizable_entry;
#line 299 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = sidebar_emphasizable_entry_is_emphasized (_tmp9_);
#line 299 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = _tmp10_;
#line 1916 "Tree.c"
	} else {
#line 299 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = FALSE;
#line 1920 "Tree.c"
	}
#line 299 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp7_) {
#line 1924 "Tree.c"
		const gchar* _tmp11_;
		gchar* _tmp12_;
#line 300 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = name;
#line 300 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = g_strdup_printf ("<b>%s</b>", _tmp11_);
#line 300 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (name);
#line 300 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		name = _tmp12_;
#line 1935 "Tree.c"
	}
#line 302 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = name;
#line 302 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (emphasizable_entry);
#line 302 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1943 "Tree.c"
}


static gboolean sidebar_tree_real_accept_cursor_changed (SidebarTree* self) {
	gboolean result = FALSE;
#line 306 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 306 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 1953 "Tree.c"
}


gboolean sidebar_tree_accept_cursor_changed (SidebarTree* self) {
#line 305 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 305 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return SIDEBAR_TREE_GET_CLASS (self)->accept_cursor_changed (self);
#line 1962 "Tree.c"
}


static void sidebar_tree_real_cursor_changed (GtkTreeView* base) {
	SidebarTree * self;
	GtkTreePath* path = NULL;
	GtkTreePath* _tmp0_;
	GtkTreePath* _tmp1_;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreePath* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	SidebarTreeEntryWrapper* _tmp4_;
	SidebarTreeEntryWrapper* _tmp5_;
#line 309 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_TREE, SidebarTree);
#line 310 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_selected_path (self);
#line 310 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp0_;
#line 311 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = path;
#line 311 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_ == NULL) {
#line 312 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (GTK_TREE_VIEW_CLASS (sidebar_tree_parent_class)->cursor_changed != NULL) {
#line 313 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			GTK_TREE_VIEW_CLASS (sidebar_tree_parent_class)->cursor_changed (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 1990 "Tree.c"
		}
#line 314 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_gtk_tree_path_free0 (path);
#line 314 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 1996 "Tree.c"
	}
#line 317 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = path;
#line 317 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_get_wrapper_at_path (self, _tmp2_);
#line 317 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp3_;
#line 319 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = self->priv->selected_wrapper;
#line 319 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = wrapper;
#line 319 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp4_ != _tmp5_) {
#line 2010 "Tree.c"
		SidebarTreeEntryWrapper* old_wrapper = NULL;
		SidebarTreeEntryWrapper* _tmp6_;
		SidebarTreeEntryWrapper* _tmp7_;
		SidebarTreeEntryWrapper* _tmp8_;
		gboolean _tmp9_ = FALSE;
		gboolean _tmp10_ = FALSE;
		gint _tmp11_;
		gboolean _tmp19_ = FALSE;
		SidebarTreeEntryWrapper* _tmp20_;
#line 320 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = self->priv->selected_wrapper;
#line 320 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = _g_object_ref0 (_tmp6_);
#line 320 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		old_wrapper = _tmp7_;
#line 321 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = wrapper;
#line 321 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->selected_wrapper = _tmp8_;
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = self->priv->editing_disabled;
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp11_ == 0) {
#line 2034 "Tree.c"
			SidebarTreeEntryWrapper* _tmp12_;
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = wrapper;
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = _tmp12_ != NULL;
#line 2040 "Tree.c"
		} else {
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = FALSE;
#line 2044 "Tree.c"
		}
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp10_) {
#line 2048 "Tree.c"
			SidebarTreeEntryWrapper* _tmp13_;
			SidebarEntry* _tmp14_;
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp13_ = wrapper;
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp14_ = _tmp13_->entry;
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, SIDEBAR_TYPE_RENAMEABLE_ENTRY);
#line 2057 "Tree.c"
		} else {
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = FALSE;
#line 2061 "Tree.c"
		}
#line 323 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp9_) {
#line 2065 "Tree.c"
			GtkCellRendererText* _tmp15_;
			SidebarTreeEntryWrapper* _tmp16_;
			SidebarEntry* _tmp17_;
			gboolean _tmp18_;
#line 324 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp15_ = self->priv->text_renderer;
#line 324 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp16_ = wrapper;
#line 324 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp17_ = _tmp16_->entry;
#line 324 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = sidebar_renameable_entry_is_user_renameable (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntry));
#line 324 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			g_object_set (_tmp15_, "editable", _tmp18_, NULL);
#line 2080 "Tree.c"
		}
#line 326 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp20_ = wrapper;
#line 326 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp20_ != NULL) {
#line 2086 "Tree.c"
			gboolean _tmp21_;
#line 326 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp21_ = self->priv->mask_entry_selected_signal;
#line 326 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp19_ = !_tmp21_;
#line 2092 "Tree.c"
		} else {
#line 326 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp19_ = FALSE;
#line 2096 "Tree.c"
		}
#line 326 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp19_) {
#line 2100 "Tree.c"
			SidebarSelectableEntry* selectable = NULL;
			SidebarTreeEntryWrapper* _tmp22_;
			SidebarEntry* _tmp23_;
			SidebarSelectableEntry* _tmp24_;
			SidebarSelectableEntry* _tmp25_;
#line 327 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp22_ = wrapper;
#line 327 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp23_ = _tmp22_->entry;
#line 327 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp24_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, SIDEBAR_TYPE_SELECTABLE_ENTRY) ? ((SidebarSelectableEntry*) _tmp23_) : NULL);
#line 327 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			selectable = _tmp24_;
#line 328 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp25_ = selectable;
#line 328 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp25_ != NULL) {
#line 2118 "Tree.c"
				gboolean _tmp26_;
#line 329 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp26_ = sidebar_tree_accept_cursor_changed (self);
#line 329 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				if (_tmp26_) {
#line 2124 "Tree.c"
					SidebarSelectableEntry* _tmp27_;
#line 330 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp27_ = selectable;
#line 330 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_ENTRY_SELECTED_SIGNAL], 0, _tmp27_);
#line 2130 "Tree.c"
				} else {
					SidebarTreeEntryWrapper* _tmp28_;
					SidebarEntry* _tmp29_;
#line 332 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp28_ = old_wrapper;
#line 332 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp29_ = _tmp28_->entry;
#line 332 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					sidebar_tree_place_cursor (self, _tmp29_, TRUE);
#line 2140 "Tree.c"
				}
			}
#line 326 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (selectable);
#line 2145 "Tree.c"
		}
#line 319 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (old_wrapper);
#line 2149 "Tree.c"
	}
#line 338 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (GTK_TREE_VIEW_CLASS (sidebar_tree_parent_class)->cursor_changed != NULL) {
#line 339 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		GTK_TREE_VIEW_CLASS (sidebar_tree_parent_class)->cursor_changed (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 2155 "Tree.c"
	}
#line 309 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 309 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (path);
#line 2161 "Tree.c"
}


void sidebar_tree_disable_editing (SidebarTree* self) {
	gint _tmp0_;
#line 342 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 343 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->editing_disabled;
#line 343 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->editing_disabled = _tmp0_ + 1;
#line 343 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp0_ == 0) {
#line 2175 "Tree.c"
		GtkCellRendererText* _tmp1_;
#line 344 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = self->priv->text_renderer;
#line 344 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_object_set (_tmp1_, "editable", FALSE, NULL);
#line 2181 "Tree.c"
	}
}


void sidebar_tree_enable_editing (SidebarTree* self) {
	GtkTreePath* path = NULL;
	GtkTreePath* _tmp0_;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	GtkTreePath* _tmp3_;
#line 347 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = sidebar_tree_get_selected_path (self);
#line 348 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp0_;
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = path;
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp3_ != NULL) {
#line 2202 "Tree.c"
		gint _tmp4_;
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = self->priv->editing_disabled;
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = _tmp4_ > 0;
#line 2208 "Tree.c"
	} else {
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = FALSE;
#line 2212 "Tree.c"
	}
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_) {
#line 2216 "Tree.c"
		gint _tmp5_;
		gint _tmp6_;
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = self->priv->editing_disabled;
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->editing_disabled = _tmp5_ - 1;
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = self->priv->editing_disabled;
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = _tmp6_ == 0;
#line 2227 "Tree.c"
	} else {
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = FALSE;
#line 2231 "Tree.c"
	}
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_) {
#line 2235 "Tree.c"
		SidebarTreeEntryWrapper* wrapper = NULL;
		GtkTreePath* _tmp7_;
		SidebarTreeEntryWrapper* _tmp8_;
		gboolean _tmp9_ = FALSE;
		SidebarTreeEntryWrapper* _tmp10_;
#line 350 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = path;
#line 350 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = sidebar_tree_get_wrapper_at_path (self, _tmp7_);
#line 350 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		wrapper = _tmp8_;
#line 351 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = wrapper;
#line 351 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp10_ != NULL) {
#line 2251 "Tree.c"
			SidebarTreeEntryWrapper* _tmp11_;
			SidebarEntry* _tmp12_;
#line 351 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp11_ = wrapper;
#line 351 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = _tmp11_->entry;
#line 351 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, SIDEBAR_TYPE_RENAMEABLE_ENTRY);
#line 2260 "Tree.c"
		} else {
#line 351 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = FALSE;
#line 2264 "Tree.c"
		}
#line 351 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp9_) {
#line 2268 "Tree.c"
			GtkCellRendererText* _tmp13_;
			SidebarTreeEntryWrapper* _tmp14_;
			SidebarEntry* _tmp15_;
			gboolean _tmp16_;
#line 352 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp13_ = self->priv->text_renderer;
#line 352 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp14_ = wrapper;
#line 352 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp15_ = _tmp14_->entry;
#line 352 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp16_ = sidebar_renameable_entry_is_user_renameable (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntry));
#line 352 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			g_object_set (_tmp13_, "editable", _tmp16_, NULL);
#line 2283 "Tree.c"
		}
#line 349 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 2287 "Tree.c"
	}
#line 347 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (path);
#line 2291 "Tree.c"
}


void sidebar_tree_toggle_branch_expansion (SidebarTree* self, GtkTreePath* path, gboolean expand_all) {
	GtkTreePath* _tmp0_;
	gboolean _tmp1_;
#line 357 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 357 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (path != NULL);
#line 358 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->expander_called_manually = TRUE;
#line 359 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = path;
#line 359 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_tree_view_row_expanded (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp0_);
#line 359 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp1_) {
#line 2310 "Tree.c"
		GtkTreePath* _tmp2_;
#line 360 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = path;
#line 360 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_view_collapse_row (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp2_);
#line 2316 "Tree.c"
	} else {
		GtkTreePath* _tmp3_;
		gboolean _tmp4_;
#line 362 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = path;
#line 362 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = expand_all;
#line 362 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_view_expand_row (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp3_, _tmp4_);
#line 2326 "Tree.c"
	}
}


gboolean sidebar_tree_expand_to_entry (SidebarTree* self, SidebarEntry* entry) {
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarEntry* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	GtkTreePath* _tmp4_;
	GtkTreePath* _tmp5_;
#line 365 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 365 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), FALSE);
#line 366 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->expander_called_manually = TRUE;
#line 367 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 367 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper (self, _tmp0_);
#line 367 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 368 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 368 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 369 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 369 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 369 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 2362 "Tree.c"
	}
#line 371 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 371 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = sidebar_tree_entry_wrapper_get_path (_tmp3_);
#line 371 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = _tmp4_;
#line 371 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_expand_to_path (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp5_);
#line 371 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (_tmp5_);
#line 373 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 373 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 373 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 2380 "Tree.c"
}


void sidebar_tree_expand_to_first_child (SidebarTree* self, SidebarEntry* entry) {
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarEntry* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	GtkTreePath* path = NULL;
	SidebarTreeEntryWrapper* _tmp3_;
	GtkTreePath* _tmp4_;
	GtkTreeIter iter = {0};
	GtkTreePath* _tmp13_;
#line 376 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 376 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 377 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->expander_called_manually = TRUE;
#line 378 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 378 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper (self, _tmp0_);
#line 378 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 379 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 379 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 380 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 380 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 2414 "Tree.c"
	}
#line 382 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 382 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = sidebar_tree_entry_wrapper_get_path (_tmp3_);
#line 382 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp4_;
#line 385 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	while (TRUE) {
#line 2424 "Tree.c"
		GtkTreeStore* _tmp5_;
		GtkTreePath* _tmp6_;
		GtkTreeIter _tmp7_ = {0};
		gboolean _tmp8_;
		GtkTreeStore* _tmp9_;
		GtkTreeIter _tmp10_;
		gboolean _tmp11_;
		GtkTreePath* _tmp12_;
#line 385 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = self->priv->store;
#line 385 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = path;
#line 385 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = gtk_tree_model_get_iter (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &_tmp7_, _tmp6_);
#line 385 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		iter = _tmp7_;
#line 385 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (!_tmp8_) {
#line 385 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			break;
#line 2445 "Tree.c"
		}
#line 386 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = self->priv->store;
#line 386 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = iter;
#line 386 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = gtk_tree_model_iter_has_child (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &_tmp10_);
#line 386 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (!_tmp11_) {
#line 387 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			break;
#line 2457 "Tree.c"
		}
#line 389 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = path;
#line 389 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_path_down (_tmp12_);
#line 2463 "Tree.c"
	}
#line 392 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = path;
#line 392 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_expand_to_path (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp13_);
#line 376 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (path);
#line 376 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 2473 "Tree.c"
}


static void _sidebar_tree_on_branch_entry_added_sidebar_branch_entry_added (SidebarBranch* _sender, SidebarEntry* entry, gpointer self) {
#line 410 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_branch_entry_added ((SidebarTree*) self, _sender, entry);
#line 2480 "Tree.c"
}


static void _sidebar_tree_on_branch_entry_removed_sidebar_branch_entry_removed (SidebarBranch* _sender, SidebarEntry* entry, gpointer self) {
#line 411 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_branch_entry_removed ((SidebarTree*) self, _sender, entry);
#line 2487 "Tree.c"
}


static void _sidebar_tree_on_branch_entry_moved_sidebar_branch_entry_moved (SidebarBranch* _sender, SidebarEntry* entry, gpointer self) {
#line 412 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_branch_entry_moved ((SidebarTree*) self, _sender, entry);
#line 2494 "Tree.c"
}


static void _sidebar_tree_on_branch_entry_reparented_sidebar_branch_entry_reparented (SidebarBranch* _sender, SidebarEntry* entry, SidebarEntry* old_parent, gpointer self) {
#line 413 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_branch_entry_reparented ((SidebarTree*) self, _sender, entry, old_parent);
#line 2501 "Tree.c"
}


static void _sidebar_tree_on_branch_children_reordered_sidebar_branch_children_reordered (SidebarBranch* _sender, SidebarEntry* entry, gpointer self) {
#line 414 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_branch_children_reordered ((SidebarTree*) self, _sender, entry);
#line 2508 "Tree.c"
}


static void _sidebar_tree_on_show_branch_sidebar_branch_show_branch (SidebarBranch* _sender, gboolean show, gpointer self) {
#line 415 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_show_branch ((SidebarTree*) self, _sender, show);
#line 2515 "Tree.c"
}


void sidebar_tree_graft (SidebarTree* self, SidebarBranch* branch, gint position) {
	gint _tmp0_;
	GeeHashMap* _tmp1_;
	SidebarBranch* _tmp2_;
	gboolean _tmp3_;
	GeeHashMap* _tmp4_;
	SidebarBranch* _tmp5_;
	gint _tmp6_;
	SidebarBranch* _tmp7_;
	gboolean _tmp8_;
	SidebarBranch* _tmp20_;
	SidebarBranch* _tmp21_;
	SidebarBranch* _tmp22_;
	SidebarBranch* _tmp23_;
	SidebarBranch* _tmp24_;
	SidebarBranch* _tmp25_;
	SidebarBranch* _tmp26_;
#line 395 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 395 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 395 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = position;
#line 395 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_return_if_fail (_tmp0_ >= 0, "position >= 0");
#line 396 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->branches;
#line 396 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = branch;
#line 396 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp2_);
#line 396 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (!_tmp3_, "!branches.has_key(branch)");
#line 398 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = self->priv->branches;
#line 398 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = branch;
#line 398 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = position;
#line 398 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp5_, (gpointer) ((gintptr) _tmp6_));
#line 400 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = branch;
#line 400 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = sidebar_branch_get_show_branch (_tmp7_);
#line 400 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp8_) {
#line 2566 "Tree.c"
		SidebarBranch* _tmp9_;
		SidebarBranch* _tmp10_;
		gboolean _tmp11_;
		SidebarBranch* _tmp15_;
		gboolean _tmp16_;
#line 401 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = branch;
#line 401 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_associate_branch (self, _tmp9_);
#line 403 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = branch;
#line 403 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = sidebar_branch_is_startup_expand_to_first_child (_tmp10_);
#line 403 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp11_) {
#line 2582 "Tree.c"
			SidebarBranch* _tmp12_;
			SidebarEntry* _tmp13_;
			SidebarEntry* _tmp14_;
#line 404 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = branch;
#line 404 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp13_ = sidebar_branch_get_root (_tmp12_);
#line 404 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp14_ = _tmp13_;
#line 404 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_expand_to_first_child (self, _tmp14_);
#line 404 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (_tmp14_);
#line 2596 "Tree.c"
		}
#line 406 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp15_ = branch;
#line 406 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp16_ = sidebar_branch_is_startup_open_grouping (_tmp15_);
#line 406 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp16_) {
#line 2604 "Tree.c"
			SidebarBranch* _tmp17_;
			SidebarEntry* _tmp18_;
			SidebarEntry* _tmp19_;
#line 407 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp17_ = branch;
#line 407 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = sidebar_branch_get_root (_tmp17_);
#line 407 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp19_ = _tmp18_;
#line 407 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_expand_to_entry (self, _tmp19_);
#line 407 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (_tmp19_);
#line 2618 "Tree.c"
		}
	}
#line 410 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp20_ = branch;
#line 410 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (_tmp20_, "entry-added", (GCallback) _sidebar_tree_on_branch_entry_added_sidebar_branch_entry_added, self, 0);
#line 411 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp21_ = branch;
#line 411 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (_tmp21_, "entry-removed", (GCallback) _sidebar_tree_on_branch_entry_removed_sidebar_branch_entry_removed, self, 0);
#line 412 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp22_ = branch;
#line 412 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (_tmp22_, "entry-moved", (GCallback) _sidebar_tree_on_branch_entry_moved_sidebar_branch_entry_moved, self, 0);
#line 413 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp23_ = branch;
#line 413 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (_tmp23_, "entry-reparented", (GCallback) _sidebar_tree_on_branch_entry_reparented_sidebar_branch_entry_reparented, self, 0);
#line 414 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp24_ = branch;
#line 414 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (_tmp24_, "children-reordered", (GCallback) _sidebar_tree_on_branch_children_reordered_sidebar_branch_children_reordered, self, 0);
#line 415 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp25_ = branch;
#line 415 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (_tmp25_, "show-branch", (GCallback) _sidebar_tree_on_show_branch_sidebar_branch_show_branch, self, 0);
#line 417 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp26_ = branch;
#line 417 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_BRANCH_ADDED_SIGNAL], 0, _tmp26_);
#line 2649 "Tree.c"
}


static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self) {
	GtkTreeIter* dup;
#line 436 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	dup = g_new0 (GtkTreeIter, 1);
#line 436 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	memcpy (dup, self, sizeof (GtkTreeIter));
#line 436 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return dup;
#line 2661 "Tree.c"
}


static gpointer __gtk_tree_iter_dup0 (gpointer self) {
#line 436 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return self ? _gtk_tree_iter_dup (self) : NULL;
#line 2668 "Tree.c"
}


static void sidebar_tree_associate_branch (SidebarTree* self, SidebarBranch* branch) {
	GeeHashMap* _tmp0_;
	SidebarBranch* _tmp1_;
	gboolean _tmp2_;
	gint position = 0;
	GeeHashMap* _tmp3_;
	SidebarBranch* _tmp4_;
	gpointer _tmp5_;
	GtkTreeIter* insertion_iter = NULL;
	GtkTreeIter iter = {0};
	gboolean found = FALSE;
	GtkTreeStore* _tmp6_;
	GtkTreeIter _tmp7_ = {0};
	gboolean _tmp8_;
	GtkTreeIter* _tmp24_;
	GtkTreeIter* _tmp29_;
	GtkTreeStore* _tmp30_;
	SidebarBranch* _tmp31_;
	SidebarEntry* _tmp32_;
	SidebarEntry* _tmp33_;
	GtkTreeStore* _tmp34_;
	GtkTreeIter* _tmp35_;
	GtkTreeIter _tmp36_;
	GtkTreePath* _tmp37_;
	GtkTreePath* _tmp38_;
	gint _tmp39_;
	SidebarTreeRootWrapper* _tmp40_;
	SidebarTreeRootWrapper* _tmp41_;
	GtkTreeIter _tmp42_;
	SidebarBranch* _tmp43_;
	SidebarBranch* _tmp44_;
	SidebarEntry* _tmp45_;
	SidebarEntry* _tmp46_;
	GtkTreeIter* _tmp47_;
	GtkTreeIter _tmp48_;
#line 421 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 421 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 422 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->branches;
#line 422 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = branch;
#line 422 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp1_);
#line 422 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp2_, "branches.has_key(branch)");
#line 424 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = self->priv->branches;
#line 424 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = branch;
#line 424 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp4_);
#line 424 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	position = (gint) ((gintptr) _tmp5_);
#line 426 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	insertion_iter = NULL;
#line 430 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = self->priv->store;
#line 430 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = gtk_tree_model_get_iter_first (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &_tmp7_);
#line 430 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	iter = _tmp7_;
#line 430 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	found = _tmp8_;
#line 431 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	while (TRUE) {
#line 2739 "Tree.c"
		gboolean _tmp9_;
		SidebarTreeRootWrapper* root_wrapper = NULL;
		GtkTreeIter _tmp10_;
		SidebarTreeEntryWrapper* _tmp11_;
		SidebarTreeRootWrapper* _tmp12_;
		SidebarTreeRootWrapper* _tmp13_;
		gint _tmp14_;
		SidebarTreeRootWrapper* _tmp15_;
		gint _tmp16_;
		GtkTreeStore* _tmp22_;
		gboolean _tmp23_;
#line 431 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = found;
#line 431 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (!_tmp9_) {
#line 431 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			break;
#line 2757 "Tree.c"
		}
#line 432 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = iter;
#line 432 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = sidebar_tree_get_wrapper_at_iter (self, &_tmp10_);
#line 432 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, SIDEBAR_TREE_TYPE_ROOT_WRAPPER) ? ((SidebarTreeRootWrapper*) _tmp11_) : NULL;
#line 432 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp12_ == NULL) {
#line 432 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (_tmp11_);
#line 2769 "Tree.c"
		}
#line 432 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		root_wrapper = _tmp12_;
#line 433 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = root_wrapper;
#line 433 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_vala_assert (_tmp13_ != NULL, "root_wrapper != null");
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp14_ = position;
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp15_ = root_wrapper;
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp16_ = _tmp15_->root_position;
#line 435 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp14_ < _tmp16_) {
#line 2785 "Tree.c"
			GtkTreeStore* _tmp17_;
			GtkTreeIter _tmp18_;
			GtkTreeIter _tmp19_ = {0};
			GtkTreeIter _tmp20_;
			GtkTreeIter* _tmp21_;
#line 436 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp17_ = self->priv->store;
#line 436 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = iter;
#line 436 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			gtk_tree_store_insert_before (_tmp17_, &_tmp19_, NULL, &_tmp18_);
#line 436 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_free0 (insertion_iter);
#line 436 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp20_ = _tmp19_;
#line 436 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp21_ = __gtk_tree_iter_dup0 (&_tmp20_);
#line 436 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			insertion_iter = _tmp21_;
#line 438 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (root_wrapper);
#line 438 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			break;
#line 2809 "Tree.c"
		}
#line 441 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp22_ = self->priv->store;
#line 441 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp23_ = gtk_tree_model_iter_next (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &iter);
#line 441 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		found = _tmp23_;
#line 431 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (root_wrapper);
#line 2819 "Tree.c"
	}
#line 445 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp24_ = insertion_iter;
#line 445 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp24_ == NULL) {
#line 2825 "Tree.c"
		GtkTreeStore* _tmp25_;
		GtkTreeIter _tmp26_ = {0};
		GtkTreeIter _tmp27_;
		GtkTreeIter* _tmp28_;
#line 446 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp25_ = self->priv->store;
#line 446 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_store_append (_tmp25_, &_tmp26_, NULL);
#line 446 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (insertion_iter);
#line 446 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp27_ = _tmp26_;
#line 446 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp28_ = __gtk_tree_iter_dup0 (&_tmp27_);
#line 446 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		insertion_iter = _tmp28_;
#line 2842 "Tree.c"
	}
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp29_ = insertion_iter;
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp30_ = self->priv->store;
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp31_ = branch;
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp32_ = sidebar_branch_get_root (_tmp31_);
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp33_ = _tmp32_;
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp34_ = self->priv->store;
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp35_ = insertion_iter;
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp36_ = *_tmp35_;
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp37_ = gtk_tree_model_get_path (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &_tmp36_);
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp38_ = _tmp37_;
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp39_ = position;
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp40_ = sidebar_tree_root_wrapper_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, GTK_TYPE_TREE_MODEL, GtkTreeModel), _tmp33_, _tmp38_, _tmp39_);
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp41_ = _tmp40_;
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp42_ = *_tmp29_;
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_associate_wrapper (self, &_tmp42_, G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, SidebarTreeEntryWrapper));
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp41_);
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (_tmp38_);
#line 448 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp33_);
#line 453 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp43_ = branch;
#line 453 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp44_ = branch;
#line 453 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp45_ = sidebar_branch_get_root (_tmp44_);
#line 453 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp46_ = _tmp45_;
#line 453 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp47_ = insertion_iter;
#line 453 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp48_ = *_tmp47_;
#line 453 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_associate_children (self, _tmp43_, _tmp46_, &_tmp48_);
#line 453 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp46_);
#line 421 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (insertion_iter);
#line 2898 "Tree.c"
}


static void sidebar_tree_associate_children (SidebarTree* self, SidebarBranch* branch, SidebarEntry* parent, GtkTreeIter* parent_iter) {
	GeeList* children = NULL;
	SidebarBranch* _tmp0_;
	SidebarEntry* _tmp1_;
	GeeList* _tmp2_;
	GeeList* _tmp3_;
#line 456 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 456 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 456 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (parent));
#line 456 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (parent_iter != NULL);
#line 458 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = branch;
#line 458 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = parent;
#line 458 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = sidebar_branch_get_children (_tmp0_, _tmp1_);
#line 458 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	children = _tmp2_;
#line 459 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = children;
#line 459 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp3_ == NULL) {
#line 460 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (children);
#line 460 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 2932 "Tree.c"
	}
	{
		GeeList* _child_list = NULL;
		GeeList* _tmp4_;
		GeeList* _tmp5_;
		gint _child_size = 0;
		GeeList* _tmp6_;
		gint _tmp7_;
		gint _tmp8_;
		gint _child_index = 0;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = children;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = _g_object_ref0 (_tmp4_);
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_list = _tmp5_;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = _child_list;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_COLLECTION, GeeCollection));
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = _tmp7_;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_size = _tmp8_;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_index = -1;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		while (TRUE) {
#line 2961 "Tree.c"
			gint _tmp9_;
			gint _tmp10_;
			gint _tmp11_;
			SidebarEntry* child = NULL;
			GeeList* _tmp12_;
			gint _tmp13_;
			gpointer _tmp14_;
			GtkTreeIter append_iter = {0};
			GtkTreeStore* _tmp15_;
			GtkTreeIter _tmp16_;
			GtkTreeIter _tmp17_ = {0};
			GtkTreeIter _tmp18_;
			SidebarEntry* _tmp19_;
			SidebarBranch* _tmp20_;
			SidebarEntry* _tmp21_;
			GtkTreeIter _tmp22_;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = _child_index;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_child_index = _tmp9_ + 1;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = _child_index;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp11_ = _child_size;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (!(_tmp10_ < _tmp11_)) {
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				break;
#line 2990 "Tree.c"
			}
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = _child_list;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp13_ = _child_index;
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp14_ = gee_list_get (_tmp12_, _tmp13_);
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			child = (SidebarEntry*) _tmp14_;
#line 464 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp15_ = self->priv->store;
#line 464 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp16_ = *parent_iter;
#line 464 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			gtk_tree_store_append (_tmp15_, &_tmp17_, &_tmp16_);
#line 464 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			append_iter = _tmp17_;
#line 466 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = append_iter;
#line 466 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp19_ = child;
#line 466 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_associate_entry (self, &_tmp18_, _tmp19_);
#line 467 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp20_ = branch;
#line 467 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp21_ = child;
#line 467 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp22_ = append_iter;
#line 467 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_associate_children (self, _tmp20_, _tmp21_, &_tmp22_);
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (child);
#line 3024 "Tree.c"
		}
#line 462 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (_child_list);
#line 3028 "Tree.c"
	}
#line 456 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (children);
#line 3032 "Tree.c"
}


static void sidebar_tree_associate_entry (SidebarTree* self, GtkTreeIter* assoc_iter, SidebarEntry* entry) {
	GtkTreeIter _tmp0_;
	GtkTreeStore* _tmp1_;
	SidebarEntry* _tmp2_;
	GtkTreeStore* _tmp3_;
	GtkTreeIter _tmp4_;
	GtkTreePath* _tmp5_;
	GtkTreePath* _tmp6_;
	SidebarTreeEntryWrapper* _tmp7_;
	SidebarTreeEntryWrapper* _tmp8_;
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (assoc_iter != NULL);
#line 471 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 472 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = *assoc_iter;
#line 472 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->store;
#line 472 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = entry;
#line 472 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = self->priv->store;
#line 472 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = *assoc_iter;
#line 472 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = gtk_tree_model_get_path (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &_tmp4_);
#line 472 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = _tmp5_;
#line 472 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = sidebar_tree_entry_wrapper_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GTK_TYPE_TREE_MODEL, GtkTreeModel), _tmp2_, _tmp6_);
#line 472 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = _tmp7_;
#line 472 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_associate_wrapper (self, &_tmp0_, _tmp8_);
#line 472 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp8_);
#line 472 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (_tmp6_);
#line 3076 "Tree.c"
}


static void _sidebar_tree_on_sidebar_tooltip_changed_sidebar_entry_sidebar_tooltip_changed (SidebarEntry* _sender, const gchar* tooltip, gpointer self) {
#line 486 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_sidebar_tooltip_changed ((SidebarTree*) self, _sender, tooltip);
#line 3083 "Tree.c"
}


static void _sidebar_tree_on_sidebar_icon_changed_sidebar_entry_sidebar_icon_changed (SidebarEntry* _sender, const gchar* icon, gpointer self) {
#line 487 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_sidebar_icon_changed ((SidebarTree*) self, _sender, icon);
#line 3090 "Tree.c"
}


static void _sidebar_tree_on_sidebar_page_created_sidebar_page_representative_page_created (SidebarPageRepresentative* _sender, Page* page, gpointer self) {
#line 491 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_sidebar_page_created ((SidebarTree*) self, _sender, page);
#line 3097 "Tree.c"
}


static void _sidebar_tree_on_sidebar_destroying_page_sidebar_page_representative_destroying_page (SidebarPageRepresentative* _sender, Page* page, gpointer self) {
#line 492 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_sidebar_destroying_page ((SidebarTree*) self, _sender, page);
#line 3104 "Tree.c"
}


static void _sidebar_tree_on_is_emphasized_changed_sidebar_emphasizable_entry_is_emphasized_changed (SidebarEmphasizableEntry* _sender, gboolean emphasized, gpointer self) {
#line 497 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_is_emphasized_changed ((SidebarTree*) self, _sender, emphasized);
#line 3111 "Tree.c"
}


static void _sidebar_tree_on_sidebar_name_changed_sidebar_renameable_entry_sidebar_name_changed (SidebarRenameableEntry* _sender, const gchar* name, gpointer self) {
#line 501 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_sidebar_name_changed ((SidebarTree*) self, _sender, name);
#line 3118 "Tree.c"
}


static void sidebar_tree_associate_wrapper (SidebarTree* self, GtkTreeIter* assoc_iter, SidebarTreeEntryWrapper* wrapper) {
	SidebarEntry* entry = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	SidebarEntry* _tmp1_;
	SidebarEntry* _tmp2_;
	GeeHashMap* _tmp3_;
	SidebarEntry* _tmp4_;
	gboolean _tmp5_;
	GeeHashMap* _tmp6_;
	SidebarEntry* _tmp7_;
	SidebarTreeEntryWrapper* _tmp8_;
	GtkTreeStore* _tmp9_;
	GtkTreeIter _tmp10_;
	SidebarEntry* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	GtkTreeStore* _tmp14_;
	GtkTreeIter _tmp15_;
	SidebarEntry* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	GtkTreeStore* _tmp21_;
	GtkTreeIter _tmp22_;
	SidebarTreeEntryWrapper* _tmp23_;
	GtkTreeIter _tmp24_;
	SidebarEntry* _tmp25_;
	SidebarEntry* _tmp26_;
	SidebarPageRepresentative* pageable = NULL;
	SidebarEntry* _tmp27_;
	SidebarPageRepresentative* _tmp28_;
	SidebarPageRepresentative* _tmp29_;
	SidebarEmphasizableEntry* emphasizable = NULL;
	SidebarEntry* _tmp32_;
	SidebarEmphasizableEntry* _tmp33_;
	SidebarEmphasizableEntry* _tmp34_;
	SidebarRenameableEntry* renameable = NULL;
	SidebarEntry* _tmp36_;
	SidebarRenameableEntry* _tmp37_;
	SidebarRenameableEntry* _tmp38_;
	SidebarEntry* _tmp40_;
#line 475 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 475 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (assoc_iter != NULL);
#line 475 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_TREE_IS_ENTRY_WRAPPER (wrapper));
#line 476 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = wrapper;
#line 476 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _tmp0_->entry;
#line 476 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 476 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	entry = _tmp2_;
#line 478 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = self->priv->entry_map;
#line 478 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = entry;
#line 478 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp4_);
#line 478 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (!_tmp5_, "!entry_map.has_key(entry)");
#line 479 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = self->priv->entry_map;
#line 479 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = entry;
#line 479 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = wrapper;
#line 479 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp7_, _tmp8_);
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = self->priv->store;
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = *assoc_iter;
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = entry;
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp12_ = sidebar_tree_get_name_for_entry (self, _tmp11_);
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = _tmp12_;
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp9_, &_tmp10_, SIDEBAR_TREE_COLUMNS_NAME, _tmp13_, -1);
#line 481 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp13_);
#line 482 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = self->priv->store;
#line 482 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = *assoc_iter;
#line 482 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = entry;
#line 482 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = sidebar_entry_get_sidebar_tooltip (_tmp16_);
#line 482 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp18_ = _tmp17_;
#line 482 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp19_ = guarded_markup_escape_text (_tmp18_);
#line 482 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp20_ = _tmp19_;
#line 482 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp14_, &_tmp15_, SIDEBAR_TREE_COLUMNS_TOOLTIP, _tmp20_, -1);
#line 482 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp20_);
#line 482 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp18_);
#line 483 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp21_ = self->priv->store;
#line 483 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp22_ = *assoc_iter;
#line 483 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp23_ = wrapper;
#line 483 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp21_, &_tmp22_, SIDEBAR_TREE_COLUMNS_WRAPPER, _tmp23_, -1);
#line 484 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp24_ = *assoc_iter;
#line 484 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_load_entry_icons (self, &_tmp24_);
#line 486 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp25_ = entry;
#line 486 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (_tmp25_, "sidebar-tooltip-changed", (GCallback) _sidebar_tree_on_sidebar_tooltip_changed_sidebar_entry_sidebar_tooltip_changed, self, 0);
#line 487 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp26_ = entry;
#line 487 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_connect_object (_tmp26_, "sidebar-icon-changed", (GCallback) _sidebar_tree_on_sidebar_icon_changed_sidebar_entry_sidebar_icon_changed, self, 0);
#line 489 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp27_ = entry;
#line 489 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp28_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE) ? ((SidebarPageRepresentative*) _tmp27_) : NULL);
#line 489 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	pageable = _tmp28_;
#line 490 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp29_ = pageable;
#line 490 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp29_ != NULL) {
#line 3258 "Tree.c"
		SidebarPageRepresentative* _tmp30_;
		SidebarPageRepresentative* _tmp31_;
#line 491 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp30_ = pageable;
#line 491 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_connect_object (_tmp30_, "page-created", (GCallback) _sidebar_tree_on_sidebar_page_created_sidebar_page_representative_page_created, self, 0);
#line 492 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp31_ = pageable;
#line 492 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_connect_object (_tmp31_, "destroying-page", (GCallback) _sidebar_tree_on_sidebar_destroying_page_sidebar_page_representative_destroying_page, self, 0);
#line 3269 "Tree.c"
	}
#line 495 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp32_ = entry;
#line 495 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp33_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, SIDEBAR_TYPE_EMPHASIZABLE_ENTRY) ? ((SidebarEmphasizableEntry*) _tmp32_) : NULL);
#line 495 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	emphasizable = _tmp33_;
#line 496 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp34_ = emphasizable;
#line 496 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp34_ != NULL) {
#line 3281 "Tree.c"
		SidebarEmphasizableEntry* _tmp35_;
#line 497 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp35_ = emphasizable;
#line 497 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_connect_object (_tmp35_, "is-emphasized-changed", (GCallback) _sidebar_tree_on_is_emphasized_changed_sidebar_emphasizable_entry_is_emphasized_changed, self, 0);
#line 3287 "Tree.c"
	}
#line 499 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp36_ = entry;
#line 499 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp37_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, SIDEBAR_TYPE_RENAMEABLE_ENTRY) ? ((SidebarRenameableEntry*) _tmp36_) : NULL);
#line 499 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	renameable = _tmp37_;
#line 500 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp38_ = renameable;
#line 500 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp38_ != NULL) {
#line 3299 "Tree.c"
		SidebarRenameableEntry* _tmp39_;
#line 501 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp39_ = renameable;
#line 501 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_connect_object (_tmp39_, "sidebar-name-changed", (GCallback) _sidebar_tree_on_sidebar_name_changed_sidebar_renameable_entry_sidebar_name_changed, self, 0);
#line 3305 "Tree.c"
	}
#line 503 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp40_ = entry;
#line 503 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_entry_grafted (_tmp40_, self);
#line 475 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (renameable);
#line 475 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (emphasizable);
#line 475 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (pageable);
#line 475 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (entry);
#line 3319 "Tree.c"
}


static SidebarTreeEntryWrapper* sidebar_tree_reparent_wrapper (SidebarTree* self, GtkTreeIter* new_iter, SidebarTreeEntryWrapper* current_wrapper) {
	SidebarTreeEntryWrapper* result = NULL;
	SidebarEntry* entry = NULL;
	SidebarTreeEntryWrapper* _tmp0_;
	SidebarEntry* _tmp1_;
	SidebarEntry* _tmp2_;
	gboolean removed = FALSE;
	GeeHashMap* _tmp3_;
	gboolean _tmp4_;
	SidebarTreeEntryWrapper* new_wrapper = NULL;
	GtkTreeStore* _tmp5_;
	GtkTreeStore* _tmp6_;
	GtkTreeIter _tmp7_;
	GtkTreePath* _tmp8_;
	GtkTreePath* _tmp9_;
	SidebarTreeEntryWrapper* _tmp10_;
	SidebarTreeEntryWrapper* _tmp11_;
	GeeHashMap* _tmp12_;
	GtkTreeStore* _tmp13_;
	GtkTreeIter _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	GtkTreeStore* _tmp17_;
	GtkTreeIter _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	GtkTreeStore* _tmp23_;
	GtkTreeIter _tmp24_;
	GtkTreeIter _tmp25_;
#line 506 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 506 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (new_iter != NULL, NULL);
#line 506 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_TREE_IS_ENTRY_WRAPPER (current_wrapper), NULL);
#line 507 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = current_wrapper;
#line 507 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _tmp0_->entry;
#line 507 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 507 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	entry = _tmp2_;
#line 509 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = self->priv->entry_map;
#line 509 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), entry, NULL);
#line 509 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	removed = _tmp4_;
#line 510 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (removed, "removed");
#line 512 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = self->priv->store;
#line 512 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = self->priv->store;
#line 512 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = *new_iter;
#line 512 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = gtk_tree_model_get_path (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &_tmp7_);
#line 512 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = _tmp8_;
#line 512 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = sidebar_tree_entry_wrapper_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GTK_TYPE_TREE_MODEL, GtkTreeModel), entry, _tmp9_);
#line 512 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = _tmp10_;
#line 512 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (_tmp9_);
#line 512 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	new_wrapper = _tmp11_;
#line 513 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp12_ = self->priv->entry_map;
#line 513 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), entry, new_wrapper);
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = self->priv->store;
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = *new_iter;
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = sidebar_tree_get_name_for_entry (self, entry);
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = _tmp15_;
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp13_, &_tmp14_, SIDEBAR_TREE_COLUMNS_NAME, _tmp16_, -1);
#line 515 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp16_);
#line 516 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = self->priv->store;
#line 516 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp18_ = *new_iter;
#line 516 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp19_ = sidebar_entry_get_sidebar_tooltip (entry);
#line 516 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp20_ = _tmp19_;
#line 516 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp21_ = guarded_markup_escape_text (_tmp20_);
#line 516 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp22_ = _tmp21_;
#line 516 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp17_, &_tmp18_, SIDEBAR_TREE_COLUMNS_TOOLTIP, _tmp22_, -1);
#line 516 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp22_);
#line 516 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp20_);
#line 517 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp23_ = self->priv->store;
#line 517 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp24_ = *new_iter;
#line 517 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp23_, &_tmp24_, SIDEBAR_TREE_COLUMNS_WRAPPER, new_wrapper, -1);
#line 518 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp25_ = *new_iter;
#line 518 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_load_entry_icons (self, &_tmp25_);
#line 520 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = new_wrapper;
#line 520 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (entry);
#line 520 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 3444 "Tree.c"
}


void sidebar_tree_prune (SidebarTree* self, SidebarBranch* branch) {
	GeeHashMap* _tmp0_;
	SidebarBranch* _tmp1_;
	gboolean _tmp2_;
	SidebarBranch* _tmp3_;
	SidebarEntry* _tmp4_;
	SidebarEntry* _tmp5_;
	gboolean _tmp6_;
	gboolean _tmp7_;
	SidebarBranch* _tmp9_;
	guint _tmp10_;
	SidebarBranch* _tmp11_;
	guint _tmp12_;
	SidebarBranch* _tmp13_;
	guint _tmp14_;
	SidebarBranch* _tmp15_;
	guint _tmp16_;
	SidebarBranch* _tmp17_;
	guint _tmp18_;
	SidebarBranch* _tmp19_;
	guint _tmp20_;
	gboolean removed = FALSE;
	GeeHashMap* _tmp21_;
	SidebarBranch* _tmp22_;
	gboolean _tmp23_;
	SidebarBranch* _tmp24_;
#line 523 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 523 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 524 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->branches;
#line 524 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = branch;
#line 524 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp1_);
#line 524 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp2_, "branches.has_key(branch)");
#line 526 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = branch;
#line 526 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = sidebar_branch_get_root (_tmp3_);
#line 526 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = _tmp4_;
#line 526 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = sidebar_tree_has_wrapper (self, _tmp5_);
#line 526 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = _tmp6_;
#line 526 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp5_);
#line 526 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp7_) {
#line 3500 "Tree.c"
		SidebarBranch* _tmp8_;
#line 527 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = branch;
#line 527 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_disassociate_branch (self, _tmp8_);
#line 3506 "Tree.c"
	}
#line 529 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = branch;
#line 529 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("entry-added", SIDEBAR_TYPE_BRANCH, &_tmp10_, NULL, FALSE);
#line 529 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (_tmp9_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp10_, 0, NULL, (GCallback) _sidebar_tree_on_branch_entry_added_sidebar_branch_entry_added, self);
#line 530 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = branch;
#line 530 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("entry-removed", SIDEBAR_TYPE_BRANCH, &_tmp12_, NULL, FALSE);
#line 530 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (_tmp11_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp12_, 0, NULL, (GCallback) _sidebar_tree_on_branch_entry_removed_sidebar_branch_entry_removed, self);
#line 531 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = branch;
#line 531 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("entry-moved", SIDEBAR_TYPE_BRANCH, &_tmp14_, NULL, FALSE);
#line 531 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (_tmp13_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp14_, 0, NULL, (GCallback) _sidebar_tree_on_branch_entry_moved_sidebar_branch_entry_moved, self);
#line 532 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = branch;
#line 532 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("entry-reparented", SIDEBAR_TYPE_BRANCH, &_tmp16_, NULL, FALSE);
#line 532 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (_tmp15_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp16_, 0, NULL, (GCallback) _sidebar_tree_on_branch_entry_reparented_sidebar_branch_entry_reparented, self);
#line 533 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = branch;
#line 533 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("children-reordered", SIDEBAR_TYPE_BRANCH, &_tmp18_, NULL, FALSE);
#line 533 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (_tmp17_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp18_, 0, NULL, (GCallback) _sidebar_tree_on_branch_children_reordered_sidebar_branch_children_reordered, self);
#line 534 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp19_ = branch;
#line 534 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("show-branch", SIDEBAR_TYPE_BRANCH, &_tmp20_, NULL, FALSE);
#line 534 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (_tmp19_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp20_, 0, NULL, (GCallback) _sidebar_tree_on_show_branch_sidebar_branch_show_branch, self);
#line 536 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp21_ = self->priv->branches;
#line 536 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp22_ = branch;
#line 536 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp23_ = gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp22_, NULL);
#line 536 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	removed = _tmp23_;
#line 537 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (removed, "removed");
#line 539 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp24_ = branch;
#line 539 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_BRANCH_REMOVED_SIGNAL], 0, _tmp24_);
#line 3558 "Tree.c"
}


static void sidebar_tree_disassociate_branch (SidebarTree* self, SidebarBranch* branch) {
	SidebarTreeRootWrapper* root_wrapper = NULL;
	SidebarBranch* _tmp0_;
	SidebarEntry* _tmp1_;
	SidebarEntry* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	SidebarTreeRootWrapper* _tmp4_;
	SidebarTreeRootWrapper* _tmp5_;
#line 542 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 542 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 543 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = branch;
#line 543 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_branch_get_root (_tmp0_);
#line 543 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _tmp1_;
#line 543 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_get_wrapper (self, _tmp2_);
#line 543 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, SIDEBAR_TREE_TYPE_ROOT_WRAPPER) ? ((SidebarTreeRootWrapper*) _tmp3_) : NULL;
#line 543 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp4_ == NULL) {
#line 543 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (_tmp3_);
#line 3588 "Tree.c"
	}
#line 543 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = _tmp4_;
#line 543 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp2_);
#line 543 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	root_wrapper = _tmp5_;
#line 544 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (root_wrapper != NULL, "root_wrapper != null");
#line 546 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_disassociate_wrapper_and_signal (self, G_TYPE_CHECK_INSTANCE_CAST (root_wrapper, SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, SidebarTreeEntryWrapper), FALSE);
#line 542 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (root_wrapper);
#line 3602 "Tree.c"
}


static void sidebar_tree_disassociate_wrapper_and_signal (SidebarTree* self, SidebarTreeEntryWrapper* wrapper, gboolean only_children) {
	gboolean selected = FALSE;
	SidebarTreeEntryWrapper* _tmp0_;
	SidebarEntry* _tmp1_;
	gboolean _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
#line 551 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 551 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_TREE_IS_ENTRY_WRAPPER (wrapper));
#line 552 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = wrapper;
#line 552 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _tmp0_->entry;
#line 552 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = sidebar_tree_is_selected (self, _tmp1_);
#line 552 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	selected = _tmp2_;
#line 554 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 554 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = only_children;
#line 554 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_disassociate_wrapper (self, _tmp3_, _tmp4_);
#line 556 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = selected;
#line 556 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp5_) {
#line 3636 "Tree.c"
		SidebarSelectableEntry* selectable = NULL;
		SidebarTreeEntryWrapper* _tmp6_;
		SidebarEntry* _tmp7_;
		SidebarSelectableEntry* _tmp8_;
		SidebarSelectableEntry* _tmp9_;
		SidebarSelectableEntry* _tmp10_;
#line 557 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = wrapper;
#line 557 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = _tmp6_->entry;
#line 557 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, SIDEBAR_TYPE_SELECTABLE_ENTRY) ? ((SidebarSelectableEntry*) _tmp7_) : NULL);
#line 557 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		selectable = _tmp8_;
#line 558 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = selectable;
#line 558 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_vala_assert (_tmp9_ != NULL, "selectable != null");
#line 560 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = selectable;
#line 560 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_SELECTED_ENTRY_REMOVED_SIGNAL], 0, _tmp10_);
#line 556 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (selectable);
#line 3661 "Tree.c"
	}
}


static void sidebar_tree_disassociate_wrapper (SidebarTree* self, SidebarTreeEntryWrapper* wrapper, gboolean only_children) {
	GeeArrayList* children = NULL;
	GeeArrayList* _tmp0_;
	GtkTreeIter child_iter = {0};
	gboolean found = FALSE;
	GtkTreeStore* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	GtkTreeIter _tmp3_ = {0};
	GtkTreeIter _tmp4_ = {0};
	gboolean _tmp5_;
	gboolean _tmp26_;
	GtkTreeIter iter = {0};
	SidebarTreeEntryWrapper* _tmp27_;
	GtkTreeIter _tmp28_ = {0};
	GtkTreeStore* _tmp29_;
	SidebarTreeEntryWrapper* _tmp30_;
	SidebarTreeEntryWrapper* _tmp31_;
	SidebarEntry* entry = NULL;
	SidebarTreeEntryWrapper* _tmp32_;
	SidebarEntry* _tmp33_;
	SidebarEntry* _tmp34_;
	SidebarEntry* _tmp35_;
	SidebarEntry* _tmp36_;
	guint _tmp37_;
	SidebarEntry* _tmp38_;
	guint _tmp39_;
	SidebarPageRepresentative* pageable = NULL;
	SidebarEntry* _tmp40_;
	SidebarPageRepresentative* _tmp41_;
	SidebarPageRepresentative* _tmp42_;
	SidebarRenameableEntry* renameable = NULL;
	SidebarEntry* _tmp47_;
	SidebarRenameableEntry* _tmp48_;
	SidebarRenameableEntry* _tmp49_;
	SidebarEmphasizableEntry* emphasizable = NULL;
	SidebarEntry* _tmp52_;
	SidebarEmphasizableEntry* _tmp53_;
	SidebarEmphasizableEntry* _tmp54_;
	gboolean removed = FALSE;
	GeeHashMap* _tmp57_;
	SidebarEntry* _tmp58_;
	gboolean _tmp59_;
	gboolean _tmp60_;
#line 564 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 564 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_TREE_IS_ENTRY_WRAPPER (wrapper));
#line 565 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = gee_array_list_new (SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 565 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	children = _tmp0_;
#line 568 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->store;
#line 568 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 568 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (_tmp2_, &_tmp3_);
#line 568 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = gtk_tree_model_iter_children (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &_tmp4_, &_tmp3_);
#line 568 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	child_iter = _tmp4_;
#line 568 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	found = _tmp5_;
#line 569 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	while (TRUE) {
#line 3731 "Tree.c"
		gboolean _tmp6_;
		SidebarTreeEntryWrapper* child_wrapper = NULL;
		GtkTreeIter _tmp7_;
		SidebarTreeEntryWrapper* _tmp8_;
		SidebarTreeEntryWrapper* _tmp9_;
		GeeArrayList* _tmp10_;
		SidebarTreeEntryWrapper* _tmp11_;
		GtkTreeStore* _tmp12_;
		gboolean _tmp13_;
#line 569 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = found;
#line 569 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (!_tmp6_) {
#line 569 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			break;
#line 3747 "Tree.c"
		}
#line 570 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = child_iter;
#line 570 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = sidebar_tree_get_wrapper_at_iter (self, &_tmp7_);
#line 570 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		child_wrapper = _tmp8_;
#line 571 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = child_wrapper;
#line 571 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_vala_assert (_tmp9_ != NULL, "child_wrapper != null");
#line 573 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = children;
#line 573 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = child_wrapper;
#line 573 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp11_);
#line 575 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = self->priv->store;
#line 575 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = gtk_tree_model_iter_next (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &child_iter);
#line 575 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		found = _tmp13_;
#line 569 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (child_wrapper);
#line 3773 "Tree.c"
	}
	{
		GeeArrayList* _child_wrapper_list = NULL;
		GeeArrayList* _tmp14_;
		GeeArrayList* _tmp15_;
		gint _child_wrapper_size = 0;
		GeeArrayList* _tmp16_;
		gint _tmp17_;
		gint _tmp18_;
		gint _child_wrapper_index = 0;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp14_ = children;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp15_ = _g_object_ref0 (_tmp14_);
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_wrapper_list = _tmp15_;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp16_ = _child_wrapper_list;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp17_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp18_ = _tmp17_;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_wrapper_size = _tmp18_;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_wrapper_index = -1;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		while (TRUE) {
#line 3802 "Tree.c"
			gint _tmp19_;
			gint _tmp20_;
			gint _tmp21_;
			SidebarTreeEntryWrapper* child_wrapper = NULL;
			GeeArrayList* _tmp22_;
			gint _tmp23_;
			gpointer _tmp24_;
			SidebarTreeEntryWrapper* _tmp25_;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp19_ = _child_wrapper_index;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_child_wrapper_index = _tmp19_ + 1;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp20_ = _child_wrapper_index;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp21_ = _child_wrapper_size;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (!(_tmp20_ < _tmp21_)) {
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				break;
#line 3823 "Tree.c"
			}
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp22_ = _child_wrapper_list;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp23_ = _child_wrapper_index;
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp24_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp23_);
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			child_wrapper = (SidebarTreeEntryWrapper*) _tmp24_;
#line 579 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp25_ = child_wrapper;
#line 579 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_disassociate_wrapper (self, _tmp25_, FALSE);
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (child_wrapper);
#line 3839 "Tree.c"
		}
#line 578 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (_child_wrapper_list);
#line 3843 "Tree.c"
	}
#line 581 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp26_ = only_children;
#line 581 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp26_) {
#line 582 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (children);
#line 582 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 3853 "Tree.c"
	}
#line 584 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp27_ = wrapper;
#line 584 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (_tmp27_, &_tmp28_);
#line 584 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	iter = _tmp28_;
#line 585 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp29_ = self->priv->store;
#line 585 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_remove (_tmp29_, &iter);
#line 587 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp30_ = self->priv->selected_wrapper;
#line 587 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp31_ = wrapper;
#line 587 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp30_ == _tmp31_) {
#line 588 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->selected_wrapper = NULL;
#line 3873 "Tree.c"
	}
#line 590 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp32_ = wrapper;
#line 590 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp33_ = _tmp32_->entry;
#line 590 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp34_ = _g_object_ref0 (_tmp33_);
#line 590 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	entry = _tmp34_;
#line 592 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp35_ = entry;
#line 592 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_entry_pruned (_tmp35_, self);
#line 594 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp36_ = entry;
#line 594 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("sidebar-tooltip-changed", SIDEBAR_TYPE_ENTRY, &_tmp37_, NULL, FALSE);
#line 594 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (_tmp36_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp37_, 0, NULL, (GCallback) _sidebar_tree_on_sidebar_tooltip_changed_sidebar_entry_sidebar_tooltip_changed, self);
#line 595 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp38_ = entry;
#line 595 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("sidebar-icon-changed", SIDEBAR_TYPE_ENTRY, &_tmp39_, NULL, FALSE);
#line 595 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (_tmp38_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp39_, 0, NULL, (GCallback) _sidebar_tree_on_sidebar_icon_changed_sidebar_entry_sidebar_icon_changed, self);
#line 597 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp40_ = entry;
#line 597 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp41_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, SIDEBAR_TYPE_PAGE_REPRESENTATIVE) ? ((SidebarPageRepresentative*) _tmp40_) : NULL);
#line 597 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	pageable = _tmp41_;
#line 598 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp42_ = pageable;
#line 598 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp42_ != NULL) {
#line 3909 "Tree.c"
		SidebarPageRepresentative* _tmp43_;
		guint _tmp44_;
		SidebarPageRepresentative* _tmp45_;
		guint _tmp46_;
#line 599 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp43_ = pageable;
#line 599 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_parse_name ("page-created", SIDEBAR_TYPE_PAGE_REPRESENTATIVE, &_tmp44_, NULL, FALSE);
#line 599 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_handlers_disconnect_matched (_tmp43_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp44_, 0, NULL, (GCallback) _sidebar_tree_on_sidebar_page_created_sidebar_page_representative_page_created, self);
#line 600 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp45_ = pageable;
#line 600 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_parse_name ("destroying-page", SIDEBAR_TYPE_PAGE_REPRESENTATIVE, &_tmp46_, NULL, FALSE);
#line 600 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_handlers_disconnect_matched (_tmp45_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp46_, 0, NULL, (GCallback) _sidebar_tree_on_sidebar_destroying_page_sidebar_page_representative_destroying_page, self);
#line 3926 "Tree.c"
	}
#line 603 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp47_ = entry;
#line 603 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp48_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp47_, SIDEBAR_TYPE_RENAMEABLE_ENTRY) ? ((SidebarRenameableEntry*) _tmp47_) : NULL);
#line 603 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	renameable = _tmp48_;
#line 604 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp49_ = renameable;
#line 604 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp49_ != NULL) {
#line 3938 "Tree.c"
		SidebarRenameableEntry* _tmp50_;
		guint _tmp51_;
#line 605 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp50_ = renameable;
#line 605 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_parse_name ("sidebar-name-changed", SIDEBAR_TYPE_RENAMEABLE_ENTRY, &_tmp51_, NULL, FALSE);
#line 605 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_handlers_disconnect_matched (_tmp50_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp51_, 0, NULL, (GCallback) _sidebar_tree_on_sidebar_name_changed_sidebar_renameable_entry_sidebar_name_changed, self);
#line 3947 "Tree.c"
	}
#line 607 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp52_ = entry;
#line 607 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp53_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp52_, SIDEBAR_TYPE_EMPHASIZABLE_ENTRY) ? ((SidebarEmphasizableEntry*) _tmp52_) : NULL);
#line 607 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	emphasizable = _tmp53_;
#line 608 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp54_ = emphasizable;
#line 608 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp54_ != NULL) {
#line 3959 "Tree.c"
		SidebarEmphasizableEntry* _tmp55_;
		guint _tmp56_;
#line 609 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp55_ = emphasizable;
#line 609 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_parse_name ("is-emphasized-changed", SIDEBAR_TYPE_EMPHASIZABLE_ENTRY, &_tmp56_, NULL, FALSE);
#line 609 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_handlers_disconnect_matched (_tmp55_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp56_, 0, NULL, (GCallback) _sidebar_tree_on_is_emphasized_changed_sidebar_emphasizable_entry_is_emphasized_changed, self);
#line 3968 "Tree.c"
	}
#line 611 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp57_ = self->priv->entry_map;
#line 611 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp58_ = entry;
#line 611 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp59_ = gee_abstract_map_unset (G_TYPE_CHECK_INSTANCE_CAST (_tmp57_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp58_, NULL);
#line 611 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	removed = _tmp59_;
#line 612 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp60_ = removed;
#line 612 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp60_, "removed");
#line 564 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (emphasizable);
#line 564 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (renameable);
#line 564 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (pageable);
#line 564 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (entry);
#line 564 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (children);
#line 3992 "Tree.c"
}


static void sidebar_tree_on_branch_entry_added (SidebarTree* self, SidebarBranch* branch, SidebarEntry* entry) {
	SidebarEntry* parent = NULL;
	SidebarBranch* _tmp0_;
	SidebarEntry* _tmp1_;
	SidebarEntry* _tmp2_;
	SidebarEntry* _tmp3_;
	SidebarTreeEntryWrapper* parent_wrapper = NULL;
	SidebarEntry* _tmp4_;
	SidebarTreeEntryWrapper* _tmp5_;
	SidebarTreeEntryWrapper* _tmp6_;
	GtkTreeIter insertion_iter = {0};
	SidebarEntry* next = NULL;
	SidebarBranch* _tmp7_;
	SidebarEntry* _tmp8_;
	SidebarEntry* _tmp9_;
	SidebarEntry* _tmp10_;
	GtkTreeIter _tmp23_;
	SidebarEntry* _tmp24_;
	SidebarBranch* _tmp25_;
	SidebarEntry* _tmp26_;
	GtkTreeIter _tmp27_;
	SidebarBranch* _tmp28_;
	gboolean _tmp29_;
#line 615 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 615 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 615 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 616 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = branch;
#line 616 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = entry;
#line 616 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = sidebar_branch_get_parent (_tmp0_, _tmp1_);
#line 616 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	parent = _tmp2_;
#line 617 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = parent;
#line 617 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp3_ != NULL, "parent != null");
#line 619 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = parent;
#line 619 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = sidebar_tree_get_wrapper (self, _tmp4_);
#line 619 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	parent_wrapper = _tmp5_;
#line 620 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = parent_wrapper;
#line 620 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp6_ != NULL, "parent_wrapper != null");
#line 623 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = branch;
#line 623 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = entry;
#line 623 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = sidebar_branch_get_next_sibling (_tmp7_, _tmp8_);
#line 623 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	next = _tmp9_;
#line 624 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = next;
#line 624 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp10_ != NULL) {
#line 4059 "Tree.c"
		SidebarTreeEntryWrapper* next_wrapper = NULL;
		SidebarEntry* _tmp11_;
		SidebarTreeEntryWrapper* _tmp12_;
		GtkTreeStore* _tmp13_;
		SidebarTreeEntryWrapper* _tmp14_;
		GtkTreeIter _tmp15_ = {0};
		SidebarTreeEntryWrapper* _tmp16_;
		GtkTreeIter _tmp17_ = {0};
		GtkTreeIter _tmp18_ = {0};
#line 625 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = next;
#line 625 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = sidebar_tree_get_wrapper (self, _tmp11_);
#line 625 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		next_wrapper = _tmp12_;
#line 628 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = self->priv->store;
#line 628 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp14_ = parent_wrapper;
#line 628 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_entry_wrapper_get_iter (_tmp14_, &_tmp15_);
#line 628 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp16_ = next_wrapper;
#line 628 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_entry_wrapper_get_iter (_tmp16_, &_tmp17_);
#line 628 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_store_insert_before (_tmp13_, &_tmp18_, &_tmp15_, &_tmp17_);
#line 628 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		insertion_iter = _tmp18_;
#line 624 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (next_wrapper);
#line 4091 "Tree.c"
	} else {
		GtkTreeStore* _tmp19_;
		SidebarTreeEntryWrapper* _tmp20_;
		GtkTreeIter _tmp21_ = {0};
		GtkTreeIter _tmp22_ = {0};
#line 631 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp19_ = self->priv->store;
#line 631 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp20_ = parent_wrapper;
#line 631 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_entry_wrapper_get_iter (_tmp20_, &_tmp21_);
#line 631 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_store_append (_tmp19_, &_tmp22_, &_tmp21_);
#line 631 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		insertion_iter = _tmp22_;
#line 4107 "Tree.c"
	}
#line 634 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp23_ = insertion_iter;
#line 634 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp24_ = entry;
#line 634 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_associate_entry (self, &_tmp23_, _tmp24_);
#line 635 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp25_ = branch;
#line 635 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp26_ = entry;
#line 635 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp27_ = insertion_iter;
#line 635 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_associate_children (self, _tmp25_, _tmp26_, &_tmp27_);
#line 637 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp28_ = branch;
#line 637 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp29_ = sidebar_branch_is_auto_open_on_new_child (_tmp28_);
#line 637 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp29_) {
#line 4129 "Tree.c"
		SidebarEntry* _tmp30_;
#line 638 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp30_ = entry;
#line 638 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_expand_to_entry (self, _tmp30_);
#line 4135 "Tree.c"
	}
#line 615 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (next);
#line 615 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (parent_wrapper);
#line 615 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (parent);
#line 4143 "Tree.c"
}


static void sidebar_tree_on_branch_entry_removed (SidebarTree* self, SidebarBranch* branch, SidebarEntry* entry) {
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarEntry* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
#line 641 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 641 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 641 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 642 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 642 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper (self, _tmp0_);
#line 642 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 643 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (wrapper != NULL, "wrapper != null");
#line 644 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (!G_TYPE_CHECK_INSTANCE_TYPE (wrapper, SIDEBAR_TREE_TYPE_ROOT_WRAPPER), "!(wrapper is RootWrapper)");
#line 646 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_disassociate_wrapper_and_signal (self, wrapper, FALSE);
#line 641 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 4171 "Tree.c"
}


static void sidebar_tree_on_branch_entry_moved (SidebarTree* self, SidebarBranch* branch, SidebarEntry* entry) {
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarEntry* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	GtkTreeIter* prev_iter = NULL;
	SidebarEntry* prev = NULL;
	SidebarBranch* _tmp4_;
	SidebarEntry* _tmp5_;
	SidebarEntry* _tmp6_;
	SidebarEntry* _tmp7_;
	GtkTreeIter entry_iter = {0};
	SidebarTreeEntryWrapper* _tmp14_;
	GtkTreeIter _tmp15_ = {0};
	GtkTreeStore* _tmp16_;
	GtkTreeIter* _tmp17_;
#line 649 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 649 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 649 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 650 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 650 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper (self, _tmp0_);
#line 650 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 651 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 651 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp2_ != NULL, "wrapper != null");
#line 652 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 652 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, SIDEBAR_TREE_TYPE_ROOT_WRAPPER), "!(wrapper is RootWrapper)");
#line 655 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	prev_iter = NULL;
#line 656 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = branch;
#line 656 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = entry;
#line 656 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = sidebar_branch_get_previous_sibling (_tmp4_, _tmp5_);
#line 656 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	prev = _tmp6_;
#line 657 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = prev;
#line 657 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp7_ != NULL) {
#line 4226 "Tree.c"
		SidebarTreeEntryWrapper* prev_wrapper = NULL;
		SidebarEntry* _tmp8_;
		SidebarTreeEntryWrapper* _tmp9_;
		SidebarTreeEntryWrapper* _tmp10_;
		SidebarTreeEntryWrapper* _tmp11_;
		GtkTreeIter _tmp12_ = {0};
		GtkTreeIter* _tmp13_;
#line 658 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = prev;
#line 658 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = sidebar_tree_get_wrapper (self, _tmp8_);
#line 658 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		prev_wrapper = _tmp9_;
#line 659 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = prev_wrapper;
#line 659 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_vala_assert (_tmp10_ != NULL, "prev_wrapper != null");
#line 661 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = prev_wrapper;
#line 661 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_entry_wrapper_get_iter (_tmp11_, &_tmp12_);
#line 661 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = __gtk_tree_iter_dup0 (&_tmp12_);
#line 661 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (prev_iter);
#line 661 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		prev_iter = _tmp13_;
#line 657 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (prev_wrapper);
#line 4256 "Tree.c"
	}
#line 664 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = wrapper;
#line 664 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (_tmp14_, &_tmp15_);
#line 664 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	entry_iter = _tmp15_;
#line 665 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = self->priv->store;
#line 665 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = prev_iter;
#line 665 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_move_after (_tmp16_, &entry_iter, _tmp17_);
#line 649 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (prev);
#line 649 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (prev_iter);
#line 649 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 4276 "Tree.c"
}


static void sidebar_tree_on_branch_entry_reparented (SidebarTree* self, SidebarBranch* branch, SidebarEntry* entry, SidebarEntry* old_parent) {
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarEntry* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	gboolean selected = FALSE;
	GtkTreePath* _tmp4_;
	GtkTreePath* _tmp5_;
	SidebarTreeEntryWrapper* _tmp6_;
	GtkTreePath* _tmp7_;
	GtkTreePath* _tmp8_;
	gint _tmp9_;
	gboolean _tmp10_;
	GtkTreeIter iter = {0};
	SidebarTreeEntryWrapper* _tmp11_;
	GtkTreeIter _tmp12_ = {0};
	GtkTreeStore* _tmp13_;
	SidebarEntry* parent = NULL;
	SidebarBranch* _tmp14_;
	SidebarEntry* _tmp15_;
	SidebarEntry* _tmp16_;
	SidebarEntry* _tmp17_;
	SidebarTreeEntryWrapper* parent_wrapper = NULL;
	SidebarEntry* _tmp18_;
	SidebarTreeEntryWrapper* _tmp19_;
	SidebarTreeEntryWrapper* _tmp20_;
	GtkTreeIter* prev_iter = NULL;
	SidebarEntry* prev = NULL;
	SidebarBranch* _tmp21_;
	SidebarEntry* _tmp22_;
	SidebarEntry* _tmp23_;
	SidebarEntry* _tmp24_;
	GtkTreeIter new_iter = {0};
	GtkTreeStore* _tmp31_;
	SidebarTreeEntryWrapper* _tmp32_;
	GtkTreeIter _tmp33_ = {0};
	GtkTreeIter* _tmp34_;
	GtkTreeIter _tmp35_ = {0};
	SidebarTreeEntryWrapper* new_wrapper = NULL;
	GtkTreeIter _tmp36_;
	SidebarTreeEntryWrapper* _tmp37_;
	SidebarTreeEntryWrapper* _tmp38_;
	gboolean _tmp39_;
#line 668 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 668 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 668 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 668 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (old_parent));
#line 670 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 670 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper (self, _tmp0_);
#line 670 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 671 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 671 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp2_ != NULL, "wrapper != null");
#line 672 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 672 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, SIDEBAR_TREE_TYPE_ROOT_WRAPPER), "!(wrapper is RootWrapper)");
#line 674 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = sidebar_tree_get_current_path (self);
#line 674 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = _tmp4_;
#line 674 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = wrapper;
#line 674 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = sidebar_tree_entry_wrapper_get_path (_tmp6_);
#line 674 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = _tmp7_;
#line 674 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = gtk_tree_path_compare (_tmp5_, _tmp8_);
#line 674 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = _tmp9_ == 0;
#line 674 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (_tmp8_);
#line 674 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (_tmp5_);
#line 674 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	selected = _tmp10_;
#line 677 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = wrapper;
#line 677 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (_tmp11_, &_tmp12_);
#line 677 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	iter = _tmp12_;
#line 678 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = self->priv->store;
#line 678 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_remove (_tmp13_, &iter);
#line 680 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = branch;
#line 680 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = entry;
#line 680 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = sidebar_branch_get_parent (_tmp14_, _tmp15_);
#line 680 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	parent = _tmp16_;
#line 681 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = parent;
#line 681 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp17_ != NULL, "parent != null");
#line 683 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp18_ = parent;
#line 683 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp19_ = sidebar_tree_get_wrapper (self, _tmp18_);
#line 683 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	parent_wrapper = _tmp19_;
#line 684 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp20_ = parent_wrapper;
#line 684 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp20_ != NULL, "parent_wrapper != null");
#line 687 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	prev_iter = NULL;
#line 688 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp21_ = branch;
#line 688 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp22_ = entry;
#line 688 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp23_ = sidebar_branch_get_previous_sibling (_tmp21_, _tmp22_);
#line 688 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	prev = _tmp23_;
#line 689 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp24_ = prev;
#line 689 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp24_ != NULL) {
#line 4412 "Tree.c"
		SidebarTreeEntryWrapper* prev_wrapper = NULL;
		SidebarEntry* _tmp25_;
		SidebarTreeEntryWrapper* _tmp26_;
		SidebarTreeEntryWrapper* _tmp27_;
		SidebarTreeEntryWrapper* _tmp28_;
		GtkTreeIter _tmp29_ = {0};
		GtkTreeIter* _tmp30_;
#line 690 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp25_ = prev;
#line 690 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp26_ = sidebar_tree_get_wrapper (self, _tmp25_);
#line 690 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		prev_wrapper = _tmp26_;
#line 691 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp27_ = prev_wrapper;
#line 691 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_vala_assert (_tmp27_ != NULL, "prev_wrapper != null");
#line 693 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp28_ = prev_wrapper;
#line 693 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_entry_wrapper_get_iter (_tmp28_, &_tmp29_);
#line 693 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp30_ = __gtk_tree_iter_dup0 (&_tmp29_);
#line 693 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_free0 (prev_iter);
#line 693 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		prev_iter = _tmp30_;
#line 689 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (prev_wrapper);
#line 4442 "Tree.c"
	}
#line 697 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp31_ = self->priv->store;
#line 697 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp32_ = parent_wrapper;
#line 697 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (_tmp32_, &_tmp33_);
#line 697 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp34_ = prev_iter;
#line 697 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_insert_after (_tmp31_, &_tmp35_, &_tmp33_, _tmp34_);
#line 697 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	new_iter = _tmp35_;
#line 699 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp36_ = new_iter;
#line 699 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp37_ = wrapper;
#line 699 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp38_ = sidebar_tree_reparent_wrapper (self, &_tmp36_, _tmp37_);
#line 699 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	new_wrapper = _tmp38_;
#line 701 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp39_ = selected;
#line 701 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp39_) {
#line 4468 "Tree.c"
		SidebarTreeEntryWrapper* _tmp40_;
		SidebarEntry* _tmp41_;
		SidebarTreeEntryWrapper* _tmp42_;
		SidebarEntry* _tmp43_;
#line 702 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp40_ = new_wrapper;
#line 702 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp41_ = _tmp40_->entry;
#line 702 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_expand_to_entry (self, _tmp41_);
#line 703 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp42_ = new_wrapper;
#line 703 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp43_ = _tmp42_->entry;
#line 703 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_place_cursor (self, _tmp43_, FALSE);
#line 4485 "Tree.c"
	}
#line 668 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (new_wrapper);
#line 668 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (prev);
#line 668 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (prev_iter);
#line 668 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (parent_wrapper);
#line 668 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (parent);
#line 668 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 4499 "Tree.c"
}


static void sidebar_tree_on_branch_children_reordered (SidebarTree* self, SidebarBranch* branch, SidebarEntry* entry) {
	GeeList* children = NULL;
	SidebarBranch* _tmp0_;
	SidebarEntry* _tmp1_;
	GeeList* _tmp2_;
	GeeList* _tmp3_;
#line 707 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 707 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 707 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 708 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = branch;
#line 708 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = entry;
#line 708 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = sidebar_branch_get_children (_tmp0_, _tmp1_);
#line 708 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	children = _tmp2_;
#line 709 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = children;
#line 709 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp3_ == NULL) {
#line 710 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (children);
#line 710 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 4531 "Tree.c"
	}
	{
		GeeList* _child_list = NULL;
		GeeList* _tmp4_;
		GeeList* _tmp5_;
		gint _child_size = 0;
		GeeList* _tmp6_;
		gint _tmp7_;
		gint _tmp8_;
		gint _child_index = 0;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = children;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = _g_object_ref0 (_tmp4_);
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_list = _tmp5_;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = _child_list;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_COLLECTION, GeeCollection));
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = _tmp7_;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_size = _tmp8_;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_child_index = -1;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		while (TRUE) {
#line 4560 "Tree.c"
			gint _tmp9_;
			gint _tmp10_;
			gint _tmp11_;
			SidebarEntry* child = NULL;
			GeeList* _tmp12_;
			gint _tmp13_;
			gpointer _tmp14_;
			SidebarTreeEntryWrapper* child_wrapper = NULL;
			SidebarEntry* _tmp15_;
			SidebarTreeEntryWrapper* _tmp16_;
			SidebarTreeEntryWrapper* _tmp17_;
			GtkTreeIter child_iter = {0};
			SidebarTreeEntryWrapper* _tmp18_;
			GtkTreeIter _tmp19_ = {0};
			GtkTreeStore* _tmp20_;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = _child_index;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_child_index = _tmp9_ + 1;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = _child_index;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp11_ = _child_size;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (!(_tmp10_ < _tmp11_)) {
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				break;
#line 4588 "Tree.c"
			}
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = _child_list;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp13_ = _child_index;
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp14_ = gee_list_get (_tmp12_, _tmp13_);
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			child = (SidebarEntry*) _tmp14_;
#line 715 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp15_ = child;
#line 715 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp16_ = sidebar_tree_get_wrapper (self, _tmp15_);
#line 715 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			child_wrapper = _tmp16_;
#line 716 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp17_ = child_wrapper;
#line 716 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_vala_assert (_tmp17_ != NULL, "child_wrapper != null");
#line 718 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = child_wrapper;
#line 718 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_entry_wrapper_get_iter (_tmp18_, &_tmp19_);
#line 718 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			child_iter = _tmp19_;
#line 719 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp20_ = self->priv->store;
#line 719 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			gtk_tree_store_move_before (_tmp20_, &child_iter, NULL);
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (child_wrapper);
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (child);
#line 4622 "Tree.c"
		}
#line 714 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (_child_list);
#line 4626 "Tree.c"
	}
#line 707 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (children);
#line 4630 "Tree.c"
}


static void sidebar_tree_on_show_branch (SidebarTree* self, SidebarBranch* branch, gboolean shown) {
	gboolean _tmp0_;
	SidebarBranch* _tmp3_;
	gboolean _tmp4_;
#line 723 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 723 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_BRANCH (branch));
#line 724 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = shown;
#line 724 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp0_) {
#line 4646 "Tree.c"
		SidebarBranch* _tmp1_;
#line 725 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = branch;
#line 725 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_associate_branch (self, _tmp1_);
#line 4652 "Tree.c"
	} else {
		SidebarBranch* _tmp2_;
#line 727 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = branch;
#line 727 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		sidebar_tree_disassociate_branch (self, _tmp2_);
#line 4659 "Tree.c"
	}
#line 729 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = branch;
#line 729 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = shown;
#line 729 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_BRANCH_SHOWN_SIGNAL], 0, _tmp3_, _tmp4_);
#line 4667 "Tree.c"
}


static void sidebar_tree_on_sidebar_tooltip_changed (SidebarTree* self, SidebarEntry* entry, const gchar* tooltip) {
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarEntry* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	GtkTreeStore* _tmp2_;
	GtkTreeIter _tmp3_ = {0};
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
#line 732 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 732 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 733 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 733 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper (self, _tmp0_);
#line 733 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 734 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (wrapper != NULL, "wrapper != null");
#line 736 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = self->priv->store;
#line 736 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (wrapper, &_tmp3_);
#line 736 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = tooltip;
#line 736 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = guarded_markup_escape_text (_tmp4_);
#line 736 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = _tmp5_;
#line 736 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp2_, &_tmp3_, SIDEBAR_TREE_COLUMNS_TOOLTIP, _tmp6_, -1);
#line 736 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp6_);
#line 732 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 4708 "Tree.c"
}


static void sidebar_tree_on_sidebar_icon_changed (SidebarTree* self, SidebarEntry* entry, const gchar* icon) {
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarEntry* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	GtkTreeStore* _tmp2_;
	GtkTreeIter _tmp3_ = {0};
	const gchar* _tmp4_;
#line 739 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 739 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 740 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 740 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper (self, _tmp0_);
#line 740 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 741 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (wrapper != NULL, "wrapper != null");
#line 743 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = self->priv->store;
#line 743 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (wrapper, &_tmp3_);
#line 743 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = icon;
#line 743 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp2_, &_tmp3_, SIDEBAR_TREE_COLUMNS_ICON, _tmp4_, -1);
#line 739 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 4741 "Tree.c"
}


static void sidebar_tree_rename_entry (SidebarTree* self, SidebarEntry* entry) {
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarEntry* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	GtkTreeStore* _tmp2_;
	GtkTreeIter _tmp3_ = {0};
	SidebarEntry* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
#line 746 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 746 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 747 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 747 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper (self, _tmp0_);
#line 747 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 748 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (wrapper != NULL, "wrapper != null");
#line 750 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = self->priv->store;
#line 750 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_get_iter (wrapper, &_tmp3_);
#line 750 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = entry;
#line 750 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = sidebar_tree_get_name_for_entry (self, _tmp4_);
#line 750 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = _tmp5_;
#line 750 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp2_, &_tmp3_, SIDEBAR_TREE_COLUMNS_NAME, _tmp6_, -1);
#line 750 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp6_);
#line 746 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 4782 "Tree.c"
}


static void sidebar_tree_on_sidebar_name_changed (SidebarTree* self, SidebarEntry* entry, const gchar* name) {
	SidebarEntry* _tmp0_;
#line 753 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 753 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_ENTRY (entry));
#line 753 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (name != NULL);
#line 754 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 754 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_rename_entry (self, _tmp0_);
#line 4798 "Tree.c"
}


static void sidebar_tree_on_sidebar_page_created (SidebarTree* self, SidebarPageRepresentative* entry, Page* page) {
	SidebarPageRepresentative* _tmp0_;
	Page* _tmp1_;
#line 757 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 757 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_PAGE_REPRESENTATIVE (entry));
#line 757 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (IS_PAGE (page));
#line 758 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 758 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = page;
#line 758 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_PAGE_CREATED_SIGNAL], 0, _tmp0_, _tmp1_);
#line 4817 "Tree.c"
}


static void sidebar_tree_on_is_emphasized_changed (SidebarTree* self, SidebarEmphasizableEntry* entry, gboolean is_emphasized) {
	SidebarEmphasizableEntry* _tmp0_;
#line 761 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 761 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_EMPHASIZABLE_ENTRY (entry));
#line 762 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 762 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_rename_entry (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SIDEBAR_TYPE_ENTRY, SidebarEntry));
#line 4831 "Tree.c"
}


static void sidebar_tree_on_sidebar_destroying_page (SidebarTree* self, SidebarPageRepresentative* entry, Page* page) {
	SidebarPageRepresentative* _tmp0_;
	Page* _tmp1_;
#line 765 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 765 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_PAGE_REPRESENTATIVE (entry));
#line 765 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (IS_PAGE (page));
#line 766 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 766 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = page;
#line 766 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_DESTROYING_PAGE_SIGNAL], 0, _tmp0_, _tmp1_);
#line 4850 "Tree.c"
}


static void sidebar_tree_load_entry_icons (SidebarTree* self, GtkTreeIter* iter) {
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreeIter _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	gchar* icon = NULL;
	SidebarTreeEntryWrapper* _tmp3_;
	SidebarEntry* _tmp4_;
	gchar* _tmp5_;
	GtkTreeStore* _tmp6_;
	GtkTreeIter _tmp7_;
	const gchar* _tmp8_;
#line 769 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 769 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (iter != NULL);
#line 770 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = *iter;
#line 770 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper_at_iter (self, &_tmp0_);
#line 770 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 771 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 771 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 772 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 772 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 4884 "Tree.c"
	}
#line 773 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 773 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_->entry;
#line 773 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = sidebar_entry_get_sidebar_icon (_tmp4_);
#line 773 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	icon = _tmp5_;
#line 774 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = self->priv->store;
#line 774 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = *iter;
#line 774 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = icon;
#line 774 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_store_set (_tmp6_, &_tmp7_, SIDEBAR_TREE_COLUMNS_ICON, _tmp8_, -1);
#line 769 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (icon);
#line 769 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 4906 "Tree.c"
}


static void sidebar_tree_load_branch_icons (SidebarTree* self, GtkTreeIter* iter) {
	GtkTreeIter _tmp0_;
	GtkTreeIter child_iter = {0};
	GtkTreeStore* _tmp1_;
	GtkTreeIter _tmp2_;
	GtkTreeIter _tmp3_ = {0};
	gboolean _tmp4_;
#line 777 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 777 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (iter != NULL);
#line 778 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = *iter;
#line 778 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_load_entry_icons (self, &_tmp0_);
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->store;
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = *iter;
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = gtk_tree_model_iter_children (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &_tmp3_, &_tmp2_);
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	child_iter = _tmp3_;
#line 781 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp4_) {
#line 4935 "Tree.c"
		{
			gboolean _tmp5_ = FALSE;
#line 782 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp5_ = TRUE;
#line 782 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			while (TRUE) {
#line 4942 "Tree.c"
				GtkTreeIter _tmp8_;
#line 782 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				if (!_tmp5_) {
#line 4946 "Tree.c"
					GtkTreeStore* _tmp6_;
					gboolean _tmp7_;
#line 784 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp6_ = self->priv->store;
#line 784 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp7_ = gtk_tree_model_iter_next (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &child_iter);
#line 784 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					if (!_tmp7_) {
#line 784 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
						break;
#line 4957 "Tree.c"
					}
				}
#line 782 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp5_ = FALSE;
#line 783 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp8_ = child_iter;
#line 783 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				sidebar_tree_load_branch_icons (self, &_tmp8_);
#line 4966 "Tree.c"
			}
		}
	}
}


static gboolean sidebar_tree_on_selection (SidebarTree* self, GtkTreeSelection* selection, GtkTreeModel* model, GtkTreePath* path, gboolean path_currently_selected) {
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreePath* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	gboolean _tmp2_ = FALSE;
	SidebarTreeEntryWrapper* _tmp3_;
#line 788 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 788 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (GTK_IS_TREE_SELECTION (selection), FALSE);
#line 788 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (GTK_IS_TREE_MODEL (model), FALSE);
#line 788 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 791 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = path;
#line 791 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper_at_path (self, _tmp0_);
#line 791 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 793 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 793 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp3_ != NULL) {
#line 4998 "Tree.c"
		SidebarTreeEntryWrapper* _tmp4_;
		SidebarEntry* _tmp5_;
#line 793 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = wrapper;
#line 793 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = _tmp4_->entry;
#line 793 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, SIDEBAR_TYPE_SELECTABLE_ENTRY);
#line 5007 "Tree.c"
	} else {
#line 793 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = FALSE;
#line 5011 "Tree.c"
	}
#line 793 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp2_;
#line 793 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 793 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5019 "Tree.c"
}


static GtkTreePath* sidebar_tree_get_path_from_event (SidebarTree* self, GdkEventButton* event) {
	GtkTreePath* result = NULL;
	gint x = 0;
	gint y = 0;
	GdkModifierType mask = 0;
	GdkEventButton* _tmp0_;
	GdkWindow* _tmp1_;
	GdkDisplay* _tmp2_;
	GdkDeviceManager* _tmp3_;
	GdkDevice* _tmp4_;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	GdkModifierType _tmp7_ = 0;
	gint cell_x = 0;
	gint cell_y = 0;
	GtkTreePath* path = NULL;
	GtkTreePath* _tmp8_ = NULL;
	gint _tmp9_;
	gint _tmp10_;
	GtkTreePath* _tmp11_ = NULL;
	gint _tmp12_ = 0;
	gint _tmp13_ = 0;
	gboolean _tmp14_;
	GtkTreePath* _tmp16_;
#line 796 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 796 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (event != NULL, NULL);
#line 799 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = event;
#line 799 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _tmp0_->window;
#line 799 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gdk_display_get_default ();
#line 799 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = gdk_display_get_device_manager (_tmp2_);
#line 799 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = gdk_device_manager_get_client_pointer (_tmp3_);
#line 799 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gdk_window_get_device_position (_tmp1_, _tmp4_, &_tmp5_, &_tmp6_, &_tmp7_);
#line 799 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	x = _tmp5_;
#line 799 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	y = _tmp6_;
#line 799 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	mask = _tmp7_;
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = x;
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = y;
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = gtk_tree_view_get_path_at_pos (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp9_, _tmp10_, &_tmp11_, NULL, &_tmp12_, &_tmp13_);
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (path);
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp11_;
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	cell_x = _tmp12_;
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	cell_y = _tmp13_;
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp14_) {
#line 5085 "Tree.c"
		GtkTreePath* _tmp15_;
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp15_ = path;
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = _tmp15_;
#line 5091 "Tree.c"
	} else {
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = NULL;
#line 5095 "Tree.c"
	}
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = _gtk_tree_path_copy0 (_tmp8_);
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp16_;
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (path);
#line 804 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5105 "Tree.c"
}


static GtkTreePath* sidebar_tree_get_current_path (SidebarTree* self) {
	GtkTreePath* result = NULL;
	GtkTreeModel* model = NULL;
	GList* rows = NULL;
	GtkTreeSelection* _tmp0_;
	GtkTreeModel* _tmp1_ = NULL;
	GList* _tmp2_;
	GtkTreeModel* _tmp3_;
	gboolean _tmp4_ = FALSE;
	GList* _tmp5_;
	guint _tmp6_;
	GtkTreePath* _tmp9_ = NULL;
	GList* _tmp10_;
	guint _tmp11_;
	GtkTreePath* _tmp14_;
#line 807 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), NULL);
#line 809 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 809 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gtk_tree_selection_get_selected_rows (_tmp0_, &_tmp1_);
#line 809 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (model);
#line 809 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = _g_object_ref0 (_tmp1_);
#line 809 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	model = _tmp3_;
#line 809 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	rows = _tmp2_;
#line 810 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = rows;
#line 810 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = g_list_length (_tmp5_);
#line 810 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp6_ == ((guint) 0)) {
#line 810 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = TRUE;
#line 5146 "Tree.c"
	} else {
		GList* _tmp7_;
		guint _tmp8_;
#line 810 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = rows;
#line 810 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = g_list_length (_tmp7_);
#line 810 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = _tmp8_ == ((guint) 1);
#line 5156 "Tree.c"
	}
#line 810 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (_tmp4_, "rows.length() == 0 || rows.length() == 1");
#line 812 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = rows;
#line 812 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = g_list_length (_tmp10_);
#line 812 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp11_ != ((guint) 0)) {
#line 5166 "Tree.c"
		GList* _tmp12_;
		gconstpointer _tmp13_;
#line 812 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = rows;
#line 812 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = g_list_nth_data (_tmp12_, (guint) 0);
#line 812 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = (GtkTreePath*) _tmp13_;
#line 5175 "Tree.c"
	} else {
#line 812 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = NULL;
#line 5179 "Tree.c"
	}
#line 812 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = _gtk_tree_path_copy0 (_tmp9_);
#line 812 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp14_;
#line 812 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__g_list_free__gtk_tree_path_free0_0 (rows);
#line 812 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (model);
#line 812 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5191 "Tree.c"
}


static gboolean sidebar_tree_on_context_menu_keypress (SidebarTree* self) {
	gboolean result = FALSE;
	GList* rows = NULL;
	GtkTreeSelection* _tmp0_;
	GList* _tmp1_;
	GList* _tmp2_;
	GtkTreePath* path = NULL;
	GList* _tmp3_;
	gconstpointer _tmp4_;
	GtkTreePath* _tmp5_;
	GtkTreePath* _tmp6_;
	GtkTreePath* _tmp7_;
	GtkTreePath* _tmp8_;
	gboolean _tmp9_;
#line 815 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 816 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 816 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_tree_selection_get_selected_rows (_tmp0_, NULL);
#line 816 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	rows = _tmp1_;
#line 817 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = rows;
#line 817 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 818 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 818 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__g_list_free__gtk_tree_path_free0_0 (rows);
#line 818 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5227 "Tree.c"
	}
#line 820 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = rows;
#line 820 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_->data;
#line 820 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = _gtk_tree_path_copy0 ((GtkTreePath*) _tmp4_);
#line 820 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp5_;
#line 821 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = path;
#line 821 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp6_ == NULL) {
#line 822 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 822 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_gtk_tree_path_free0 (path);
#line 822 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		__g_list_free__gtk_tree_path_free0_0 (rows);
#line 822 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5249 "Tree.c"
	}
#line 824 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = path;
#line 824 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_scroll_to_cell (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp7_, NULL, FALSE, (gfloat) 0, (gfloat) 0);
#line 826 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = path;
#line 826 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = sidebar_tree_popup_context_menu (self, _tmp8_, NULL);
#line 826 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp9_;
#line 826 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (path);
#line 826 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	__g_list_free__gtk_tree_path_free0_0 (rows);
#line 826 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5267 "Tree.c"
}


static gboolean sidebar_tree_popup_context_menu (SidebarTree* self, GtkTreePath* path, GdkEventButton* event) {
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreePath* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	SidebarContextable* contextable = NULL;
	SidebarTreeEntryWrapper* _tmp3_;
	SidebarEntry* _tmp4_;
	SidebarContextable* _tmp5_;
	SidebarContextable* _tmp6_;
	SidebarSelectableEntry* selectable = NULL;
	SidebarTreeEntryWrapper* _tmp7_;
	SidebarEntry* _tmp8_;
	SidebarSelectableEntry* _tmp9_;
	SidebarSelectableEntry* _tmp10_;
	GtkMenu* context_menu = NULL;
	SidebarContextable* _tmp12_;
	GdkEventButton* _tmp13_;
	GtkMenu* _tmp14_;
	GtkMenu* _tmp15_;
	GtkMenu* _tmp16_;
	GtkWidget* _tmp17_;
	GdkEventButton* _tmp19_;
#line 829 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 829 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 830 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = path;
#line 830 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper_at_path (self, _tmp0_);
#line 830 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 831 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 831 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 832 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 832 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 832 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5315 "Tree.c"
	}
#line 834 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 834 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_->entry;
#line 834 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, SIDEBAR_TYPE_CONTEXTABLE) ? ((SidebarContextable*) _tmp4_) : NULL);
#line 834 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	contextable = _tmp5_;
#line 835 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = contextable;
#line 835 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp6_ == NULL) {
#line 836 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 836 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (contextable);
#line 836 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 836 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5337 "Tree.c"
	}
#line 839 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = wrapper;
#line 839 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = _tmp7_->entry;
#line 839 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, SIDEBAR_TYPE_SELECTABLE_ENTRY) ? ((SidebarSelectableEntry*) _tmp8_) : NULL);
#line 839 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	selectable = _tmp9_;
#line 840 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = selectable;
#line 840 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp10_ != NULL) {
#line 5351 "Tree.c"
		SidebarSelectableEntry* _tmp11_;
#line 841 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = selectable;
#line 841 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_emit (self, sidebar_tree_signals[SIDEBAR_TREE_ENTRY_SELECTED_SIGNAL], 0, _tmp11_);
#line 5357 "Tree.c"
	}
#line 843 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp12_ = contextable;
#line 843 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = event;
#line 843 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = sidebar_contextable_get_sidebar_context_menu (_tmp12_, _tmp13_);
#line 843 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	context_menu = _tmp14_;
#line 844 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = context_menu;
#line 844 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp15_ == NULL) {
#line 845 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 845 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (context_menu);
#line 845 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (selectable);
#line 845 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (contextable);
#line 845 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 845 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5383 "Tree.c"
	}
#line 847 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = context_menu;
#line 847 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = gtk_menu_get_attach_widget (_tmp16_);
#line 847 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp17_ == NULL) {
#line 5391 "Tree.c"
		GtkMenu* _tmp18_;
#line 848 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp18_ = context_menu;
#line 848 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_menu_attach_to_widget (_tmp18_, G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), NULL);
#line 5397 "Tree.c"
	}
#line 851 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp19_ = event;
#line 851 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp19_ != NULL) {
#line 5403 "Tree.c"
		GtkMenu* _tmp20_;
		GdkEventButton* _tmp21_;
		guint _tmp22_;
		GdkEventButton* _tmp23_;
		guint32 _tmp24_;
#line 852 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp20_ = context_menu;
#line 852 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp21_ = event;
#line 852 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp22_ = _tmp21_->button;
#line 852 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp23_ = event;
#line 852 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp24_ = _tmp23_->time;
#line 852 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_menu_popup (_tmp20_, NULL, NULL, NULL, NULL, _tmp22_, _tmp24_);
#line 5421 "Tree.c"
	} else {
		GtkMenu* _tmp25_;
		guint32 _tmp26_;
#line 854 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp25_ = context_menu;
#line 854 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp26_ = gtk_get_current_event_time ();
#line 854 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_menu_popup (_tmp25_, NULL, NULL, NULL, NULL, (guint) 0, _tmp26_);
#line 5431 "Tree.c"
	}
#line 856 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 856 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (context_menu);
#line 856 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (selectable);
#line 856 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (contextable);
#line 856 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 856 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5445 "Tree.c"
}


static gboolean sidebar_tree_popup_default_context_menu (SidebarTree* self, GdkEventButton* event) {
	gboolean result = FALSE;
	GtkMenu* _tmp0_;
	GdkEventButton* _tmp1_;
	guint _tmp2_;
	GdkEventButton* _tmp3_;
	guint32 _tmp4_;
#line 859 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 859 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 860 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->default_context_menu;
#line 860 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = event;
#line 860 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _tmp1_->button;
#line 860 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = event;
#line 860 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_->time;
#line 860 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_menu_popup (_tmp0_, NULL, NULL, NULL, NULL, _tmp2_, _tmp4_);
#line 861 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 861 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5476 "Tree.c"
}


gboolean sidebar_tree_on_toggle_row (SidebarTree* self, GtkTreeIter* iter, GtkTreePath* path) {
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreeIter _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	gboolean should_allow_toggle = FALSE;
	gboolean _tmp3_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	GtkTreePath* _tmp6_;
	gboolean _tmp7_;
	gboolean _tmp16_;
#line 864 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 864 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 864 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 866 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = *iter;
#line 866 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper_at_iter (self, &_tmp0_);
#line 866 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 867 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 867 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 868 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 868 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 868 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5515 "Tree.c"
	}
#line 872 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = self->priv->expander_called_manually;
#line 872 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	should_allow_toggle = _tmp3_;
#line 875 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->expander_called_manually = FALSE;
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = path;
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = gtk_tree_view_row_expanded (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp6_);
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp7_) {
#line 5529 "Tree.c"
		GtkTreeStore* _tmp8_;
		GtkTreeIter _tmp9_;
		gboolean _tmp10_;
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = self->priv->store;
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = *iter;
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = gtk_tree_model_iter_has_child (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &_tmp9_);
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = _tmp10_;
#line 5541 "Tree.c"
	} else {
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = FALSE;
#line 5545 "Tree.c"
	}
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp5_) {
#line 5549 "Tree.c"
		SidebarTreeEntryWrapper* _tmp11_;
		SidebarEntry* _tmp12_;
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = wrapper;
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = _tmp11_->entry;
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, SIDEBAR_TYPE_SELECTABLE_ENTRY);
#line 5558 "Tree.c"
	} else {
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = FALSE;
#line 5562 "Tree.c"
	}
#line 878 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp4_) {
#line 5566 "Tree.c"
		gint _tmp13_;
		gint _tmp14_;
#line 880 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = self->priv->expander_special_count;
#line 880 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->expander_special_count = _tmp13_ + 1;
#line 881 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp14_ = self->priv->expander_special_count;
#line 881 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp14_ == 1) {
#line 883 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			result = TRUE;
#line 883 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (wrapper);
#line 883 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			return result;
#line 5583 "Tree.c"
		} else {
			gboolean _tmp15_;
#line 886 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp15_ = should_allow_toggle;
#line 886 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			should_allow_toggle = !_tmp15_;
#line 5590 "Tree.c"
		}
	} else {
#line 890 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->expander_special_count = 0;
#line 5595 "Tree.c"
	}
#line 893 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = should_allow_toggle;
#line 893 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp16_) {
#line 894 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 894 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 894 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5607 "Tree.c"
	}
#line 897 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 897 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 897 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5615 "Tree.c"
}


static gboolean sidebar_tree_real_button_press_event (GtkWidget* base, GdkEventButton* event) {
	SidebarTree * self;
	gboolean result = FALSE;
	GtkTreePath* path = NULL;
	GdkEventButton* _tmp0_;
	GtkTreePath* _tmp1_;
	gboolean _tmp2_ = FALSE;
	GtkTreePath* _tmp3_;
	gboolean _tmp6_ = FALSE;
	GdkEventButton* _tmp7_;
	guint _tmp8_;
	GdkEventButton* _tmp58_;
	gboolean _tmp59_;
#line 900 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_TREE, SidebarTree);
#line 900 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 901 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = event;
#line 901 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_path_from_event (self, _tmp0_);
#line 901 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp1_;
#line 904 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = path;
#line 904 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp3_ == NULL) {
#line 5646 "Tree.c"
		GdkEventButton* _tmp4_;
		guint _tmp5_;
#line 904 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = event;
#line 904 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = _tmp4_->button;
#line 904 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = _tmp5_ != ((guint) 3);
#line 5655 "Tree.c"
	} else {
#line 904 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = FALSE;
#line 5659 "Tree.c"
	}
#line 904 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_) {
#line 905 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = TRUE;
#line 905 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_gtk_tree_path_free0 (path);
#line 905 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 5669 "Tree.c"
	}
#line 908 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = event;
#line 908 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = _tmp7_->button;
#line 908 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp8_ == ((guint) 3)) {
#line 5677 "Tree.c"
		GdkEventButton* _tmp9_;
		GdkEventType _tmp10_;
#line 908 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = event;
#line 908 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = _tmp9_->type;
#line 908 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = _tmp10_ == GDK_BUTTON_PRESS;
#line 5686 "Tree.c"
	} else {
#line 908 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = FALSE;
#line 5690 "Tree.c"
	}
#line 908 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp6_) {
#line 5694 "Tree.c"
		GtkTreePath* _tmp11_;
#line 910 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = path;
#line 910 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp11_ != NULL) {
#line 5700 "Tree.c"
			GtkTreePath* _tmp12_;
			GdkEventButton* _tmp13_;
#line 911 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = path;
#line 911 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp13_ = event;
#line 911 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_popup_context_menu (self, _tmp12_, _tmp13_);
#line 5709 "Tree.c"
		} else {
			GdkEventButton* _tmp14_;
#line 913 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp14_ = event;
#line 913 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_tree_popup_default_context_menu (self, _tmp14_);
#line 5716 "Tree.c"
		}
	} else {
		gboolean _tmp15_ = FALSE;
		GdkEventButton* _tmp16_;
		guint _tmp17_;
#line 914 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp16_ = event;
#line 914 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp17_ = _tmp16_->button;
#line 914 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp17_ == ((guint) 1)) {
#line 5728 "Tree.c"
			GdkEventButton* _tmp18_;
			GdkEventType _tmp19_;
#line 914 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = event;
#line 914 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp19_ = _tmp18_->type;
#line 914 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp15_ = _tmp19_ == GDK_BUTTON_PRESS;
#line 5737 "Tree.c"
		} else {
#line 914 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp15_ = FALSE;
#line 5741 "Tree.c"
		}
#line 914 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp15_) {
#line 5745 "Tree.c"
			GtkTreePath* _tmp20_;
			SidebarTreeEntryWrapper* wrapper = NULL;
			GtkTreePath* _tmp23_;
			SidebarTreeEntryWrapper* _tmp24_;
			SidebarTreeEntryWrapper* _tmp25_;
			gboolean _tmp28_ = FALSE;
			SidebarTreeEntryWrapper* _tmp29_;
			SidebarEntry* _tmp30_;
			gboolean _tmp34_ = FALSE;
			gboolean _tmp35_ = FALSE;
			const GtkTreeRowReference* _tmp36_;
			gboolean _tmp48_ = FALSE;
			SidebarTreeEntryWrapper* _tmp49_;
			SidebarEntry* _tmp50_;
			GtkTreeStore* _tmp55_;
			GtkTreePath* _tmp56_;
			GtkTreeRowReference* _tmp57_;
#line 915 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp20_ = path;
#line 915 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp20_ == NULL) {
#line 5767 "Tree.c"
				GdkEventButton* _tmp21_;
				gboolean _tmp22_;
#line 916 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_gtk_tree_row_reference_free0 (self->priv->old_path_ref);
#line 916 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				self->priv->old_path_ref = NULL;
#line 917 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp21_ = event;
#line 917 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp22_ = GTK_WIDGET_CLASS (sidebar_tree_parent_class)->button_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), _tmp21_);
#line 917 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = _tmp22_;
#line 917 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_gtk_tree_path_free0 (path);
#line 917 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 5784 "Tree.c"
			}
#line 920 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp23_ = path;
#line 920 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp24_ = sidebar_tree_get_wrapper_at_path (self, _tmp23_);
#line 920 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			wrapper = _tmp24_;
#line 922 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp25_ = wrapper;
#line 922 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp25_ == NULL) {
#line 5796 "Tree.c"
				GdkEventButton* _tmp26_;
				gboolean _tmp27_;
#line 923 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_gtk_tree_row_reference_free0 (self->priv->old_path_ref);
#line 923 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				self->priv->old_path_ref = NULL;
#line 924 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp26_ = event;
#line 924 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp27_ = GTK_WIDGET_CLASS (sidebar_tree_parent_class)->button_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), _tmp26_);
#line 924 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = _tmp27_;
#line 924 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_g_object_unref0 (wrapper);
#line 924 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_gtk_tree_path_free0 (path);
#line 924 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 5815 "Tree.c"
			}
#line 928 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp29_ = wrapper;
#line 928 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp30_ = _tmp29_->entry;
#line 928 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, SIDEBAR_TYPE_EXPANDABLE_ENTRY)) {
#line 928 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp28_ = TRUE;
#line 5825 "Tree.c"
			} else {
				SidebarTreeEntryWrapper* _tmp31_;
				SidebarEntry* _tmp32_;
#line 929 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp31_ = wrapper;
#line 929 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp32_ = _tmp31_->entry;
#line 929 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp28_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY);
#line 5835 "Tree.c"
			}
#line 928 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp28_) {
#line 5839 "Tree.c"
				GtkTreePath* _tmp33_;
#line 931 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp33_ = path;
#line 931 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				sidebar_tree_toggle_branch_expansion (self, _tmp33_, FALSE);
#line 5845 "Tree.c"
			}
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp36_ = self->priv->old_path_ref;
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp36_ != NULL) {
#line 5851 "Tree.c"
				const GtkTreeRowReference* _tmp37_;
				GtkTreePath* _tmp38_;
				GtkTreePath* _tmp39_;
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp37_ = self->priv->old_path_ref;
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp38_ = gtk_tree_row_reference_get_path (_tmp37_);
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp39_ = _tmp38_;
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp35_ = _tmp39_ != NULL;
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_gtk_tree_path_free0 (_tmp39_);
#line 5865 "Tree.c"
			} else {
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp35_ = FALSE;
#line 5869 "Tree.c"
			}
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp35_) {
#line 5873 "Tree.c"
				const GtkTreeRowReference* _tmp40_;
				GtkTreePath* _tmp41_;
				GtkTreePath* _tmp42_;
				GtkTreePath* _tmp43_;
				gint _tmp44_;
#line 936 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp40_ = self->priv->old_path_ref;
#line 936 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp41_ = gtk_tree_row_reference_get_path (_tmp40_);
#line 936 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp42_ = _tmp41_;
#line 936 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp43_ = path;
#line 936 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp44_ = gtk_tree_path_compare (_tmp42_, _tmp43_);
#line 936 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp34_ = _tmp44_ == 0;
#line 936 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_gtk_tree_path_free0 (_tmp42_);
#line 5893 "Tree.c"
			} else {
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp34_ = FALSE;
#line 5897 "Tree.c"
			}
#line 935 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp34_) {
#line 5901 "Tree.c"
				GtkCellRendererText* _tmp45_;
				GdkEventButton* _tmp46_;
				gboolean _tmp47_;
#line 939 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp45_ = self->priv->text_renderer;
#line 939 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				g_object_set (_tmp45_, "editable", FALSE, NULL);
#line 940 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp46_ = event;
#line 940 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp47_ = GTK_WIDGET_CLASS (sidebar_tree_parent_class)->button_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), _tmp46_);
#line 940 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = _tmp47_;
#line 940 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_g_object_unref0 (wrapper);
#line 940 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_gtk_tree_path_free0 (path);
#line 940 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 5921 "Tree.c"
			}
#line 945 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp49_ = wrapper;
#line 945 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp50_ = _tmp49_->entry;
#line 945 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, SIDEBAR_TYPE_RENAMEABLE_ENTRY)) {
#line 5929 "Tree.c"
				SidebarTreeEntryWrapper* _tmp51_;
				SidebarEntry* _tmp52_;
				gboolean _tmp53_;
#line 946 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp51_ = wrapper;
#line 946 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp52_ = _tmp51_->entry;
#line 946 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp53_ = sidebar_renameable_entry_is_user_renameable (G_TYPE_CHECK_INSTANCE_CAST (_tmp52_, SIDEBAR_TYPE_RENAMEABLE_ENTRY, SidebarRenameableEntry));
#line 946 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp48_ = _tmp53_;
#line 5941 "Tree.c"
			} else {
#line 945 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp48_ = FALSE;
#line 5945 "Tree.c"
			}
#line 945 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			if (_tmp48_) {
#line 5949 "Tree.c"
				GtkCellRendererText* _tmp54_;
#line 947 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp54_ = self->priv->text_renderer;
#line 947 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				g_object_set (_tmp54_, "editable", TRUE, NULL);
#line 5955 "Tree.c"
			}
#line 951 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp55_ = self->priv->store;
#line 951 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp56_ = path;
#line 951 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp57_ = gtk_tree_row_reference_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, GTK_TYPE_TREE_MODEL, GtkTreeModel), _tmp56_);
#line 951 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_gtk_tree_row_reference_free0 (self->priv->old_path_ref);
#line 951 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			self->priv->old_path_ref = _tmp57_;
#line 914 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (wrapper);
#line 5969 "Tree.c"
		}
	}
#line 954 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp58_ = event;
#line 954 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp59_ = GTK_WIDGET_CLASS (sidebar_tree_parent_class)->button_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), _tmp58_);
#line 954 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp59_;
#line 954 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (path);
#line 954 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 5982 "Tree.c"
}


gboolean sidebar_tree_is_keypress_interpreted (SidebarTree* self, GdkEventKey* event) {
	gboolean result = FALSE;
	GdkEventKey* _tmp0_;
	guint _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	GQuark _tmp5_ = 0U;
#line 958 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp4_label0 = 0;
#line 958 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp4_label1 = 0;
#line 958 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp4_label2 = 0;
#line 958 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp4_label3 = 0;
#line 957 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 957 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 958 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = event;
#line 958 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _tmp0_->keyval;
#line 958 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gdk_keyval_name (_tmp1_);
#line 958 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = _tmp2_;
#line 958 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = (NULL == _tmp3_) ? 0 : g_quark_from_string (_tmp3_);
#line 958 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if ((((_tmp5_ == ((0 != _tmp4_label0) ? _tmp4_label0 : (_tmp4_label0 = g_quark_from_static_string ("F2")))) || (_tmp5_ == ((0 != _tmp4_label1) ? _tmp4_label1 : (_tmp4_label1 = g_quark_from_static_string ("Delete"))))) || (_tmp5_ == ((0 != _tmp4_label2) ? _tmp4_label2 : (_tmp4_label2 = g_quark_from_static_string ("Return"))))) || (_tmp5_ == ((0 != _tmp4_label3) ? _tmp4_label3 : (_tmp4_label3 = g_quark_from_static_string ("KP_Enter"))))) {
#line 958 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		switch (0) {
#line 6019 "Tree.c"
			default:
			{
#line 963 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = TRUE;
#line 963 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 6026 "Tree.c"
			}
		}
	} else {
#line 958 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		switch (0) {
#line 6032 "Tree.c"
			default:
			{
#line 966 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = FALSE;
#line 966 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 6039 "Tree.c"
			}
		}
	}
}


static gboolean sidebar_tree_real_key_press_event (GtkWidget* base, GdkEventKey* event) {
	SidebarTree * self;
	gboolean result = FALSE;
	GdkEventKey* _tmp0_;
	guint _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	GQuark _tmp5_ = 0U;
#line 971 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp4_label0 = 0;
#line 971 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp4_label1 = 0;
#line 971 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp4_label2 = 0;
#line 971 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	static GQuark _tmp4_label3 = 0;
#line 6062 "Tree.c"
	GdkEventKey* _tmp15_;
	gboolean _tmp16_;
#line 970 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_TREE, SidebarTree);
#line 970 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 971 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = event;
#line 971 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _tmp0_->keyval;
#line 971 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gdk_keyval_name (_tmp1_);
#line 971 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = _tmp2_;
#line 971 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = (NULL == _tmp3_) ? 0 : g_quark_from_string (_tmp3_);
#line 971 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if ((_tmp5_ == ((0 != _tmp4_label0) ? _tmp4_label0 : (_tmp4_label0 = g_quark_from_static_string ("Return")))) || (_tmp5_ == ((0 != _tmp4_label1) ? _tmp4_label1 : (_tmp4_label1 = g_quark_from_static_string ("KP_Enter"))))) {
#line 971 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		switch (0) {
#line 6083 "Tree.c"
			default:
			{
				GtkTreePath* path = NULL;
				GtkTreePath* _tmp6_;
				GtkTreePath* _tmp7_;
#line 974 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp6_ = sidebar_tree_get_current_path (self);
#line 974 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				path = _tmp6_;
#line 975 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp7_ = path;
#line 975 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				if (_tmp7_ != NULL) {
#line 6097 "Tree.c"
					GtkTreePath* _tmp8_;
#line 976 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp8_ = path;
#line 976 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					sidebar_tree_toggle_branch_expansion (self, _tmp8_, FALSE);
#line 6103 "Tree.c"
				}
#line 978 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = TRUE;
#line 978 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_gtk_tree_path_free0 (path);
#line 978 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 6111 "Tree.c"
			}
		}
	} else if (_tmp5_ == ((0 != _tmp4_label2) ? _tmp4_label2 : (_tmp4_label2 = g_quark_from_static_string ("F2")))) {
#line 971 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		switch (0) {
#line 6117 "Tree.c"
			default:
			{
				gboolean _tmp9_;
#line 981 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp9_ = sidebar_tree_rename_in_place (self);
#line 981 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = _tmp9_;
#line 981 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 6127 "Tree.c"
			}
		}
	} else if (_tmp5_ == ((0 != _tmp4_label3) ? _tmp4_label3 : (_tmp4_label3 = g_quark_from_static_string ("Delete")))) {
#line 971 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		switch (0) {
#line 6133 "Tree.c"
			default:
			{
				GtkTreePath* path = NULL;
				GtkTreePath* _tmp10_;
				gboolean _tmp11_ = FALSE;
				GtkTreePath* _tmp12_;
#line 984 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp10_ = sidebar_tree_get_current_path (self);
#line 984 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				path = _tmp10_;
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_tmp12_ = path;
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				if (_tmp12_ != NULL) {
#line 6148 "Tree.c"
					GtkTreePath* _tmp13_;
					gboolean _tmp14_;
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp13_ = path;
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp14_ = sidebar_tree_destroy_path (self, _tmp13_);
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp11_ = _tmp14_;
#line 6157 "Tree.c"
				} else {
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
					_tmp11_ = FALSE;
#line 6161 "Tree.c"
				}
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				result = _tmp11_;
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				_gtk_tree_path_free0 (path);
#line 986 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
				return result;
#line 6169 "Tree.c"
			}
		}
	}
#line 989 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = event;
#line 989 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = GTK_WIDGET_CLASS (sidebar_tree_parent_class)->key_press_event (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), _tmp15_);
#line 989 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp16_;
#line 989 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 6181 "Tree.c"
}


gboolean sidebar_tree_rename_entry_in_place (SidebarTree* self, SidebarEntry* entry) {
	gboolean result = FALSE;
	SidebarEntry* _tmp0_;
	gboolean _tmp1_;
	SidebarEntry* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
#line 992 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 992 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), FALSE);
#line 993 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 993 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_expand_to_entry (self, _tmp0_);
#line 993 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (!_tmp1_) {
#line 994 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 994 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 6206 "Tree.c"
	}
#line 996 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = entry;
#line 996 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_place_cursor (self, _tmp2_, FALSE);
#line 996 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (!_tmp3_) {
#line 997 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 997 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 6218 "Tree.c"
	}
#line 999 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = sidebar_tree_rename_in_place (self);
#line 999 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp4_;
#line 999 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 6226 "Tree.c"
}


static gboolean sidebar_tree_rename_in_place (SidebarTree* self) {
	gboolean result = FALSE;
	GtkTreePath* cursor_path = NULL;
	GtkTreeViewColumn* cursor_column = NULL;
	GtkTreePath* _tmp0_ = NULL;
	GtkTreeViewColumn* _tmp1_ = NULL;
	GtkTreeViewColumn* _tmp2_;
	GtkTreePath* _tmp3_;
	gboolean _tmp4_;
#line 1002 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 1005 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_get_cursor (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), &_tmp0_, &_tmp1_);
#line 1005 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (cursor_path);
#line 1005 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	cursor_path = _tmp0_;
#line 1005 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (cursor_column);
#line 1005 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 1005 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	cursor_column = _tmp2_;
#line 1007 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = cursor_path;
#line 1007 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = sidebar_tree_can_rename_path (self, _tmp3_);
#line 1007 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp4_) {
#line 6259 "Tree.c"
		GtkTreePath* _tmp5_;
		GtkTreeViewColumn* _tmp6_;
		GtkCellRendererText* _tmp7_;
#line 1008 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = cursor_path;
#line 1008 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = cursor_column;
#line 1008 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = self->priv->text_renderer;
#line 1008 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_view_set_cursor_on_cell (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp5_, _tmp6_, G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_cell_renderer_get_type (), GtkCellRenderer), TRUE);
#line 1010 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = TRUE;
#line 1010 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (cursor_column);
#line 1010 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_gtk_tree_path_free0 (cursor_path);
#line 1010 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 6279 "Tree.c"
	}
#line 1013 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = FALSE;
#line 1013 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (cursor_column);
#line 1013 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (cursor_path);
#line 1013 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 6289 "Tree.c"
}


gboolean sidebar_tree_scroll_to_entry (SidebarTree* self, SidebarEntry* entry) {
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	SidebarEntry* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	GtkTreePath* _tmp4_;
	GtkTreePath* _tmp5_;
#line 1016 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 1016 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), FALSE);
#line 1017 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 1017 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper (self, _tmp0_);
#line 1017 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 1018 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 1018 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 1019 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1019 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1019 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 6322 "Tree.c"
	}
#line 1021 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 1021 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = sidebar_tree_entry_wrapper_get_path (_tmp3_);
#line 1021 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = _tmp4_;
#line 1021 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_view_scroll_to_cell (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp5_, NULL, FALSE, (gfloat) 0, (gfloat) 0);
#line 1021 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (_tmp5_);
#line 1023 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 1023 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 1023 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 6340 "Tree.c"
}


static void sidebar_tree_real_drag_data_get (GtkWidget* base, GdkDragContext* context, GtkSelectionData* selection_data, guint info, guint time) {
	SidebarTree * self;
	SidebarInternalDragSourceEntry* drag_source = NULL;
	SidebarEntry* _tmp0_;
	SidebarInternalDragSourceEntry* _tmp6_;
	SidebarInternalDragSourceEntry* _tmp16_;
	GtkSelectionData* _tmp17_;
#line 1026 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_TREE, SidebarTree);
#line 1026 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (context));
#line 1026 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (selection_data != NULL);
#line 1028 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	drag_source = NULL;
#line 1030 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->internal_drag_source_entry;
#line 1030 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp0_ != NULL) {
#line 6363 "Tree.c"
		SidebarSelectableEntry* selectable = NULL;
		SidebarEntry* _tmp1_;
		SidebarSelectableEntry* _tmp2_;
		SidebarSelectableEntry* _tmp3_;
#line 1031 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = self->priv->internal_drag_source_entry;
#line 1031 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, SIDEBAR_TYPE_SELECTABLE_ENTRY) ? ((SidebarSelectableEntry*) _tmp1_) : NULL);
#line 1031 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		selectable = _tmp2_;
#line 1033 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = selectable;
#line 1033 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp3_ == NULL) {
#line 6378 "Tree.c"
			SidebarEntry* _tmp4_;
			SidebarInternalDragSourceEntry* _tmp5_;
#line 1034 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp4_ = self->priv->internal_drag_source_entry;
#line 1034 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY) ? ((SidebarInternalDragSourceEntry*) _tmp4_) : NULL);
#line 1034 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (drag_source);
#line 1034 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			drag_source = _tmp5_;
#line 6389 "Tree.c"
		}
#line 1030 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (selectable);
#line 6393 "Tree.c"
	}
#line 1038 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = drag_source;
#line 1038 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp6_ == NULL) {
#line 6399 "Tree.c"
		GtkTreePath* selected_path = NULL;
		GtkTreePath* _tmp7_;
		GtkTreePath* _tmp8_;
		SidebarTreeEntryWrapper* wrapper = NULL;
		GtkTreePath* _tmp9_;
		SidebarTreeEntryWrapper* _tmp10_;
		SidebarTreeEntryWrapper* _tmp11_;
		SidebarTreeEntryWrapper* _tmp12_;
		SidebarEntry* _tmp13_;
		SidebarInternalDragSourceEntry* _tmp14_;
		SidebarInternalDragSourceEntry* _tmp15_;
#line 1039 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = sidebar_tree_get_selected_path (self);
#line 1039 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		selected_path = _tmp7_;
#line 1040 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = selected_path;
#line 1040 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp8_ == NULL) {
#line 1041 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_gtk_tree_path_free0 (selected_path);
#line 1041 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (drag_source);
#line 1041 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			return;
#line 6425 "Tree.c"
		}
#line 1043 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = selected_path;
#line 1043 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp10_ = sidebar_tree_get_wrapper_at_path (self, _tmp9_);
#line 1043 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		wrapper = _tmp10_;
#line 1044 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = wrapper;
#line 1044 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp11_ == NULL) {
#line 1045 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (wrapper);
#line 1045 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_gtk_tree_path_free0 (selected_path);
#line 1045 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (drag_source);
#line 1045 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			return;
#line 6445 "Tree.c"
		}
#line 1047 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = wrapper;
#line 1047 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = _tmp12_->entry;
#line 1047 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, SIDEBAR_TYPE_INTERNAL_DRAG_SOURCE_ENTRY) ? ((SidebarInternalDragSourceEntry*) _tmp13_) : NULL);
#line 1047 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (drag_source);
#line 1047 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		drag_source = _tmp14_;
#line 1048 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp15_ = drag_source;
#line 1048 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp15_ == NULL) {
#line 1049 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (wrapper);
#line 1049 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_gtk_tree_path_free0 (selected_path);
#line 1049 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_g_object_unref0 (drag_source);
#line 1049 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			return;
#line 6469 "Tree.c"
		}
#line 1038 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1038 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_gtk_tree_path_free0 (selected_path);
#line 6475 "Tree.c"
	}
#line 1052 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = drag_source;
#line 1052 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = selection_data;
#line 1052 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_internal_drag_source_entry_prepare_selection_data (_tmp16_, _tmp17_);
#line 1026 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (drag_source);
#line 6485 "Tree.c"
}


static void sidebar_tree_real_drag_data_received (GtkWidget* base, GdkDragContext* context, gint x, gint y, GtkSelectionData* selection_data, guint info, guint time) {
	SidebarTree * self;
	GtkTreePath* path = NULL;
	GtkTreeViewDropPosition pos = 0;
	gint _tmp0_;
	gint _tmp1_;
	GtkTreePath* _tmp2_ = NULL;
	GtkTreeViewDropPosition _tmp3_ = 0;
	gboolean _tmp4_;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreePath* _tmp14_;
	SidebarTreeEntryWrapper* _tmp15_;
	GdkDragContext* _tmp16_;
	GtkWidget* _tmp17_;
	SidebarTreeEntryWrapper* _tmp27_;
	SidebarInternalDropTargetEntry* targetable = NULL;
	SidebarTreeEntryWrapper* _tmp30_;
	SidebarEntry* _tmp31_;
	SidebarInternalDropTargetEntry* _tmp32_;
	SidebarInternalDropTargetEntry* _tmp33_;
	gboolean success = FALSE;
	GtkSelectionData* _tmp36_;
	GdkAtom _tmp37_;
	gchar* _tmp38_;
	gchar* _tmp39_;
	gboolean _tmp40_;
	GdkDragContext* _tmp57_;
	gboolean _tmp58_;
	guint _tmp59_;
#line 1055 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_TREE, SidebarTree);
#line 1055 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GDK_IS_DRAG_CONTEXT (context));
#line 1055 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (selection_data != NULL);
#line 1060 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = x;
#line 1060 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = y;
#line 1060 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = gtk_tree_view_get_dest_row_at_pos (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp0_, _tmp1_, &_tmp2_, &_tmp3_);
#line 1060 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (path);
#line 1060 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp2_;
#line 1060 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	pos = _tmp3_;
#line 1060 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (!_tmp4_) {
#line 6538 "Tree.c"
		GdkDragContext* _tmp5_;
		GtkWidget* _tmp6_;
#line 1062 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = context;
#line 1062 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = gtk_drag_get_source_widget (_tmp5_);
#line 1062 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp6_ == NULL) {
#line 6547 "Tree.c"
			SidebarTreeExternalDropHandler _tmp7_;
			void* _tmp7__target;
			GdkDragContext* _tmp8_;
			GtkSelectionData* _tmp9_;
			guint _tmp10_;
			guint _tmp11_;
#line 1063 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp7_ = self->priv->drop_handler;
#line 1063 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp7__target = self->priv->drop_handler_target;
#line 1063 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp8_ = context;
#line 1063 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp9_ = selection_data;
#line 1063 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = info;
#line 1063 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp11_ = time;
#line 1063 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp7_ (_tmp8_, NULL, _tmp9_, _tmp10_, _tmp11_, _tmp7__target);
#line 6568 "Tree.c"
		} else {
			GdkDragContext* _tmp12_;
			guint _tmp13_;
#line 1065 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = context;
#line 1065 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp13_ = time;
#line 1065 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			gtk_drag_finish (_tmp12_, FALSE, FALSE, (guint32) _tmp13_);
#line 6578 "Tree.c"
		}
#line 1067 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_gtk_tree_path_free0 (path);
#line 1067 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 6584 "Tree.c"
	}
#line 1071 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp14_ = path;
#line 1071 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = sidebar_tree_get_wrapper_at_path (self, _tmp14_);
#line 1071 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp15_;
#line 1074 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = context;
#line 1074 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = gtk_drag_get_source_widget (_tmp16_);
#line 1074 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp17_ == NULL) {
#line 6598 "Tree.c"
		SidebarEntry* _tmp18_ = NULL;
		SidebarTreeEntryWrapper* _tmp19_;
		SidebarTreeExternalDropHandler _tmp22_;
		void* _tmp22__target;
		GdkDragContext* _tmp23_;
		GtkSelectionData* _tmp24_;
		guint _tmp25_;
		guint _tmp26_;
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp19_ = wrapper;
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp19_ != NULL) {
#line 6611 "Tree.c"
			SidebarTreeEntryWrapper* _tmp20_;
			SidebarEntry* _tmp21_;
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp20_ = wrapper;
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp21_ = _tmp20_->entry;
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = _tmp21_;
#line 6620 "Tree.c"
		} else {
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp18_ = NULL;
#line 6624 "Tree.c"
		}
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp22_ = self->priv->drop_handler;
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp22__target = self->priv->drop_handler_target;
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp23_ = context;
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp24_ = selection_data;
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp25_ = info;
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp26_ = time;
#line 1075 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp22_ (_tmp23_, _tmp18_, _tmp24_, _tmp25_, _tmp26_, _tmp22__target);
#line 1078 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1078 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_gtk_tree_path_free0 (path);
#line 1078 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 6646 "Tree.c"
	}
#line 1082 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp27_ = wrapper;
#line 1082 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp27_ == NULL) {
#line 6652 "Tree.c"
		GdkDragContext* _tmp28_;
		guint _tmp29_;
#line 1083 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp28_ = context;
#line 1083 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp29_ = time;
#line 1083 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_drag_finish (_tmp28_, FALSE, FALSE, (guint32) _tmp29_);
#line 1085 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1085 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_gtk_tree_path_free0 (path);
#line 1085 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 6667 "Tree.c"
	}
#line 1088 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp30_ = wrapper;
#line 1088 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp31_ = _tmp30_->entry;
#line 1088 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp32_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, SIDEBAR_TYPE_INTERNAL_DROP_TARGET_ENTRY) ? ((SidebarInternalDropTargetEntry*) _tmp31_) : NULL);
#line 1088 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	targetable = _tmp32_;
#line 1089 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp33_ = targetable;
#line 1089 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp33_ == NULL) {
#line 6681 "Tree.c"
		GdkDragContext* _tmp34_;
		guint _tmp35_;
#line 1090 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp34_ = context;
#line 1090 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp35_ = time;
#line 1090 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_drag_finish (_tmp34_, FALSE, FALSE, (guint32) _tmp35_);
#line 1092 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (targetable);
#line 1092 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1092 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_gtk_tree_path_free0 (path);
#line 1092 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return;
#line 6698 "Tree.c"
	}
#line 1095 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	success = FALSE;
#line 1097 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp36_ = selection_data;
#line 1097 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp37_ = gtk_selection_data_get_data_type (_tmp36_);
#line 1097 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp38_ = gdk_atom_name (_tmp37_);
#line 1097 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp39_ = _tmp38_;
#line 1097 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp40_ = g_strcmp0 (_tmp39_, LIBRARY_WINDOW_TAG_PATH_MIME_TYPE) == 0;
#line 1097 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_free0 (_tmp39_);
#line 1097 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp40_) {
#line 6716 "Tree.c"
		SidebarInternalDropTargetEntry* _tmp41_;
		GtkSelectionData* _tmp42_;
		gboolean _tmp43_;
#line 1098 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp41_ = targetable;
#line 1098 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp42_ = selection_data;
#line 1098 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp43_ = sidebar_internal_drop_target_entry_internal_drop_received_arbitrary (_tmp41_, _tmp42_);
#line 1098 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		success = _tmp43_;
#line 6728 "Tree.c"
	} else {
		GeeList* media = NULL;
		GtkSelectionData* _tmp44_;
		guchar* _tmp45_;
		GtkSelectionData* _tmp46_;
		gint _tmp47_;
		GeeList* _tmp48_;
		gboolean _tmp49_ = FALSE;
		GeeList* _tmp50_;
#line 1100 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp44_ = selection_data;
#line 1100 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp45_ = gtk_selection_data_get_data (_tmp44_);
#line 1100 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp46_ = selection_data;
#line 1100 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp47_ = gtk_selection_data_get_length (_tmp46_);
#line 1100 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp48_ = unserialize_media_sources (_tmp45_, _tmp47_);
#line 1100 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		media = _tmp48_;
#line 1102 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp50_ = media;
#line 1102 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp50_ != NULL) {
#line 6754 "Tree.c"
			GeeList* _tmp51_;
			gint _tmp52_;
			gint _tmp53_;
#line 1102 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp51_ = media;
#line 1102 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp52_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1102 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp53_ = _tmp52_;
#line 1102 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp49_ = _tmp53_ > 0;
#line 6766 "Tree.c"
		} else {
#line 1102 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp49_ = FALSE;
#line 6770 "Tree.c"
		}
#line 1102 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp49_) {
#line 6774 "Tree.c"
			SidebarInternalDropTargetEntry* _tmp54_;
			GeeList* _tmp55_;
			gboolean _tmp56_;
#line 1103 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp54_ = targetable;
#line 1103 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp55_ = media;
#line 1103 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp56_ = sidebar_internal_drop_target_entry_internal_drop_received (_tmp54_, _tmp55_);
#line 1103 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			success = _tmp56_;
#line 6786 "Tree.c"
		}
#line 1097 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (media);
#line 6790 "Tree.c"
	}
#line 1106 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp57_ = context;
#line 1106 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp58_ = success;
#line 1106 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp59_ = time;
#line 1106 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_drag_finish (_tmp57_, _tmp58_, FALSE, (guint32) _tmp59_);
#line 1055 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (targetable);
#line 1055 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 1055 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (path);
#line 6806 "Tree.c"
}


static gboolean sidebar_tree_real_drag_motion (GtkWidget* base, GdkDragContext* context, gint x, gint y, guint time) {
	SidebarTree * self;
	gboolean result = FALSE;
	GdkDragContext* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	guint _tmp3_;
	GtkTreePath* path = NULL;
	GtkTreeViewDropPosition pos = 0;
	gboolean has_dest = FALSE;
	gint _tmp4_;
	gint _tmp5_;
	GtkTreePath* _tmp6_ = NULL;
	GtkTreeViewDropPosition _tmp7_ = 0;
	gboolean _tmp8_;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_;
	GdkDragContext* _tmp15_;
	GdkDragContext* _tmp16_;
	GdkDragAction _tmp17_;
	guint _tmp18_;
#line 1109 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, SIDEBAR_TYPE_TREE, SidebarTree);
#line 1109 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (GDK_IS_DRAG_CONTEXT (context), FALSE);
#line 1111 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = context;
#line 1111 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = x;
#line 1111 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = y;
#line 1111 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = time;
#line 1111 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	GTK_WIDGET_CLASS (sidebar_tree_parent_class)->drag_motion (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), gtk_widget_get_type (), GtkWidget), _tmp0_, _tmp1_, _tmp2_, _tmp3_);
#line 1115 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = x;
#line 1115 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = y;
#line 1115 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = gtk_tree_view_get_dest_row_at_pos (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp4_, _tmp5_, &_tmp6_, &_tmp7_);
#line 1115 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (path);
#line 1115 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	path = _tmp6_;
#line 1115 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	pos = _tmp7_;
#line 1115 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	has_dest = _tmp8_;
#line 1118 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = has_dest;
#line 1118 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (!_tmp10_) {
#line 1118 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = TRUE;
#line 6865 "Tree.c"
	} else {
		GtkTreeViewDropPosition _tmp11_;
#line 1118 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp11_ = pos;
#line 1118 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = _tmp11_ == GTK_TREE_VIEW_DROP_BEFORE;
#line 6872 "Tree.c"
	}
#line 1118 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp9_) {
#line 6876 "Tree.c"
		GtkTreePath* _tmp12_;
#line 1119 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp12_ = path;
#line 1119 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		gtk_tree_view_set_drag_dest_row (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp12_, GTK_TREE_VIEW_DROP_INTO_OR_BEFORE);
#line 6882 "Tree.c"
	} else {
		GtkTreeViewDropPosition _tmp13_;
#line 1120 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp13_ = pos;
#line 1120 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp13_ == GTK_TREE_VIEW_DROP_AFTER) {
#line 6889 "Tree.c"
			GtkTreePath* _tmp14_;
#line 1121 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp14_ = path;
#line 1121 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			gtk_tree_view_set_drag_dest_row (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView), _tmp14_, GTK_TREE_VIEW_DROP_INTO_OR_AFTER);
#line 6895 "Tree.c"
		}
	}
#line 1123 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = context;
#line 1123 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp16_ = context;
#line 1123 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp17_ = gdk_drag_context_get_suggested_action (_tmp16_);
#line 1123 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp18_ = time;
#line 1123 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gdk_drag_status (_tmp15_, _tmp17_, (guint32) _tmp18_);
#line 1125 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = has_dest;
#line 1125 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (path);
#line 1125 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 6914 "Tree.c"
}


static gboolean sidebar_tree_can_rename_path (SidebarTree* self, GtkTreePath* path) {
	gboolean result = FALSE;
	gint _tmp0_;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreePath* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	SidebarRenameableEntry* renameable = NULL;
	SidebarTreeEntryWrapper* _tmp4_;
	SidebarEntry* _tmp5_;
	SidebarRenameableEntry* _tmp6_;
	SidebarRenameableEntry* _tmp7_;
	SidebarTreeEntryWrapper* _tmp8_;
	SidebarEntry* _tmp9_;
	GtkTreeSelection* _tmp10_;
	GtkTreePath* _tmp11_;
#line 1129 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 1129 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 1130 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->editing_disabled;
#line 1130 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp0_ > 0) {
#line 1131 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1131 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 6946 "Tree.c"
	}
#line 1133 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = path;
#line 1133 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = sidebar_tree_get_wrapper_at_path (self, _tmp1_);
#line 1133 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp2_;
#line 1134 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 1134 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp3_ == NULL) {
#line 1135 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1135 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1135 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 6964 "Tree.c"
	}
#line 1137 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = wrapper;
#line 1137 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = _tmp4_->entry;
#line 1137 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, SIDEBAR_TYPE_RENAMEABLE_ENTRY) ? ((SidebarRenameableEntry*) _tmp5_) : NULL);
#line 1137 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	renameable = _tmp6_;
#line 1138 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = renameable;
#line 1138 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp7_ == NULL) {
#line 1139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (renameable);
#line 1139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1139 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 6986 "Tree.c"
	}
#line 1141 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp8_ = wrapper;
#line 1141 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp9_ = _tmp8_->entry;
#line 1141 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, SIDEBAR_TYPE_HEADER)) {
#line 1142 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1142 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (renameable);
#line 1142 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1142 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 7002 "Tree.c"
	}
#line 1144 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp10_ = gtk_tree_view_get_selection (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_tree_view_get_type (), GtkTreeView));
#line 1144 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp11_ = path;
#line 1144 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	gtk_tree_selection_select_path (_tmp10_, _tmp11_);
#line 1146 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 1146 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (renameable);
#line 1146 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 1146 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 7018 "Tree.c"
}


static gboolean sidebar_tree_destroy_path (SidebarTree* self, GtkTreePath* path) {
	gboolean result = FALSE;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreePath* _tmp0_;
	SidebarTreeEntryWrapper* _tmp1_;
	SidebarTreeEntryWrapper* _tmp2_;
	SidebarDestroyableEntry* destroyable = NULL;
	SidebarTreeEntryWrapper* _tmp3_;
	SidebarEntry* _tmp4_;
	SidebarDestroyableEntry* _tmp5_;
	SidebarDestroyableEntry* _tmp6_;
	SidebarDestroyableEntry* _tmp7_;
#line 1149 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 1149 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 1150 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = path;
#line 1150 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_wrapper_at_path (self, _tmp0_);
#line 1150 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp1_;
#line 1151 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = wrapper;
#line 1151 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp2_ == NULL) {
#line 1152 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1152 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1152 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 7054 "Tree.c"
	}
#line 1154 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = wrapper;
#line 1154 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_->entry;
#line 1154 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, SIDEBAR_TYPE_DESTROYABLE_ENTRY) ? ((SidebarDestroyableEntry*) _tmp4_) : NULL);
#line 1154 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	destroyable = _tmp5_;
#line 1155 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = destroyable;
#line 1155 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp6_ == NULL) {
#line 1156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		result = FALSE;
#line 1156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (destroyable);
#line 1156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (wrapper);
#line 1156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		return result;
#line 7076 "Tree.c"
	}
#line 1158 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp7_ = destroyable;
#line 1158 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_destroyable_entry_destroy_source (_tmp7_);
#line 1160 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = TRUE;
#line 1160 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (destroyable);
#line 1160 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 1160 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 7090 "Tree.c"
}


static void _sidebar_tree_on_editing_done_gtk_cell_editable_editing_done (GtkCellEditable* _sender, gpointer self) {
#line 1166 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_on_editing_done ((SidebarTree*) self);
#line 7097 "Tree.c"
}


static gboolean _sidebar_tree_on_editing_focus_out_gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self) {
	gboolean result;
	result = sidebar_tree_on_editing_focus_out ((SidebarTree*) self, event);
#line 1167 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 7106 "Tree.c"
}


static void sidebar_tree_on_editing_started (SidebarTree* self, GtkCellEditable* editable, const gchar* path) {
	GtkCellEditable* _tmp0_;
#line 1163 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 1163 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (GTK_IS_CELL_EDITABLE (editable));
#line 1163 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (path != NULL);
#line 1164 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = editable;
#line 1164 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_entry_get_type ())) {
#line 7122 "Tree.c"
		GtkCellEditable* _tmp1_;
		GtkEntry* _tmp2_;
		GtkEntry* _tmp3_;
		GtkEntry* _tmp4_;
		GtkEntry* _tmp5_;
#line 1165 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp1_ = editable;
#line 1165 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_entry_get_type (), GtkEntry));
#line 1165 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (self->priv->text_entry);
#line 1165 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		self->priv->text_entry = _tmp2_;
#line 1166 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp3_ = self->priv->text_entry;
#line 1166 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GTK_TYPE_CELL_EDITABLE, GtkCellEditable), "editing-done", (GCallback) _sidebar_tree_on_editing_done_gtk_cell_editable_editing_done, self, 0);
#line 1167 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp4_ = self->priv->text_entry;
#line 1167 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget), "focus-out-event", (GCallback) _sidebar_tree_on_editing_focus_out_gtk_widget_focus_out_event, self, 0);
#line 1168 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp5_ = self->priv->text_entry;
#line 1168 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		g_object_set (_tmp5_, "editable", TRUE, NULL);
#line 7148 "Tree.c"
	}
}


static void sidebar_tree_on_editing_canceled (SidebarTree* self) {
	GtkEntry* _tmp0_;
	GtkEntry* _tmp1_;
	guint _tmp2_;
	GtkEntry* _tmp3_;
	guint _tmp4_;
#line 1172 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 1173 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->text_entry;
#line 1173 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_set (_tmp0_, "editable", FALSE, NULL);
#line 1175 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = self->priv->text_entry;
#line 1175 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("editing-done", GTK_TYPE_CELL_EDITABLE, &_tmp2_, NULL, FALSE);
#line 1175 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GTK_TYPE_CELL_EDITABLE, GtkCellEditable), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp2_, 0, NULL, (GCallback) _sidebar_tree_on_editing_done_gtk_cell_editable_editing_done, self);
#line 1176 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = self->priv->text_entry;
#line 1176 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("focus-out-event", gtk_widget_get_type (), &_tmp4_, NULL, FALSE);
#line 1176 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp4_, 0, NULL, (GCallback) _sidebar_tree_on_editing_focus_out_gtk_widget_focus_out_event, self);
#line 7177 "Tree.c"
}


static void sidebar_tree_on_editing_done (SidebarTree* self) {
	GtkEntry* _tmp0_;
	SidebarTreeEntryWrapper* wrapper = NULL;
	GtkTreePath* _tmp1_;
	GtkTreePath* _tmp2_;
	SidebarTreeEntryWrapper* _tmp3_;
	SidebarTreeEntryWrapper* _tmp4_;
	SidebarTreeEntryWrapper* _tmp5_;
	GtkEntry* _tmp13_;
	guint _tmp14_;
	GtkEntry* _tmp15_;
	guint _tmp16_;
#line 1179 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 1180 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->text_entry;
#line 1180 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_object_set (_tmp0_, "editable", FALSE, NULL);
#line 1182 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = sidebar_tree_get_current_path (self);
#line 1182 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _tmp1_;
#line 1182 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = sidebar_tree_get_wrapper_at_path (self, _tmp2_);
#line 1182 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_;
#line 1182 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (_tmp2_);
#line 1182 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	wrapper = _tmp4_;
#line 1183 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = wrapper;
#line 1183 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (_tmp5_ != NULL) {
#line 7215 "Tree.c"
		SidebarRenameableEntry* renameable = NULL;
		SidebarTreeEntryWrapper* _tmp6_;
		SidebarEntry* _tmp7_;
		SidebarRenameableEntry* _tmp8_;
		SidebarRenameableEntry* _tmp9_;
#line 1184 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp6_ = wrapper;
#line 1184 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp7_ = _tmp6_->entry;
#line 1184 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, SIDEBAR_TYPE_RENAMEABLE_ENTRY) ? ((SidebarRenameableEntry*) _tmp7_) : NULL);
#line 1184 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		renameable = _tmp8_;
#line 1185 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_tmp9_ = renameable;
#line 1185 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		if (_tmp9_ != NULL) {
#line 7233 "Tree.c"
			SidebarRenameableEntry* _tmp10_;
			GtkEntry* _tmp11_;
			const gchar* _tmp12_;
#line 1186 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp10_ = renameable;
#line 1186 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp11_ = self->priv->text_entry;
#line 1186 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			_tmp12_ = gtk_entry_get_text (_tmp11_);
#line 1186 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
			sidebar_renameable_entry_rename (_tmp10_, _tmp12_);
#line 7245 "Tree.c"
		}
#line 1183 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		_g_object_unref0 (renameable);
#line 7249 "Tree.c"
	}
#line 1189 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp13_ = self->priv->text_entry;
#line 1189 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("editing-done", GTK_TYPE_CELL_EDITABLE, &_tmp14_, NULL, FALSE);
#line 1189 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GTK_TYPE_CELL_EDITABLE, GtkCellEditable), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp14_, 0, NULL, (GCallback) _sidebar_tree_on_editing_done_gtk_cell_editable_editing_done, self);
#line 1190 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp15_ = self->priv->text_entry;
#line 1190 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("focus-out-event", gtk_widget_get_type (), &_tmp16_, NULL, FALSE);
#line 1190 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_widget_get_type (), GtkWidget), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp16_, 0, NULL, (GCallback) _sidebar_tree_on_editing_focus_out_gtk_widget_focus_out_event, self);
#line 1179 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (wrapper);
#line 7265 "Tree.c"
}


static gboolean sidebar_tree_on_editing_focus_out (SidebarTree* self, GdkEventFocus* event) {
	gboolean result = FALSE;
#line 1193 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_TREE (self), FALSE);
#line 1193 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 1197 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = FALSE;
#line 1197 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 7279 "Tree.c"
}


static void sidebar_tree_on_new_search (SidebarTree* self) {
	SavedSearchDialog* _tmp0_;
	SavedSearchDialog* _tmp1_;
#line 1200 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 1201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = saved_search_dialog_new ();
#line 1201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _tmp0_;
#line 1201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	saved_search_dialog_show (_tmp1_);
#line 1201 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_saved_search_dialog_unref0 (_tmp1_);
#line 7296 "Tree.c"
}


static void sidebar_tree_on_new_tag (SidebarTree* self) {
	NewRootTagCommand* creation_command = NULL;
	NewRootTagCommand* _tmp0_;
	CommandManager* _tmp1_;
	CommandManager* _tmp2_;
	LibraryWindow* _tmp3_;
	LibraryWindow* _tmp4_;
	Tag* _tmp5_;
	Tag* _tmp6_;
#line 1204 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_IS_TREE (self));
#line 1205 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = new_root_tag_command_new ();
#line 1205 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	creation_command = _tmp0_;
#line 1206 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = app_window_get_command_manager ();
#line 1206 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = _tmp1_;
#line 1206 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	command_manager_execute (_tmp2_, G_TYPE_CHECK_INSTANCE_CAST (creation_command, TYPE_COMMAND, Command));
#line 1206 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_command_manager_unref0 (_tmp2_);
#line 1207 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = library_window_get_app ();
#line 1207 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = _tmp3_;
#line 1207 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = new_root_tag_command_get_created_tag (creation_command);
#line 1207 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = _tmp5_;
#line 1207 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	library_window_rename_tag_in_sidebar (_tmp4_, _tmp6_);
#line 1207 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp6_);
#line 1207 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (_tmp4_);
#line 1204 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (creation_command);
#line 7339 "Tree.c"
}


static void g_cclosure_user_marshal_VOID__OBJECT_BOOLEAN (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__OBJECT_BOOLEAN) (gpointer data1, gpointer arg_1, gboolean arg_2, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_BOOLEAN callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (n_param_values == 3);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data1 = closure->data;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data2 = param_values->data[0].v_pointer;
#line 7358 "Tree.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data1 = param_values->data[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data2 = closure->data;
#line 7364 "Tree.c"
	}
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	callback = (GMarshalFunc_VOID__OBJECT_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	callback (data1, g_value_get_object (param_values + 1), g_value_get_boolean (param_values + 2), data2);
#line 7370 "Tree.c"
}


static void g_cclosure_user_marshal_VOID__OBJECT_OBJECT (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__OBJECT_OBJECT) (gpointer data1, gpointer arg_1, gpointer arg_2, gpointer data2);
	register GMarshalFunc_VOID__OBJECT_OBJECT callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (n_param_values == 3);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data1 = closure->data;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data2 = param_values->data[0].v_pointer;
#line 7389 "Tree.c"
	} else {
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data1 = param_values->data[0].v_pointer;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
		data2 = closure->data;
#line 7395 "Tree.c"
	}
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	callback = (GMarshalFunc_VOID__OBJECT_OBJECT) (marshal_data ? marshal_data : cc->callback);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	callback (data1, g_value_get_object (param_values + 1), g_value_get_object (param_values + 2), data2);
#line 7401 "Tree.c"
}


static SidebarTreeEntryWrapper* sidebar_tree_entry_wrapper_construct (GType object_type, GtkTreeModel* model, SidebarEntry* entry, GtkTreePath* path) {
	SidebarTreeEntryWrapper * self = NULL;
	SidebarEntry* _tmp0_;
	SidebarEntry* _tmp1_;
	GtkTreeModel* _tmp2_;
	GtkTreePath* _tmp3_;
	GtkTreeRowReference* _tmp4_;
#line 19 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (GTK_IS_TREE_MODEL (model), NULL);
#line 19 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), NULL);
#line 19 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 19 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = (SidebarTreeEntryWrapper*) g_object_new (object_type, NULL);
#line 20 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = entry;
#line 20 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 20 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->entry);
#line 20 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->entry = _tmp1_;
#line 21 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = model;
#line 21 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = path;
#line 21 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp4_ = gtk_tree_row_reference_new (_tmp2_, _tmp3_);
#line 21 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_row_reference_free0 (self->row);
#line 21 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->row = _tmp4_;
#line 19 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return self;
#line 7440 "Tree.c"
}


static SidebarTreeEntryWrapper* sidebar_tree_entry_wrapper_new (GtkTreeModel* model, SidebarEntry* entry, GtkTreePath* path) {
#line 19 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return sidebar_tree_entry_wrapper_construct (SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, model, entry, path);
#line 7447 "Tree.c"
}


static GtkTreePath* sidebar_tree_entry_wrapper_get_path (SidebarTreeEntryWrapper* self) {
	GtkTreePath* result = NULL;
	const GtkTreeRowReference* _tmp0_;
	GtkTreePath* _tmp1_;
#line 24 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_TREE_IS_ENTRY_WRAPPER (self), NULL);
#line 25 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->row;
#line 25 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_tree_row_reference_get_path (_tmp0_);
#line 25 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	result = _tmp1_;
#line 25 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return result;
#line 7465 "Tree.c"
}


static void sidebar_tree_entry_wrapper_get_iter (SidebarTreeEntryWrapper* self, GtkTreeIter* result) {
	GtkTreeIter iter = {0};
	gboolean valid = FALSE;
	const GtkTreeRowReference* _tmp0_;
	GtkTreeModel* _tmp1_;
	GtkTreePath* _tmp2_;
	GtkTreePath* _tmp3_;
	GtkTreeIter _tmp4_ = {0};
	gboolean _tmp5_;
	gboolean _tmp6_;
#line 28 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_if_fail (SIDEBAR_TREE_IS_ENTRY_WRAPPER (self));
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->row;
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_tree_row_reference_get_model (_tmp0_);
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = sidebar_tree_entry_wrapper_get_path (self);
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = _tmp2_;
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp5_ = gtk_tree_model_get_iter (_tmp1_, &_tmp4_, _tmp3_);
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	iter = _tmp4_;
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp6_ = _tmp5_;
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_path_free0 (_tmp3_);
#line 30 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	valid = _tmp6_;
#line 31 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_vala_assert (valid, "valid");
#line 33 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	*result = iter;
#line 33 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return;
#line 7505 "Tree.c"
}


static void sidebar_tree_entry_wrapper_class_init (SidebarTreeEntryWrapperClass * klass) {
#line 15 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_entry_wrapper_parent_class = g_type_class_peek_parent (klass);
#line 15 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_OBJECT_CLASS (klass)->finalize = sidebar_tree_entry_wrapper_finalize;
#line 7514 "Tree.c"
}


static void sidebar_tree_entry_wrapper_instance_init (SidebarTreeEntryWrapper * self) {
}


static void sidebar_tree_entry_wrapper_finalize (GObject * obj) {
	SidebarTreeEntryWrapper * self;
#line 15 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, SidebarTreeEntryWrapper);
#line 16 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->entry);
#line 17 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_row_reference_free0 (self->row);
#line 15 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_OBJECT_CLASS (sidebar_tree_entry_wrapper_parent_class)->finalize (obj);
#line 7532 "Tree.c"
}


static GType sidebar_tree_entry_wrapper_get_type (void) {
	static volatile gsize sidebar_tree_entry_wrapper_type_id__volatile = 0;
	if (g_once_init_enter (&sidebar_tree_entry_wrapper_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SidebarTreeEntryWrapperClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) sidebar_tree_entry_wrapper_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SidebarTreeEntryWrapper), 0, (GInstanceInitFunc) sidebar_tree_entry_wrapper_instance_init, NULL };
		GType sidebar_tree_entry_wrapper_type_id;
		sidebar_tree_entry_wrapper_type_id = g_type_register_static (G_TYPE_OBJECT, "SidebarTreeEntryWrapper", &g_define_type_info, 0);
		g_once_init_leave (&sidebar_tree_entry_wrapper_type_id__volatile, sidebar_tree_entry_wrapper_type_id);
	}
	return sidebar_tree_entry_wrapper_type_id__volatile;
}


static SidebarTreeRootWrapper* sidebar_tree_root_wrapper_construct (GType object_type, GtkTreeModel* model, SidebarEntry* entry, GtkTreePath* path, gint root_position) {
	SidebarTreeRootWrapper * self = NULL;
	GtkTreeModel* _tmp0_;
	SidebarEntry* _tmp1_;
	GtkTreePath* _tmp2_;
	gint _tmp3_;
#line 40 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (GTK_IS_TREE_MODEL (model), NULL);
#line 40 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (SIDEBAR_IS_ENTRY (entry), NULL);
#line 40 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 41 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = model;
#line 41 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = entry;
#line 41 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = path;
#line 41 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = (SidebarTreeRootWrapper*) sidebar_tree_entry_wrapper_construct (object_type, _tmp0_, _tmp1_, _tmp2_);
#line 43 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = root_position;
#line 43 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->root_position = _tmp3_;
#line 40 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return self;
#line 7574 "Tree.c"
}


static SidebarTreeRootWrapper* sidebar_tree_root_wrapper_new (GtkTreeModel* model, SidebarEntry* entry, GtkTreePath* path, gint root_position) {
#line 40 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	return sidebar_tree_root_wrapper_construct (SIDEBAR_TREE_TYPE_ROOT_WRAPPER, model, entry, path, root_position);
#line 7581 "Tree.c"
}


static void sidebar_tree_root_wrapper_class_init (SidebarTreeRootWrapperClass * klass) {
#line 37 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_root_wrapper_parent_class = g_type_class_peek_parent (klass);
#line 37 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_OBJECT_CLASS (klass)->finalize = sidebar_tree_root_wrapper_finalize;
#line 7590 "Tree.c"
}


static void sidebar_tree_root_wrapper_instance_init (SidebarTreeRootWrapper * self) {
}


static void sidebar_tree_root_wrapper_finalize (GObject * obj) {
	SidebarTreeRootWrapper * self;
#line 37 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SIDEBAR_TREE_TYPE_ROOT_WRAPPER, SidebarTreeRootWrapper);
#line 37 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_OBJECT_CLASS (sidebar_tree_root_wrapper_parent_class)->finalize (obj);
#line 7604 "Tree.c"
}


static GType sidebar_tree_root_wrapper_get_type (void) {
	static volatile gsize sidebar_tree_root_wrapper_type_id__volatile = 0;
	if (g_once_init_enter (&sidebar_tree_root_wrapper_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SidebarTreeRootWrapperClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) sidebar_tree_root_wrapper_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SidebarTreeRootWrapper), 0, (GInstanceInitFunc) sidebar_tree_root_wrapper_instance_init, NULL };
		GType sidebar_tree_root_wrapper_type_id;
		sidebar_tree_root_wrapper_type_id = g_type_register_static (SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, "SidebarTreeRootWrapper", &g_define_type_info, 0);
		g_once_init_leave (&sidebar_tree_root_wrapper_type_id__volatile, sidebar_tree_root_wrapper_type_id);
	}
	return sidebar_tree_root_wrapper_type_id__volatile;
}


static void sidebar_tree_class_init (SidebarTreeClass * klass) {
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_type_class_add_private (klass, sizeof (SidebarTreePrivate));
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((SidebarTreeClass *) klass)->accept_cursor_changed = (gboolean (*) (SidebarTree *)) sidebar_tree_real_accept_cursor_changed;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((GtkTreeViewClass *) klass)->cursor_changed = (void (*) (GtkTreeView *)) sidebar_tree_real_cursor_changed;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((GtkWidgetClass *) klass)->button_press_event = (gboolean (*) (GtkWidget *, GdkEventButton*)) sidebar_tree_real_button_press_event;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((GtkWidgetClass *) klass)->key_press_event = (gboolean (*) (GtkWidget *, GdkEventKey*)) sidebar_tree_real_key_press_event;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((GtkWidgetClass *) klass)->drag_data_get = (void (*) (GtkWidget *, GdkDragContext*, GtkSelectionData*, guint, guint)) sidebar_tree_real_drag_data_get;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((GtkWidgetClass *) klass)->drag_data_received = (void (*) (GtkWidget *, GdkDragContext*, gint, gint, GtkSelectionData*, guint, guint)) sidebar_tree_real_drag_data_received;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	((GtkWidgetClass *) klass)->drag_motion = (gboolean (*) (GtkWidget *, GdkDragContext*, gint, gint, guint)) sidebar_tree_real_drag_motion;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_OBJECT_CLASS (klass)->finalize = sidebar_tree_finalize;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_ENTRY_SELECTED_SIGNAL] = g_signal_new ("entry-selected", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, SIDEBAR_TYPE_SELECTABLE_ENTRY);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_SELECTED_ENTRY_REMOVED_SIGNAL] = g_signal_new ("selected-entry-removed", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, SIDEBAR_TYPE_SELECTABLE_ENTRY);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_BRANCH_ADDED_SIGNAL] = g_signal_new ("branch-added", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, SIDEBAR_TYPE_BRANCH);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_BRANCH_REMOVED_SIGNAL] = g_signal_new ("branch-removed", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, SIDEBAR_TYPE_BRANCH);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_BRANCH_SHOWN_SIGNAL] = g_signal_new ("branch-shown", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_BOOLEAN, G_TYPE_NONE, 2, SIDEBAR_TYPE_BRANCH, G_TYPE_BOOLEAN);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_PAGE_CREATED_SIGNAL] = g_signal_new ("page-created", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_OBJECT, G_TYPE_NONE, 2, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, TYPE_PAGE);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	sidebar_tree_signals[SIDEBAR_TREE_DESTROYING_PAGE_SIGNAL] = g_signal_new ("destroying-page", SIDEBAR_TYPE_TREE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__OBJECT_OBJECT, G_TYPE_NONE, 2, SIDEBAR_TYPE_PAGE_REPRESENTATIVE, TYPE_PAGE);
#line 7655 "Tree.c"
}


static void sidebar_tree_instance_init (SidebarTree * self) {
	GtkTreeStore* _tmp0_;
	GtkBuilder* _tmp1_;
	GeeHashMap* _tmp2_;
	GeeHashMap* _tmp3_;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv = SIDEBAR_TREE_GET_PRIVATE (self);
#line 55 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = gtk_tree_store_new ((gint) SIDEBAR_TREE_COLUMNS_N_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, G_TYPE_STRING);
#line 55 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->store = _tmp0_;
#line 62 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp1_ = gtk_builder_new ();
#line 62 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->builder = _tmp1_;
#line 65 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->text_entry = NULL;
#line 66 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = gee_hash_map_new (SIDEBAR_TYPE_ENTRY, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, SIDEBAR_TREE_TYPE_ENTRY_WRAPPER, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 66 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->entry_map = _tmp2_;
#line 68 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp3_ = gee_hash_map_new (SIDEBAR_TYPE_BRANCH, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, G_TYPE_INT, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 68 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->branches = _tmp3_;
#line 69 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->editing_disabled = 0;
#line 70 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->mask_entry_selected_signal = FALSE;
#line 71 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->selected_wrapper = NULL;
#line 72 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->default_context_menu = NULL;
#line 73 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->expander_called_manually = FALSE;
#line 74 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->expander_special_count = 0;
#line 75 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->is_internal_drag_in_progress = FALSE;
#line 76 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->internal_drag_source_entry = NULL;
#line 77 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self->priv->old_path_ref = NULL;
#line 7702 "Tree.c"
}


static void sidebar_tree_finalize (GObject * obj) {
	SidebarTree * self;
	GtkCellRendererText* _tmp0_;
	guint _tmp1_;
	GtkCellRendererText* _tmp2_;
	guint _tmp3_;
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SIDEBAR_TYPE_TREE, SidebarTree);
#line 156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp0_ = self->priv->text_renderer;
#line 156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("editing-canceled", gtk_cell_renderer_get_type (), &_tmp1_, NULL, FALSE);
#line 156 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_cell_renderer_get_type (), GtkCellRenderer), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _sidebar_tree_on_editing_canceled_gtk_cell_renderer_editing_canceled, self);
#line 157 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_tmp2_ = self->priv->text_renderer;
#line 157 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_parse_name ("editing-started", gtk_cell_renderer_get_type (), &_tmp3_, NULL, FALSE);
#line 157 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_cell_renderer_get_type (), GtkCellRenderer), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _sidebar_tree_on_editing_started_gtk_cell_renderer_editing_started, self);
#line 55 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->store);
#line 62 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->builder);
#line 63 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->text_renderer);
#line 65 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->text_entry);
#line 66 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->entry_map);
#line 68 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->branches);
#line 72 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->default_context_menu);
#line 76 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_g_object_unref0 (self->priv->internal_drag_source_entry);
#line 77 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	_gtk_tree_row_reference_free0 (self->priv->old_path_ref);
#line 7 "/home/jens/Source/shotwell/src/sidebar/Tree.vala"
	G_OBJECT_CLASS (sidebar_tree_parent_class)->finalize (obj);
#line 7746 "Tree.c"
}


GType sidebar_tree_get_type (void) {
	static volatile gsize sidebar_tree_type_id__volatile = 0;
	if (g_once_init_enter (&sidebar_tree_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SidebarTreeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) sidebar_tree_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SidebarTree), 0, (GInstanceInitFunc) sidebar_tree_instance_init, NULL };
		GType sidebar_tree_type_id;
		sidebar_tree_type_id = g_type_register_static (gtk_tree_view_get_type (), "SidebarTree", &g_define_type_info, 0);
		g_once_init_leave (&sidebar_tree_type_id__volatile, sidebar_tree_type_id);
	}
	return sidebar_tree_type_id__volatile;
}



