/* PicasaPublishing.c generated by valac 0.36.6, the Vala compiler
 * generated from PicasaPublishing.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include "shotwell-plugin-common.h"
#include <glib/gi18n-lib.h>
#include <libxml/tree.h>
#include <float.h>
#include <math.h>
#include <gtk/gtk.h>
#include "shotwell-authenticator.h"
#include <libsoup/soup.h>
#include <gobject/gvaluecollector.h>


#define TYPE_PICASA_SERVICE (picasa_service_get_type ())
#define PICASA_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PICASA_SERVICE, PicasaService))
#define PICASA_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PICASA_SERVICE, PicasaServiceClass))
#define IS_PICASA_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PICASA_SERVICE))
#define IS_PICASA_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PICASA_SERVICE))
#define PICASA_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PICASA_SERVICE, PicasaServiceClass))

typedef struct _PicasaService PicasaService;
typedef struct _PicasaServiceClass PicasaServiceClass;
typedef struct _PicasaServicePrivate PicasaServicePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER (publishing_picasa_picasa_publisher_get_type ())
#define PUBLISHING_PICASA_PICASA_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER, PublishingPicasaPicasaPublisher))
#define PUBLISHING_PICASA_PICASA_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER, PublishingPicasaPicasaPublisherClass))
#define PUBLISHING_PICASA_IS_PICASA_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER))
#define PUBLISHING_PICASA_IS_PICASA_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER))
#define PUBLISHING_PICASA_PICASA_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER, PublishingPicasaPicasaPublisherClass))

typedef struct _PublishingPicasaPicasaPublisher PublishingPicasaPicasaPublisher;
typedef struct _PublishingPicasaPicasaPublisherClass PublishingPicasaPicasaPublisherClass;
typedef struct _PublishingPicasaPicasaPublisherPrivate PublishingPicasaPicasaPublisherPrivate;

#define PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS (publishing_picasa_publishing_parameters_get_type ())
#define PUBLISHING_PICASA_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS, PublishingPicasaPublishingParameters))
#define PUBLISHING_PICASA_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS, PublishingPicasaPublishingParametersClass))
#define PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_PICASA_PUBLISHING_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS, PublishingPicasaPublishingParametersClass))

typedef struct _PublishingPicasaPublishingParameters PublishingPicasaPublishingParameters;
typedef struct _PublishingPicasaPublishingParametersClass PublishingPicasaPublishingParametersClass;
#define _publishing_picasa_publishing_parameters_unref0(var) ((var == NULL) ? NULL : (var = (publishing_picasa_publishing_parameters_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define PUBLISHING_PICASA_TYPE_ALBUM (publishing_picasa_album_get_type ())
#define PUBLISHING_PICASA_ALBUM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PICASA_TYPE_ALBUM, PublishingPicasaAlbum))
#define PUBLISHING_PICASA_ALBUM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PICASA_TYPE_ALBUM, PublishingPicasaAlbumClass))
#define PUBLISHING_PICASA_IS_ALBUM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PICASA_TYPE_ALBUM))
#define PUBLISHING_PICASA_IS_ALBUM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PICASA_TYPE_ALBUM))
#define PUBLISHING_PICASA_ALBUM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PICASA_TYPE_ALBUM, PublishingPicasaAlbumClass))

typedef struct _PublishingPicasaAlbum PublishingPicasaAlbum;
typedef struct _PublishingPicasaAlbumClass PublishingPicasaAlbumClass;
#define _publishing_rest_support_session_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_session_unref (var), NULL)))

#define PUBLISHING_PICASA_TYPE_ALBUM_DIRECTORY_TRANSACTION (publishing_picasa_album_directory_transaction_get_type ())
#define PUBLISHING_PICASA_ALBUM_DIRECTORY_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PICASA_TYPE_ALBUM_DIRECTORY_TRANSACTION, PublishingPicasaAlbumDirectoryTransaction))
#define PUBLISHING_PICASA_ALBUM_DIRECTORY_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PICASA_TYPE_ALBUM_DIRECTORY_TRANSACTION, PublishingPicasaAlbumDirectoryTransactionClass))
#define PUBLISHING_PICASA_IS_ALBUM_DIRECTORY_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PICASA_TYPE_ALBUM_DIRECTORY_TRANSACTION))
#define PUBLISHING_PICASA_IS_ALBUM_DIRECTORY_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PICASA_TYPE_ALBUM_DIRECTORY_TRANSACTION))
#define PUBLISHING_PICASA_ALBUM_DIRECTORY_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PICASA_TYPE_ALBUM_DIRECTORY_TRANSACTION, PublishingPicasaAlbumDirectoryTransactionClass))

typedef struct _PublishingPicasaAlbumDirectoryTransaction PublishingPicasaAlbumDirectoryTransaction;
typedef struct _PublishingPicasaAlbumDirectoryTransactionClass PublishingPicasaAlbumDirectoryTransactionClass;
#define _publishing_rest_support_transaction_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_transaction_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _publishing_rest_support_xml_document_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_xml_document_unref (var), NULL)))

#define PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE (publishing_picasa_publishing_options_pane_get_type ())
#define PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPicasaPublishingOptionsPane))
#define PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPicasaPublishingOptionsPaneClass))
#define PUBLISHING_PICASA_IS_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_PICASA_IS_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPicasaPublishingOptionsPaneClass))

typedef struct _PublishingPicasaPublishingOptionsPane PublishingPicasaPublishingOptionsPane;
typedef struct _PublishingPicasaPublishingOptionsPaneClass PublishingPicasaPublishingOptionsPaneClass;

#define PUBLISHING_PICASA_TYPE_UPLOADER (publishing_picasa_uploader_get_type ())
#define PUBLISHING_PICASA_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PICASA_TYPE_UPLOADER, PublishingPicasaUploader))
#define PUBLISHING_PICASA_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PICASA_TYPE_UPLOADER, PublishingPicasaUploaderClass))
#define PUBLISHING_PICASA_IS_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PICASA_TYPE_UPLOADER))
#define PUBLISHING_PICASA_IS_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PICASA_TYPE_UPLOADER))
#define PUBLISHING_PICASA_UPLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PICASA_TYPE_UPLOADER, PublishingPicasaUploaderClass))

typedef struct _PublishingPicasaUploader PublishingPicasaUploader;
typedef struct _PublishingPicasaUploaderClass PublishingPicasaUploaderClass;
#define _publishing_rest_support_batch_uploader_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_batch_uploader_unref (var), NULL)))
typedef struct _PublishingPicasaAlbumPrivate PublishingPicasaAlbumPrivate;
typedef struct _PublishingPicasaParamSpecAlbum PublishingPicasaParamSpecAlbum;
typedef struct _PublishingPicasaAlbumDirectoryTransactionPrivate PublishingPicasaAlbumDirectoryTransactionPrivate;

#define PUBLISHING_PICASA_TYPE_UPLOAD_TRANSACTION (publishing_picasa_upload_transaction_get_type ())
#define PUBLISHING_PICASA_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PICASA_TYPE_UPLOAD_TRANSACTION, PublishingPicasaUploadTransaction))
#define PUBLISHING_PICASA_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PICASA_TYPE_UPLOAD_TRANSACTION, PublishingPicasaUploadTransactionClass))
#define PUBLISHING_PICASA_IS_UPLOAD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PICASA_TYPE_UPLOAD_TRANSACTION))
#define PUBLISHING_PICASA_IS_UPLOAD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PICASA_TYPE_UPLOAD_TRANSACTION))
#define PUBLISHING_PICASA_UPLOAD_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PICASA_TYPE_UPLOAD_TRANSACTION, PublishingPicasaUploadTransactionClass))

typedef struct _PublishingPicasaUploadTransaction PublishingPicasaUploadTransaction;
typedef struct _PublishingPicasaUploadTransactionClass PublishingPicasaUploadTransactionClass;
typedef struct _PublishingPicasaUploadTransactionPrivate PublishingPicasaUploadTransactionPrivate;
#define _g_mapped_file_unref0(var) ((var == NULL) ? NULL : (var = (g_mapped_file_unref (var), NULL)))
#define __vala_SoupBuffer_free0(var) ((var == NULL) ? NULL : (var = (_vala_SoupBuffer_free (var), NULL)))
#define __vala_SoupMultipart_free0(var) ((var == NULL) ? NULL : (var = (_vala_SoupMultipart_free (var), NULL)))
typedef struct _PublishingPicasaPublishingOptionsPanePrivate PublishingPicasaPublishingOptionsPanePrivate;

#define PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION (publishing_picasa_publishing_options_pane_size_description_get_type ())
#define PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_SIZE_DESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION, PublishingPicasaPublishingOptionsPaneSizeDescription))
#define PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_SIZE_DESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION, PublishingPicasaPublishingOptionsPaneSizeDescriptionClass))
#define PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_IS_SIZE_DESCRIPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION))
#define PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_IS_SIZE_DESCRIPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION))
#define PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_SIZE_DESCRIPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION, PublishingPicasaPublishingOptionsPaneSizeDescriptionClass))

typedef struct _PublishingPicasaPublishingOptionsPaneSizeDescription PublishingPicasaPublishingOptionsPaneSizeDescription;
typedef struct _PublishingPicasaPublishingOptionsPaneSizeDescriptionClass PublishingPicasaPublishingOptionsPaneSizeDescriptionClass;
#define _g_slist_free0(var) ((var == NULL) ? NULL : (var = (g_slist_free (var), NULL)))
typedef struct _PublishingPicasaPublishingOptionsPaneSizeDescriptionPrivate PublishingPicasaPublishingOptionsPaneSizeDescriptionPrivate;
#define _publishing_picasa_publishing_options_pane_size_description_unref0(var) ((var == NULL) ? NULL : (var = (publishing_picasa_publishing_options_pane_size_description_unref (var), NULL)))
typedef struct _PublishingPicasaPublishingOptionsPaneParamSpecSizeDescription PublishingPicasaPublishingOptionsPaneParamSpecSizeDescription;
enum  {
	PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL,
	PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL,
	PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_LAST_SIGNAL
};
static guint publishing_picasa_publishing_options_pane_signals[PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_LAST_SIGNAL] = {0};
typedef struct _PublishingPicasaPublishingParametersPrivate PublishingPicasaPublishingParametersPrivate;
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
typedef struct _PublishingPicasaParamSpecPublishingParameters PublishingPicasaParamSpecPublishingParameters;
typedef struct _PublishingPicasaUploaderPrivate PublishingPicasaUploaderPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PicasaService {
	GObject parent_instance;
	PicasaServicePrivate * priv;
};

struct _PicasaServiceClass {
	GObjectClass parent_class;
};

struct _PublishingPicasaPicasaPublisher {
	PublishingRESTSupportGooglePublisher parent_instance;
	PublishingPicasaPicasaPublisherPrivate * priv;
};

struct _PublishingPicasaPicasaPublisherClass {
	PublishingRESTSupportGooglePublisherClass parent_class;
};

struct _PublishingPicasaPicasaPublisherPrivate {
	gboolean running;
	SpitPublishingProgressCallback progress_reporter;
	gpointer progress_reporter_target;
	GDestroyNotify progress_reporter_target_destroy_notify;
	PublishingPicasaPublishingParameters* publishing_parameters;
	SpitPublishingAuthenticator* authenticator;
};

struct _PublishingPicasaAlbum {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingPicasaAlbumPrivate * priv;
	gchar* name;
	gchar* url;
};

struct _PublishingPicasaAlbumClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingPicasaAlbum *self);
};

struct _PublishingPicasaParamSpecAlbum {
	GParamSpec parent_instance;
};

struct _PublishingPicasaAlbumDirectoryTransaction {
	PublishingRESTSupportGooglePublisherAuthenticatedTransaction parent_instance;
	PublishingPicasaAlbumDirectoryTransactionPrivate * priv;
};

struct _PublishingPicasaAlbumDirectoryTransactionClass {
	PublishingRESTSupportGooglePublisherAuthenticatedTransactionClass parent_class;
};

struct _PublishingPicasaUploadTransaction {
	PublishingRESTSupportGooglePublisherAuthenticatedTransaction parent_instance;
	PublishingPicasaUploadTransactionPrivate * priv;
};

struct _PublishingPicasaUploadTransactionClass {
	PublishingRESTSupportGooglePublisherAuthenticatedTransactionClass parent_class;
};

struct _PublishingPicasaUploadTransactionPrivate {
	PublishingPicasaPublishingParameters* parameters;
	PublishingRESTSupportGoogleSession* session;
	gchar* mime_type;
	SpitPublishingPublishable* publishable;
	GMappedFile* mapped_file;
};

struct _PublishingPicasaPublishingOptionsPane {
	GObject parent_instance;
	PublishingPicasaPublishingOptionsPanePrivate * priv;
};

struct _PublishingPicasaPublishingOptionsPaneClass {
	GObjectClass parent_class;
};

struct _PublishingPicasaPublishingOptionsPanePrivate {
	GtkBuilder* builder;
	GtkBox* pane_widget;
	GtkLabel* login_identity_label;
	GtkLabel* publish_to_label;
	GtkComboBoxText* existing_albums_combo;
	GtkCheckButton* public_check;
	GtkComboBoxText* size_combo;
	GtkCheckButton* strip_metadata_check;
	GtkButton* publish_button;
	GtkButton* logout_button;
	PublishingPicasaPublishingOptionsPaneSizeDescription** size_descriptions;
	gint size_descriptions_length1;
	gint _size_descriptions_size_;
	PublishingPicasaPublishingParameters* parameters;
};

struct _PublishingPicasaPublishingOptionsPaneSizeDescription {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingPicasaPublishingOptionsPaneSizeDescriptionPrivate * priv;
	gchar* name;
	gint major_axis_pixels;
};

struct _PublishingPicasaPublishingOptionsPaneSizeDescriptionClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingPicasaPublishingOptionsPaneSizeDescription *self);
};

struct _PublishingPicasaPublishingOptionsPaneParamSpecSizeDescription {
	GParamSpec parent_instance;
};

struct _PublishingPicasaPublishingParameters {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingPicasaPublishingParametersPrivate * priv;
};

struct _PublishingPicasaPublishingParametersClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingPicasaPublishingParameters *self);
};

struct _PublishingPicasaPublishingParametersPrivate {
	gchar* target_album_name;
	gchar* target_album_url;
	gboolean album_public;
	gboolean strip_metadata;
	gint major_axis_size_pixels;
	gint major_axis_size_selection_id;
	gchar* user_name;
	PublishingPicasaAlbum** albums;
	gint albums_length1;
	gint _albums_size_;
	SpitPublishingPublisherMediaType media_type;
};

struct _PublishingPicasaParamSpecPublishingParameters {
	GParamSpec parent_instance;
};

struct _PublishingPicasaUploader {
	PublishingRESTSupportBatchUploader parent_instance;
	PublishingPicasaUploaderPrivate * priv;
};

struct _PublishingPicasaUploaderClass {
	PublishingRESTSupportBatchUploaderClass parent_class;
};

struct _PublishingPicasaUploaderPrivate {
	PublishingPicasaPublishingParameters* parameters;
};


static gpointer picasa_service_parent_class = NULL;
static GdkPixbuf** picasa_service_icon_pixbuf_set;
static gint picasa_service_icon_pixbuf_set_length1;
static GdkPixbuf** picasa_service_icon_pixbuf_set = NULL;
static gint picasa_service_icon_pixbuf_set_length1 = 0;
static gint _picasa_service_icon_pixbuf_set_size_ = 0;
static SpitPluggableIface * picasa_service_spit_pluggable_parent_iface = NULL;
static SpitPublishingServiceIface * picasa_service_spit_publishing_service_parent_iface = NULL;
static gpointer publishing_picasa_picasa_publisher_parent_class = NULL;
static gpointer publishing_picasa_album_parent_class = NULL;
static gpointer publishing_picasa_album_directory_transaction_parent_class = NULL;
static gpointer publishing_picasa_upload_transaction_parent_class = NULL;
static gpointer publishing_picasa_publishing_options_pane_parent_class = NULL;
static gpointer publishing_picasa_publishing_options_pane_size_description_parent_class = NULL;
static SpitPublishingDialogPaneIface * publishing_picasa_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_picasa_publishing_parameters_parent_class = NULL;
static gpointer publishing_picasa_uploader_parent_class = NULL;

GType picasa_service_get_type (void) G_GNUC_CONST;
enum  {
	PICASA_SERVICE_DUMMY_PROPERTY
};
#define PICASA_SERVICE_ICON_FILENAME "picasa.png"
PicasaService* picasa_service_new (GFile* resource_directory);
PicasaService* picasa_service_construct (GType object_type, GFile* resource_directory);
static gint picasa_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface);
static const gchar* picasa_service_real_get_id (SpitPluggable* base);
static const gchar* picasa_service_real_get_pluggable_name (SpitPluggable* base);
static void picasa_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info);
static GdkPixbuf** _vala_array_dup4 (GdkPixbuf** self, int length);
static SpitPublishingPublisher* picasa_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host);
PublishingPicasaPicasaPublisher* publishing_picasa_picasa_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host);
PublishingPicasaPicasaPublisher* publishing_picasa_picasa_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host);
GType publishing_picasa_picasa_publisher_get_type (void) G_GNUC_CONST;
static SpitPublishingPublisherMediaType picasa_service_real_get_supported_media (SpitPublishingService* base);
static void picasa_service_real_activation (SpitPluggable* base, gboolean enabled);
static void picasa_service_finalize (GObject * obj);
#define PUBLISHING_PICASA_DEFAULT_ALBUM_NAME _ ("Shotwell Connect")
gpointer publishing_picasa_publishing_parameters_ref (gpointer instance);
void publishing_picasa_publishing_parameters_unref (gpointer instance);
GParamSpec* publishing_picasa_param_spec_publishing_parameters (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_picasa_value_set_publishing_parameters (GValue* value, gpointer v_object);
void publishing_picasa_value_take_publishing_parameters (GValue* value, gpointer v_object);
gpointer publishing_picasa_value_get_publishing_parameters (const GValue* value);
GType publishing_picasa_publishing_parameters_get_type (void) G_GNUC_CONST;
#define PUBLISHING_PICASA_PICASA_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER, PublishingPicasaPicasaPublisherPrivate))
enum  {
	PUBLISHING_PICASA_PICASA_PUBLISHER_DUMMY_PROPERTY
};
#define PUBLISHING_PICASA_PICASA_PUBLISHER_DEFAULT_ALBUM_FEED_URL "https://picasaweb.google.com/data/feed/api/user/default/albumid/defaul" \
"t"
PublishingPicasaPublishingParameters* publishing_picasa_publishing_parameters_new (void);
PublishingPicasaPublishingParameters* publishing_picasa_publishing_parameters_construct (GType object_type);
static void publishing_picasa_picasa_publisher_load_parameters_from_configuration_system (PublishingPicasaPicasaPublisher* self, PublishingPicasaPublishingParameters* parameters);
void publishing_picasa_publishing_parameters_set_media_type (PublishingPicasaPublishingParameters* self, SpitPublishingPublisherMediaType media_type);
gpointer publishing_picasa_album_ref (gpointer instance);
void publishing_picasa_album_unref (gpointer instance);
GParamSpec* publishing_picasa_param_spec_album (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_picasa_value_set_album (GValue* value, gpointer v_object);
void publishing_picasa_value_take_album (GValue* value, gpointer v_object);
gpointer publishing_picasa_value_get_album (const GValue* value);
GType publishing_picasa_album_get_type (void) G_GNUC_CONST;
static PublishingPicasaAlbum** publishing_picasa_picasa_publisher_extract_albums_helper (PublishingPicasaPicasaPublisher* self, xmlNode* document_root, int* result_length1, GError** error);
PublishingPicasaAlbum* publishing_picasa_album_new (const gchar* name, const gchar* url);
PublishingPicasaAlbum* publishing_picasa_album_construct (GType object_type, const gchar* name, const gchar* url);
static void _vala_array_add12 (PublishingPicasaAlbum** * array, int* length, int* size, PublishingPicasaAlbum* value);
static void _vala_array_add13 (PublishingPicasaAlbum** * array, int* length, int* size, PublishingPicasaAlbum* value);
void publishing_picasa_publishing_parameters_set_major_axis_size_selection_id (PublishingPicasaPublishingParameters* self, gint selection_id);
void publishing_picasa_publishing_parameters_set_strip_metadata (PublishingPicasaPublishingParameters* self, gboolean strip_metadata);
void publishing_picasa_publishing_parameters_set_target_album_name (PublishingPicasaPublishingParameters* self, const gchar* target_album_name);
static void publishing_picasa_picasa_publisher_save_parameters_to_configuration_system (PublishingPicasaPicasaPublisher* self, PublishingPicasaPublishingParameters* parameters);
gint publishing_picasa_publishing_parameters_get_major_axis_size_selection_id (PublishingPicasaPublishingParameters* self);
gboolean publishing_picasa_publishing_parameters_get_strip_metadata (PublishingPicasaPublishingParameters* self);
gchar* publishing_picasa_publishing_parameters_get_target_album_name (PublishingPicasaPublishingParameters* self);
static void publishing_picasa_picasa_publisher_real_on_login_flow_complete (PublishingRESTSupportGooglePublisher* base);
void publishing_picasa_publishing_parameters_set_user_name (PublishingPicasaPublishingParameters* self, const gchar* user_name);
static void publishing_picasa_picasa_publisher_do_fetch_account_information (PublishingPicasaPicasaPublisher* self);
static void publishing_picasa_picasa_publisher_on_initial_album_fetch_complete (PublishingPicasaPicasaPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_picasa_picasa_publisher_on_initial_album_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void publishing_picasa_picasa_publisher_on_initial_album_fetch_error (PublishingPicasaPicasaPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_picasa_picasa_publisher_on_initial_album_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
GType publishing_picasa_album_directory_transaction_get_type (void) G_GNUC_CONST;
static void publishing_picasa_picasa_publisher_do_parse_and_display_account_information (PublishingPicasaPicasaPublisher* self, PublishingPicasaAlbumDirectoryTransaction* transaction);
static void publishing_picasa_picasa_publisher_on_publishing_options_logout (PublishingPicasaPicasaPublisher* self);
static void publishing_picasa_picasa_publisher_on_publishing_options_publish (PublishingPicasaPicasaPublisher* self);
static void publishing_picasa_picasa_publisher_do_upload (PublishingPicasaPicasaPublisher* self);
static void publishing_picasa_picasa_publisher_on_upload_status_updated (PublishingPicasaPicasaPublisher* self, gint file_number, gdouble completed_fraction);
static void publishing_picasa_picasa_publisher_on_upload_complete (PublishingPicasaPicasaPublisher* self, PublishingRESTSupportBatchUploader* uploader, gint num_published);
static void _publishing_picasa_picasa_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender, gint num_photos_published, gpointer self);
static void publishing_picasa_picasa_publisher_on_upload_error (PublishingPicasaPicasaPublisher* self, PublishingRESTSupportBatchUploader* uploader, GError* err);
static void _publishing_picasa_picasa_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender, GError* err, gpointer self);
static void publishing_picasa_picasa_publisher_do_show_success_pane (PublishingPicasaPicasaPublisher* self);
PublishingPicasaAlbumDirectoryTransaction* publishing_picasa_album_directory_transaction_new (PublishingRESTSupportGoogleSession* session);
PublishingPicasaAlbumDirectoryTransaction* publishing_picasa_album_directory_transaction_construct (GType object_type, PublishingRESTSupportGoogleSession* session);
gchar* publishing_picasa_album_directory_transaction_validate_xml (PublishingRESTSupportXmlDocument* doc);
static gchar* _publishing_picasa_album_directory_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc, gpointer self);
void publishing_picasa_publishing_parameters_set_albums (PublishingPicasaPublishingParameters* self, PublishingPicasaAlbum** albums, int albums_length1);
static void publishing_picasa_picasa_publisher_do_show_publishing_options_pane (PublishingPicasaPicasaPublisher* self);
GType publishing_picasa_publishing_options_pane_get_type (void) G_GNUC_CONST;
PublishingPicasaPublishingOptionsPane* publishing_picasa_publishing_options_pane_new (GtkBuilder* builder, PublishingPicasaPublishingParameters* parameters, gboolean can_logout);
PublishingPicasaPublishingOptionsPane* publishing_picasa_publishing_options_pane_construct (GType object_type, GtkBuilder* builder, PublishingPicasaPublishingParameters* parameters, gboolean can_logout);
static void _publishing_picasa_picasa_publisher_on_publishing_options_publish_publishing_picasa_publishing_options_pane_publish (PublishingPicasaPublishingOptionsPane* _sender, gpointer self);
static void _publishing_picasa_picasa_publisher_on_publishing_options_logout_publishing_picasa_publishing_options_pane_logout (PublishingPicasaPublishingOptionsPane* _sender, gpointer self);
gint publishing_picasa_publishing_parameters_get_major_axis_size_pixels (PublishingPicasaPublishingParameters* self);
GType publishing_picasa_uploader_get_type (void) G_GNUC_CONST;
PublishingPicasaUploader* publishing_picasa_uploader_new (PublishingRESTSupportGoogleSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingPicasaPublishingParameters* parameters);
PublishingPicasaUploader* publishing_picasa_uploader_construct (GType object_type, PublishingRESTSupportGoogleSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingPicasaPublishingParameters* parameters);
static void _publishing_picasa_picasa_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self);
static void publishing_picasa_picasa_publisher_real_do_logout (PublishingRESTSupportGooglePublisher* base);
static gboolean publishing_picasa_picasa_publisher_real_is_running (PublishingRESTSupportGooglePublisher* base);
static void publishing_picasa_picasa_publisher_real_start (PublishingRESTSupportGooglePublisher* base);
static void publishing_picasa_picasa_publisher_real_stop (PublishingRESTSupportGooglePublisher* base);
static SpitPublishingAuthenticator* publishing_picasa_picasa_publisher_real_get_authenticator (PublishingRESTSupportGooglePublisher* base);
static void publishing_picasa_picasa_publisher_finalize (GObject * obj);
enum  {
	PUBLISHING_PICASA_ALBUM_DUMMY_PROPERTY
};
static void publishing_picasa_album_finalize (PublishingPicasaAlbum * obj);
enum  {
	PUBLISHING_PICASA_ALBUM_DIRECTORY_TRANSACTION_DUMMY_PROPERTY
};
#define PUBLISHING_PICASA_ALBUM_DIRECTORY_TRANSACTION_ENDPOINT_URL "https://picasaweb.google.com/data/feed/api/user/" "default"
GType publishing_picasa_upload_transaction_get_type (void) G_GNUC_CONST;
#define PUBLISHING_PICASA_UPLOAD_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PICASA_TYPE_UPLOAD_TRANSACTION, PublishingPicasaUploadTransactionPrivate))
enum  {
	PUBLISHING_PICASA_UPLOAD_TRANSACTION_DUMMY_PROPERTY
};
#define PUBLISHING_PICASA_UPLOAD_TRANSACTION_METADATA_TEMPLATE "<?xml version=\"1.0\" ?><atom:entry xmlns:atom='http://www.w3.org/2005" \
"/Atom' xmlns:mrss='http://search.yahoo.com/mrss/'> <atom:title>%s</ato" \
"m:title> %s <atom:category scheme='http://schemas.google.com/g/2005#ki" \
"nd' term='http://schemas.google.com/photos/2007#photo'/> %s </atom:ent" \
"ry>"
PublishingPicasaUploadTransaction* publishing_picasa_upload_transaction_new (PublishingRESTSupportGoogleSession* session, PublishingPicasaPublishingParameters* parameters, SpitPublishingPublishable* publishable);
PublishingPicasaUploadTransaction* publishing_picasa_upload_transaction_construct (GType object_type, PublishingRESTSupportGoogleSession* session, PublishingPicasaPublishingParameters* parameters, SpitPublishingPublishable* publishable);
gchar* publishing_picasa_publishing_parameters_get_target_album_feed_url (PublishingPicasaPublishingParameters* self);
static void publishing_picasa_upload_transaction_real_execute (PublishingRESTSupportTransaction* base, GError** error);
static void _vala_SoupBuffer_free (SoupBuffer* self);
static void _vala_SoupMultipart_free (SoupMultipart* self);
static void publishing_picasa_upload_transaction_finalize (PublishingRESTSupportTransaction * obj);
static gpointer publishing_picasa_publishing_options_pane_size_description_ref (gpointer instance);
static void publishing_picasa_publishing_options_pane_size_description_unref (gpointer instance);
static GParamSpec* publishing_picasa_publishing_options_pane_param_spec_size_description (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) G_GNUC_UNUSED;
static void publishing_picasa_publishing_options_pane_value_set_size_description (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static void publishing_picasa_publishing_options_pane_value_take_size_description (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static gpointer publishing_picasa_publishing_options_pane_value_get_size_description (const GValue* value) G_GNUC_UNUSED;
static GType publishing_picasa_publishing_options_pane_size_description_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPicasaPublishingOptionsPanePrivate))
enum  {
	PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_DUMMY_PROPERTY
};
#define PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_DEFAULT_SIZE_CONFIG_KEY "default_size"
#define PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_LAST_ALBUM_CONFIG_KEY "last_album"
static PublishingPicasaPublishingOptionsPaneSizeDescription** publishing_picasa_publishing_options_pane_create_size_descriptions (PublishingPicasaPublishingOptionsPane* self, int* result_length1);
gchar* publishing_picasa_publishing_parameters_get_user_name (PublishingPicasaPublishingParameters* self);
SpitPublishingPublisherMediaType publishing_picasa_publishing_parameters_get_media_type (PublishingPicasaPublishingParameters* self);
static void publishing_picasa_publishing_options_pane_on_logout_clicked (PublishingPicasaPublishingOptionsPane* self);
static void _publishing_picasa_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_picasa_publishing_options_pane_on_publish_clicked (PublishingPicasaPublishingOptionsPane* self);
static void _publishing_picasa_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
void publishing_picasa_publishing_parameters_set_major_axis_size_pixels (PublishingPicasaPublishingParameters* self, gint pixels);
PublishingPicasaAlbum** publishing_picasa_publishing_parameters_get_albums (PublishingPicasaPublishingParameters* self, int* result_length1);
void publishing_picasa_publishing_parameters_set_target_album_entry_url (PublishingPicasaPublishingParameters* self, const gchar* target_album_url);
static PublishingPicasaPublishingOptionsPaneSizeDescription* publishing_picasa_publishing_options_pane_size_description_new (const gchar* name, gint major_axis_pixels);
static PublishingPicasaPublishingOptionsPaneSizeDescription* publishing_picasa_publishing_options_pane_size_description_construct (GType object_type, const gchar* name, gint major_axis_pixels);
static void _vala_array_add14 (PublishingPicasaPublishingOptionsPaneSizeDescription** * array, int* length, int* size, PublishingPicasaPublishingOptionsPaneSizeDescription* value);
static void _vala_array_add15 (PublishingPicasaPublishingOptionsPaneSizeDescription** * array, int* length, int* size, PublishingPicasaPublishingOptionsPaneSizeDescription* value);
static void _vala_array_add16 (PublishingPicasaPublishingOptionsPaneSizeDescription** * array, int* length, int* size, PublishingPicasaPublishingOptionsPaneSizeDescription* value);
static void _vala_array_add17 (PublishingPicasaPublishingOptionsPaneSizeDescription** * array, int* length, int* size, PublishingPicasaPublishingOptionsPaneSizeDescription* value);
#define PUBLISHING_PICASA_PUBLISHING_PARAMETERS_ORIGINAL_SIZE -1
static void _vala_array_add18 (PublishingPicasaPublishingOptionsPaneSizeDescription** * array, int* length, int* size, PublishingPicasaPublishingOptionsPaneSizeDescription* value);
void publishing_picasa_publishing_options_pane_installed (PublishingPicasaPublishingOptionsPane* self);
static GtkWidget* publishing_picasa_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_picasa_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_picasa_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void publishing_picasa_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
enum  {
	PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_SIZE_DESCRIPTION_DUMMY_PROPERTY
};
static void publishing_picasa_publishing_options_pane_size_description_finalize (PublishingPicasaPublishingOptionsPaneSizeDescription * obj);
static void publishing_picasa_publishing_options_pane_finalize (GObject * obj);
#define PUBLISHING_PICASA_PUBLISHING_PARAMETERS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS, PublishingPicasaPublishingParametersPrivate))
enum  {
	PUBLISHING_PICASA_PUBLISHING_PARAMETERS_DUMMY_PROPERTY
};
gchar* publishing_picasa_publishing_parameters_get_target_album_entry_url (PublishingPicasaPublishingParameters* self);
static PublishingPicasaAlbum** _vala_array_dup5 (PublishingPicasaAlbum** self, int length);
static PublishingPicasaAlbum** _vala_array_dup6 (PublishingPicasaAlbum** self, int length);
static void publishing_picasa_publishing_parameters_finalize (PublishingPicasaPublishingParameters * obj);
#define PUBLISHING_PICASA_UPLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PICASA_TYPE_UPLOADER, PublishingPicasaUploaderPrivate))
enum  {
	PUBLISHING_PICASA_UPLOADER_DUMMY_PROPERTY
};
static PublishingRESTSupportTransaction* publishing_picasa_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base, SpitPublishingPublishable* publishable);
static void publishing_picasa_uploader_finalize (PublishingRESTSupportBatchUploader * obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


PicasaService* picasa_service_construct (GType object_type, GFile* resource_directory) {
	PicasaService * self = NULL;
	GdkPixbuf** _tmp0_;
	gint _tmp0__length1;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = (PicasaService*) g_object_new (object_type, NULL);
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = picasa_service_icon_pixbuf_set;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0__length1 = picasa_service_icon_pixbuf_set_length1;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (_tmp0_ == NULL) {
#line 519 "PicasaPublishing.c"
		gint _tmp1_;
		GdkPixbuf** _tmp2_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp2_ = resources_load_from_resource (PLUGIN_RESOURCE_PATH "/" PICASA_SERVICE_ICON_FILENAME, &_tmp1_);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		picasa_service_icon_pixbuf_set = (_vala_array_free (picasa_service_icon_pixbuf_set, picasa_service_icon_pixbuf_set_length1, (GDestroyNotify) g_object_unref), NULL);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		picasa_service_icon_pixbuf_set = _tmp2_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		picasa_service_icon_pixbuf_set_length1 = _tmp1_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_picasa_service_icon_pixbuf_set_size_ = picasa_service_icon_pixbuf_set_length1;
#line 532 "PicasaPublishing.c"
	}
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self;
#line 536 "PicasaPublishing.c"
}


PicasaService* picasa_service_new (GFile* resource_directory) {
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return picasa_service_construct (TYPE_PICASA_SERVICE, resource_directory);
#line 543 "PicasaPublishing.c"
}


static gint picasa_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface) {
	PicasaService * self;
	gint result = 0;
	gint _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PICASA_SERVICE, PicasaService);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = min_host_interface;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = max_host_interface;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = spit_negotiate_interfaces (_tmp0_, _tmp1_, SPIT_PUBLISHING_CURRENT_INTERFACE);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp2_;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 565 "PicasaPublishing.c"
}


static const gchar* picasa_service_real_get_id (SpitPluggable* base) {
	PicasaService * self;
	const gchar* result = NULL;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PICASA_SERVICE, PicasaService);
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = "org.yorba.shotwell.publishing.picasa";
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 578 "PicasaPublishing.c"
}


static const gchar* picasa_service_real_get_pluggable_name (SpitPluggable* base) {
	PicasaService * self;
	const gchar* result = NULL;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PICASA_SERVICE, PicasaService);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = "Picasa Web Albums";
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 591 "PicasaPublishing.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self ? g_object_ref (self) : NULL;
#line 598 "PicasaPublishing.c"
}


static GdkPixbuf** _vala_array_dup4 (GdkPixbuf** self, int length) {
	GdkPixbuf** result;
	int i;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = g_new0 (GdkPixbuf*, length + 1);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	for (i = 0; i < length; i++) {
#line 609 "PicasaPublishing.c"
		GdkPixbuf* _tmp0_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		result[i] = _tmp0_;
#line 615 "PicasaPublishing.c"
	}
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 619 "PicasaPublishing.c"
}


static void picasa_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info) {
	PicasaService * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GdkPixbuf** _tmp7_;
	gint _tmp7__length1;
	GdkPixbuf** _tmp8_;
	gint _tmp8__length1;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PICASA_SERVICE, PicasaService);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (info != NULL);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = g_strdup ("Lucas Beeler");
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 ((*info).authors);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*info).authors = _tmp0_;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = g_strdup (_ ("Copyright 2016 Software Freedom Conservancy Inc."));
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 ((*info).copyright);
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*info).copyright = _tmp1_;
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = g_strdup (RESOURCES_TRANSLATORS);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 ((*info).translators);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*info).translators = _tmp2_;
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = g_strdup (_VERSION);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 ((*info).version);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*info).version = _tmp3_;
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = g_strdup (RESOURCES_WEBSITE_NAME);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 ((*info).website_name);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*info).website_name = _tmp4_;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = g_strdup (RESOURCES_WEBSITE_URL);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 ((*info).website_url);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*info).website_url = _tmp5_;
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*info).is_license_wordwrapped = FALSE;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp6_ = g_strdup (RESOURCES_LICENSE);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 ((*info).license);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*info).license = _tmp6_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp7_ = picasa_service_icon_pixbuf_set;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp7__length1 = picasa_service_icon_pixbuf_set_length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp8_ = (_tmp7_ != NULL) ? _vala_array_dup4 (_tmp7_, _tmp7__length1) : ((gpointer) _tmp7_);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp8__length1 = _tmp7__length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*info).icons = (_vala_array_free ((*info).icons, (*info).icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*info).icons = _tmp8_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*info).icons_length1 = _tmp8__length1;
#line 698 "PicasaPublishing.c"
}


static SpitPublishingPublisher* picasa_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host) {
	PicasaService * self;
	SpitPublishingPublisher* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	PublishingPicasaPicasaPublisher* _tmp1_;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PICASA_SERVICE, PicasaService);
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = host;
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = publishing_picasa_picasa_publisher_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_SERVICE, SpitPublishingService), _tmp0_);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher);
#line 44 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 719 "PicasaPublishing.c"
}


static SpitPublishingPublisherMediaType picasa_service_real_get_supported_media (SpitPublishingService* base) {
	PicasaService * self;
	SpitPublishingPublisherMediaType result = 0;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PICASA_SERVICE, PicasaService);
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO | SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO;
#line 48 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 732 "PicasaPublishing.c"
}


static void picasa_service_real_activation (SpitPluggable* base, gboolean enabled) {
	PicasaService * self;
#line 52 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PICASA_SERVICE, PicasaService);
#line 740 "PicasaPublishing.c"
}


static void picasa_service_class_init (PicasaServiceClass * klass) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	picasa_service_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = picasa_service_finalize;
#line 749 "PicasaPublishing.c"
}


static void picasa_service_spit_pluggable_interface_init (SpitPluggableIface * iface) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	picasa_service_spit_pluggable_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	iface->get_pluggable_interface = (gint (*) (SpitPluggable *, gint, gint)) picasa_service_real_get_pluggable_interface;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	iface->get_id = (const gchar* (*) (SpitPluggable *)) picasa_service_real_get_id;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	iface->get_pluggable_name = (const gchar* (*) (SpitPluggable *)) picasa_service_real_get_pluggable_name;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	iface->get_info = (void (*) (SpitPluggable *, SpitPluggableInfo*)) picasa_service_real_get_info;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	iface->activation = (void (*) (SpitPluggable *, gboolean)) picasa_service_real_activation;
#line 766 "PicasaPublishing.c"
}


static void picasa_service_spit_publishing_service_interface_init (SpitPublishingServiceIface * iface) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	picasa_service_spit_publishing_service_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	iface->create_publisher = (SpitPublishingPublisher* (*) (SpitPublishingService *, SpitPublishingPluginHost*)) picasa_service_real_create_publisher;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	iface->get_supported_media = (SpitPublishingPublisherMediaType (*) (SpitPublishingService *)) picasa_service_real_get_supported_media;
#line 777 "PicasaPublishing.c"
}


static void picasa_service_instance_init (PicasaService * self) {
}


static void picasa_service_finalize (GObject * obj) {
	PicasaService * self;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PICASA_SERVICE, PicasaService);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	G_OBJECT_CLASS (picasa_service_parent_class)->finalize (obj);
#line 791 "PicasaPublishing.c"
}


GType picasa_service_get_type (void) {
	static volatile gsize picasa_service_type_id__volatile = 0;
	if (g_once_init_enter (&picasa_service_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PicasaServiceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) picasa_service_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PicasaService), 0, (GInstanceInitFunc) picasa_service_instance_init, NULL };
		static const GInterfaceInfo spit_pluggable_info = { (GInterfaceInitFunc) picasa_service_spit_pluggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo spit_publishing_service_info = { (GInterfaceInitFunc) picasa_service_spit_publishing_service_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType picasa_service_type_id;
		picasa_service_type_id = g_type_register_static (G_TYPE_OBJECT, "PicasaService", &g_define_type_info, 0);
		g_type_add_interface_static (picasa_service_type_id, SPIT_TYPE_PLUGGABLE, &spit_pluggable_info);
		g_type_add_interface_static (picasa_service_type_id, SPIT_PUBLISHING_TYPE_SERVICE, &spit_publishing_service_info);
		g_once_init_leave (&picasa_service_type_id__volatile, picasa_service_type_id);
	}
	return picasa_service_type_id__volatile;
}


PublishingPicasaPicasaPublisher* publishing_picasa_picasa_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host) {
	PublishingPicasaPicasaPublisher * self = NULL;
	SpitPublishingService* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	PublishingPicasaPublishingParameters* _tmp2_;
	PublishingPicasaPublishingParameters* _tmp3_;
	SpitPublishingPublisherMediaType media_type = 0;
	SpitPublishingPluginHost* _tmp4_;
	gint _tmp5_;
	SpitPublishingPublishable** _tmp6_;
	PublishingPicasaPublishingParameters* _tmp11_;
	SpitPublishingPublisherMediaType _tmp12_;
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_SERVICE (service), NULL);
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = service;
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = host;
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = (PublishingPicasaPicasaPublisher*) publishing_rest_support_google_publisher_construct (object_type, _tmp0_, _tmp1_, "https://picasaweb.google.com/data/");
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = publishing_picasa_publishing_parameters_new ();
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_picasa_publishing_parameters_unref0 (self->priv->publishing_parameters);
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->publishing_parameters = _tmp2_;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = self->priv->publishing_parameters;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_load_parameters_from_configuration_system (self, _tmp3_);
#line 74 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	media_type = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_NONE;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = host;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp6_ = spit_publishing_plugin_host_get_publishables (_tmp4_, &_tmp5_);
#line 849 "PicasaPublishing.c"
	{
		SpitPublishingPublishable** p_collection = NULL;
		gint p_collection_length1 = 0;
		gint _p_collection_size_ = 0;
		gint p_it = 0;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		p_collection = _tmp6_;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		p_collection_length1 = _tmp5_;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		for (p_it = 0; p_it < _tmp5_; p_it = p_it + 1) {
#line 861 "PicasaPublishing.c"
			SpitPublishingPublishable* _tmp7_;
			SpitPublishingPublishable* p = NULL;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp7_ = _g_object_ref0 (p_collection[p_it]);
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			p = _tmp7_;
#line 868 "PicasaPublishing.c"
			{
				SpitPublishingPublisherMediaType _tmp8_;
				SpitPublishingPublishable* _tmp9_;
				SpitPublishingPublisherMediaType _tmp10_;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp8_ = media_type;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp9_ = p;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp10_ = spit_publishing_publishable_get_media_type (_tmp9_);
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				media_type = _tmp8_ | _tmp10_;
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_g_object_unref0 (p);
#line 883 "PicasaPublishing.c"
			}
		}
#line 75 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		p_collection = (_vala_array_free (p_collection, p_collection_length1, (GDestroyNotify) g_object_unref), NULL);
#line 888 "PicasaPublishing.c"
	}
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp11_ = self->priv->publishing_parameters;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp12_ = media_type;
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_parameters_set_media_type (_tmp11_, _tmp12_);
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 79 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self;
#line 912 "PicasaPublishing.c"
}


PublishingPicasaPicasaPublisher* publishing_picasa_picasa_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host) {
#line 67 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return publishing_picasa_picasa_publisher_construct (PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER, service, host);
#line 919 "PicasaPublishing.c"
}


static void _vala_array_add12 (PublishingPicasaAlbum** * array, int* length, int* size, PublishingPicasaAlbum* value) {
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if ((*length) == (*size)) {
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*array = g_renew (PublishingPicasaAlbum*, *array, (*size) + 1);
#line 930 "PicasaPublishing.c"
	}
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[(*length)++] = value;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[*length] = NULL;
#line 936 "PicasaPublishing.c"
}


static void _vala_array_add13 (PublishingPicasaAlbum** * array, int* length, int* size, PublishingPicasaAlbum* value) {
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if ((*length) == (*size)) {
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*array = g_renew (PublishingPicasaAlbum*, *array, (*size) + 1);
#line 947 "PicasaPublishing.c"
	}
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[(*length)++] = value;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[*length] = NULL;
#line 953 "PicasaPublishing.c"
}


static PublishingPicasaAlbum** publishing_picasa_picasa_publisher_extract_albums_helper (PublishingPicasaPicasaPublisher* self, xmlNode* document_root, int* result_length1, GError** error) {
	PublishingPicasaAlbum** result = NULL;
	PublishingPicasaAlbum** _result_ = NULL;
	PublishingPicasaAlbum** _tmp0_;
	gint _result__length1;
	gint __result__size_;
	xmlNode* doc_node_iter = NULL;
	xmlNode* _tmp1_;
	const gchar* _tmp2_;
	PublishingPicasaAlbum** _tmp9_;
	gint _tmp9__length1;
	PublishingPicasaAlbum* _tmp10_;
	PublishingPicasaAlbum** _tmp39_;
	gint _tmp39__length1;
	GError * _inner_error_ = NULL;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self), NULL);
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = g_new0 (PublishingPicasaAlbum*, 0 + 1);
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_result_ = _tmp0_;
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_result__length1 = 0;
#line 84 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	__result__size_ = _result__length1;
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	doc_node_iter = NULL;
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = document_root;
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = _tmp1_->name;
#line 87 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (g_strcmp0 (_tmp2_, "feed") == 0) {
#line 990 "PicasaPublishing.c"
		xmlNode* _tmp3_;
		xmlNode* _tmp4_;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp3_ = document_root;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp4_ = _tmp3_->children;
#line 88 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		doc_node_iter = _tmp4_;
#line 999 "PicasaPublishing.c"
	} else {
		xmlNode* _tmp5_;
		const gchar* _tmp6_;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp5_ = document_root;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp6_ = _tmp5_->name;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		if (g_strcmp0 (_tmp6_, "entry") == 0) {
#line 1009 "PicasaPublishing.c"
			xmlNode* _tmp7_;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp7_ = document_root;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			doc_node_iter = _tmp7_;
#line 1015 "PicasaPublishing.c"
		} else {
			GError* _tmp8_;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp8_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE, "response root node " "isn't a <feed> or <entry>");
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_inner_error_ = _tmp8_;
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				g_propagate_error (error, _inner_error_);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_result_ = (_vala_array_free (_result_, _result__length1, (GDestroyNotify) publishing_picasa_album_unref), NULL);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				return NULL;
#line 1030 "PicasaPublishing.c"
			} else {
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_result_ = (_vala_array_free (_result_, _result__length1, (GDestroyNotify) publishing_picasa_album_unref), NULL);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				g_clear_error (&_inner_error_);
#line 92 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				return NULL;
#line 1040 "PicasaPublishing.c"
			}
		}
	}
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp9_ = _result_;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp9__length1 = _result__length1;
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp10_ = publishing_picasa_album_new (_ ("Default album"), PUBLISHING_PICASA_PICASA_PUBLISHER_DEFAULT_ALBUM_FEED_URL);
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_vala_array_add12 (&_result_, &_result__length1, &__result__size_, _tmp10_);
#line 1052 "PicasaPublishing.c"
	{
		gboolean _tmp11_ = FALSE;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp11_ = TRUE;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		while (TRUE) {
#line 1059 "PicasaPublishing.c"
			xmlNode* _tmp14_;
			xmlNode* _tmp15_;
			const gchar* _tmp16_;
			gchar* name_val = NULL;
			gchar* url_val = NULL;
			xmlNode* album_node_iter = NULL;
			xmlNode* _tmp17_;
			xmlNode* _tmp18_;
			const gchar* _tmp34_;
			PublishingPicasaAlbum** _tmp35_;
			gint _tmp35__length1;
			const gchar* _tmp36_;
			const gchar* _tmp37_;
			PublishingPicasaAlbum* _tmp38_;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			if (!_tmp11_) {
#line 1076 "PicasaPublishing.c"
				xmlNode* _tmp12_;
				xmlNode* _tmp13_;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp12_ = doc_node_iter;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp13_ = _tmp12_->next;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				doc_node_iter = _tmp13_;
#line 1085 "PicasaPublishing.c"
			}
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp11_ = FALSE;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp14_ = doc_node_iter;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			if (!(_tmp14_ != NULL)) {
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				break;
#line 1095 "PicasaPublishing.c"
			}
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp15_ = doc_node_iter;
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp16_ = _tmp15_->name;
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			if (g_strcmp0 (_tmp16_, "entry") != 0) {
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				continue;
#line 1105 "PicasaPublishing.c"
			}
#line 102 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			name_val = NULL;
#line 103 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			url_val = NULL;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp17_ = doc_node_iter;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp18_ = _tmp17_->children;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			album_node_iter = _tmp18_;
#line 1117 "PicasaPublishing.c"
			{
				gboolean _tmp19_ = FALSE;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp19_ = TRUE;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				while (TRUE) {
#line 1124 "PicasaPublishing.c"
					xmlNode* _tmp22_;
					xmlNode* _tmp23_;
					const gchar* _tmp24_;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					if (!_tmp19_) {
#line 1130 "PicasaPublishing.c"
						xmlNode* _tmp20_;
						xmlNode* _tmp21_;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp20_ = album_node_iter;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp21_ = _tmp20_->next;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						album_node_iter = _tmp21_;
#line 1139 "PicasaPublishing.c"
					}
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp19_ = FALSE;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp22_ = album_node_iter;
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					if (!(_tmp22_ != NULL)) {
#line 105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						break;
#line 1149 "PicasaPublishing.c"
					}
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp23_ = album_node_iter;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp24_ = _tmp23_->name;
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					if (g_strcmp0 (_tmp24_, "title") == 0) {
#line 1157 "PicasaPublishing.c"
						xmlNode* _tmp25_;
						gchar* _tmp26_;
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp25_ = album_node_iter;
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp26_ = (gchar*) xmlNodeGetContent (_tmp25_);
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_g_free0 (name_val);
#line 107 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						name_val = _tmp26_;
#line 1168 "PicasaPublishing.c"
					} else {
						xmlNode* _tmp27_;
						const gchar* _tmp28_;
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp27_ = album_node_iter;
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp28_ = _tmp27_->name;
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						if (g_strcmp0 (_tmp28_, "id") == 0) {
#line 1178 "PicasaPublishing.c"
							xmlNode* _tmp29_;
							xmlNs* _tmp30_;
							const gchar* _tmp31_;
							xmlNode* _tmp32_;
							gchar* _tmp33_;
#line 112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
							_tmp29_ = album_node_iter;
#line 112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
							_tmp30_ = _tmp29_->ns;
#line 112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
							_tmp31_ = _tmp30_->prefix;
#line 112 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
							if (_tmp31_ != NULL) {
#line 113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
								continue;
#line 1194 "PicasaPublishing.c"
							}
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
							_tmp32_ = album_node_iter;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
							_tmp33_ = (gchar*) xmlNodeGetContent (_tmp32_);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
							_g_free0 (url_val);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
							url_val = _tmp33_;
#line 1204 "PicasaPublishing.c"
						}
					}
				}
			}
#line 119 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp34_ = url_val;
#line 119 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			if (g_strcmp0 (_tmp34_, PUBLISHING_PICASA_PICASA_PUBLISHER_DEFAULT_ALBUM_FEED_URL) == 0) {
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_g_free0 (url_val);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_g_free0 (name_val);
#line 120 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				continue;
#line 1219 "PicasaPublishing.c"
			}
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp35_ = _result_;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp35__length1 = _result__length1;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp36_ = name_val;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp37_ = url_val;
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp38_ = publishing_picasa_album_new (_tmp36_, _tmp37_);
#line 123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_vala_array_add13 (&_result_, &_result__length1, &__result__size_, _tmp38_);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (url_val);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (name_val);
#line 1237 "PicasaPublishing.c"
		}
	}
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp39_ = _result_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp39__length1 = _result__length1;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (result_length1) {
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*result_length1 = _tmp39__length1;
#line 1248 "PicasaPublishing.c"
	}
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp39_;
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 1254 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_load_parameters_from_configuration_system (PublishingPicasaPicasaPublisher* self, PublishingPicasaPublishingParameters* parameters) {
	PublishingPicasaPublishingParameters* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	gint _tmp2_;
	PublishingPicasaPublishingParameters* _tmp3_;
	SpitPublishingPluginHost* _tmp4_;
	gboolean _tmp5_;
	PublishingPicasaPublishingParameters* _tmp6_;
	SpitPublishingPluginHost* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (parameters));
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = parameters;
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "default-size", 0);
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_parameters_set_major_axis_size_selection_id (_tmp0_, _tmp2_);
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = parameters;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip-metadata", FALSE);
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_parameters_set_strip_metadata (_tmp3_, _tmp5_);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp6_ = parameters;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp7_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp8_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-album", NULL);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp9_ = _tmp8_;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_parameters_set_target_album_name (_tmp6_, _tmp9_);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp9_);
#line 1301 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_save_parameters_to_configuration_system (PublishingPicasaPicasaPublisher* self, PublishingPicasaPublishingParameters* parameters) {
	SpitPublishingPluginHost* _tmp0_;
	PublishingPicasaPublishingParameters* _tmp1_;
	gint _tmp2_;
	SpitPublishingPluginHost* _tmp3_;
	PublishingPicasaPublishingParameters* _tmp4_;
	gboolean _tmp5_;
	SpitPublishingPluginHost* _tmp6_;
	PublishingPicasaPublishingParameters* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (parameters));
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = parameters;
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = publishing_picasa_publishing_parameters_get_major_axis_size_selection_id (_tmp1_);
#line 136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "default-size", _tmp2_);
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = parameters;
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = publishing_picasa_publishing_parameters_get_strip_metadata (_tmp4_);
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip_metadata", _tmp5_);
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp6_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp7_ = parameters;
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp8_ = publishing_picasa_publishing_parameters_get_target_album_name (_tmp7_);
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp9_ = _tmp8_;
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-album", _tmp9_);
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp9_);
#line 1348 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_real_on_login_flow_complete (PublishingRESTSupportGooglePublisher* base) {
	PublishingPicasaPicasaPublisher * self;
	PublishingPicasaPublishingParameters* _tmp0_;
	PublishingRESTSupportGoogleSession* _tmp1_;
	PublishingRESTSupportGoogleSession* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
#line 141 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER, PublishingPicasaPicasaPublisher);
#line 142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:142: EVENT: OAuth login flow complete.");
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = self->priv->publishing_parameters;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = publishing_rest_support_google_publisher_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = _tmp1_;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = publishing_rest_support_google_session_get_user_name (_tmp2_);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = _tmp3_;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_parameters_set_user_name (_tmp0_, _tmp4_);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp4_);
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp2_);
#line 147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_do_fetch_account_information (self);
#line 1381 "PicasaPublishing.c"
}


static void _publishing_picasa_picasa_publisher_on_initial_album_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_on_initial_album_fetch_complete ((PublishingPicasaPicasaPublisher*) self, _sender);
#line 1388 "PicasaPublishing.c"
}


static void _publishing_picasa_picasa_publisher_on_initial_album_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_on_initial_album_fetch_error ((PublishingPicasaPicasaPublisher*) self, _sender, err);
#line 1395 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_on_initial_album_fetch_complete (PublishingPicasaPicasaPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportTransaction* _tmp2_;
	guint _tmp3_;
	gboolean _tmp4_;
	PublishingRESTSupportTransaction* _tmp5_;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = txn;
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_picasa_picasa_publisher_on_initial_album_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = txn;
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 152 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_picasa_picasa_publisher_on_initial_album_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!_tmp4_) {
#line 155 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 1428 "PicasaPublishing.c"
	}
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:157: EVENT: finished fetching account and album " \
"information.");
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = txn;
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_do_parse_and_display_account_information (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_PICASA_TYPE_ALBUM_DIRECTORY_TRANSACTION, PublishingPicasaAlbumDirectoryTransaction));
#line 1436 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_on_initial_album_fetch_error (PublishingPicasaPicasaPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportTransaction* _tmp2_;
	guint _tmp3_;
	gboolean _tmp4_;
	PublishingRESTSupportTransaction* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gboolean _tmp8_ = FALSE;
	PublishingRESTSupportTransaction* _tmp9_;
	guint _tmp10_;
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 162 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = bad_txn;
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_picasa_picasa_publisher_on_initial_album_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = bad_txn;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_picasa_picasa_publisher_on_initial_album_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!_tmp4_) {
#line 168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 1474 "PicasaPublishing.c"
	}
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = bad_txn;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp6_ = publishing_rest_support_transaction_get_response (_tmp5_);
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp7_ = _tmp6_;
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:170: EVENT: fetching account and album informati" \
"on failed; response = '%s'.", _tmp7_);
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp7_);
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp9_ = bad_txn;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp10_ = publishing_rest_support_transaction_get_status_code (_tmp9_);
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (_tmp10_ == ((guint) 403)) {
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp8_ = TRUE;
#line 1494 "PicasaPublishing.c"
	} else {
		PublishingRESTSupportTransaction* _tmp11_;
		guint _tmp12_;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp11_ = bad_txn;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp12_ = publishing_rest_support_transaction_get_status_code (_tmp11_);
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp8_ = _tmp12_ == ((guint) 404);
#line 1504 "PicasaPublishing.c"
	}
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (_tmp8_) {
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_rest_support_google_publisher_do_logout (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 1510 "PicasaPublishing.c"
	} else {
		SpitPublishingPluginHost* _tmp13_;
		GError* _tmp14_;
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp13_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp14_ = err;
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp13_, _tmp14_);
#line 1520 "PicasaPublishing.c"
	}
}


static void publishing_picasa_picasa_publisher_on_publishing_options_logout (PublishingPicasaPicasaPublisher* self) {
	gboolean _tmp0_;
#line 181 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!_tmp0_) {
#line 183 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 1535 "PicasaPublishing.c"
	}
#line 185 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:185: EVENT: user clicked 'Logout' in the publish" \
"ing options pane.");
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_rest_support_google_publisher_do_logout (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 1541 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_on_publishing_options_publish (PublishingPicasaPicasaPublisher* self) {
	gboolean _tmp0_;
	PublishingPicasaPublishingParameters* _tmp1_;
#line 190 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!_tmp0_) {
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 1556 "PicasaPublishing.c"
	}
#line 194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:194: EVENT: user clicked 'Publish' in the publis" \
"hing options pane.");
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = self->priv->publishing_parameters;
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_save_parameters_to_configuration_system (self, _tmp1_);
#line 198 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_do_upload (self);
#line 1566 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_on_upload_status_updated (PublishingPicasaPicasaPublisher* self, gint file_number, gdouble completed_fraction) {
	gboolean _tmp0_;
	gdouble _tmp1_;
	SpitPublishingProgressCallback _tmp2_;
	void* _tmp2__target;
	SpitPublishingProgressCallback _tmp3_;
	void* _tmp3__target;
	gint _tmp4_;
	gdouble _tmp5_;
#line 201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 202 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!_tmp0_) {
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 1587 "PicasaPublishing.c"
	}
#line 205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = completed_fraction;
#line 205 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:205: EVENT: uploader reports upload %.2f percent" \
" complete.", 100.0 * _tmp1_);
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = self->priv->progress_reporter;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2__target = self->priv->progress_reporter_target;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_vala_assert (_tmp2_ != NULL, "progress_reporter != null");
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = self->priv->progress_reporter;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3__target = self->priv->progress_reporter_target;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = file_number;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = completed_fraction;
#line 209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ (_tmp4_, _tmp5_, _tmp3__target);
#line 1609 "PicasaPublishing.c"
}


static void _publishing_picasa_picasa_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender, gint num_photos_published, gpointer self) {
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_on_upload_complete ((PublishingPicasaPicasaPublisher*) self, _sender, num_photos_published);
#line 1616 "PicasaPublishing.c"
}


static void _publishing_picasa_picasa_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender, GError* err, gpointer self) {
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_on_upload_error ((PublishingPicasaPicasaPublisher*) self, _sender, err);
#line 1623 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_on_upload_complete (PublishingPicasaPicasaPublisher* self, PublishingRESTSupportBatchUploader* uploader, gint num_published) {
	gboolean _tmp0_;
	gint _tmp1_;
	PublishingRESTSupportBatchUploader* _tmp2_;
	guint _tmp3_;
	PublishingRESTSupportBatchUploader* _tmp4_;
	guint _tmp5_;
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!_tmp0_) {
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 1644 "PicasaPublishing.c"
	}
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = num_published;
#line 217 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:217: EVENT: uploader reports upload complete; %d" \
" items published.", _tmp1_);
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = uploader;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp3_, NULL, FALSE);
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_picasa_picasa_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = uploader;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp5_, NULL, FALSE);
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp4_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp5_, 0, NULL, (GCallback) _publishing_picasa_picasa_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 222 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_do_show_success_pane (self);
#line 1664 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_on_upload_error (PublishingPicasaPicasaPublisher* self, PublishingRESTSupportBatchUploader* uploader, GError* err) {
	gboolean _tmp0_;
	GError* _tmp1_;
	const gchar* _tmp2_;
	PublishingRESTSupportBatchUploader* _tmp3_;
	guint _tmp4_;
	PublishingRESTSupportBatchUploader* _tmp5_;
	guint _tmp6_;
	SpitPublishingPluginHost* _tmp7_;
	GError* _tmp8_;
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 225 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!_tmp0_) {
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 1688 "PicasaPublishing.c"
	}
#line 230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = err;
#line 230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = _tmp1_->message;
#line 230 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:230: EVENT: uploader reports upload error = '%s'" \
".", _tmp2_);
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = uploader;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp4_, NULL, FALSE);
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp3_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp4_, 0, NULL, (GCallback) _publishing_picasa_picasa_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = uploader;
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp6_, NULL, FALSE);
#line 233 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp5_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp6_, 0, NULL, (GCallback) _publishing_picasa_picasa_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp7_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp8_ = err;
#line 235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spit_publishing_plugin_host_post_error (_tmp7_, _tmp8_);
#line 1714 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_do_fetch_account_information (PublishingPicasaPicasaPublisher* self) {
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	PublishingPicasaAlbumDirectoryTransaction* directory_trans = NULL;
	PublishingRESTSupportGoogleSession* _tmp2_;
	PublishingRESTSupportGoogleSession* _tmp3_;
	PublishingPicasaAlbumDirectoryTransaction* _tmp4_;
	PublishingPicasaAlbumDirectoryTransaction* _tmp5_;
	GError * _inner_error_ = NULL;
#line 238 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:239: ACTION: fetching account and album informat" \
"ion.");
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 241 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp0_);
#line 242 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 242 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp1_, TRUE);
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = publishing_rest_support_google_publisher_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = _tmp2_;
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = publishing_picasa_album_directory_transaction_new (_tmp3_);
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = _tmp4_;
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp3_);
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	directory_trans = _tmp5_;
#line 246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (directory_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_picasa_picasa_publisher_on_initial_album_fetch_error_publishing_rest_support_transaction_network_error, self, 0);
#line 247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (directory_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_picasa_picasa_publisher_on_initial_album_fetch_complete_publishing_rest_support_transaction_completed, self, 0);
#line 1755 "PicasaPublishing.c"
	{
#line 250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (directory_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 1763 "PicasaPublishing.c"
				goto __catch6_spit_publishing_publishing_error;
			}
#line 250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_publishing_rest_support_transaction_unref0 (directory_trans);
#line 250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_clear_error (&_inner_error_);
#line 250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return;
#line 1774 "PicasaPublishing.c"
		}
	}
	goto __finally6;
	__catch6_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp6_;
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		err = _inner_error_;
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_inner_error_ = NULL;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp6_ = err;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_picasa_publisher_on_initial_album_fetch_error (self, G_TYPE_CHECK_INSTANCE_CAST (directory_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), _tmp6_);
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_error_free0 (err);
#line 1792 "PicasaPublishing.c"
	}
	__finally6:
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_publishing_rest_support_transaction_unref0 (directory_trans);
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_clear_error (&_inner_error_);
#line 249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 1805 "PicasaPublishing.c"
	}
#line 238 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_rest_support_transaction_unref0 (directory_trans);
#line 1809 "PicasaPublishing.c"
}


static gchar* _publishing_picasa_album_directory_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc, gpointer self) {
	gchar* result;
	result = publishing_picasa_album_directory_transaction_validate_xml (doc);
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 1818 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_do_parse_and_display_account_information (PublishingPicasaPicasaPublisher* self, PublishingPicasaAlbumDirectoryTransaction* transaction) {
	PublishingRESTSupportXmlDocument* response_doc = NULL;
	GError * _inner_error_ = NULL;
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_ALBUM_DIRECTORY_TRANSACTION (transaction));
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:260: ACTION: parsing account and album informati" \
"on from server response XML");
#line 1831 "PicasaPublishing.c"
	{
		PublishingRESTSupportXmlDocument* _tmp0_ = NULL;
		PublishingPicasaAlbumDirectoryTransaction* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		PublishingRESTSupportXmlDocument* _tmp4_;
		PublishingRESTSupportXmlDocument* _tmp5_;
		PublishingRESTSupportXmlDocument* _tmp6_;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp1_ = transaction;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp2_ = publishing_rest_support_transaction_get_response (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp3_ = _tmp2_;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp4_ = publishing_rest_support_xml_document_parse_string (_tmp3_, _publishing_picasa_album_directory_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp5_ = _tmp4_;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_free0 (_tmp3_);
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp0_ = _tmp5_;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 1858 "PicasaPublishing.c"
				goto __catch7_spit_publishing_publishing_error;
			}
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_clear_error (&_inner_error_);
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return;
#line 1869 "PicasaPublishing.c"
		}
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp6_ = _tmp0_;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp0_ = NULL;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (response_doc);
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		response_doc = _tmp6_;
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (_tmp0_);
#line 1881 "PicasaPublishing.c"
	}
	goto __finally7;
	__catch7_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		SpitPublishingPluginHost* _tmp7_;
		GError* _tmp8_;
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		err = _inner_error_;
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_inner_error_ = NULL;
#line 267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp7_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp8_ = err;
#line 267 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp7_, _tmp8_);
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_error_free0 (err);
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (response_doc);
#line 268 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 1905 "PicasaPublishing.c"
	}
	__finally7:
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (response_doc);
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_clear_error (&_inner_error_);
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 1918 "PicasaPublishing.c"
	}
	{
		PublishingPicasaAlbum** _tmp9_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp10_;
		xmlNode* _tmp11_;
		gint _tmp12_;
		PublishingPicasaAlbum** _tmp13_;
		gint _tmp9__length1;
		gint __tmp9__size_;
		PublishingPicasaPublishingParameters* _tmp14_;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp10_ = response_doc;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp11_ = publishing_rest_support_xml_document_get_root_node (_tmp10_);
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp13_ = publishing_picasa_picasa_publisher_extract_albums_helper (self, _tmp11_, &_tmp12_, &_inner_error_);
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp9_ = _tmp13_;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp9__length1 = _tmp12_;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		__tmp9__size_ = _tmp9__length1;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 1945 "PicasaPublishing.c"
				goto __catch8_spit_publishing_publishing_error;
			}
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (response_doc);
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_clear_error (&_inner_error_);
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return;
#line 1956 "PicasaPublishing.c"
		}
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp14_ = self->priv->publishing_parameters;
#line 272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_publishing_parameters_set_albums (_tmp14_, _tmp9_, _tmp9__length1);
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp9_ = (_vala_array_free (_tmp9_, _tmp9__length1, (GDestroyNotify) publishing_picasa_album_unref), NULL);
#line 1964 "PicasaPublishing.c"
	}
	goto __finally8;
	__catch8_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		SpitPublishingPluginHost* _tmp15_;
		GError* _tmp16_;
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		err = _inner_error_;
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_inner_error_ = NULL;
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp15_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp16_ = err;
#line 274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp15_, _tmp16_);
#line 275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_error_free0 (err);
#line 275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (response_doc);
#line 275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 1988 "PicasaPublishing.c"
	}
	__finally8:
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (response_doc);
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_clear_error (&_inner_error_);
#line 271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 2001 "PicasaPublishing.c"
	}
#line 278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_do_show_publishing_options_pane (self);
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_rest_support_xml_document_unref0 (response_doc);
#line 2007 "PicasaPublishing.c"
}


static void _publishing_picasa_picasa_publisher_on_publishing_options_publish_publishing_picasa_publishing_options_pane_publish (PublishingPicasaPublishingOptionsPane* _sender, gpointer self) {
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_on_publishing_options_publish ((PublishingPicasaPicasaPublisher*) self);
#line 2014 "PicasaPublishing.c"
}


static void _publishing_picasa_picasa_publisher_on_publishing_options_logout_publishing_picasa_publishing_options_pane_logout (PublishingPicasaPublishingOptionsPane* _sender, gpointer self) {
#line 297 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_on_publishing_options_logout ((PublishingPicasaPicasaPublisher*) self);
#line 2021 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_do_show_publishing_options_pane (PublishingPicasaPicasaPublisher* self) {
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_;
	PublishingPicasaPublishingOptionsPane* opts_pane = NULL;
	GtkBuilder* _tmp7_;
	PublishingPicasaPublishingParameters* _tmp8_;
	SpitPublishingAuthenticator* _tmp9_;
	gboolean _tmp10_;
	PublishingPicasaPublishingOptionsPane* _tmp11_;
	PublishingPicasaPublishingOptionsPane* _tmp12_;
	PublishingPicasaPublishingOptionsPane* _tmp13_;
	SpitPublishingPluginHost* _tmp14_;
	PublishingPicasaPublishingOptionsPane* _tmp15_;
	SpitPublishingPluginHost* _tmp16_;
	GError * _inner_error_ = NULL;
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:282: ACTION: showing publishing options pane.");
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = gtk_builder_new ();
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	builder = _tmp0_;
#line 2048 "PicasaPublishing.c"
	{
		GtkBuilder* _tmp1_;
#line 286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp1_ = builder;
#line 286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		gtk_builder_add_from_resource (_tmp1_, PLUGIN_RESOURCE_PATH "/" "picasa_publishing_options_pane.ui", &_inner_error_);
#line 286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2057 "PicasaPublishing.c"
			goto __catch9_g_error;
		}
	}
	goto __finally9;
	__catch9_g_error:
	{
		GError* e = NULL;
		GError* _tmp2_;
		const gchar* _tmp3_;
		SpitPublishingPluginHost* _tmp4_;
		GError* _tmp5_;
		GError* _tmp6_;
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		e = _inner_error_;
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_inner_error_ = NULL;
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp2_ = e;
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp3_ = _tmp2_->message;
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_warning ("PicasaPublishing.vala:288: Could not parse UI file! Error: %s.", _tmp3_);
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp4_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp5_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, _ ("A file required for publishing is unavailable. Publishing to Picasa ca" \
"n’t continue."));
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp6_ = _tmp5_;
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		spit_publishing_plugin_host_post_error (_tmp4_, _tmp6_);
#line 289 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_error_free0 (_tmp6_);
#line 292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_error_free0 (e);
#line 292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_object_unref0 (builder);
#line 292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 2096 "PicasaPublishing.c"
	}
	__finally9:
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_object_unref0 (builder);
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_clear_error (&_inner_error_);
#line 285 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 2109 "PicasaPublishing.c"
	}
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp7_ = builder;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp8_ = self->priv->publishing_parameters;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp9_ = self->priv->authenticator;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp10_ = spit_publishing_authenticator_can_logout (_tmp9_);
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp11_ = publishing_picasa_publishing_options_pane_new (_tmp7_, _tmp8_, _tmp10_);
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	opts_pane = _tmp11_;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp12_ = opts_pane;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_connect_object (_tmp12_, "publish", (GCallback) _publishing_picasa_picasa_publisher_on_publishing_options_publish_publishing_picasa_publishing_options_pane_publish, self, 0);
#line 297 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp13_ = opts_pane;
#line 297 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_connect_object (_tmp13_, "logout", (GCallback) _publishing_picasa_picasa_publisher_on_publishing_options_logout_publishing_picasa_publishing_options_pane_logout, self, 0);
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp14_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp15_ = opts_pane;
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp14_, G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp16_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp16_, FALSE);
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (opts_pane);
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (builder);
#line 2145 "PicasaPublishing.c"
}


static void _publishing_picasa_picasa_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self) {
#line 325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_on_upload_status_updated ((PublishingPicasaPicasaPublisher*) self, file_number, fraction_complete);
#line 2152 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_do_upload (PublishingPicasaPicasaPublisher* self) {
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	PublishingPicasaPublishingParameters* _tmp2_;
	gint _tmp3_;
	PublishingPicasaPublishingParameters* _tmp4_;
	gboolean _tmp5_;
	void* _tmp6_;
	GDestroyNotify _tmp7_;
	SpitPublishingProgressCallback _tmp8_;
	gboolean _tmp9_;
	SpitPublishingPublishable** publishables = NULL;
	SpitPublishingPluginHost* _tmp10_;
	gint _tmp11_;
	SpitPublishingPublishable** _tmp12_;
	gint publishables_length1;
	gint _publishables_size_;
	PublishingPicasaUploader* uploader = NULL;
	PublishingRESTSupportGoogleSession* _tmp13_;
	PublishingRESTSupportGoogleSession* _tmp14_;
	SpitPublishingPublishable** _tmp15_;
	gint _tmp15__length1;
	PublishingPicasaPublishingParameters* _tmp16_;
	PublishingPicasaUploader* _tmp17_;
	PublishingPicasaUploader* _tmp18_;
	PublishingPicasaUploader* _tmp19_;
	PublishingPicasaUploader* _tmp20_;
	PublishingPicasaUploader* _tmp21_;
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:304: ACTION: uploading media items to remote ser" \
"ver.");
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = self->priv->publishing_parameters;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = publishing_picasa_publishing_parameters_get_major_axis_size_pixels (_tmp2_);
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = self->priv->publishing_parameters;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = publishing_picasa_publishing_parameters_get_strip_metadata (_tmp4_);
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp8_ = spit_publishing_plugin_host_serialize_publishables (_tmp1_, _tmp3_, _tmp5_, &_tmp6_, &_tmp7_);
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter = _tmp8_;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter_target = _tmp6_;
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = _tmp7_;
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp9_ = publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!_tmp9_) {
#line 317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 2224 "PicasaPublishing.c"
	}
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp10_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp12_ = spit_publishing_plugin_host_get_publishables (_tmp10_, &_tmp11_);
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishables = _tmp12_;
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishables_length1 = _tmp11_;
#line 319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishables_size_ = publishables_length1;
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp13_ = publishing_rest_support_google_publisher_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp14_ = _tmp13_;
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp15_ = publishables;
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp15__length1 = publishables_length1;
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp16_ = self->priv->publishing_parameters;
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp17_ = publishing_picasa_uploader_new (_tmp14_, _tmp15_, _tmp15__length1, _tmp16_);
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp18_ = _tmp17_;
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp14_);
#line 320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	uploader = _tmp18_;
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp19_ = uploader;
#line 322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-complete", (GCallback) _publishing_picasa_picasa_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self, 0);
#line 323 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp20_ = uploader;
#line 323 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-error", (GCallback) _publishing_picasa_picasa_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self, 0);
#line 325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp21_ = uploader;
#line 325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_rest_support_batch_uploader_upload (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), _publishing_picasa_picasa_publisher_on_upload_status_updated_spit_publishing_progress_callback, self);
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_rest_support_batch_uploader_unref0 (uploader);
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishables = (_vala_array_free (publishables, publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 2270 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_do_show_success_pane (PublishingPicasaPicasaPublisher* self) {
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
#line 328 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PICASA_PUBLISHER (self));
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:329: ACTION: showing success pane.");
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 332 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spit_publishing_plugin_host_install_success_pane (_tmp1_);
#line 2289 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_real_do_logout (PublishingRESTSupportGooglePublisher* base) {
	PublishingPicasaPicasaPublisher * self;
	PublishingRESTSupportGoogleSession* _tmp0_;
	PublishingRESTSupportGoogleSession* _tmp1_;
	SpitPublishingAuthenticator* _tmp2_;
	gboolean _tmp3_;
#line 335 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER, PublishingPicasaPicasaPublisher);
#line 336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:336: ACTION: logging out user.");
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = _tmp0_;
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_rest_support_google_session_deauthenticate (_tmp1_);
#line 337 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = self->priv->authenticator;
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = spit_publishing_authenticator_can_logout (_tmp2_);
#line 339 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (_tmp3_) {
#line 2317 "PicasaPublishing.c"
		SpitPublishingAuthenticator* _tmp4_;
		SpitPublishingAuthenticator* _tmp5_;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp4_ = self->priv->authenticator;
#line 340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		spit_publishing_authenticator_logout (_tmp4_);
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp5_ = self->priv->authenticator;
#line 341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		spit_publishing_authenticator_authenticate (_tmp5_);
#line 2328 "PicasaPublishing.c"
	}
}


static gboolean publishing_picasa_picasa_publisher_real_is_running (PublishingRESTSupportGooglePublisher* base) {
	PublishingPicasaPicasaPublisher * self;
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER, PublishingPicasaPicasaPublisher);
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = self->priv->running;
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp0_;
#line 346 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 2345 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_real_start (PublishingRESTSupportGooglePublisher* base) {
	PublishingPicasaPicasaPublisher * self;
	gboolean _tmp0_;
	SpitPublishingAuthenticator* _tmp1_;
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER, PublishingPicasaPicasaPublisher);
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:350: PicasaPublisher: start( ) invoked.");
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (_tmp0_) {
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return;
#line 2363 "PicasaPublishing.c"
	}
#line 355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->running = TRUE;
#line 357 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = self->priv->authenticator;
#line 357 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spit_publishing_authenticator_authenticate (_tmp1_);
#line 2371 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_real_stop (PublishingRESTSupportGooglePublisher* base) {
	PublishingPicasaPicasaPublisher * self;
	PublishingRESTSupportGoogleSession* _tmp0_;
	PublishingRESTSupportGoogleSession* _tmp1_;
#line 360 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER, PublishingPicasaPicasaPublisher);
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_debug ("PicasaPublishing.vala:361: PicasaPublisher: stop( ) invoked.");
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_rest_support_google_publisher_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = _tmp0_;
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_rest_support_session_stop_transactions (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 365 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->running = FALSE;
#line 2393 "PicasaPublishing.c"
}


static SpitPublishingAuthenticator* publishing_picasa_picasa_publisher_real_get_authenticator (PublishingRESTSupportGooglePublisher* base) {
	PublishingPicasaPicasaPublisher * self;
	SpitPublishingAuthenticator* result = NULL;
	SpitPublishingAuthenticator* _tmp0_;
	SpitPublishingAuthenticator* _tmp5_;
	SpitPublishingAuthenticator* _tmp6_;
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER, PublishingPicasaPicasaPublisher);
#line 369 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = self->priv->authenticator;
#line 369 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (_tmp0_ == NULL) {
#line 2409 "PicasaPublishing.c"
		PublishingAuthenticatorFactory* _tmp1_;
		PublishingAuthenticatorFactory* _tmp2_;
		SpitPublishingPluginHost* _tmp3_;
		SpitPublishingAuthenticator* _tmp4_;
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp1_ = publishing_authenticator_factory_get_instance ();
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp2_ = _tmp1_;
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp3_ = publishing_rest_support_google_publisher_get_host (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, PublishingRESTSupportGooglePublisher));
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp4_ = spit_publishing_authenticator_factory_create (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, SPIT_PUBLISHING_TYPE_AUTHENTICATOR_FACTORY, SpitPublishingAuthenticatorFactory), "picasa", _tmp3_);
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_object_unref0 (self->priv->authenticator);
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		self->priv->authenticator = _tmp4_;
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_object_unref0 (_tmp2_);
#line 2428 "PicasaPublishing.c"
	}
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = self->priv->authenticator;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp6_;
#line 373 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 2438 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_class_init (PublishingPicasaPicasaPublisherClass * klass) {
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_picasa_publisher_parent_class = g_type_class_peek_parent (klass);
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPicasaPicasaPublisherPrivate));
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	((PublishingRESTSupportGooglePublisherClass *) klass)->on_login_flow_complete = (void (*) (PublishingRESTSupportGooglePublisher *)) publishing_picasa_picasa_publisher_real_on_login_flow_complete;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	((PublishingRESTSupportGooglePublisherClass *) klass)->do_logout = (void (*) (PublishingRESTSupportGooglePublisher *)) publishing_picasa_picasa_publisher_real_do_logout;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	((PublishingRESTSupportGooglePublisherClass *) klass)->is_running = (gboolean (*) (PublishingRESTSupportGooglePublisher *)) publishing_picasa_picasa_publisher_real_is_running;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	((PublishingRESTSupportGooglePublisherClass *) klass)->start = (void (*) (PublishingRESTSupportGooglePublisher *)) publishing_picasa_picasa_publisher_real_start;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	((PublishingRESTSupportGooglePublisherClass *) klass)->stop = (void (*) (PublishingRESTSupportGooglePublisher *)) publishing_picasa_picasa_publisher_real_stop;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	((PublishingRESTSupportGooglePublisherClass *) klass)->get_authenticator = (SpitPublishingAuthenticator* (*) (PublishingRESTSupportGooglePublisher *)) publishing_picasa_picasa_publisher_real_get_authenticator;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_picasa_picasa_publisher_finalize;
#line 2461 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_instance_init (PublishingPicasaPicasaPublisher * self) {
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv = PUBLISHING_PICASA_PICASA_PUBLISHER_GET_PRIVATE (self);
#line 2468 "PicasaPublishing.c"
}


static void publishing_picasa_picasa_publisher_finalize (GObject * obj) {
	PublishingPicasaPicasaPublisher * self;
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PICASA_TYPE_PICASA_PUBLISHER, PublishingPicasaPicasaPublisher);
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_picasa_publishing_parameters_unref0 (self->priv->publishing_parameters);
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->authenticator);
#line 60 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	G_OBJECT_CLASS (publishing_picasa_picasa_publisher_parent_class)->finalize (obj);
#line 2490 "PicasaPublishing.c"
}


GType publishing_picasa_picasa_publisher_get_type (void) {
	static volatile gsize publishing_picasa_picasa_publisher_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_picasa_picasa_publisher_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPicasaPicasaPublisherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_picasa_picasa_publisher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPicasaPicasaPublisher), 0, (GInstanceInitFunc) publishing_picasa_picasa_publisher_instance_init, NULL };
		GType publishing_picasa_picasa_publisher_type_id;
		publishing_picasa_picasa_publisher_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_PUBLISHER, "PublishingPicasaPicasaPublisher", &g_define_type_info, 0);
		g_once_init_leave (&publishing_picasa_picasa_publisher_type_id__volatile, publishing_picasa_picasa_publisher_type_id);
	}
	return publishing_picasa_picasa_publisher_type_id__volatile;
}


PublishingPicasaAlbum* publishing_picasa_album_construct (GType object_type, const gchar* name, const gchar* url) {
	PublishingPicasaAlbum* self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = (PublishingPicasaAlbum*) g_type_create_instance (object_type);
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = name;
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->name);
#line 382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->name = _tmp1_;
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = url;
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->url);
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->url = _tmp3_;
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self;
#line 2536 "PicasaPublishing.c"
}


PublishingPicasaAlbum* publishing_picasa_album_new (const gchar* name, const gchar* url) {
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return publishing_picasa_album_construct (PUBLISHING_PICASA_TYPE_ALBUM, name, url);
#line 2543 "PicasaPublishing.c"
}


static void publishing_picasa_value_album_init (GValue* value) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 2550 "PicasaPublishing.c"
}


static void publishing_picasa_value_album_free_value (GValue* value) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (value->data[0].v_pointer) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_album_unref (value->data[0].v_pointer);
#line 2559 "PicasaPublishing.c"
	}
}


static void publishing_picasa_value_album_copy_value (const GValue* src_value, GValue* dest_value) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		dest_value->data[0].v_pointer = publishing_picasa_album_ref (src_value->data[0].v_pointer);
#line 2569 "PicasaPublishing.c"
	} else {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 2573 "PicasaPublishing.c"
	}
}


static gpointer publishing_picasa_value_album_peek_pointer (const GValue* value) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return value->data[0].v_pointer;
#line 2581 "PicasaPublishing.c"
}


static gchar* publishing_picasa_value_album_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 2588 "PicasaPublishing.c"
		PublishingPicasaAlbum * object;
		object = collect_values[0].v_pointer;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2595 "PicasaPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2599 "PicasaPublishing.c"
		}
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = publishing_picasa_album_ref (object);
#line 2603 "PicasaPublishing.c"
	} else {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2607 "PicasaPublishing.c"
	}
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return NULL;
#line 2611 "PicasaPublishing.c"
}


static gchar* publishing_picasa_value_album_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingPicasaAlbum ** object_p;
	object_p = collect_values[0].v_pointer;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!object_p) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 2622 "PicasaPublishing.c"
	}
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*object_p = NULL;
#line 2628 "PicasaPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 2632 "PicasaPublishing.c"
	} else {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*object_p = publishing_picasa_album_ref (value->data[0].v_pointer);
#line 2636 "PicasaPublishing.c"
	}
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return NULL;
#line 2640 "PicasaPublishing.c"
}


GParamSpec* publishing_picasa_param_spec_album (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingPicasaParamSpecAlbum* spec;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_PICASA_TYPE_ALBUM), NULL);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 2654 "PicasaPublishing.c"
}


gpointer publishing_picasa_value_get_album (const GValue* value) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PICASA_TYPE_ALBUM), NULL);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return value->data[0].v_pointer;
#line 2663 "PicasaPublishing.c"
}


void publishing_picasa_value_set_album (GValue* value, gpointer v_object) {
	PublishingPicasaAlbum * old;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PICASA_TYPE_ALBUM));
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	old = value->data[0].v_pointer;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (v_object) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PICASA_TYPE_ALBUM));
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_album_ref (value->data[0].v_pointer);
#line 2683 "PicasaPublishing.c"
	} else {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2687 "PicasaPublishing.c"
	}
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (old) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_album_unref (old);
#line 2693 "PicasaPublishing.c"
	}
}


void publishing_picasa_value_take_album (GValue* value, gpointer v_object) {
	PublishingPicasaAlbum * old;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PICASA_TYPE_ALBUM));
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	old = value->data[0].v_pointer;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (v_object) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PICASA_TYPE_ALBUM));
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 2712 "PicasaPublishing.c"
	} else {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2716 "PicasaPublishing.c"
	}
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (old) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_album_unref (old);
#line 2722 "PicasaPublishing.c"
	}
}


static void publishing_picasa_album_class_init (PublishingPicasaAlbumClass * klass) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_album_parent_class = g_type_class_peek_parent (klass);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	((PublishingPicasaAlbumClass *) klass)->finalize = publishing_picasa_album_finalize;
#line 2732 "PicasaPublishing.c"
}


static void publishing_picasa_album_instance_init (PublishingPicasaAlbum * self) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->ref_count = 1;
#line 2739 "PicasaPublishing.c"
}


static void publishing_picasa_album_finalize (PublishingPicasaAlbum * obj) {
	PublishingPicasaAlbum * self;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PICASA_TYPE_ALBUM, PublishingPicasaAlbum);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_handlers_destroy (self);
#line 378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->name);
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->url);
#line 2753 "PicasaPublishing.c"
}


GType publishing_picasa_album_get_type (void) {
	static volatile gsize publishing_picasa_album_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_picasa_album_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_picasa_value_album_init, publishing_picasa_value_album_free_value, publishing_picasa_value_album_copy_value, publishing_picasa_value_album_peek_pointer, "p", publishing_picasa_value_album_collect_value, "p", publishing_picasa_value_album_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPicasaAlbumClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_picasa_album_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPicasaAlbum), 0, (GInstanceInitFunc) publishing_picasa_album_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_picasa_album_type_id;
		publishing_picasa_album_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingPicasaAlbum", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_picasa_album_type_id__volatile, publishing_picasa_album_type_id);
	}
	return publishing_picasa_album_type_id__volatile;
}


gpointer publishing_picasa_album_ref (gpointer instance) {
	PublishingPicasaAlbum * self;
	self = instance;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return instance;
#line 2778 "PicasaPublishing.c"
}


void publishing_picasa_album_unref (gpointer instance) {
	PublishingPicasaAlbum * self;
	self = instance;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		PUBLISHING_PICASA_ALBUM_GET_CLASS (self)->finalize (self);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2791 "PicasaPublishing.c"
	}
}


PublishingPicasaAlbumDirectoryTransaction* publishing_picasa_album_directory_transaction_construct (GType object_type, PublishingRESTSupportGoogleSession* session) {
	PublishingPicasaAlbumDirectoryTransaction* self = NULL;
	PublishingRESTSupportGoogleSession* _tmp0_;
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_GOOGLE_SESSION (session), NULL);
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = session;
#line 393 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = (PublishingPicasaAlbumDirectoryTransaction*) publishing_rest_support_google_publisher_authenticated_transaction_construct (object_type, _tmp0_, PUBLISHING_PICASA_ALBUM_DIRECTORY_TRANSACTION_ENDPOINT_URL, PUBLISHING_REST_SUPPORT_HTTP_METHOD_GET);
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self;
#line 2807 "PicasaPublishing.c"
}


PublishingPicasaAlbumDirectoryTransaction* publishing_picasa_album_directory_transaction_new (PublishingRESTSupportGoogleSession* session) {
#line 392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return publishing_picasa_album_directory_transaction_construct (PUBLISHING_PICASA_TYPE_ALBUM_DIRECTORY_TRANSACTION, session);
#line 2814 "PicasaPublishing.c"
}


gchar* publishing_picasa_album_directory_transaction_validate_xml (PublishingRESTSupportXmlDocument* doc) {
	gchar* result = NULL;
	xmlNode* document_root = NULL;
	PublishingRESTSupportXmlDocument* _tmp0_;
	xmlNode* _tmp1_;
	gboolean _tmp2_ = FALSE;
	xmlNode* _tmp3_;
	const gchar* _tmp4_;
#line 396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_XML_DOCUMENT (doc), NULL);
#line 397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = doc;
#line 397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = publishing_rest_support_xml_document_get_root_node (_tmp0_);
#line 397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	document_root = _tmp1_;
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = document_root;
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = _tmp3_->name;
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (g_strcmp0 (_tmp4_, "feed") == 0) {
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp2_ = TRUE;
#line 2842 "PicasaPublishing.c"
	} else {
		xmlNode* _tmp5_;
		const gchar* _tmp6_;
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp5_ = document_root;
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp6_ = _tmp5_->name;
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp2_ = g_strcmp0 (_tmp6_, "entry") == 0;
#line 2852 "PicasaPublishing.c"
	}
#line 398 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (_tmp2_) {
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		result = NULL;
#line 399 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return result;
#line 2860 "PicasaPublishing.c"
	} else {
		gchar* _tmp7_;
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp7_ = g_strdup ("response root node isn't a <feed> or <entry>");
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		result = _tmp7_;
#line 401 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return result;
#line 2869 "PicasaPublishing.c"
	}
}


static void publishing_picasa_album_directory_transaction_class_init (PublishingPicasaAlbumDirectoryTransactionClass * klass) {
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_album_directory_transaction_parent_class = g_type_class_peek_parent (klass);
#line 2877 "PicasaPublishing.c"
}


static void publishing_picasa_album_directory_transaction_instance_init (PublishingPicasaAlbumDirectoryTransaction * self) {
}


GType publishing_picasa_album_directory_transaction_get_type (void) {
	static volatile gsize publishing_picasa_album_directory_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_picasa_album_directory_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPicasaAlbumDirectoryTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_picasa_album_directory_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPicasaAlbumDirectoryTransaction), 0, (GInstanceInitFunc) publishing_picasa_album_directory_transaction_instance_init, NULL };
		GType publishing_picasa_album_directory_transaction_type_id;
		publishing_picasa_album_directory_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_GOOGLE_PUBLISHER_TYPE_AUTHENTICATED_TRANSACTION, "PublishingPicasaAlbumDirectoryTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_picasa_album_directory_transaction_type_id__volatile, publishing_picasa_album_directory_transaction_type_id);
	}
	return publishing_picasa_album_directory_transaction_type_id__volatile;
}


static gpointer _publishing_rest_support_session_ref0 (gpointer self) {
#line 419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self ? publishing_rest_support_session_ref (self) : NULL;
#line 2900 "PicasaPublishing.c"
}


static gpointer _publishing_picasa_publishing_parameters_ref0 (gpointer self) {
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self ? publishing_picasa_publishing_parameters_ref (self) : NULL;
#line 2907 "PicasaPublishing.c"
}


PublishingPicasaUploadTransaction* publishing_picasa_upload_transaction_construct (GType object_type, PublishingRESTSupportGoogleSession* session, PublishingPicasaPublishingParameters* parameters, SpitPublishingPublishable* publishable) {
	PublishingPicasaUploadTransaction* self = NULL;
	PublishingRESTSupportGoogleSession* _tmp0_;
	PublishingPicasaPublishingParameters* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	PublishingRESTSupportGoogleSession* _tmp4_;
	gboolean _tmp5_;
	PublishingRESTSupportGoogleSession* _tmp6_;
	PublishingRESTSupportGoogleSession* _tmp7_;
	PublishingPicasaPublishingParameters* _tmp8_;
	PublishingPicasaPublishingParameters* _tmp9_;
	SpitPublishingPublishable* _tmp10_;
	SpitPublishingPublishable* _tmp11_;
	SpitPublishingPublishable* _tmp12_;
	SpitPublishingPublisherMediaType _tmp13_;
	GError * _inner_error_ = NULL;
#line 414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_GOOGLE_SESSION (session), NULL);
#line 414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = session;
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = parameters;
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = publishing_picasa_publishing_parameters_get_target_album_feed_url (_tmp1_);
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = _tmp2_;
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = (PublishingPicasaUploadTransaction*) publishing_rest_support_google_publisher_authenticated_transaction_construct (object_type, _tmp0_, _tmp3_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp3_);
#line 418 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = session;
#line 418 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 418 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_vala_assert (_tmp5_, "session.is_authenticated()");
#line 419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp6_ = session;
#line 419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp7_ = _publishing_rest_support_session_ref0 (_tmp6_);
#line 419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->session = _tmp7_;
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp8_ = parameters;
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp9_ = _publishing_picasa_publishing_parameters_ref0 (_tmp8_);
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_picasa_publishing_parameters_unref0 (self->priv->parameters);
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->parameters = _tmp9_;
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp10_ = publishable;
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp11_ = _g_object_ref0 (_tmp10_);
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->publishable);
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->publishable = _tmp11_;
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp12_ = publishable;
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp13_ = spit_publishing_publishable_get_media_type (_tmp12_);
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (_tmp13_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 2982 "PicasaPublishing.c"
		{
			GFileInfo* info = NULL;
			SpitPublishingPublishable* _tmp14_;
			GFile* _tmp15_;
			GFile* _tmp16_;
			GFileInfo* _tmp17_;
			GFileInfo* _tmp18_;
			GFileInfo* _tmp19_;
			const gchar* _tmp20_;
			gchar* _tmp21_;
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp14_ = self->priv->publishable;
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp15_ = spit_publishing_publishable_get_serialized_file (_tmp14_);
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp16_ = _tmp15_;
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp17_ = g_file_query_info (_tmp16_, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE, G_FILE_QUERY_INFO_NONE, NULL, &_inner_error_);
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp18_ = _tmp17_;
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_object_unref0 (_tmp16_);
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			info = _tmp18_;
#line 424 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3009 "PicasaPublishing.c"
				goto __catch10_g_error;
			}
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp19_ = info;
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp20_ = g_file_info_get_content_type (_tmp19_);
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp21_ = g_content_type_get_mime_type (_tmp20_);
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (self->priv->mime_type);
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			self->priv->mime_type = _tmp21_;
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_object_unref0 (info);
#line 3024 "PicasaPublishing.c"
		}
		goto __finally10;
		__catch10_g_error:
		{
			GError* err = NULL;
			gchar* _tmp22_;
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			err = _inner_error_;
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_inner_error_ = NULL;
#line 427 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp22_ = g_strdup ("video/mpeg");
#line 427 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (self->priv->mime_type);
#line 427 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			self->priv->mime_type = _tmp22_;
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_error_free0 (err);
#line 3043 "PicasaPublishing.c"
		}
		__finally10:
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_clear_error (&_inner_error_);
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return NULL;
#line 3054 "PicasaPublishing.c"
		}
	} else {
		gchar* _tmp23_;
#line 430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp23_ = g_strdup ("image/jpeg");
#line 430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_free0 (self->priv->mime_type);
#line 430 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		self->priv->mime_type = _tmp23_;
#line 3064 "PicasaPublishing.c"
	}
#line 414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self;
#line 3068 "PicasaPublishing.c"
}


PublishingPicasaUploadTransaction* publishing_picasa_upload_transaction_new (PublishingRESTSupportGoogleSession* session, PublishingPicasaPublishingParameters* parameters, SpitPublishingPublishable* publishable) {
#line 414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return publishing_picasa_upload_transaction_construct (PUBLISHING_PICASA_TYPE_UPLOAD_TRANSACTION, session, parameters, publishable);
#line 3075 "PicasaPublishing.c"
}


static glong string_strnlen (gchar* str, glong maxlen) {
	glong result = 0L;
	gchar* end = NULL;
	gchar* _tmp0_;
	glong _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 1322 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = str;
#line 1322 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = maxlen;
#line 1322 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp2_ = memchr (_tmp0_, 0, (gsize) _tmp1_);
#line 1322 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	end = _tmp2_;
#line 1323 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = end;
#line 1323 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp3_ == NULL) {
#line 3098 "PicasaPublishing.c"
		glong _tmp4_;
#line 1324 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = maxlen;
#line 1324 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = _tmp4_;
#line 1324 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 3106 "PicasaPublishing.c"
	} else {
		gchar* _tmp5_;
		gchar* _tmp6_;
#line 1326 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp5_ = end;
#line 1326 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6_ = str;
#line 1326 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = (glong) (_tmp5_ - _tmp6_);
#line 1326 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 3118 "PicasaPublishing.c"
	}
}


static gchar* string_substring (const gchar* self, glong offset, glong len) {
	gchar* result = NULL;
	glong string_length = 0L;
	gboolean _tmp0_ = FALSE;
	glong _tmp1_;
	glong _tmp8_;
	glong _tmp14_;
	glong _tmp17_;
	glong _tmp18_;
	glong _tmp19_;
	glong _tmp20_;
	glong _tmp21_;
	gchar* _tmp22_;
#line 1333 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = offset;
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp1_ >= ((glong) 0)) {
#line 3142 "PicasaPublishing.c"
		glong _tmp2_;
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp2_ = len;
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp0_ = _tmp2_ >= ((glong) 0);
#line 3148 "PicasaPublishing.c"
	} else {
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp0_ = FALSE;
#line 3152 "PicasaPublishing.c"
	}
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 3156 "PicasaPublishing.c"
		glong _tmp3_;
		glong _tmp4_;
		glong _tmp5_;
#line 1337 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp3_ = offset;
#line 1337 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = len;
#line 1337 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp5_ = string_strnlen ((gchar*) self, _tmp3_ + _tmp4_);
#line 1337 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		string_length = _tmp5_;
#line 3168 "PicasaPublishing.c"
	} else {
		gint _tmp6_;
		gint _tmp7_;
#line 1339 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6_ = strlen (self);
#line 1339 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp7_ = _tmp6_;
#line 1339 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		string_length = (glong) _tmp7_;
#line 3178 "PicasaPublishing.c"
	}
#line 1342 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp8_ = offset;
#line 1342 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp8_ < ((glong) 0)) {
#line 3184 "PicasaPublishing.c"
		glong _tmp9_;
		glong _tmp10_;
		glong _tmp11_;
#line 1343 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp9_ = string_length;
#line 1343 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp10_ = offset;
#line 1343 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		offset = _tmp9_ + _tmp10_;
#line 1344 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp11_ = offset;
#line 1344 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp11_ >= ((glong) 0), NULL);
#line 3198 "PicasaPublishing.c"
	} else {
		glong _tmp12_;
		glong _tmp13_;
#line 1346 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp12_ = offset;
#line 1346 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp13_ = string_length;
#line 1346 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp12_ <= _tmp13_, NULL);
#line 3208 "PicasaPublishing.c"
	}
#line 1348 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp14_ = len;
#line 1348 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp14_ < ((glong) 0)) {
#line 3214 "PicasaPublishing.c"
		glong _tmp15_;
		glong _tmp16_;
#line 1349 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1349 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp16_ = offset;
#line 1349 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		len = _tmp15_ - _tmp16_;
#line 3223 "PicasaPublishing.c"
	}
#line 1351 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp17_ = offset;
#line 1351 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp18_ = len;
#line 1351 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp19_ = string_length;
#line 1351 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail ((_tmp17_ + _tmp18_) <= _tmp19_, NULL);
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp20_ = offset;
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp21_ = len;
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp22_ = g_strndup (((gchar*) self) + _tmp20_, (gsize) _tmp21_);
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp22_;
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 3243 "PicasaPublishing.c"
}


static gchar* _vala_g_strjoinv (const gchar* separator, gchar** str_array, int str_array_length1) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gchar** _tmp3_;
	gint _tmp3__length1;
#line 1078 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = separator;
#line 1078 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp0_ == NULL) {
#line 1079 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		separator = "";
#line 3260 "PicasaPublishing.c"
	}
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = str_array;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3__length1 = str_array_length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp2_ = TRUE;
#line 3270 "PicasaPublishing.c"
	} else {
		gchar** _tmp4_;
		gint _tmp4__length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = str_array;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4__length1 = str_array_length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp4__length1 > 0;
#line 3280 "PicasaPublishing.c"
	}
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp2_) {
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 3286 "PicasaPublishing.c"
	} else {
		gboolean _tmp5_ = FALSE;
		gchar** _tmp6_;
		gint _tmp6__length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6_ = str_array;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6__length1 = str_array_length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		if (_tmp6__length1 == -1) {
#line 3297 "PicasaPublishing.c"
			gchar** _tmp7_;
			gint _tmp7__length1;
			const gchar* _tmp8_;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp7_ = str_array;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp7__length1 = str_array_length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp8_ = _tmp7_[0];
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp5_ = _tmp8_ != NULL;
#line 3309 "PicasaPublishing.c"
		} else {
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp5_ = FALSE;
#line 3313 "PicasaPublishing.c"
		}
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp1_ = _tmp5_;
#line 3317 "PicasaPublishing.c"
	}
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 3321 "PicasaPublishing.c"
		gint i = 0;
		gsize len = 0UL;
		gint _tmp31_;
		gint _tmp33_;
		gint _tmp34_;
		gsize _tmp35_;
		const gchar* _tmp36_;
		gint _tmp37_;
		gint _tmp38_;
		gint _tmp39_;
		const gchar* res = NULL;
		gsize _tmp40_;
		void* _tmp41_;
		void* ptr = NULL;
		const gchar* _tmp42_;
		gchar** _tmp43_;
		gint _tmp43__length1;
		const gchar* _tmp44_;
		void* _tmp45_;
		const gchar* _tmp62_;
#line 1083 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		len = (gsize) 1;
#line 3344 "PicasaPublishing.c"
		{
			gboolean _tmp9_ = FALSE;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			i = 0;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp9_ = TRUE;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 3353 "PicasaPublishing.c"
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				gchar** _tmp13_;
				gint _tmp13__length1;
				gint _tmp21_ = 0;
				gchar** _tmp22_;
				gint _tmp22__length1;
				gint _tmp23_;
				const gchar* _tmp24_;
				gsize _tmp30_;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (!_tmp9_) {
#line 3366 "PicasaPublishing.c"
					gint _tmp10_;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp10_ = i;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					i = _tmp10_ + 1;
#line 3372 "PicasaPublishing.c"
				}
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp9_ = FALSE;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp13_ = str_array;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp13__length1 = str_array_length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (_tmp13__length1 != -1) {
#line 3382 "PicasaPublishing.c"
					gint _tmp14_;
					gchar** _tmp15_;
					gint _tmp15__length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp14_ = i;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp15_ = str_array;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp15__length1 = str_array_length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp12_ = _tmp14_ < _tmp15__length1;
#line 3394 "PicasaPublishing.c"
				} else {
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp12_ = FALSE;
#line 3398 "PicasaPublishing.c"
				}
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (_tmp12_) {
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp11_ = TRUE;
#line 3404 "PicasaPublishing.c"
				} else {
					gboolean _tmp16_ = FALSE;
					gchar** _tmp17_;
					gint _tmp17__length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp17_ = str_array;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp17__length1 = str_array_length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					if (_tmp17__length1 == -1) {
#line 3415 "PicasaPublishing.c"
						gchar** _tmp18_;
						gint _tmp18__length1;
						gint _tmp19_;
						const gchar* _tmp20_;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp18_ = str_array;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp18__length1 = str_array_length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp19_ = i;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp20_ = _tmp18_[_tmp19_];
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp16_ = _tmp20_ != NULL;
#line 3430 "PicasaPublishing.c"
					} else {
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp16_ = FALSE;
#line 3434 "PicasaPublishing.c"
					}
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp11_ = _tmp16_;
#line 3438 "PicasaPublishing.c"
				}
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (!_tmp11_) {
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					break;
#line 3444 "PicasaPublishing.c"
				}
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp22_ = str_array;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp22__length1 = str_array_length1;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp23_ = i;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp24_ = _tmp22_[_tmp23_];
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (_tmp24_ != NULL) {
#line 3456 "PicasaPublishing.c"
					gchar** _tmp25_;
					gint _tmp25__length1;
					gint _tmp26_;
					const gchar* _tmp27_;
					gint _tmp28_;
					gint _tmp29_;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp25_ = str_array;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp25__length1 = str_array_length1;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp26_ = i;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp27_ = _tmp25_[_tmp26_];
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp28_ = strlen ((const gchar*) _tmp27_);
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp29_ = _tmp28_;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp21_ = _tmp29_;
#line 3477 "PicasaPublishing.c"
				} else {
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp21_ = 0;
#line 3481 "PicasaPublishing.c"
				}
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp30_ = len;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				len = _tmp30_ + _tmp21_;
#line 3487 "PicasaPublishing.c"
			}
		}
#line 1087 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp31_ = i;
#line 1087 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		if (_tmp31_ == 0) {
#line 3494 "PicasaPublishing.c"
			gchar* _tmp32_;
#line 1088 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp32_ = g_strdup ("");
#line 1088 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			result = _tmp32_;
#line 1088 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			return result;
#line 3502 "PicasaPublishing.c"
		}
#line 1090 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp33_ = i;
#line 1090 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		str_array_length1 = _tmp33_;
#line 1090 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp34_ = str_array_length1;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp35_ = len;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp36_ = separator;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp37_ = strlen ((const gchar*) _tmp36_);
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp38_ = _tmp37_;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp39_ = i;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		len = _tmp35_ + (_tmp38_ * (_tmp39_ - 1));
#line 1093 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp40_ = len;
#line 1093 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp41_ = g_malloc (_tmp40_);
#line 1093 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		res = _tmp41_;
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp42_ = res;
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp43_ = str_array;
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp43__length1 = str_array_length1;
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp44_ = _tmp43_[0];
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp45_ = g_stpcpy ((void*) _tmp42_, (const gchar*) _tmp44_);
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		ptr = _tmp45_;
#line 3540 "PicasaPublishing.c"
		{
			gboolean _tmp46_ = FALSE;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			i = 1;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp46_ = TRUE;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 3549 "PicasaPublishing.c"
				gint _tmp48_;
				gchar** _tmp49_;
				gint _tmp49__length1;
				void* _tmp50_;
				const gchar* _tmp51_;
				void* _tmp52_;
				const gchar* _tmp53_ = NULL;
				gchar** _tmp54_;
				gint _tmp54__length1;
				gint _tmp55_;
				const gchar* _tmp56_;
				void* _tmp60_;
				void* _tmp61_;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (!_tmp46_) {
#line 3565 "PicasaPublishing.c"
					gint _tmp47_;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp47_ = i;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					i = _tmp47_ + 1;
#line 3571 "PicasaPublishing.c"
				}
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp46_ = FALSE;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp48_ = i;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp49_ = str_array;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp49__length1 = str_array_length1;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (!(_tmp48_ < _tmp49__length1)) {
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					break;
#line 3585 "PicasaPublishing.c"
				}
#line 1096 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp50_ = ptr;
#line 1096 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp51_ = separator;
#line 1096 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp52_ = g_stpcpy (_tmp50_, (const gchar*) _tmp51_);
#line 1096 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				ptr = _tmp52_;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp54_ = str_array;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp54__length1 = str_array_length1;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp55_ = i;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp56_ = _tmp54_[_tmp55_];
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (_tmp56_ != NULL) {
#line 3605 "PicasaPublishing.c"
					gchar** _tmp57_;
					gint _tmp57__length1;
					gint _tmp58_;
					const gchar* _tmp59_;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp57_ = str_array;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp57__length1 = str_array_length1;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp58_ = i;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp59_ = _tmp57_[_tmp58_];
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp53_ = (const gchar*) _tmp59_;
#line 3620 "PicasaPublishing.c"
				} else {
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp53_ = "";
#line 3624 "PicasaPublishing.c"
				}
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp60_ = ptr;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp61_ = g_stpcpy (_tmp60_, _tmp53_);
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				ptr = _tmp61_;
#line 3632 "PicasaPublishing.c"
			}
		}
#line 1100 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp62_ = res;
#line 1100 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		res = NULL;
#line 1100 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = (gchar*) _tmp62_;
#line 1100 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 3643 "PicasaPublishing.c"
	} else {
		gchar* _tmp63_;
#line 1102 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp63_ = g_strdup ("");
#line 1102 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = _tmp63_;
#line 1102 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 3652 "PicasaPublishing.c"
	}
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1;
	gint _res_size_;
	gint _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	guint8* _tmp3_;
	gint _tmp3__length1;
	guint8* _tmp4_;
	gint _tmp4__length1;
#line 1428 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1429 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1429 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1429 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 3697 "PicasaPublishing.c"
	}
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 3703 "PicasaPublishing.c"
}


static void _vala_SoupBuffer_free (SoupBuffer* self) {
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_boxed_free (soup_buffer_get_type (), self);
#line 3710 "PicasaPublishing.c"
}


static void _vala_SoupMultipart_free (SoupMultipart* self) {
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_boxed_free (soup_multipart_get_type (), self);
#line 3717 "PicasaPublishing.c"
}


static void publishing_picasa_upload_transaction_real_execute (PublishingRESTSupportTransaction* base, GError** error) {
	PublishingPicasaUploadTransaction * self;
	SoupMultipart* message_parts = NULL;
	SoupMultipart* _tmp0_;
	gchar* summary = NULL;
	gchar* _tmp1_;
	SpitPublishingPublishable* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gboolean _tmp5_;
	gchar** keywords = NULL;
	SpitPublishingPublishable* _tmp12_;
	gint _tmp13_;
	gchar** _tmp14_;
	gint keywords_length1;
	gint _keywords_size_;
	gchar* keywords_string = NULL;
	gchar* _tmp15_;
	gchar** _tmp16_;
	gint _tmp16__length1;
	gchar* metadata = NULL;
	SpitPublishingPublishable* _tmp51_;
	gchar* _tmp52_;
	gchar* _tmp53_;
	gchar* _tmp54_;
	gchar* _tmp55_;
	const gchar* _tmp56_;
	const gchar* _tmp57_;
	gchar* _tmp58_;
	gchar* _tmp59_;
	SoupBuffer* metadata_buffer = NULL;
	const gchar* _tmp60_;
	guint8* _tmp61_;
	gint _tmp61__length1;
	guint8* _tmp62_;
	gint _tmp62__length1;
	SoupBuffer* _tmp63_;
	SoupMultipart* _tmp64_;
	SoupBuffer* _tmp65_;
	guint8* photo_data = NULL;
	GMappedFile* _tmp87_;
	gchar* _tmp88_;
	gint photo_data_length1;
	gint _photo_data_size_;
	GMappedFile* _tmp89_;
	gsize _tmp90_;
	gint _tmp91_;
	SoupBuffer* bindable_data = NULL;
	SoupBuffer* _tmp92_;
	SoupMultipart* _tmp93_;
	SpitPublishingPublishable* _tmp94_;
	GFile* _tmp95_;
	GFile* _tmp96_;
	gchar* _tmp97_;
	gchar* _tmp98_;
	const gchar* _tmp99_;
	SoupMessage* outbound_message = NULL;
	gchar* _tmp100_;
	gchar* _tmp101_;
	SoupMultipart* _tmp102_;
	SoupMessage* _tmp103_;
	SoupMessage* _tmp104_;
	SoupMessageHeaders* _tmp105_;
	PublishingRESTSupportGoogleSession* _tmp106_;
	gchar* _tmp107_;
	gchar* _tmp108_;
	gchar* _tmp109_;
	gchar* _tmp110_;
	GError * _inner_error_ = NULL;
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PICASA_TYPE_UPLOAD_TRANSACTION, PublishingPicasaUploadTransaction);
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = soup_multipart_new ("multipart/related");
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	message_parts = _tmp0_;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = g_strdup ("");
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	summary = _tmp1_;
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = self->priv->publishable;
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = spit_publishing_publishable_get_publishing_name (_tmp2_);
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = _tmp3_;
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = g_strcmp0 (_tmp4_, "") != 0;
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp4_);
#line 439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (_tmp5_) {
#line 3812 "PicasaPublishing.c"
		SpitPublishingPublishable* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp6_ = self->priv->publishable;
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp7_ = spit_publishing_publishable_get_publishing_name (_tmp6_);
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp8_ = _tmp7_;
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp9_ = publishing_rest_support_decimal_entity_encode (_tmp8_);
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp10_ = _tmp9_;
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp11_ = g_strdup_printf ("<atom:summary>%s</atom:summary>", _tmp10_);
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_free0 (summary);
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		summary = _tmp11_;
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_free0 (_tmp10_);
#line 440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_free0 (_tmp8_);
#line 3839 "PicasaPublishing.c"
	}
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp12_ = self->priv->publishable;
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp14_ = spit_publishing_publishable_get_publishing_keywords (_tmp12_, &_tmp13_);
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	keywords = _tmp14_;
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	keywords_length1 = _tmp13_;
#line 444 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_keywords_size_ = keywords_length1;
#line 445 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp15_ = g_strdup ("");
#line 445 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	keywords_string = _tmp15_;
#line 446 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp16_ = keywords;
#line 446 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp16__length1 = keywords_length1;
#line 446 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (_tmp16__length1 > 0) {
#line 3861 "PicasaPublishing.c"
		const gchar* _tmp47_;
		gchar* _tmp48_;
		const gchar* _tmp49_;
		gchar* _tmp50_;
		{
			gint i = 0;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			i = 0;
#line 3870 "PicasaPublishing.c"
			{
				gboolean _tmp17_ = FALSE;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp17_ = TRUE;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				while (TRUE) {
#line 3877 "PicasaPublishing.c"
					gint _tmp19_;
					gchar** _tmp20_;
					gint _tmp20__length1;
					gchar** tmp = NULL;
					gint tmp_length1 = 0;
					gint _tmp_size_ = 0;
					gchar** _tmp21_;
					gint _tmp21__length1;
					gint _tmp22_;
					const gchar* _tmp23_;
					gboolean _tmp24_;
					const gchar* _tmp37_;
					gint _tmp38_;
					gint _tmp39_;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					if (!_tmp17_) {
#line 3894 "PicasaPublishing.c"
						gint _tmp18_;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp18_ = i;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						i = _tmp18_ + 1;
#line 3900 "PicasaPublishing.c"
					}
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp17_ = FALSE;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp19_ = i;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp20_ = keywords;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp20__length1 = keywords_length1;
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					if (!(_tmp19_ < _tmp20__length1)) {
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						break;
#line 3914 "PicasaPublishing.c"
					}
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp21_ = keywords;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp21__length1 = keywords_length1;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp22_ = i;
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp23_ = _tmp21_[_tmp22_];
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp24_ = g_str_has_prefix (_tmp23_, "/");
#line 450 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					if (_tmp24_) {
#line 3928 "PicasaPublishing.c"
						gchar** _tmp25_;
						gint _tmp25__length1;
						gint _tmp26_;
						const gchar* _tmp27_;
						gchar* _tmp28_;
						gchar* _tmp29_;
						gchar** _tmp30_;
						gchar** _tmp31_;
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp25_ = keywords;
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp25__length1 = keywords_length1;
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp26_ = i;
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp27_ = _tmp25_[_tmp26_];
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp28_ = string_substring (_tmp27_, (glong) 1, (glong) -1);
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp29_ = _tmp28_;
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp31_ = _tmp30_ = g_strsplit (_tmp29_, "/", 0);
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						tmp = (_vala_array_free (tmp, tmp_length1, (GDestroyNotify) g_free), NULL);
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						tmp = _tmp31_;
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						tmp_length1 = _vala_array_length (_tmp30_);
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp_size_ = tmp_length1;
#line 451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_g_free0 (_tmp29_);
#line 3961 "PicasaPublishing.c"
					} else {
						gchar** _tmp32_;
						gint _tmp32__length1;
						gint _tmp33_;
						const gchar* _tmp34_;
						gchar** _tmp35_;
						gchar** _tmp36_;
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp32_ = keywords;
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp32__length1 = keywords_length1;
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp33_ = i;
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp34_ = _tmp32_[_tmp33_];
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp36_ = _tmp35_ = g_strsplit (_tmp34_, "/", 0);
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						tmp = (_vala_array_free (tmp, tmp_length1, (GDestroyNotify) g_free), NULL);
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						tmp = _tmp36_;
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						tmp_length1 = _vala_array_length (_tmp35_);
#line 453 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp_size_ = tmp_length1;
#line 3987 "PicasaPublishing.c"
					}
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp37_ = keywords_string;
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp38_ = strlen (_tmp37_);
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp39_ = _tmp38_;
#line 455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					if (_tmp39_ > 0) {
#line 3997 "PicasaPublishing.c"
						const gchar* _tmp40_;
						gchar** _tmp41_;
						gint _tmp41__length1;
						gchar* _tmp42_;
						gchar* _tmp43_;
						gchar* _tmp44_;
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp40_ = keywords_string;
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp41_ = tmp;
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp41__length1 = tmp_length1;
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp42_ = _vala_g_strjoinv (", ", _tmp41_, _tmp41__length1);
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp43_ = _tmp42_;
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp44_ = g_strjoin (", ", _tmp40_, _tmp43_, NULL);
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_g_free0 (keywords_string);
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						keywords_string = _tmp44_;
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_g_free0 (_tmp43_);
#line 4022 "PicasaPublishing.c"
					} else {
						gchar** _tmp45_;
						gint _tmp45__length1;
						gchar* _tmp46_;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp45_ = tmp;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp45__length1 = tmp_length1;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp46_ = _vala_g_strjoinv (", ", _tmp45_, _tmp45__length1);
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_g_free0 (keywords_string);
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						keywords_string = _tmp46_;
#line 4037 "PicasaPublishing.c"
					}
#line 447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					tmp = (_vala_array_free (tmp, tmp_length1, (GDestroyNotify) g_free), NULL);
#line 4041 "PicasaPublishing.c"
				}
			}
		}
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp47_ = keywords_string;
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp48_ = publishing_rest_support_decimal_entity_encode (_tmp47_);
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_free0 (keywords_string);
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		keywords_string = _tmp48_;
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp49_ = keywords_string;
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp50_ = g_strdup_printf ("<mrss:group><mrss:keywords>%s</mrss:keywords></mrss:group>", _tmp49_);
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_free0 (keywords_string);
#line 462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		keywords_string = _tmp50_;
#line 4061 "PicasaPublishing.c"
	}
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp51_ = self->priv->publishable;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp52_ = spit_publishing_publishable_get_param_string (_tmp51_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp53_ = _tmp52_;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp54_ = publishing_rest_support_decimal_entity_encode (_tmp53_);
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp55_ = _tmp54_;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp56_ = summary;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp57_ = keywords_string;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp58_ = g_strdup_printf (PUBLISHING_PICASA_UPLOAD_TRANSACTION_METADATA_TEMPLATE, _tmp55_, _tmp56_, _tmp57_);
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp59_ = _tmp58_;
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp55_);
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp53_);
#line 465 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	metadata = _tmp59_;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp60_ = metadata;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp61_ = string_get_data (_tmp60_, &_tmp61__length1);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp62_ = _tmp61_;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp62__length1 = _tmp61__length1;
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp63_ = soup_buffer_new (SOUP_MEMORY_COPY, _tmp62_, _tmp62__length1);
#line 468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	metadata_buffer = _tmp63_;
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp64_ = message_parts;
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp65_ = metadata_buffer;
#line 469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	soup_multipart_append_form_file (_tmp64_, "", "", "application/atom+xml", _tmp65_);
#line 4105 "PicasaPublishing.c"
	{
		GMappedFile* _tmp66_ = NULL;
		SpitPublishingPublishable* _tmp67_;
		GFile* _tmp68_;
		GFile* _tmp69_;
		gchar* _tmp70_;
		gchar* _tmp71_;
		GMappedFile* _tmp72_;
		GMappedFile* _tmp73_;
		GMappedFile* _tmp74_;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp67_ = self->priv->publishable;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp68_ = spit_publishing_publishable_get_serialized_file (_tmp67_);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp69_ = _tmp68_;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp70_ = g_file_get_path (_tmp69_);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp71_ = _tmp70_;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp72_ = g_mapped_file_new (_tmp71_, FALSE, &_inner_error_);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp73_ = _tmp72_;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_free0 (_tmp71_);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_object_unref0 (_tmp69_);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp66_ = _tmp73_;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			if (_inner_error_->domain == G_FILE_ERROR) {
#line 4140 "PicasaPublishing.c"
				goto __catch11_g_file_error;
			}
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			__vala_SoupBuffer_free0 (metadata_buffer);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (metadata);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (keywords_string);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (summary);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			__vala_SoupMultipart_free0 (message_parts);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_clear_error (&_inner_error_);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return;
#line 4161 "PicasaPublishing.c"
		}
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp74_ = _tmp66_;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp66_ = NULL;
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_mapped_file_unref0 (self->priv->mapped_file);
#line 473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		self->priv->mapped_file = _tmp74_;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_mapped_file_unref0 (_tmp66_);
#line 4173 "PicasaPublishing.c"
	}
	goto __finally11;
	__catch11_g_file_error:
	{
		GError* e = NULL;
		gchar* msg = NULL;
		SpitPublishingPublishable* _tmp75_;
		GFile* _tmp76_;
		GFile* _tmp77_;
		gchar* _tmp78_;
		gchar* _tmp79_;
		GError* _tmp80_;
		const gchar* _tmp81_;
		gchar* _tmp82_;
		gchar* _tmp83_;
		const gchar* _tmp84_;
		const gchar* _tmp85_;
		GError* _tmp86_;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		e = _inner_error_;
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_inner_error_ = NULL;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp75_ = self->priv->publishable;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp76_ = spit_publishing_publishable_get_serialized_file (_tmp75_);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp77_ = _tmp76_;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp78_ = g_file_get_path (_tmp77_);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp79_ = _tmp78_;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp80_ = e;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp81_ = _tmp80_->message;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp82_ = g_strdup_printf ("Picasa: couldn't read data from %s: %s", _tmp79_, _tmp81_);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp83_ = _tmp82_;
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_free0 (_tmp79_);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_object_unref0 (_tmp77_);
#line 475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		msg = _tmp83_;
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp84_ = msg;
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_warning ("PicasaPublishing.vala:477: %s", _tmp84_);
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp85_ = msg;
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp86_ = g_error_new_literal (SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR, _tmp85_);
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_inner_error_ = _tmp86_;
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_free0 (msg);
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_g_error_free0 (e);
#line 4234 "PicasaPublishing.c"
		goto __finally11;
	}
	__finally11:
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_propagate_error (error, _inner_error_);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			__vala_SoupBuffer_free0 (metadata_buffer);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (metadata);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (keywords_string);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (summary);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			__vala_SoupMultipart_free0 (message_parts);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return;
#line 4258 "PicasaPublishing.c"
		} else {
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			__vala_SoupBuffer_free0 (metadata_buffer);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (metadata);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (keywords_string);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (summary);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			__vala_SoupMultipart_free0 (message_parts);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_clear_error (&_inner_error_);
#line 472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return;
#line 4278 "PicasaPublishing.c"
		}
	}
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp87_ = self->priv->mapped_file;
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp88_ = g_mapped_file_get_contents (_tmp87_);
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	photo_data = (guint8*) _tmp88_;
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	photo_data_length1 = sizeof (gchar) / sizeof (guint8);
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_photo_data_size_ = photo_data_length1;
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp89_ = self->priv->mapped_file;
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp90_ = g_mapped_file_get_length (_tmp89_);
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	photo_data_length1 = (gint) _tmp90_;
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp91_ = photo_data_length1;
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp92_ = soup_buffer_new (SOUP_MEMORY_TEMPORARY, photo_data, photo_data_length1);
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	bindable_data = _tmp92_;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp93_ = message_parts;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp94_ = self->priv->publishable;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp95_ = spit_publishing_publishable_get_serialized_file (_tmp94_);
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp96_ = _tmp95_;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp97_ = g_file_get_path (_tmp96_);
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp98_ = _tmp97_;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp99_ = self->priv->mime_type;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	soup_multipart_append_form_file (_tmp93_, "", _tmp98_, _tmp99_, bindable_data);
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp98_);
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (_tmp96_);
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp100_ = publishing_rest_support_transaction_get_endpoint_url (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp101_ = _tmp100_;
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp102_ = message_parts;
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp103_ = soup_form_request_new_from_multipart (_tmp101_, _tmp102_);
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp104_ = _tmp103_;
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp101_);
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	outbound_message = _tmp104_;
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp105_ = outbound_message->request_headers;
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp106_ = self->priv->session;
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp107_ = publishing_rest_support_google_session_get_access_token (_tmp106_);
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp108_ = _tmp107_;
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp109_ = g_strconcat ("Bearer ", _tmp108_, NULL);
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp110_ = _tmp109_;
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	soup_message_headers_append (_tmp105_, "Authorization", _tmp110_);
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp110_);
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp108_);
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_rest_support_transaction_set_message (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), outbound_message);
#line 500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_rest_support_transaction_set_is_executed (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), TRUE);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_rest_support_transaction_send (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_propagate_error (error, _inner_error_);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_object_unref0 (outbound_message);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			__vala_SoupBuffer_free0 (bindable_data);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			__vala_SoupBuffer_free0 (metadata_buffer);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (metadata);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (keywords_string);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (summary);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			__vala_SoupMultipart_free0 (message_parts);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return;
#line 4385 "PicasaPublishing.c"
		} else {
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_object_unref0 (outbound_message);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			__vala_SoupBuffer_free0 (bindable_data);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			__vala_SoupBuffer_free0 (metadata_buffer);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (metadata);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (keywords_string);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_g_free0 (summary);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			__vala_SoupMultipart_free0 (message_parts);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			g_clear_error (&_inner_error_);
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return;
#line 4409 "PicasaPublishing.c"
		}
	}
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (outbound_message);
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	__vala_SoupBuffer_free0 (bindable_data);
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	__vala_SoupBuffer_free0 (metadata_buffer);
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (metadata);
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (keywords_string);
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (summary);
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	__vala_SoupMultipart_free0 (message_parts);
#line 4428 "PicasaPublishing.c"
}


static void publishing_picasa_upload_transaction_class_init (PublishingPicasaUploadTransactionClass * klass) {
#line 405 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_upload_transaction_parent_class = g_type_class_peek_parent (klass);
#line 405 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_picasa_upload_transaction_finalize;
#line 405 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPicasaUploadTransactionPrivate));
#line 405 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->execute = (void (*) (PublishingRESTSupportTransaction *, GError**)) publishing_picasa_upload_transaction_real_execute;
#line 4441 "PicasaPublishing.c"
}


static void publishing_picasa_upload_transaction_instance_init (PublishingPicasaUploadTransaction * self) {
#line 405 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv = PUBLISHING_PICASA_UPLOAD_TRANSACTION_GET_PRIVATE (self);
#line 4448 "PicasaPublishing.c"
}


static void publishing_picasa_upload_transaction_finalize (PublishingRESTSupportTransaction * obj) {
	PublishingPicasaUploadTransaction * self;
#line 405 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PICASA_TYPE_UPLOAD_TRANSACTION, PublishingPicasaUploadTransaction);
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_picasa_publishing_parameters_unref0 (self->priv->parameters);
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->priv->mime_type);
#line 411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->publishable);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_mapped_file_unref0 (self->priv->mapped_file);
#line 405 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_picasa_upload_transaction_parent_class)->finalize (obj);
#line 4468 "PicasaPublishing.c"
}


GType publishing_picasa_upload_transaction_get_type (void) {
	static volatile gsize publishing_picasa_upload_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_picasa_upload_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPicasaUploadTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_picasa_upload_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPicasaUploadTransaction), 0, (GInstanceInitFunc) publishing_picasa_upload_transaction_instance_init, NULL };
		GType publishing_picasa_upload_transaction_type_id;
		publishing_picasa_upload_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_GOOGLE_PUBLISHER_TYPE_AUTHENTICATED_TRANSACTION, "PublishingPicasaUploadTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_picasa_upload_transaction_type_id__volatile, publishing_picasa_upload_transaction_type_id);
	}
	return publishing_picasa_upload_transaction_type_id__volatile;
}


static gpointer _publishing_picasa_publishing_options_pane_size_description_ref0 (gpointer self) {
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self ? publishing_picasa_publishing_options_pane_size_description_ref (self) : NULL;
#line 4487 "PicasaPublishing.c"
}


static void _publishing_picasa_publishing_options_pane_on_logout_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_options_pane_on_logout_clicked ((PublishingPicasaPublishingOptionsPane*) self);
#line 4494 "PicasaPublishing.c"
}


static void _publishing_picasa_publishing_options_pane_on_publish_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_options_pane_on_publish_clicked ((PublishingPicasaPublishingOptionsPane*) self);
#line 4501 "PicasaPublishing.c"
}


PublishingPicasaPublishingOptionsPane* publishing_picasa_publishing_options_pane_construct (GType object_type, GtkBuilder* builder, PublishingPicasaPublishingParameters* parameters, gboolean can_logout) {
	PublishingPicasaPublishingOptionsPane * self = NULL;
	gint _tmp0_;
	PublishingPicasaPublishingOptionsPaneSizeDescription** _tmp1_;
	GtkBuilder* _tmp2_;
	GtkBuilder* _tmp3_;
	GtkBuilder* _tmp4_;
	GtkBuilder* _tmp5_;
	GSList* _tmp6_;
	GSList* _tmp7_;
	guint _tmp8_;
	PublishingPicasaPublishingParameters* _tmp9_;
	PublishingPicasaPublishingParameters* _tmp10_;
	GtkBuilder* _tmp11_;
	GObject* _tmp12_;
	GtkBox* _tmp13_;
	GtkBuilder* _tmp14_;
	GObject* _tmp15_;
	GtkLabel* _tmp16_;
	GtkBuilder* _tmp17_;
	GObject* _tmp18_;
	GtkLabel* _tmp19_;
	GtkBuilder* _tmp20_;
	GObject* _tmp21_;
	GtkComboBoxText* _tmp22_;
	GtkBuilder* _tmp23_;
	GObject* _tmp24_;
	GtkCheckButton* _tmp25_;
	GtkBuilder* _tmp26_;
	GObject* _tmp27_;
	GtkComboBoxText* _tmp28_;
	GtkBuilder* _tmp29_;
	GObject* _tmp30_;
	GtkCheckButton* _tmp31_;
	GtkBuilder* _tmp32_;
	GObject* _tmp33_;
	GtkButton* _tmp34_;
	GtkBuilder* _tmp35_;
	GObject* _tmp36_;
	GtkButton* _tmp37_;
	gboolean _tmp38_;
	GtkLabel* _tmp43_;
	PublishingPicasaPublishingParameters* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	gchar* _tmp47_;
	gchar* _tmp48_;
	GtkCheckButton* _tmp49_;
	PublishingPicasaPublishingParameters* _tmp50_;
	gboolean _tmp51_;
	PublishingPicasaPublishingParameters* _tmp52_;
	SpitPublishingPublisherMediaType _tmp53_;
	GtkButton* _tmp68_;
	GtkButton* _tmp69_;
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (GTK_IS_BUILDER (builder), NULL);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = (PublishingPicasaPublishingOptionsPane*) g_object_new (object_type, NULL);
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = publishing_picasa_publishing_options_pane_create_size_descriptions (self, &_tmp0_);
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->size_descriptions = (_vala_array_free (self->priv->size_descriptions, self->priv->size_descriptions_length1, (GDestroyNotify) publishing_picasa_publishing_options_pane_size_description_unref), NULL);
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->size_descriptions = _tmp1_;
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->size_descriptions_length1 = _tmp0_;
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->_size_descriptions_size_ = self->priv->size_descriptions_length1;
#line 538 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = builder;
#line 538 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 538 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 538 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->builder = _tmp3_;
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = builder;
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_vala_assert (_tmp4_ != NULL, "builder != null");
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = builder;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp6_ = gtk_builder_get_objects (_tmp5_);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp7_ = _tmp6_;
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp8_ = g_slist_length (_tmp7_);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_vala_assert (_tmp8_ > ((guint) 0), "builder.get_objects().length() > 0");
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_slist_free0 (_tmp7_);
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp9_ = parameters;
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp10_ = _publishing_picasa_publishing_parameters_ref0 (_tmp9_);
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_picasa_publishing_parameters_unref0 (self->priv->parameters);
#line 542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->parameters = _tmp10_;
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp11_ = builder;
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp12_ = gtk_builder_get_object (_tmp11_, "picasa_pane_widget");
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_box_get_type (), GtkBox));
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->pane_widget = _tmp13_;
#line 546 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp14_ = builder;
#line 546 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp15_ = gtk_builder_get_object (_tmp14_, "login_identity_label");
#line 546 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp16_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_label_get_type (), GtkLabel));
#line 546 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->login_identity_label);
#line 546 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->login_identity_label = _tmp16_;
#line 547 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp17_ = builder;
#line 547 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp18_ = gtk_builder_get_object (_tmp17_, "publish_to_label");
#line 547 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp19_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_label_get_type (), GtkLabel));
#line 547 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->publish_to_label);
#line 547 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->publish_to_label = _tmp19_;
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp20_ = builder;
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp21_ = gtk_builder_get_object (_tmp20_, "existing_albums_combo");
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_combo_box_text_get_type (), GtkComboBoxText));
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->existing_albums_combo);
#line 548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->existing_albums_combo = _tmp22_;
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp23_ = builder;
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp24_ = gtk_builder_get_object (_tmp23_, "public_check");
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp25_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_check_button_get_type (), GtkCheckButton));
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->public_check);
#line 549 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->public_check = _tmp25_;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp26_ = builder;
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp27_ = gtk_builder_get_object (_tmp26_, "size_combo");
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp28_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_combo_box_text_get_type (), GtkComboBoxText));
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->size_combo);
#line 550 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->size_combo = _tmp28_;
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp29_ = self->priv->builder;
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp30_ = gtk_builder_get_object (_tmp29_, "strip_metadata_check");
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp31_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, gtk_check_button_get_type (), GtkCheckButton));
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->strip_metadata_check = _tmp31_;
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp32_ = builder;
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp33_ = gtk_builder_get_object (_tmp32_, "publish_button");
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp34_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, gtk_button_get_type (), GtkButton));
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->publish_button = _tmp34_;
#line 553 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp35_ = builder;
#line 553 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp36_ = gtk_builder_get_object (_tmp35_, "logout_button");
#line 553 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp37_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, gtk_button_get_type (), GtkButton));
#line 553 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 553 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->logout_button = _tmp37_;
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp38_ = can_logout;
#line 555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!_tmp38_) {
#line 4701 "PicasaPublishing.c"
		GtkButton* _tmp39_;
		GtkContainer* _tmp40_;
		GtkContainer* _tmp41_;
		GtkButton* _tmp42_;
#line 556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp39_ = self->priv->logout_button;
#line 556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp40_ = gtk_widget_get_parent (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, gtk_widget_get_type (), GtkWidget));
#line 556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp41_ = _tmp40_;
#line 556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp42_ = self->priv->logout_button;
#line 556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		gtk_container_remove (_tmp41_, G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, gtk_widget_get_type (), GtkWidget));
#line 4716 "PicasaPublishing.c"
	}
#line 560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp43_ = self->priv->login_identity_label;
#line 560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp44_ = parameters;
#line 560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp45_ = publishing_picasa_publishing_parameters_get_user_name (_tmp44_);
#line 560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp46_ = _tmp45_;
#line 560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp47_ = g_strdup_printf (_ ("You are logged into Picasa Web Albums as %s."), _tmp46_);
#line 560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp48_ = _tmp47_;
#line 560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	gtk_label_set_label (_tmp43_, _tmp48_);
#line 560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp48_);
#line 560 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (_tmp46_);
#line 562 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp49_ = self->priv->strip_metadata_check;
#line 562 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp50_ = parameters;
#line 562 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp51_ = publishing_picasa_publishing_parameters_get_strip_metadata (_tmp50_);
#line 562 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp51_);
#line 565 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp52_ = parameters;
#line 565 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp53_ = publishing_picasa_publishing_parameters_get_media_type (_tmp52_);
#line 565 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if ((_tmp53_ & SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO) == 0) {
#line 4750 "PicasaPublishing.c"
		GtkLabel* _tmp54_;
		GtkComboBoxText* _tmp55_;
		GtkComboBoxText* _tmp56_;
#line 566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp54_ = self->priv->publish_to_label;
#line 566 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		gtk_label_set_label (_tmp54_, _ ("Videos will appear in:"));
#line 567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp55_ = self->priv->size_combo;
#line 567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		gtk_widget_set_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp56_ = self->priv->size_combo;
#line 568 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 4766 "PicasaPublishing.c"
	} else {
		GtkLabel* _tmp57_;
		PublishingPicasaPublishingOptionsPaneSizeDescription** _tmp58_;
		gint _tmp58__length1;
		GtkComboBoxText* _tmp63_;
		GtkComboBoxText* _tmp64_;
		GtkComboBoxText* _tmp65_;
		PublishingPicasaPublishingParameters* _tmp66_;
		gint _tmp67_;
#line 571 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp57_ = self->priv->publish_to_label;
#line 571 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		gtk_label_set_label (_tmp57_, _ ("Photos will appear in:"));
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp58_ = self->priv->size_descriptions;
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp58__length1 = self->priv->size_descriptions_length1;
#line 4784 "PicasaPublishing.c"
		{
			PublishingPicasaPublishingOptionsPaneSizeDescription** desc_collection = NULL;
			gint desc_collection_length1 = 0;
			gint _desc_collection_size_ = 0;
			gint desc_it = 0;
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			desc_collection = _tmp58_;
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			desc_collection_length1 = _tmp58__length1;
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			for (desc_it = 0; desc_it < _tmp58__length1; desc_it = desc_it + 1) {
#line 4796 "PicasaPublishing.c"
				PublishingPicasaPublishingOptionsPaneSizeDescription* _tmp59_;
				PublishingPicasaPublishingOptionsPaneSizeDescription* desc = NULL;
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp59_ = _publishing_picasa_publishing_options_pane_size_description_ref0 (desc_collection[desc_it]);
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				desc = _tmp59_;
#line 4803 "PicasaPublishing.c"
				{
					GtkComboBoxText* _tmp60_;
					PublishingPicasaPublishingOptionsPaneSizeDescription* _tmp61_;
					const gchar* _tmp62_;
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp60_ = self->priv->size_combo;
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp61_ = desc;
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp62_ = _tmp61_->name;
#line 573 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					gtk_combo_box_text_append_text (_tmp60_, _tmp62_);
#line 572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_publishing_picasa_publishing_options_pane_size_description_unref0 (desc);
#line 4818 "PicasaPublishing.c"
				}
			}
		}
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp63_ = self->priv->size_combo;
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		gtk_widget_set_visible (G_TYPE_CHECK_INSTANCE_CAST (_tmp63_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp64_ = self->priv->size_combo;
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp65_ = self->priv->size_combo;
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp66_ = parameters;
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp67_ = publishing_picasa_publishing_parameters_get_major_axis_size_selection_id (_tmp66_);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp65_, gtk_combo_box_get_type (), GtkComboBox), _tmp67_);
#line 4838 "PicasaPublishing.c"
	}
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp68_ = self->priv->logout_button;
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_connect_object (_tmp68_, "clicked", (GCallback) _publishing_picasa_publishing_options_pane_on_logout_clicked_gtk_button_clicked, self, 0);
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp69_ = self->priv->publish_button;
#line 582 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_connect_object (_tmp69_, "clicked", (GCallback) _publishing_picasa_publishing_options_pane_on_publish_clicked_gtk_button_clicked, self, 0);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self;
#line 4850 "PicasaPublishing.c"
}


PublishingPicasaPublishingOptionsPane* publishing_picasa_publishing_options_pane_new (GtkBuilder* builder, PublishingPicasaPublishingParameters* parameters, gboolean can_logout) {
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return publishing_picasa_publishing_options_pane_construct (PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE, builder, parameters, can_logout);
#line 4857 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_options_pane_on_publish_clicked (PublishingPicasaPublishingOptionsPane* self) {
	gint _tmp0_ = 0;
	GtkComboBoxText* _tmp1_;
	gint _tmp2_;
	gint size_combo_last_active = 0;
	PublishingPicasaPublishingParameters* _tmp5_;
	PublishingPicasaPublishingParameters* _tmp6_;
	PublishingPicasaPublishingOptionsPaneSizeDescription** _tmp7_;
	gint _tmp7__length1;
	PublishingPicasaPublishingOptionsPaneSizeDescription* _tmp8_;
	gint _tmp9_;
	PublishingPicasaPublishingParameters* _tmp10_;
	GtkCheckButton* _tmp11_;
	gboolean _tmp12_;
	PublishingPicasaAlbum** albums = NULL;
	PublishingPicasaPublishingParameters* _tmp13_;
	gint _tmp14_;
	PublishingPicasaAlbum** _tmp15_;
	gint albums_length1;
	gint _albums_size_;
	PublishingPicasaPublishingParameters* _tmp16_;
	GtkComboBoxText* _tmp17_;
	gint _tmp18_;
	PublishingPicasaAlbum* _tmp19_;
	const gchar* _tmp20_;
	PublishingPicasaPublishingParameters* _tmp21_;
	GtkComboBoxText* _tmp22_;
	gint _tmp23_;
	PublishingPicasaAlbum* _tmp24_;
	const gchar* _tmp25_;
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_OPTIONS_PANE (self));
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = self->priv->size_combo;
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (_tmp2_ >= 0) {
#line 4899 "PicasaPublishing.c"
		GtkComboBoxText* _tmp3_;
		gint _tmp4_;
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp3_ = self->priv->size_combo;
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp4_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_combo_box_get_type (), GtkComboBox));
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp0_ = _tmp4_;
#line 4908 "PicasaPublishing.c"
	} else {
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp0_ = 0;
#line 4912 "PicasaPublishing.c"
	}
#line 589 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	size_combo_last_active = _tmp0_;
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = self->priv->parameters;
#line 591 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_parameters_set_major_axis_size_selection_id (_tmp5_, size_combo_last_active);
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp6_ = self->priv->parameters;
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp7_ = self->priv->size_descriptions;
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp7__length1 = self->priv->size_descriptions_length1;
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp8_ = _tmp7_[size_combo_last_active];
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp9_ = _tmp8_->major_axis_pixels;
#line 592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_parameters_set_major_axis_size_pixels (_tmp6_, _tmp9_);
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp10_ = self->priv->parameters;
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp11_ = self->priv->strip_metadata_check;
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp12_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_parameters_set_strip_metadata (_tmp10_, _tmp12_);
#line 596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp13_ = self->priv->parameters;
#line 596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp15_ = publishing_picasa_publishing_parameters_get_albums (_tmp13_, &_tmp14_);
#line 596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	albums = _tmp15_;
#line 596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	albums_length1 = _tmp14_;
#line 596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_albums_size_ = albums_length1;
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp16_ = self->priv->parameters;
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp17_ = self->priv->existing_albums_combo;
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp18_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_combo_box_get_type (), GtkComboBox));
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp19_ = albums[_tmp18_];
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp20_ = _tmp19_->name;
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_parameters_set_target_album_name (_tmp16_, _tmp20_);
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp21_ = self->priv->parameters;
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp22_ = self->priv->existing_albums_combo;
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp23_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_combo_box_get_type (), GtkComboBox));
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp24_ = albums[_tmp23_];
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp25_ = _tmp24_->url;
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_parameters_set_target_album_entry_url (_tmp21_, _tmp25_);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_emit (self, publishing_picasa_publishing_options_pane_signals[PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL], 0);
#line 585 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	albums = (_vala_array_free (albums, albums_length1, (GDestroyNotify) publishing_picasa_album_unref), NULL);
#line 4978 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_options_pane_on_logout_clicked (PublishingPicasaPublishingOptionsPane* self) {
#line 603 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_OPTIONS_PANE (self));
#line 604 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_emit (self, publishing_picasa_publishing_options_pane_signals[PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL], 0);
#line 4987 "PicasaPublishing.c"
}


static void _vala_array_add14 (PublishingPicasaPublishingOptionsPaneSizeDescription** * array, int* length, int* size, PublishingPicasaPublishingOptionsPaneSizeDescription* value) {
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if ((*length) == (*size)) {
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*array = g_renew (PublishingPicasaPublishingOptionsPaneSizeDescription*, *array, (*size) + 1);
#line 4998 "PicasaPublishing.c"
	}
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[(*length)++] = value;
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[*length] = NULL;
#line 5004 "PicasaPublishing.c"
}


static void _vala_array_add15 (PublishingPicasaPublishingOptionsPaneSizeDescription** * array, int* length, int* size, PublishingPicasaPublishingOptionsPaneSizeDescription* value) {
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if ((*length) == (*size)) {
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*array = g_renew (PublishingPicasaPublishingOptionsPaneSizeDescription*, *array, (*size) + 1);
#line 5015 "PicasaPublishing.c"
	}
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[(*length)++] = value;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[*length] = NULL;
#line 5021 "PicasaPublishing.c"
}


static void _vala_array_add16 (PublishingPicasaPublishingOptionsPaneSizeDescription** * array, int* length, int* size, PublishingPicasaPublishingOptionsPaneSizeDescription* value) {
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if ((*length) == (*size)) {
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*array = g_renew (PublishingPicasaPublishingOptionsPaneSizeDescription*, *array, (*size) + 1);
#line 5032 "PicasaPublishing.c"
	}
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[(*length)++] = value;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[*length] = NULL;
#line 5038 "PicasaPublishing.c"
}


static void _vala_array_add17 (PublishingPicasaPublishingOptionsPaneSizeDescription** * array, int* length, int* size, PublishingPicasaPublishingOptionsPaneSizeDescription* value) {
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if ((*length) == (*size)) {
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*array = g_renew (PublishingPicasaPublishingOptionsPaneSizeDescription*, *array, (*size) + 1);
#line 5049 "PicasaPublishing.c"
	}
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[(*length)++] = value;
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[*length] = NULL;
#line 5055 "PicasaPublishing.c"
}


static void _vala_array_add18 (PublishingPicasaPublishingOptionsPaneSizeDescription** * array, int* length, int* size, PublishingPicasaPublishingOptionsPaneSizeDescription* value) {
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if ((*length) == (*size)) {
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*array = g_renew (PublishingPicasaPublishingOptionsPaneSizeDescription*, *array, (*size) + 1);
#line 5066 "PicasaPublishing.c"
	}
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[(*length)++] = value;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	(*array)[*length] = NULL;
#line 5072 "PicasaPublishing.c"
}


static PublishingPicasaPublishingOptionsPaneSizeDescription** publishing_picasa_publishing_options_pane_create_size_descriptions (PublishingPicasaPublishingOptionsPane* self, int* result_length1) {
	PublishingPicasaPublishingOptionsPaneSizeDescription** result = NULL;
	PublishingPicasaPublishingOptionsPaneSizeDescription** _result_ = NULL;
	PublishingPicasaPublishingOptionsPaneSizeDescription** _tmp0_;
	gint _result__length1;
	gint __result__size_;
	PublishingPicasaPublishingOptionsPaneSizeDescription** _tmp1_;
	gint _tmp1__length1;
	PublishingPicasaPublishingOptionsPaneSizeDescription* _tmp2_;
	PublishingPicasaPublishingOptionsPaneSizeDescription** _tmp3_;
	gint _tmp3__length1;
	PublishingPicasaPublishingOptionsPaneSizeDescription* _tmp4_;
	PublishingPicasaPublishingOptionsPaneSizeDescription** _tmp5_;
	gint _tmp5__length1;
	PublishingPicasaPublishingOptionsPaneSizeDescription* _tmp6_;
	PublishingPicasaPublishingOptionsPaneSizeDescription** _tmp7_;
	gint _tmp7__length1;
	PublishingPicasaPublishingOptionsPaneSizeDescription* _tmp8_;
	PublishingPicasaPublishingOptionsPaneSizeDescription** _tmp9_;
	gint _tmp9__length1;
	PublishingPicasaPublishingOptionsPaneSizeDescription* _tmp10_;
	PublishingPicasaPublishingOptionsPaneSizeDescription** _tmp11_;
	gint _tmp11__length1;
#line 607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = g_new0 (PublishingPicasaPublishingOptionsPaneSizeDescription*, 0 + 1);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_result_ = _tmp0_;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_result__length1 = 0;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	__result__size_ = _result__length1;
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = _result_;
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1__length1 = _result__length1;
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = publishing_picasa_publishing_options_pane_size_description_new (_ ("Small (640 × 480 pixels)"), 640);
#line 610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_vala_array_add14 (&_result_, &_result__length1, &__result__size_, _tmp2_);
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = _result_;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3__length1 = _result__length1;
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = publishing_picasa_publishing_options_pane_size_description_new (_ ("Medium (1024 × 768 pixels)"), 1024);
#line 611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_vala_array_add15 (&_result_, &_result__length1, &__result__size_, _tmp4_);
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = _result_;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5__length1 = _result__length1;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp6_ = publishing_picasa_publishing_options_pane_size_description_new (_ ("Recommended (1600 × 1200 pixels)"), 1600);
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_vala_array_add16 (&_result_, &_result__length1, &__result__size_, _tmp6_);
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp7_ = _result_;
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp7__length1 = _result__length1;
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp8_ = publishing_picasa_publishing_options_pane_size_description_new (_ ("Google+ (2048 × 1536 pixels)"), 2048);
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_vala_array_add17 (&_result_, &_result__length1, &__result__size_, _tmp8_);
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp9_ = _result_;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp9__length1 = _result__length1;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp10_ = publishing_picasa_publishing_options_pane_size_description_new (_ ("Original Size"), PUBLISHING_PICASA_PUBLISHING_PARAMETERS_ORIGINAL_SIZE);
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_vala_array_add18 (&_result_, &_result__length1, &__result__size_, _tmp10_);
#line 616 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp11_ = _result_;
#line 616 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp11__length1 = _result__length1;
#line 616 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (result_length1) {
#line 616 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*result_length1 = _tmp11__length1;
#line 5157 "PicasaPublishing.c"
	}
#line 616 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp11_;
#line 616 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 5163 "PicasaPublishing.c"
}


void publishing_picasa_publishing_options_pane_installed (PublishingPicasaPublishingOptionsPane* self) {
	gint default_album_id = 0;
	gchar* last_album = NULL;
	PublishingPicasaPublishingParameters* _tmp0_;
	gchar* _tmp1_;
	PublishingPicasaAlbum** albums = NULL;
	PublishingPicasaPublishingParameters* _tmp2_;
	gint _tmp3_;
	PublishingPicasaAlbum** _tmp4_;
	gint albums_length1;
	gint _albums_size_;
	gint _tmp32_;
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_OPTIONS_PANE (self));
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	default_album_id = -1;
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = self->priv->parameters;
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = publishing_picasa_publishing_parameters_get_target_album_name (_tmp0_);
#line 621 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	last_album = _tmp1_;
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = self->priv->parameters;
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = publishing_picasa_publishing_parameters_get_albums (_tmp2_, &_tmp3_);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	albums = _tmp4_;
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	albums_length1 = _tmp3_;
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_albums_size_ = albums_length1;
#line 5199 "PicasaPublishing.c"
	{
		gint i = 0;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		i = 0;
#line 5204 "PicasaPublishing.c"
		{
			gboolean _tmp5_ = FALSE;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			_tmp5_ = TRUE;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			while (TRUE) {
#line 5211 "PicasaPublishing.c"
				gint _tmp7_;
				PublishingPicasaAlbum** _tmp8_;
				gint _tmp8__length1;
				GtkComboBoxText* _tmp9_;
				PublishingPicasaAlbum** _tmp10_;
				gint _tmp10__length1;
				gint _tmp11_;
				PublishingPicasaAlbum* _tmp12_;
				const gchar* _tmp13_;
				gboolean _tmp14_ = FALSE;
				PublishingPicasaAlbum** _tmp15_;
				gint _tmp15__length1;
				gint _tmp16_;
				PublishingPicasaAlbum* _tmp17_;
				const gchar* _tmp18_;
				const gchar* _tmp19_;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				if (!_tmp5_) {
#line 5230 "PicasaPublishing.c"
					gint _tmp6_;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp6_ = i;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					i = _tmp6_ + 1;
#line 5236 "PicasaPublishing.c"
				}
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp5_ = FALSE;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp7_ = i;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp8_ = albums;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp8__length1 = albums_length1;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				if (!(_tmp7_ < _tmp8__length1)) {
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					break;
#line 5250 "PicasaPublishing.c"
				}
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp9_ = self->priv->existing_albums_combo;
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp10_ = albums;
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp10__length1 = albums_length1;
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp11_ = i;
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp12_ = _tmp10_[_tmp11_];
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp13_ = _tmp12_->name;
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				gtk_combo_box_text_append_text (_tmp9_, _tmp13_);
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp15_ = albums;
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp15__length1 = albums_length1;
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp16_ = i;
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp17_ = _tmp15_[_tmp16_];
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp18_ = _tmp17_->name;
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				_tmp19_ = last_album;
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				if (g_strcmp0 (_tmp18_, _tmp19_) == 0) {
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp14_ = TRUE;
#line 5282 "PicasaPublishing.c"
				} else {
					gboolean _tmp20_ = FALSE;
					gboolean _tmp21_ = FALSE;
					PublishingPicasaAlbum** _tmp22_;
					gint _tmp22__length1;
					gint _tmp23_;
					PublishingPicasaAlbum* _tmp24_;
					const gchar* _tmp25_;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp22_ = albums;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp22__length1 = albums_length1;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp23_ = i;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp24_ = _tmp22_[_tmp23_];
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp25_ = _tmp24_->name;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					if (g_strcmp0 (_tmp25_, PUBLISHING_PICASA_DEFAULT_ALBUM_NAME) == 0) {
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp21_ = TRUE;
#line 5305 "PicasaPublishing.c"
					} else {
						PublishingPicasaAlbum** _tmp26_;
						gint _tmp26__length1;
						gint _tmp27_;
						PublishingPicasaAlbum* _tmp28_;
						const gchar* _tmp29_;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp26_ = albums;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp26__length1 = albums_length1;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp27_ = i;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp28_ = _tmp26_[_tmp27_];
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp29_ = _tmp28_->name;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp21_ = g_strcmp0 (_tmp29_, _ ("Default album")) == 0;
#line 5324 "PicasaPublishing.c"
					}
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					if (_tmp21_) {
#line 5328 "PicasaPublishing.c"
						gint _tmp30_;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp30_ = default_album_id;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp20_ = _tmp30_ == -1;
#line 5334 "PicasaPublishing.c"
					} else {
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
						_tmp20_ = FALSE;
#line 5338 "PicasaPublishing.c"
					}
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp14_ = _tmp20_;
#line 5342 "PicasaPublishing.c"
				}
#line 629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
				if (_tmp14_) {
#line 5346 "PicasaPublishing.c"
					gint _tmp31_;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					_tmp31_ = i;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
					default_album_id = _tmp31_;
#line 5352 "PicasaPublishing.c"
				}
			}
		}
	}
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp32_ = default_album_id;
#line 634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (_tmp32_ >= 0) {
#line 5361 "PicasaPublishing.c"
		GtkComboBoxText* _tmp33_;
		gint _tmp34_;
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp33_ = self->priv->existing_albums_combo;
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp34_ = default_album_id;
#line 635 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, gtk_combo_box_get_type (), GtkComboBox), _tmp34_);
#line 5370 "PicasaPublishing.c"
	}
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	albums = (_vala_array_free (albums, albums_length1, (GDestroyNotify) publishing_picasa_album_unref), NULL);
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (last_album);
#line 5376 "PicasaPublishing.c"
}


static GtkWidget* publishing_picasa_publishing_options_pane_real_get_widget (SpitPublishingDialogPane* base) {
	PublishingPicasaPublishingOptionsPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_;
	GtkWidget* _tmp1_;
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPicasaPublishingOptionsPane);
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = self->priv->pane_widget;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp1_;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 5395 "PicasaPublishing.c"
}


static SpitPublishingDialogPaneGeometryOptions publishing_picasa_publishing_options_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base) {
	PublishingPicasaPublishingOptionsPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPicasaPublishingOptionsPane);
#line 644 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 644 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 5408 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_options_pane_real_on_pane_installed (SpitPublishingDialogPane* base) {
	PublishingPicasaPublishingOptionsPane * self;
#line 647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPicasaPublishingOptionsPane);
#line 648 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_options_pane_installed (self);
#line 5418 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_options_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base) {
	PublishingPicasaPublishingOptionsPane * self;
#line 651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPicasaPublishingOptionsPane);
#line 5426 "PicasaPublishing.c"
}


static PublishingPicasaPublishingOptionsPaneSizeDescription* publishing_picasa_publishing_options_pane_size_description_construct (GType object_type, const gchar* name, gint major_axis_pixels) {
	PublishingPicasaPublishingOptionsPaneSizeDescription* self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gint _tmp2_;
#line 510 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 510 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = (PublishingPicasaPublishingOptionsPaneSizeDescription*) g_type_create_instance (object_type);
#line 511 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = name;
#line 511 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 511 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->name);
#line 511 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->name = _tmp1_;
#line 512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = major_axis_pixels;
#line 512 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->major_axis_pixels = _tmp2_;
#line 510 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self;
#line 5453 "PicasaPublishing.c"
}


static PublishingPicasaPublishingOptionsPaneSizeDescription* publishing_picasa_publishing_options_pane_size_description_new (const gchar* name, gint major_axis_pixels) {
#line 510 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return publishing_picasa_publishing_options_pane_size_description_construct (PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION, name, major_axis_pixels);
#line 5460 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_options_pane_value_size_description_init (GValue* value) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 5467 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_options_pane_value_size_description_free_value (GValue* value) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (value->data[0].v_pointer) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_publishing_options_pane_size_description_unref (value->data[0].v_pointer);
#line 5476 "PicasaPublishing.c"
	}
}


static void publishing_picasa_publishing_options_pane_value_size_description_copy_value (const GValue* src_value, GValue* dest_value) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		dest_value->data[0].v_pointer = publishing_picasa_publishing_options_pane_size_description_ref (src_value->data[0].v_pointer);
#line 5486 "PicasaPublishing.c"
	} else {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 5490 "PicasaPublishing.c"
	}
}


static gpointer publishing_picasa_publishing_options_pane_value_size_description_peek_pointer (const GValue* value) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return value->data[0].v_pointer;
#line 5498 "PicasaPublishing.c"
}


static gchar* publishing_picasa_publishing_options_pane_value_size_description_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 5505 "PicasaPublishing.c"
		PublishingPicasaPublishingOptionsPaneSizeDescription * object;
		object = collect_values[0].v_pointer;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 5512 "PicasaPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 5516 "PicasaPublishing.c"
		}
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = publishing_picasa_publishing_options_pane_size_description_ref (object);
#line 5520 "PicasaPublishing.c"
	} else {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 5524 "PicasaPublishing.c"
	}
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return NULL;
#line 5528 "PicasaPublishing.c"
}


static gchar* publishing_picasa_publishing_options_pane_value_size_description_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingPicasaPublishingOptionsPaneSizeDescription ** object_p;
	object_p = collect_values[0].v_pointer;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!object_p) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 5539 "PicasaPublishing.c"
	}
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*object_p = NULL;
#line 5545 "PicasaPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 5549 "PicasaPublishing.c"
	} else {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*object_p = publishing_picasa_publishing_options_pane_size_description_ref (value->data[0].v_pointer);
#line 5553 "PicasaPublishing.c"
	}
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return NULL;
#line 5557 "PicasaPublishing.c"
}


static GParamSpec* publishing_picasa_publishing_options_pane_param_spec_size_description (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingPicasaPublishingOptionsPaneParamSpecSizeDescription* spec;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION), NULL);
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 5571 "PicasaPublishing.c"
}


static gpointer publishing_picasa_publishing_options_pane_value_get_size_description (const GValue* value) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION), NULL);
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return value->data[0].v_pointer;
#line 5580 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_options_pane_value_set_size_description (GValue* value, gpointer v_object) {
	PublishingPicasaPublishingOptionsPaneSizeDescription * old;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION));
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	old = value->data[0].v_pointer;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (v_object) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION));
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_publishing_options_pane_size_description_ref (value->data[0].v_pointer);
#line 5600 "PicasaPublishing.c"
	} else {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 5604 "PicasaPublishing.c"
	}
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (old) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_publishing_options_pane_size_description_unref (old);
#line 5610 "PicasaPublishing.c"
	}
}


static void publishing_picasa_publishing_options_pane_value_take_size_description (GValue* value, gpointer v_object) {
	PublishingPicasaPublishingOptionsPaneSizeDescription * old;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION));
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	old = value->data[0].v_pointer;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (v_object) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION));
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 5629 "PicasaPublishing.c"
	} else {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 5633 "PicasaPublishing.c"
	}
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (old) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_publishing_options_pane_size_description_unref (old);
#line 5639 "PicasaPublishing.c"
	}
}


static void publishing_picasa_publishing_options_pane_size_description_class_init (PublishingPicasaPublishingOptionsPaneSizeDescriptionClass * klass) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_options_pane_size_description_parent_class = g_type_class_peek_parent (klass);
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	((PublishingPicasaPublishingOptionsPaneSizeDescriptionClass *) klass)->finalize = publishing_picasa_publishing_options_pane_size_description_finalize;
#line 5649 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_options_pane_size_description_instance_init (PublishingPicasaPublishingOptionsPaneSizeDescription * self) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->ref_count = 1;
#line 5656 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_options_pane_size_description_finalize (PublishingPicasaPublishingOptionsPaneSizeDescription * obj) {
	PublishingPicasaPublishingOptionsPaneSizeDescription * self;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_TYPE_SIZE_DESCRIPTION, PublishingPicasaPublishingOptionsPaneSizeDescription);
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_handlers_destroy (self);
#line 507 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->name);
#line 5668 "PicasaPublishing.c"
}


static GType publishing_picasa_publishing_options_pane_size_description_get_type (void) {
	static volatile gsize publishing_picasa_publishing_options_pane_size_description_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_picasa_publishing_options_pane_size_description_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_picasa_publishing_options_pane_value_size_description_init, publishing_picasa_publishing_options_pane_value_size_description_free_value, publishing_picasa_publishing_options_pane_value_size_description_copy_value, publishing_picasa_publishing_options_pane_value_size_description_peek_pointer, "p", publishing_picasa_publishing_options_pane_value_size_description_collect_value, "p", publishing_picasa_publishing_options_pane_value_size_description_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPicasaPublishingOptionsPaneSizeDescriptionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_picasa_publishing_options_pane_size_description_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPicasaPublishingOptionsPaneSizeDescription), 0, (GInstanceInitFunc) publishing_picasa_publishing_options_pane_size_description_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_picasa_publishing_options_pane_size_description_type_id;
		publishing_picasa_publishing_options_pane_size_description_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingPicasaPublishingOptionsPaneSizeDescription", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_picasa_publishing_options_pane_size_description_type_id__volatile, publishing_picasa_publishing_options_pane_size_description_type_id);
	}
	return publishing_picasa_publishing_options_pane_size_description_type_id__volatile;
}


static gpointer publishing_picasa_publishing_options_pane_size_description_ref (gpointer instance) {
	PublishingPicasaPublishingOptionsPaneSizeDescription * self;
	self = instance;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return instance;
#line 5693 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_options_pane_size_description_unref (gpointer instance) {
	PublishingPicasaPublishingOptionsPaneSizeDescription * self;
	self = instance;
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_SIZE_DESCRIPTION_GET_CLASS (self)->finalize (self);
#line 506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 5706 "PicasaPublishing.c"
	}
}


static void publishing_picasa_publishing_options_pane_class_init (PublishingPicasaPublishingOptionsPaneClass * klass) {
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_options_pane_parent_class = g_type_class_peek_parent (klass);
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPicasaPublishingOptionsPanePrivate));
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_picasa_publishing_options_pane_finalize;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_options_pane_signals[PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL] = g_signal_new ("publish", PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_options_pane_signals[PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL] = g_signal_new ("logout", PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 5722 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_options_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface) {
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_options_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	iface->get_widget = (GtkWidget* (*) (SpitPublishingDialogPane *)) publishing_picasa_publishing_options_pane_real_get_widget;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*) (SpitPublishingDialogPane *)) publishing_picasa_publishing_options_pane_real_get_preferred_geometry;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	iface->on_pane_installed = (void (*) (SpitPublishingDialogPane *)) publishing_picasa_publishing_options_pane_real_on_pane_installed;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	iface->on_pane_uninstalled = (void (*) (SpitPublishingDialogPane *)) publishing_picasa_publishing_options_pane_real_on_pane_uninstalled;
#line 5737 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_options_pane_instance_init (PublishingPicasaPublishingOptionsPane * self) {
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv = PUBLISHING_PICASA_PUBLISHING_OPTIONS_PANE_GET_PRIVATE (self);
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->builder = NULL;
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->pane_widget = NULL;
#line 521 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->login_identity_label = NULL;
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->publish_to_label = NULL;
#line 523 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->existing_albums_combo = NULL;
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->public_check = NULL;
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->size_combo = NULL;
#line 526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->strip_metadata_check = NULL;
#line 527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->publish_button = NULL;
#line 528 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->logout_button = NULL;
#line 5764 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_options_pane_finalize (GObject * obj) {
	PublishingPicasaPublishingOptionsPane * self;
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PICASA_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPicasaPublishingOptionsPane);
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->builder);
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->pane_widget);
#line 521 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->login_identity_label);
#line 522 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->publish_to_label);
#line 523 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->existing_albums_combo);
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->public_check);
#line 525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->size_combo);
#line 526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 528 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->size_descriptions = (_vala_array_free (self->priv->size_descriptions, self->priv->size_descriptions_length1, (GDestroyNotify) publishing_picasa_publishing_options_pane_size_description_unref), NULL);
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_picasa_publishing_parameters_unref0 (self->priv->parameters);
#line 505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	G_OBJECT_CLASS (publishing_picasa_publishing_options_pane_parent_class)->finalize (obj);
#line 5798 "PicasaPublishing.c"
}


GType publishing_picasa_publishing_options_pane_get_type (void) {
	static volatile gsize publishing_picasa_publishing_options_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_picasa_publishing_options_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPicasaPublishingOptionsPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_picasa_publishing_options_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPicasaPublishingOptionsPane), 0, (GInstanceInitFunc) publishing_picasa_publishing_options_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_picasa_publishing_options_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_picasa_publishing_options_pane_type_id;
		publishing_picasa_publishing_options_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingPicasaPublishingOptionsPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_picasa_publishing_options_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_picasa_publishing_options_pane_type_id__volatile, publishing_picasa_publishing_options_pane_type_id);
	}
	return publishing_picasa_publishing_options_pane_type_id__volatile;
}


PublishingPicasaPublishingParameters* publishing_picasa_publishing_parameters_construct (GType object_type) {
	PublishingPicasaPublishingParameters* self = NULL;
	gchar* _tmp0_;
#line 668 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = (PublishingPicasaPublishingParameters*) g_type_create_instance (object_type);
#line 669 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = g_strdup ("[unknown]");
#line 669 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->priv->user_name);
#line 669 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->user_name = _tmp0_;
#line 670 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->priv->target_album_name);
#line 670 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->target_album_name = NULL;
#line 671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->major_axis_size_selection_id = 0;
#line 672 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->major_axis_size_pixels = PUBLISHING_PICASA_PUBLISHING_PARAMETERS_ORIGINAL_SIZE;
#line 673 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->priv->target_album_url);
#line 673 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->target_album_url = NULL;
#line 674 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->album_public = FALSE;
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_picasa_album_unref), NULL);
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->albums = NULL;
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->albums_length1 = 0;
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->_albums_size_ = self->priv->albums_length1;
#line 676 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->strip_metadata = FALSE;
#line 677 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->media_type = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO;
#line 668 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self;
#line 5855 "PicasaPublishing.c"
}


PublishingPicasaPublishingParameters* publishing_picasa_publishing_parameters_new (void) {
#line 668 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return publishing_picasa_publishing_parameters_construct (PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS);
#line 5862 "PicasaPublishing.c"
}


gchar* publishing_picasa_publishing_parameters_get_target_album_name (PublishingPicasaPublishingParameters* self) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 680 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = self->priv->target_album_name;
#line 681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp1_;
#line 681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 5880 "PicasaPublishing.c"
}


void publishing_picasa_publishing_parameters_set_target_album_name (PublishingPicasaPublishingParameters* self, const gchar* target_album_name) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self));
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (target_album_name != NULL);
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = target_album_name;
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->priv->target_album_name);
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->target_album_name = _tmp1_;
#line 5899 "PicasaPublishing.c"
}


void publishing_picasa_publishing_parameters_set_target_album_entry_url (PublishingPicasaPublishingParameters* self, const gchar* target_album_url) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 688 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self));
#line 688 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (target_album_url != NULL);
#line 689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = target_album_url;
#line 689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->priv->target_album_url);
#line 689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->target_album_url = _tmp1_;
#line 5918 "PicasaPublishing.c"
}


gchar* publishing_picasa_publishing_parameters_get_target_album_entry_url (PublishingPicasaPublishingParameters* self) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = self->priv->target_album_url;
#line 693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp1_;
#line 693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 5936 "PicasaPublishing.c"
}


static gchar* string_replace (const gchar* self, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError * _inner_error_ = NULL;
#line 1407 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1407 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (old != NULL, NULL);
#line 1407 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if ((*((gchar*) self)) == '\0') {
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 5955 "PicasaPublishing.c"
	} else {
		const gchar* _tmp2_;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp2_ = old;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp1_ = (*((gchar*) _tmp2_)) == '\0';
#line 5962 "PicasaPublishing.c"
	}
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp0_ = TRUE;
#line 5968 "PicasaPublishing.c"
	} else {
		const gchar* _tmp3_;
		const gchar* _tmp4_;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp3_ = old;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = replacement;
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp0_ = g_strcmp0 (_tmp3_, _tmp4_) == 0;
#line 5978 "PicasaPublishing.c"
	}
#line 1408 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 5982 "PicasaPublishing.c"
		gchar* _tmp5_;
#line 1409 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp5_ = g_strdup (self);
#line 1409 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = _tmp5_;
#line 1409 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 5990 "PicasaPublishing.c"
	}
	{
		GRegex* regex = NULL;
		const gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		GRegex* _tmp9_;
		GRegex* _tmp10_;
		gchar* _tmp11_ = NULL;
		GRegex* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6_ = old;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp7_ = g_regex_escape_string (_tmp6_, -1);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp8_ = _tmp7_;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp9_ = g_regex_new (_tmp8_, 0, 0, &_inner_error_);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp10_ = _tmp9_;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_free0 (_tmp8_);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		regex = _tmp10_;
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 6022 "PicasaPublishing.c"
				goto __catch12_g_regex_error;
			}
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1412 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			return NULL;
#line 6031 "PicasaPublishing.c"
		}
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp12_ = regex;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp13_ = replacement;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp14_ = g_regex_replace_literal (_tmp12_, self, (gssize) -1, 0, _tmp13_, 0, &_inner_error_);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp11_ = _tmp14_;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 6047 "PicasaPublishing.c"
				goto __catch12_g_regex_error;
			}
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_g_regex_unref0 (regex);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			g_clear_error (&_inner_error_);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			return NULL;
#line 6058 "PicasaPublishing.c"
		}
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp15_ = _tmp11_;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp11_ = NULL;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = _tmp15_;
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_free0 (_tmp11_);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_regex_unref0 (regex);
#line 1413 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 6072 "PicasaPublishing.c"
	}
	goto __finally12;
	__catch12_g_regex_error:
	{
		GError* e = NULL;
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		e = _inner_error_;
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_inner_error_ = NULL;
#line 1415 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_assert_not_reached ();
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_g_error_free0 (e);
#line 6086 "PicasaPublishing.c"
	}
	__finally12:
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_clear_error (&_inner_error_);
#line 1411 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return NULL;
#line 6097 "PicasaPublishing.c"
	}
}


gchar* publishing_picasa_publishing_parameters_get_target_album_feed_url (PublishingPicasaPublishingParameters* self) {
	gchar* result = NULL;
	gchar* entry_url = NULL;
	gchar* _tmp0_;
	gchar* feed_url = NULL;
	gchar* _tmp1_;
#line 696 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_picasa_publishing_parameters_get_target_album_entry_url (self);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	entry_url = _tmp0_;
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = string_replace (entry_url, "entry", "feed");
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	feed_url = _tmp1_;
#line 700 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = feed_url;
#line 700 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (entry_url);
#line 700 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 6124 "PicasaPublishing.c"
}


gchar* publishing_picasa_publishing_parameters_get_user_name (PublishingPicasaPublishingParameters* self) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 703 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = self->priv->user_name;
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp1_;
#line 704 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 6142 "PicasaPublishing.c"
}


void publishing_picasa_publishing_parameters_set_user_name (PublishingPicasaPublishingParameters* self, const gchar* user_name) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 707 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self));
#line 707 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (user_name != NULL);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = user_name;
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->priv->user_name);
#line 708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->user_name = _tmp1_;
#line 6161 "PicasaPublishing.c"
}


static gpointer _publishing_picasa_album_ref0 (gpointer self) {
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self ? publishing_picasa_album_ref (self) : NULL;
#line 6168 "PicasaPublishing.c"
}


static PublishingPicasaAlbum** _vala_array_dup5 (PublishingPicasaAlbum** self, int length) {
	PublishingPicasaAlbum** result;
	int i;
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = g_new0 (PublishingPicasaAlbum*, length + 1);
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	for (i = 0; i < length; i++) {
#line 6179 "PicasaPublishing.c"
		PublishingPicasaAlbum* _tmp0_;
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp0_ = _publishing_picasa_album_ref0 (self[i]);
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		result[i] = _tmp0_;
#line 6185 "PicasaPublishing.c"
	}
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 6189 "PicasaPublishing.c"
}


PublishingPicasaAlbum** publishing_picasa_publishing_parameters_get_albums (PublishingPicasaPublishingParameters* self, int* result_length1) {
	PublishingPicasaAlbum** result = NULL;
	PublishingPicasaAlbum** _tmp0_;
	gint _tmp0__length1;
	PublishingPicasaAlbum** _tmp1_;
	gint _tmp1__length1;
	PublishingPicasaAlbum** _tmp2_;
	gint _tmp2__length1;
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self), NULL);
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = self->priv->albums;
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0__length1 = self->priv->albums_length1;
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup5 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1__length1 = _tmp0__length1;
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = _tmp1_;
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2__length1 = _tmp1__length1;
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (result_length1) {
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*result_length1 = _tmp2__length1;
#line 6219 "PicasaPublishing.c"
	}
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp2_;
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 6225 "PicasaPublishing.c"
}


static PublishingPicasaAlbum** _vala_array_dup6 (PublishingPicasaAlbum** self, int length) {
	PublishingPicasaAlbum** result;
	int i;
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = g_new0 (PublishingPicasaAlbum*, length + 1);
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	for (i = 0; i < length; i++) {
#line 6236 "PicasaPublishing.c"
		PublishingPicasaAlbum* _tmp0_;
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		_tmp0_ = _publishing_picasa_album_ref0 (self[i]);
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		result[i] = _tmp0_;
#line 6242 "PicasaPublishing.c"
	}
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 6246 "PicasaPublishing.c"
}


void publishing_picasa_publishing_parameters_set_albums (PublishingPicasaPublishingParameters* self, PublishingPicasaAlbum** albums, int albums_length1) {
	PublishingPicasaAlbum** _tmp0_;
	gint _tmp0__length1;
	PublishingPicasaAlbum** _tmp1_;
	gint _tmp1__length1;
#line 715 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self));
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = albums;
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0__length1 = albums_length1;
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = (_tmp0_ != NULL) ? _vala_array_dup6 (_tmp0_, _tmp0__length1) : ((gpointer) _tmp0_);
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1__length1 = _tmp0__length1;
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_picasa_album_unref), NULL);
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->albums = _tmp1_;
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->albums_length1 = _tmp1__length1;
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->_albums_size_ = self->priv->albums_length1;
#line 6273 "PicasaPublishing.c"
}


void publishing_picasa_publishing_parameters_set_major_axis_size_pixels (PublishingPicasaPublishingParameters* self, gint pixels) {
	gint _tmp0_;
#line 719 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self));
#line 720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = pixels;
#line 720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->major_axis_size_pixels = _tmp0_;
#line 6285 "PicasaPublishing.c"
}


gint publishing_picasa_publishing_parameters_get_major_axis_size_pixels (PublishingPicasaPublishingParameters* self) {
	gint result = 0;
	gint _tmp0_;
#line 723 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self), 0);
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = self->priv->major_axis_size_pixels;
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp0_;
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 6300 "PicasaPublishing.c"
}


void publishing_picasa_publishing_parameters_set_major_axis_size_selection_id (PublishingPicasaPublishingParameters* self, gint selection_id) {
	gint _tmp0_;
#line 727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self));
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = selection_id;
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->major_axis_size_selection_id = _tmp0_;
#line 6312 "PicasaPublishing.c"
}


gint publishing_picasa_publishing_parameters_get_major_axis_size_selection_id (PublishingPicasaPublishingParameters* self) {
	gint result = 0;
	gint _tmp0_;
#line 731 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self), 0);
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = self->priv->major_axis_size_selection_id;
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp0_;
#line 732 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 6327 "PicasaPublishing.c"
}


void publishing_picasa_publishing_parameters_set_strip_metadata (PublishingPicasaPublishingParameters* self, gboolean strip_metadata) {
	gboolean _tmp0_;
#line 735 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self));
#line 736 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = strip_metadata;
#line 736 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->strip_metadata = _tmp0_;
#line 6339 "PicasaPublishing.c"
}


gboolean publishing_picasa_publishing_parameters_get_strip_metadata (PublishingPicasaPublishingParameters* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 739 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self), FALSE);
#line 740 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = self->priv->strip_metadata;
#line 740 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp0_;
#line 740 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 6354 "PicasaPublishing.c"
}


void publishing_picasa_publishing_parameters_set_media_type (PublishingPicasaPublishingParameters* self, SpitPublishingPublisherMediaType media_type) {
	SpitPublishingPublisherMediaType _tmp0_;
#line 743 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self));
#line 744 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = media_type;
#line 744 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->media_type = _tmp0_;
#line 6366 "PicasaPublishing.c"
}


SpitPublishingPublisherMediaType publishing_picasa_publishing_parameters_get_media_type (PublishingPicasaPublishingParameters* self) {
	SpitPublishingPublisherMediaType result = 0;
	SpitPublishingPublisherMediaType _tmp0_;
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (self), 0);
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = self->priv->media_type;
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp0_;
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 6381 "PicasaPublishing.c"
}


static void publishing_picasa_value_publishing_parameters_init (GValue* value) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 6388 "PicasaPublishing.c"
}


static void publishing_picasa_value_publishing_parameters_free_value (GValue* value) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (value->data[0].v_pointer) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_publishing_parameters_unref (value->data[0].v_pointer);
#line 6397 "PicasaPublishing.c"
	}
}


static void publishing_picasa_value_publishing_parameters_copy_value (const GValue* src_value, GValue* dest_value) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		dest_value->data[0].v_pointer = publishing_picasa_publishing_parameters_ref (src_value->data[0].v_pointer);
#line 6407 "PicasaPublishing.c"
	} else {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 6411 "PicasaPublishing.c"
	}
}


static gpointer publishing_picasa_value_publishing_parameters_peek_pointer (const GValue* value) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return value->data[0].v_pointer;
#line 6419 "PicasaPublishing.c"
}


static gchar* publishing_picasa_value_publishing_parameters_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 6426 "PicasaPublishing.c"
		PublishingPicasaPublishingParameters * object;
		object = collect_values[0].v_pointer;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6433 "PicasaPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 6437 "PicasaPublishing.c"
		}
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = publishing_picasa_publishing_parameters_ref (object);
#line 6441 "PicasaPublishing.c"
	} else {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 6445 "PicasaPublishing.c"
	}
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return NULL;
#line 6449 "PicasaPublishing.c"
}


static gchar* publishing_picasa_value_publishing_parameters_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingPicasaPublishingParameters ** object_p;
	object_p = collect_values[0].v_pointer;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!object_p) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 6460 "PicasaPublishing.c"
	}
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*object_p = NULL;
#line 6466 "PicasaPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 6470 "PicasaPublishing.c"
	} else {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		*object_p = publishing_picasa_publishing_parameters_ref (value->data[0].v_pointer);
#line 6474 "PicasaPublishing.c"
	}
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return NULL;
#line 6478 "PicasaPublishing.c"
}


GParamSpec* publishing_picasa_param_spec_publishing_parameters (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingPicasaParamSpecPublishingParameters* spec;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 6492 "PicasaPublishing.c"
}


gpointer publishing_picasa_value_get_publishing_parameters (const GValue* value) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return value->data[0].v_pointer;
#line 6501 "PicasaPublishing.c"
}


void publishing_picasa_value_set_publishing_parameters (GValue* value, gpointer v_object) {
	PublishingPicasaPublishingParameters * old;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS));
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	old = value->data[0].v_pointer;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (v_object) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS));
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_publishing_parameters_ref (value->data[0].v_pointer);
#line 6521 "PicasaPublishing.c"
	} else {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 6525 "PicasaPublishing.c"
	}
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (old) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_publishing_parameters_unref (old);
#line 6531 "PicasaPublishing.c"
	}
}


void publishing_picasa_value_take_publishing_parameters (GValue* value, gpointer v_object) {
	PublishingPicasaPublishingParameters * old;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS));
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	old = value->data[0].v_pointer;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (v_object) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS));
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 6550 "PicasaPublishing.c"
	} else {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 6554 "PicasaPublishing.c"
	}
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (old) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		publishing_picasa_publishing_parameters_unref (old);
#line 6560 "PicasaPublishing.c"
	}
}


static void publishing_picasa_publishing_parameters_class_init (PublishingPicasaPublishingParametersClass * klass) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_publishing_parameters_parent_class = g_type_class_peek_parent (klass);
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	((PublishingPicasaPublishingParametersClass *) klass)->finalize = publishing_picasa_publishing_parameters_finalize;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPicasaPublishingParametersPrivate));
#line 6572 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_parameters_instance_init (PublishingPicasaPublishingParameters * self) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv = PUBLISHING_PICASA_PUBLISHING_PARAMETERS_GET_PRIVATE (self);
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->ref_count = 1;
#line 6581 "PicasaPublishing.c"
}


static void publishing_picasa_publishing_parameters_finalize (PublishingPicasaPublishingParameters * obj) {
	PublishingPicasaPublishingParameters * self;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PICASA_TYPE_PUBLISHING_PARAMETERS, PublishingPicasaPublishingParameters);
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_signal_handlers_destroy (self);
#line 658 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->priv->target_album_name);
#line 659 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->priv->target_album_url);
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_free0 (self->priv->user_name);
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->albums = (_vala_array_free (self->priv->albums, self->priv->albums_length1, (GDestroyNotify) publishing_picasa_album_unref), NULL);
#line 6599 "PicasaPublishing.c"
}


GType publishing_picasa_publishing_parameters_get_type (void) {
	static volatile gsize publishing_picasa_publishing_parameters_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_picasa_publishing_parameters_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_picasa_value_publishing_parameters_init, publishing_picasa_value_publishing_parameters_free_value, publishing_picasa_value_publishing_parameters_copy_value, publishing_picasa_value_publishing_parameters_peek_pointer, "p", publishing_picasa_value_publishing_parameters_collect_value, "p", publishing_picasa_value_publishing_parameters_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPicasaPublishingParametersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_picasa_publishing_parameters_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPicasaPublishingParameters), 0, (GInstanceInitFunc) publishing_picasa_publishing_parameters_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_picasa_publishing_parameters_type_id;
		publishing_picasa_publishing_parameters_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingPicasaPublishingParameters", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_picasa_publishing_parameters_type_id__volatile, publishing_picasa_publishing_parameters_type_id);
	}
	return publishing_picasa_publishing_parameters_type_id__volatile;
}


gpointer publishing_picasa_publishing_parameters_ref (gpointer instance) {
	PublishingPicasaPublishingParameters * self;
	self = instance;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return instance;
#line 6624 "PicasaPublishing.c"
}


void publishing_picasa_publishing_parameters_unref (gpointer instance) {
	PublishingPicasaPublishingParameters * self;
	self = instance;
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		PUBLISHING_PICASA_PUBLISHING_PARAMETERS_GET_CLASS (self)->finalize (self);
#line 655 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 6637 "PicasaPublishing.c"
	}
}


PublishingPicasaUploader* publishing_picasa_uploader_construct (GType object_type, PublishingRESTSupportGoogleSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingPicasaPublishingParameters* parameters) {
	PublishingPicasaUploader* self = NULL;
	PublishingRESTSupportGoogleSession* _tmp0_;
	SpitPublishingPublishable** _tmp1_;
	gint _tmp1__length1;
	PublishingPicasaPublishingParameters* _tmp2_;
	PublishingPicasaPublishingParameters* _tmp3_;
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_GOOGLE_SESSION (session), NULL);
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PICASA_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = session;
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = publishables;
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1__length1 = publishables_length1;
#line 757 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = (PublishingPicasaUploader*) publishing_rest_support_batch_uploader_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, _tmp1__length1);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = parameters;
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = _publishing_picasa_publishing_parameters_ref0 (_tmp2_);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_picasa_publishing_parameters_unref0 (self->priv->parameters);
#line 759 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv->parameters = _tmp3_;
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return self;
#line 6671 "PicasaPublishing.c"
}


PublishingPicasaUploader* publishing_picasa_uploader_new (PublishingRESTSupportGoogleSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingPicasaPublishingParameters* parameters) {
#line 755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return publishing_picasa_uploader_construct (PUBLISHING_PICASA_TYPE_UPLOADER, session, publishables, publishables_length1, parameters);
#line 6678 "PicasaPublishing.c"
}


static PublishingRESTSupportTransaction* publishing_picasa_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base, SpitPublishingPublishable* publishable) {
	PublishingPicasaUploader * self;
	PublishingRESTSupportTransaction* result = NULL;
	PublishingRESTSupportSession* _tmp0_;
	PublishingRESTSupportGoogleSession* _tmp1_;
	PublishingPicasaPublishingParameters* _tmp2_;
	SpitPublishingPublishable* _tmp3_;
	SpitPublishingPublishable* _tmp4_;
	PublishingPicasaUploadTransaction* _tmp5_;
	PublishingRESTSupportTransaction* _tmp6_;
#line 762 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PICASA_TYPE_UPLOADER, PublishingPicasaUploader);
#line 762 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp0_ = publishing_rest_support_batch_uploader_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_GOOGLE_SESSION, PublishingRESTSupportGoogleSession);
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp2_ = self->priv->parameters;
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp3_ = publishing_rest_support_batch_uploader_get_current_publishable (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp4_ = _tmp3_;
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp5_ = publishing_picasa_upload_transaction_new (_tmp1_, _tmp2_, _tmp4_);
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_tmp6_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction);
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_g_object_unref0 (_tmp4_);
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	result = _tmp6_;
#line 764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	return result;
#line 6718 "PicasaPublishing.c"
}


static void publishing_picasa_uploader_class_init (PublishingPicasaUploaderClass * klass) {
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	publishing_picasa_uploader_parent_class = g_type_class_peek_parent (klass);
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->finalize = publishing_picasa_uploader_finalize;
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPicasaUploaderPrivate));
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->create_transaction = (PublishingRESTSupportTransaction* (*) (PublishingRESTSupportBatchUploader *, SpitPublishingPublishable*)) publishing_picasa_uploader_real_create_transaction;
#line 6731 "PicasaPublishing.c"
}


static void publishing_picasa_uploader_instance_init (PublishingPicasaUploader * self) {
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self->priv = PUBLISHING_PICASA_UPLOADER_GET_PRIVATE (self);
#line 6738 "PicasaPublishing.c"
}


static void publishing_picasa_uploader_finalize (PublishingRESTSupportBatchUploader * obj) {
	PublishingPicasaUploader * self;
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PICASA_TYPE_UPLOADER, PublishingPicasaUploader);
#line 753 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	_publishing_picasa_publishing_parameters_unref0 (self->priv->parameters);
#line 752 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PicasaPublishing.vala"
	PUBLISHING_REST_SUPPORT_BATCH_UPLOADER_CLASS (publishing_picasa_uploader_parent_class)->finalize (obj);
#line 6750 "PicasaPublishing.c"
}


GType publishing_picasa_uploader_get_type (void) {
	static volatile gsize publishing_picasa_uploader_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_picasa_uploader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPicasaUploaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_picasa_uploader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPicasaUploader), 0, (GInstanceInitFunc) publishing_picasa_uploader_instance_init, NULL };
		GType publishing_picasa_uploader_type_id;
		publishing_picasa_uploader_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, "PublishingPicasaUploader", &g_define_type_info, 0);
		g_once_init_leave (&publishing_picasa_uploader_type_id__volatile, publishing_picasa_uploader_type_id);
	}
	return publishing_picasa_uploader_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



