/* Dialogs.c generated by valac 0.36.6, the Vala compiler
 * generated from Dialogs.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */
/* namespace for future migration of AppWindow alert and other question dialogs into single*/
/* place: http://trac.yorba.org/ticket/3452*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gee.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <time.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gobject/gvaluecollector.h>


#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_TAG (tag_get_type ())
#define TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG, Tag))
#define TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG, TagClass))
#define IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG))
#define IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG))
#define TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG, TagClass))

typedef struct _Tag Tag;
typedef struct _TagClass TagClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_SAVED_SEARCH (saved_search_get_type ())
#define SAVED_SEARCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SAVED_SEARCH, SavedSearch))
#define SAVED_SEARCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SAVED_SEARCH, SavedSearchClass))
#define IS_SAVED_SEARCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SAVED_SEARCH))
#define IS_SAVED_SEARCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SAVED_SEARCH))
#define SAVED_SEARCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SAVED_SEARCH, SavedSearchClass))

typedef struct _SavedSearch SavedSearch;
typedef struct _SavedSearchClass SavedSearchClass;

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_PHOTO_SOURCE (photo_source_get_type ())
#define PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_SOURCE, PhotoSource))
#define PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_SOURCE, PhotoSourceClass))
#define IS_PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_SOURCE))
#define IS_PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_SOURCE))
#define PHOTO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_SOURCE, PhotoSourceClass))

typedef struct _PhotoSource PhotoSource;
typedef struct _PhotoSourceClass PhotoSourceClass;

#define TYPE_PHOTO (photo_get_type ())
#define PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO, Photo))
#define PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO, PhotoClass))
#define IS_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO))
#define IS_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO))
#define PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO, PhotoClass))

typedef struct _Photo Photo;
typedef struct _PhotoClass PhotoClass;

#define TYPE_EXPORT_DIALOG (export_dialog_get_type ())
#define EXPORT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EXPORT_DIALOG, ExportDialog))
#define EXPORT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EXPORT_DIALOG, ExportDialogClass))
#define IS_EXPORT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EXPORT_DIALOG))
#define IS_EXPORT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EXPORT_DIALOG))
#define EXPORT_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EXPORT_DIALOG, ExportDialogClass))

typedef struct _ExportDialog ExportDialog;
typedef struct _ExportDialogClass ExportDialogClass;
typedef struct _ExportDialogPrivate ExportDialogPrivate;

#define TYPE_SCALE_CONSTRAINT (scale_constraint_get_type ())

#define TYPE_EXPORT_FORMAT_PARAMETERS (export_format_parameters_get_type ())

#define TYPE_EXPORT_FORMAT_MODE (export_format_mode_get_type ())

#define TYPE_PHOTO_FILE_FORMAT (photo_file_format_get_type ())

#define JPEG_TYPE_QUALITY (jpeg_quality_get_type ())
typedef struct _ExportFormatParameters ExportFormatParameters;

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;

#define TYPE_PHOTO_FILE_FORMAT_PROPERTIES (photo_file_format_properties_get_type ())
#define PHOTO_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatProperties))
#define PHOTO_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatPropertiesClass))
#define IS_PHOTO_FILE_FORMAT_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES))
#define IS_PHOTO_FILE_FORMAT_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_FILE_FORMAT_PROPERTIES))
#define PHOTO_FILE_FORMAT_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_FILE_FORMAT_PROPERTIES, PhotoFileFormatPropertiesClass))

typedef struct _PhotoFileFormatProperties PhotoFileFormatProperties;
typedef struct _PhotoFileFormatPropertiesClass PhotoFileFormatPropertiesClass;
#define _photo_file_format_properties_unref0(var) ((var == NULL) ? NULL : (var = (photo_file_format_properties_unref (var), NULL)))

#define TYPE_BATCH_IMPORT_RESULT (batch_import_result_get_type ())
#define BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResult))
#define BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))
#define IS_BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_RESULT))
#define IS_BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_RESULT))
#define BATCH_IMPORT_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))

typedef struct _BatchImportResult BatchImportResult;
typedef struct _BatchImportResultClass BatchImportResultClass;
typedef struct _BatchImportResultPrivate BatchImportResultPrivate;

#define TYPE_BATCH_IMPORT_JOB (batch_import_job_get_type ())
#define BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJob))
#define BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))
#define IS_BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_JOB))
#define IS_BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_JOB))
#define BATCH_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))

typedef struct _BatchImportJob BatchImportJob;
typedef struct _BatchImportJobClass BatchImportJobClass;

#define TYPE_IMPORT_RESULT (import_result_get_type ())

#define TYPE_DUPLICATED_FILE (duplicated_file_get_type ())
#define DUPLICATED_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DUPLICATED_FILE, DuplicatedFile))
#define DUPLICATED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DUPLICATED_FILE, DuplicatedFileClass))
#define IS_DUPLICATED_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DUPLICATED_FILE))
#define IS_DUPLICATED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DUPLICATED_FILE))
#define DUPLICATED_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DUPLICATED_FILE, DuplicatedFileClass))

typedef struct _DuplicatedFile DuplicatedFile;
typedef struct _DuplicatedFileClass DuplicatedFileClass;
#define _batch_import_result_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_result_unref (var), NULL)))

#define IMPORT_UI_TYPE_QUESTION_PARAMS (import_ui_question_params_get_type ())
#define IMPORT_UI_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParams))
#define IMPORT_UI_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))
#define IMPORT_UI_IS_QUESTION_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_IS_QUESTION_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), IMPORT_UI_TYPE_QUESTION_PARAMS))
#define IMPORT_UI_QUESTION_PARAMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParamsClass))

typedef struct _ImportUIQuestionParams ImportUIQuestionParams;
typedef struct _ImportUIQuestionParamsClass ImportUIQuestionParamsClass;
typedef struct _ImportUIQuestionParamsPrivate ImportUIQuestionParamsPrivate;
typedef struct _ImportUIParamSpecQuestionParams ImportUIParamSpecQuestionParams;

#define TYPE_IMPORT_MANIFEST (import_manifest_get_type ())
#define IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_MANIFEST, ImportManifest))
#define IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_MANIFEST, ImportManifestClass))
#define IS_IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_MANIFEST))
#define IS_IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_MANIFEST))
#define IMPORT_MANIFEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_MANIFEST, ImportManifestClass))

typedef struct _ImportManifest ImportManifest;
typedef struct _ImportManifestClass ImportManifestClass;
typedef struct _ImportManifestPrivate ImportManifestPrivate;
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_TEXT_ENTRY_DIALOG_MEDIATOR (text_entry_dialog_mediator_get_type ())
#define TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator))
#define TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorClass))
#define IS_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR))
#define IS_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR))
#define TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorClass))

typedef struct _TextEntryDialogMediator TextEntryDialogMediator;
typedef struct _TextEntryDialogMediatorClass TextEntryDialogMediatorClass;
typedef struct _TextEntryDialogMediatorPrivate TextEntryDialogMediatorPrivate;

#define TYPE_TEXT_ENTRY_DIALOG (text_entry_dialog_get_type ())
#define TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialog))
#define TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialogClass))
#define IS_TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TEXT_ENTRY_DIALOG))
#define IS_TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TEXT_ENTRY_DIALOG))
#define TEXT_ENTRY_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialogClass))

typedef struct _TextEntryDialog TextEntryDialog;
typedef struct _TextEntryDialogClass TextEntryDialogClass;
typedef struct _ParamSpecTextEntryDialogMediator ParamSpecTextEntryDialogMediator;

#define TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR (multi_text_entry_dialog_mediator_get_type ())
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediator))
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorClass))
#define IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR))
#define IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR))
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorClass))

typedef struct _MultiTextEntryDialogMediator MultiTextEntryDialogMediator;
typedef struct _MultiTextEntryDialogMediatorClass MultiTextEntryDialogMediatorClass;
typedef struct _MultiTextEntryDialogMediatorPrivate MultiTextEntryDialogMediatorPrivate;

#define TYPE_MULTI_TEXT_ENTRY_DIALOG (multi_text_entry_dialog_get_type ())
#define MULTI_TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialog))
#define MULTI_TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialogClass))
#define IS_MULTI_TEXT_ENTRY_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG))
#define IS_MULTI_TEXT_ENTRY_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MULTI_TEXT_ENTRY_DIALOG))
#define MULTI_TEXT_ENTRY_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialogClass))

typedef struct _MultiTextEntryDialog MultiTextEntryDialog;
typedef struct _MultiTextEntryDialogClass MultiTextEntryDialogClass;
typedef struct _ParamSpecMultiTextEntryDialogMediator ParamSpecMultiTextEntryDialogMediator;

#define TYPE_ENTRY_MULTI_COMPLETION (entry_multi_completion_get_type ())
#define ENTRY_MULTI_COMPLETION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ENTRY_MULTI_COMPLETION, EntryMultiCompletion))
#define ENTRY_MULTI_COMPLETION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ENTRY_MULTI_COMPLETION, EntryMultiCompletionClass))
#define IS_ENTRY_MULTI_COMPLETION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ENTRY_MULTI_COMPLETION))
#define IS_ENTRY_MULTI_COMPLETION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ENTRY_MULTI_COMPLETION))
#define ENTRY_MULTI_COMPLETION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ENTRY_MULTI_COMPLETION, EntryMultiCompletionClass))

typedef struct _EntryMultiCompletion EntryMultiCompletion;
typedef struct _EntryMultiCompletionClass EntryMultiCompletionClass;
typedef struct _EntryMultiCompletionPrivate EntryMultiCompletionPrivate;

#define TYPE_SET_BACKGROUND_PHOTO_DIALOG (set_background_photo_dialog_get_type ())
#define SET_BACKGROUND_PHOTO_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_BACKGROUND_PHOTO_DIALOG, SetBackgroundPhotoDialog))
#define SET_BACKGROUND_PHOTO_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_BACKGROUND_PHOTO_DIALOG, SetBackgroundPhotoDialogClass))
#define IS_SET_BACKGROUND_PHOTO_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_BACKGROUND_PHOTO_DIALOG))
#define IS_SET_BACKGROUND_PHOTO_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_BACKGROUND_PHOTO_DIALOG))
#define SET_BACKGROUND_PHOTO_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_BACKGROUND_PHOTO_DIALOG, SetBackgroundPhotoDialogClass))

typedef struct _SetBackgroundPhotoDialog SetBackgroundPhotoDialog;
typedef struct _SetBackgroundPhotoDialogClass SetBackgroundPhotoDialogClass;
typedef struct _SetBackgroundPhotoDialogPrivate SetBackgroundPhotoDialogPrivate;

#define TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG (set_background_slideshow_dialog_get_type ())
#define SET_BACKGROUND_SLIDESHOW_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG, SetBackgroundSlideshowDialog))
#define SET_BACKGROUND_SLIDESHOW_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG, SetBackgroundSlideshowDialogClass))
#define IS_SET_BACKGROUND_SLIDESHOW_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG))
#define IS_SET_BACKGROUND_SLIDESHOW_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG))
#define SET_BACKGROUND_SLIDESHOW_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG, SetBackgroundSlideshowDialogClass))

typedef struct _SetBackgroundSlideshowDialog SetBackgroundSlideshowDialog;
typedef struct _SetBackgroundSlideshowDialogClass SetBackgroundSlideshowDialogClass;
typedef struct _SetBackgroundSlideshowDialogPrivate SetBackgroundSlideshowDialogPrivate;
typedef struct _TextEntryDialogPrivate TextEntryDialogPrivate;
typedef struct _MultiTextEntryDialogPrivate MultiTextEntryDialogPrivate;

#define TYPE_EVENT_RENAME_DIALOG (event_rename_dialog_get_type ())
#define EVENT_RENAME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EVENT_RENAME_DIALOG, EventRenameDialog))
#define EVENT_RENAME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EVENT_RENAME_DIALOG, EventRenameDialogClass))
#define IS_EVENT_RENAME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EVENT_RENAME_DIALOG))
#define IS_EVENT_RENAME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EVENT_RENAME_DIALOG))
#define EVENT_RENAME_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EVENT_RENAME_DIALOG, EventRenameDialogClass))

typedef struct _EventRenameDialog EventRenameDialog;
typedef struct _EventRenameDialogClass EventRenameDialogClass;
typedef struct _EventRenameDialogPrivate EventRenameDialogPrivate;

#define TYPE_EDIT_TITLE_DIALOG (edit_title_dialog_get_type ())
#define EDIT_TITLE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EDIT_TITLE_DIALOG, EditTitleDialog))
#define EDIT_TITLE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EDIT_TITLE_DIALOG, EditTitleDialogClass))
#define IS_EDIT_TITLE_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EDIT_TITLE_DIALOG))
#define IS_EDIT_TITLE_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EDIT_TITLE_DIALOG))
#define EDIT_TITLE_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EDIT_TITLE_DIALOG, EditTitleDialogClass))

typedef struct _EditTitleDialog EditTitleDialog;
typedef struct _EditTitleDialogClass EditTitleDialogClass;
typedef struct _EditTitleDialogPrivate EditTitleDialogPrivate;

#define TYPE_EDIT_COMMENT_DIALOG (edit_comment_dialog_get_type ())
#define EDIT_COMMENT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialog))
#define EDIT_COMMENT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialogClass))
#define IS_EDIT_COMMENT_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EDIT_COMMENT_DIALOG))
#define IS_EDIT_COMMENT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EDIT_COMMENT_DIALOG))
#define EDIT_COMMENT_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EDIT_COMMENT_DIALOG, EditCommentDialogClass))

typedef struct _EditCommentDialog EditCommentDialog;
typedef struct _EditCommentDialogClass EditCommentDialogClass;
typedef struct _EditCommentDialogPrivate EditCommentDialogPrivate;

#define TYPE_PROGRESS_DIALOG (progress_dialog_get_type ())
#define PROGRESS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PROGRESS_DIALOG, ProgressDialog))
#define PROGRESS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PROGRESS_DIALOG, ProgressDialogClass))
#define IS_PROGRESS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PROGRESS_DIALOG))
#define IS_PROGRESS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PROGRESS_DIALOG))
#define PROGRESS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PROGRESS_DIALOG, ProgressDialogClass))

typedef struct _ProgressDialog ProgressDialog;
typedef struct _ProgressDialogClass ProgressDialogClass;
typedef struct _ProgressDialogPrivate ProgressDialogPrivate;

#define TYPE_ADJUST_DATE_TIME_DIALOG (adjust_date_time_dialog_get_type ())
#define ADJUST_DATE_TIME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialog))
#define ADJUST_DATE_TIME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialogClass))
#define IS_ADJUST_DATE_TIME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ADJUST_DATE_TIME_DIALOG))
#define IS_ADJUST_DATE_TIME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ADJUST_DATE_TIME_DIALOG))
#define ADJUST_DATE_TIME_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialogClass))

typedef struct _AdjustDateTimeDialog AdjustDateTimeDialog;
typedef struct _AdjustDateTimeDialogClass AdjustDateTimeDialogClass;
typedef struct _AdjustDateTimeDialogPrivate AdjustDateTimeDialogPrivate;

#define ADJUST_DATE_TIME_DIALOG_TYPE_TIME_SYSTEM (adjust_date_time_dialog_time_system_get_type ())

#define TYPE_DATEABLE (dateable_get_type ())
#define DATEABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATEABLE, Dateable))
#define IS_DATEABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATEABLE))
#define DATEABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_DATEABLE, DateableIface))

typedef struct _Dateable Dateable;
typedef struct _DateableIface DateableIface;

#define TYPE_TAGS_DIALOG (tags_dialog_get_type ())
#define TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAGS_DIALOG, TagsDialog))
#define TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAGS_DIALOG, TagsDialogClass))
#define IS_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAGS_DIALOG))
#define IS_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAGS_DIALOG))
#define TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAGS_DIALOG, TagsDialogClass))

typedef struct _TagsDialog TagsDialog;
typedef struct _TagsDialogClass TagsDialogClass;
typedef struct _TagsDialogPrivate TagsDialogPrivate;

#define TYPE_HIERARCHICAL_TAG_INDEX (hierarchical_tag_index_get_type ())
#define HIERARCHICAL_TAG_INDEX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndex))
#define HIERARCHICAL_TAG_INDEX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndexClass))
#define IS_HIERARCHICAL_TAG_INDEX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_HIERARCHICAL_TAG_INDEX))
#define IS_HIERARCHICAL_TAG_INDEX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_HIERARCHICAL_TAG_INDEX))
#define HIERARCHICAL_TAG_INDEX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_HIERARCHICAL_TAG_INDEX, HierarchicalTagIndexClass))

typedef struct _HierarchicalTagIndex HierarchicalTagIndex;
typedef struct _HierarchicalTagIndexClass HierarchicalTagIndexClass;
#define _hierarchical_tag_index_unref0(var) ((var == NULL) ? NULL : (var = (hierarchical_tag_index_unref (var), NULL)))

#define TYPE_ADD_TAGS_DIALOG (add_tags_dialog_get_type ())
#define ADD_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ADD_TAGS_DIALOG, AddTagsDialog))
#define ADD_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ADD_TAGS_DIALOG, AddTagsDialogClass))
#define IS_ADD_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ADD_TAGS_DIALOG))
#define IS_ADD_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ADD_TAGS_DIALOG))
#define ADD_TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ADD_TAGS_DIALOG, AddTagsDialogClass))

typedef struct _AddTagsDialog AddTagsDialog;
typedef struct _AddTagsDialogClass AddTagsDialogClass;
typedef struct _AddTagsDialogPrivate AddTagsDialogPrivate;

#define TYPE_MODIFY_TAGS_DIALOG (modify_tags_dialog_get_type ())
#define MODIFY_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialog))
#define MODIFY_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialogClass))
#define IS_MODIFY_TAGS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MODIFY_TAGS_DIALOG))
#define IS_MODIFY_TAGS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MODIFY_TAGS_DIALOG))
#define MODIFY_TAGS_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialogClass))

typedef struct _ModifyTagsDialog ModifyTagsDialog;
typedef struct _ModifyTagsDialogClass ModifyTagsDialogClass;
typedef struct _ModifyTagsDialogPrivate ModifyTagsDialogPrivate;

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;

#define TYPE_CONTAINER_SOURCE_COLLECTION (container_source_collection_get_type ())
#define CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollection))
#define CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))
#define IS_CONTAINER_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONTAINER_SOURCE_COLLECTION))
#define IS_CONTAINER_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONTAINER_SOURCE_COLLECTION))
#define CONTAINER_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONTAINER_SOURCE_COLLECTION, ContainerSourceCollectionClass))

typedef struct _ContainerSourceCollection ContainerSourceCollection;
typedef struct _ContainerSourceCollectionClass ContainerSourceCollectionClass;

#define TYPE_TAG_SOURCE_COLLECTION (tag_source_collection_get_type ())
#define TAG_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollection))
#define TAG_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollectionClass))
#define IS_TAG_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TAG_SOURCE_COLLECTION))
#define IS_TAG_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TAG_SOURCE_COLLECTION))
#define TAG_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TAG_SOURCE_COLLECTION, TagSourceCollectionClass))

typedef struct _TagSourceCollection TagSourceCollection;
typedef struct _TagSourceCollectionClass TagSourceCollectionClass;

#define TYPE_WELCOME_SERVICE_ENTRY (welcome_service_entry_get_type ())
#define WELCOME_SERVICE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_WELCOME_SERVICE_ENTRY, WelcomeServiceEntry))
#define IS_WELCOME_SERVICE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_WELCOME_SERVICE_ENTRY))
#define WELCOME_SERVICE_ENTRY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_WELCOME_SERVICE_ENTRY, WelcomeServiceEntryIface))

typedef struct _WelcomeServiceEntry WelcomeServiceEntry;
typedef struct _WelcomeServiceEntryIface WelcomeServiceEntryIface;

#define TYPE_WELCOME_DIALOG (welcome_dialog_get_type ())
#define WELCOME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_WELCOME_DIALOG, WelcomeDialog))
#define WELCOME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_WELCOME_DIALOG, WelcomeDialogClass))
#define IS_WELCOME_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_WELCOME_DIALOG))
#define IS_WELCOME_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_WELCOME_DIALOG))
#define WELCOME_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_WELCOME_DIALOG, WelcomeDialogClass))

typedef struct _WelcomeDialog WelcomeDialog;
typedef struct _WelcomeDialogClass WelcomeDialogClass;
typedef struct _WelcomeDialogPrivate WelcomeDialogPrivate;

#define SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST (spit_data_imports_welcome_import_meta_host_get_type ())
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHost))
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHostClass))
#define SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST))
#define SPIT_DATA_IMPORTS_IS_WELCOME_IMPORT_META_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST))
#define SPIT_DATA_IMPORTS_WELCOME_IMPORT_META_HOST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_DATA_IMPORTS_TYPE_WELCOME_IMPORT_META_HOST, SpitDataImportsWelcomeImportMetaHostClass))

typedef struct _SpitDataImportsWelcomeImportMetaHost SpitDataImportsWelcomeImportMetaHost;
typedef struct _SpitDataImportsWelcomeImportMetaHostClass SpitDataImportsWelcomeImportMetaHostClass;

#define TYPE_PREFERENCES_DIALOG (preferences_dialog_get_type ())
#define PREFERENCES_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PREFERENCES_DIALOG, PreferencesDialog))
#define PREFERENCES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PREFERENCES_DIALOG, PreferencesDialogClass))
#define IS_PREFERENCES_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PREFERENCES_DIALOG))
#define IS_PREFERENCES_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PREFERENCES_DIALOG))
#define PREFERENCES_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PREFERENCES_DIALOG, PreferencesDialogClass))

typedef struct _PreferencesDialog PreferencesDialog;
typedef struct _PreferencesDialogClass PreferencesDialogClass;
typedef struct _PreferencesDialogPrivate PreferencesDialogPrivate;

#define TYPE_SORTED_LIST (sorted_list_get_type ())
#define SORTED_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SORTED_LIST, SortedList))
#define SORTED_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SORTED_LIST, SortedListClass))
#define IS_SORTED_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SORTED_LIST))
#define IS_SORTED_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SORTED_LIST))
#define SORTED_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SORTED_LIST, SortedListClass))

typedef struct _SortedList SortedList;
typedef struct _SortedListClass SortedListClass;

#define PREFERENCES_DIALOG_TYPE_PATH_FORMAT (preferences_dialog_path_format_get_type ())
#define PREFERENCES_DIALOG_PATH_FORMAT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PREFERENCES_DIALOG_TYPE_PATH_FORMAT, PreferencesDialogPathFormat))
#define PREFERENCES_DIALOG_PATH_FORMAT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PREFERENCES_DIALOG_TYPE_PATH_FORMAT, PreferencesDialogPathFormatClass))
#define PREFERENCES_DIALOG_IS_PATH_FORMAT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PREFERENCES_DIALOG_TYPE_PATH_FORMAT))
#define PREFERENCES_DIALOG_IS_PATH_FORMAT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PREFERENCES_DIALOG_TYPE_PATH_FORMAT))
#define PREFERENCES_DIALOG_PATH_FORMAT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PREFERENCES_DIALOG_TYPE_PATH_FORMAT, PreferencesDialogPathFormatClass))

typedef struct _PreferencesDialogPathFormat PreferencesDialogPathFormat;
typedef struct _PreferencesDialogPathFormatClass PreferencesDialogPathFormatClass;

#define PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR (plugins_manifest_widget_mediator_get_type ())
#define PLUGINS_MANIFEST_WIDGET_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR, PluginsManifestWidgetMediator))
#define PLUGINS_MANIFEST_WIDGET_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR, PluginsManifestWidgetMediatorClass))
#define PLUGINS_IS_MANIFEST_WIDGET_MEDIATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR))
#define PLUGINS_IS_MANIFEST_WIDGET_MEDIATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR))
#define PLUGINS_MANIFEST_WIDGET_MEDIATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PLUGINS_TYPE_MANIFEST_WIDGET_MEDIATOR, PluginsManifestWidgetMediatorClass))

typedef struct _PluginsManifestWidgetMediator PluginsManifestWidgetMediator;
typedef struct _PluginsManifestWidgetMediatorClass PluginsManifestWidgetMediatorClass;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
#define _plugins_manifest_widget_mediator_unref0(var) ((var == NULL) ? NULL : (var = (plugins_manifest_widget_mediator_unref (var), NULL)))

#define TYPE_RAW_DEVELOPER (raw_developer_get_type ())
typedef struct _PreferencesDialogPathFormatPrivate PreferencesDialogPathFormatPrivate;
#define _preferences_dialog_path_format_unref0(var) ((var == NULL) ? NULL : (var = (preferences_dialog_path_format_unref (var), NULL)))
#define _preferences_dialog_unref0(var) ((var == NULL) ? NULL : (var = (preferences_dialog_unref (var), NULL)))
typedef struct _PreferencesDialogParamSpecPathFormat PreferencesDialogParamSpecPathFormat;
typedef struct _ParamSpecPreferencesDialog ParamSpecPreferencesDialog;

#define TYPE_LIBRARY_PHOTO (library_photo_get_type ())
#define LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO, LibraryPhoto))
#define LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))
#define IS_LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO))
#define IS_LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO))
#define LIBRARY_PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))

typedef struct _LibraryPhoto LibraryPhoto;
typedef struct _LibraryPhotoClass LibraryPhotoClass;

#define TYPE_VIDEO_SOURCE (video_source_get_type ())
#define VIDEO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_SOURCE, VideoSource))
#define VIDEO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_SOURCE, VideoSourceClass))
#define IS_VIDEO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_SOURCE))
#define IS_VIDEO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_SOURCE))
#define VIDEO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_SOURCE, VideoSourceClass))

typedef struct _VideoSource VideoSource;
typedef struct _VideoSourceClass VideoSourceClass;

#define TYPE_VIDEO (video_get_type ())
#define VIDEO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO, Video))
#define VIDEO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO, VideoClass))
#define IS_VIDEO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO))
#define IS_VIDEO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO))
#define VIDEO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO, VideoClass))

typedef struct _Video Video;
typedef struct _VideoClass VideoClass;

#define TYPE_MEDIA_SOURCE_COLLECTION (media_source_collection_get_type ())
#define MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection))
#define MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))
#define IS_MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_COLLECTION))
#define IS_MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_COLLECTION))
#define MEDIA_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))

typedef struct _MediaSourceCollection MediaSourceCollection;
typedef struct _MediaSourceCollectionClass MediaSourceCollectionClass;

#define TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION (library_photo_source_collection_get_type ())
#define LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollection))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define IS_LIBRARY_PHOTO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION))
#define LIBRARY_PHOTO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO_SOURCE_COLLECTION, LibraryPhotoSourceCollectionClass))

typedef struct _LibraryPhotoSourceCollection LibraryPhotoSourceCollection;
typedef struct _LibraryPhotoSourceCollectionClass LibraryPhotoSourceCollectionClass;

#define TYPE_VIDEO_SOURCE_COLLECTION (video_source_collection_get_type ())
#define VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollection))
#define VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))
#define IS_VIDEO_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_SOURCE_COLLECTION))
#define IS_VIDEO_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_SOURCE_COLLECTION))
#define VIDEO_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_SOURCE_COLLECTION, VideoSourceCollectionClass))

typedef struct _VideoSourceCollection VideoSourceCollection;
typedef struct _VideoSourceCollectionClass VideoSourceCollectionClass;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ExportDialog {
	GtkDialog parent_instance;
	ExportDialogPrivate * priv;
};

struct _ExportDialogClass {
	GtkDialogClass parent_class;
};

struct _ExportDialogPrivate {
	GtkGrid* table;
	GtkComboBoxText* quality_combo;
	GtkComboBoxText* constraint_combo;
	GtkComboBoxText* format_combo;
	GtkSwitch* export_metadata;
	GeeArrayList* format_options;
	GtkEntry* pixels_entry;
	GtkWidget* ok_button;
	gboolean in_insert;
};

typedef enum  {
	SCALE_CONSTRAINT_ORIGINAL,
	SCALE_CONSTRAINT_DIMENSIONS,
	SCALE_CONSTRAINT_WIDTH,
	SCALE_CONSTRAINT_HEIGHT,
	SCALE_CONSTRAINT_FILL_VIEWPORT
} ScaleConstraint;

typedef enum  {
	EXPORT_FORMAT_MODE_UNMODIFIED,
	EXPORT_FORMAT_MODE_CURRENT,
	EXPORT_FORMAT_MODE_SPECIFIED,
	EXPORT_FORMAT_MODE_LAST
} ExportFormatMode;

typedef enum  {
	PHOTO_FILE_FORMAT_JFIF,
	PHOTO_FILE_FORMAT_RAW,
	PHOTO_FILE_FORMAT_PNG,
	PHOTO_FILE_FORMAT_TIFF,
	PHOTO_FILE_FORMAT_BMP,
	PHOTO_FILE_FORMAT_UNKNOWN
} PhotoFileFormat;

typedef enum  {
	JPEG_QUALITY_LOW = 50,
	JPEG_QUALITY_MEDIUM = 75,
	JPEG_QUALITY_HIGH = 90,
	JPEG_QUALITY_MAXIMUM = 100
} JpegQuality;

struct _ExportFormatParameters {
	ExportFormatMode mode;
	PhotoFileFormat specified_format;
	JpegQuality quality;
	gboolean export_metadata;
};

typedef enum  {
	IMPORT_RESULT_SUCCESS,
	IMPORT_RESULT_FILE_ERROR,
	IMPORT_RESULT_DECODE_ERROR,
	IMPORT_RESULT_DATABASE_ERROR,
	IMPORT_RESULT_USER_ABORT,
	IMPORT_RESULT_NOT_A_FILE,
	IMPORT_RESULT_PHOTO_EXISTS,
	IMPORT_RESULT_UNSUPPORTED_FORMAT,
	IMPORT_RESULT_NOT_AN_IMAGE,
	IMPORT_RESULT_DISK_FAILURE,
	IMPORT_RESULT_DISK_FULL,
	IMPORT_RESULT_CAMERA_ERROR,
	IMPORT_RESULT_FILE_WRITE_ERROR,
	IMPORT_RESULT_PIXBUF_CORRUPT_IMAGE
} ImportResult;

struct _BatchImportResult {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BatchImportResultPrivate * priv;
	BatchImportJob* job;
	GFile* file;
	gchar* src_identifier;
	gchar* dest_identifier;
	ImportResult result;
	gchar* errmsg;
	DuplicatedFile* duplicate_of;
};

struct _BatchImportResultClass {
	GTypeClass parent_class;
	void (*finalize) (BatchImportResult *self);
};

struct _ImportUIQuestionParams {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportUIQuestionParamsPrivate * priv;
	gchar* question;
	gchar* yes_button;
	gchar* no_button;
};

struct _ImportUIQuestionParamsClass {
	GTypeClass parent_class;
	void (*finalize) (ImportUIQuestionParams *self);
};

struct _ImportUIParamSpecQuestionParams {
	GParamSpec parent_instance;
};

struct _ImportManifest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportManifestPrivate * priv;
	GeeList* imported;
	GeeList* success;
	GeeList* camera_failed;
	GeeList* failed;
	GeeList* write_failed;
	GeeList* skipped_photos;
	GeeList* skipped_files;
	GeeList* aborted;
	GeeList* already_imported;
	GeeList* corrupt_files;
	GeeList* all;
};

struct _ImportManifestClass {
	GTypeClass parent_class;
	void (*finalize) (ImportManifest *self);
};

struct _TextEntryDialogMediator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	TextEntryDialogMediatorPrivate * priv;
};

struct _TextEntryDialogMediatorClass {
	GTypeClass parent_class;
	void (*finalize) (TextEntryDialogMediator *self);
	gboolean (*on_modify_validate) (TextEntryDialogMediator* self, const gchar* text);
};

struct _TextEntryDialogMediatorPrivate {
	TextEntryDialog* dialog;
};

typedef gboolean (*TextEntryDialogOnModifyValidateType) (const gchar* text, void* user_data);
struct _ParamSpecTextEntryDialogMediator {
	GParamSpec parent_instance;
};

struct _MultiTextEntryDialogMediator {
	GTypeInstance parent_instance;
	volatile int ref_count;
	MultiTextEntryDialogMediatorPrivate * priv;
};

struct _MultiTextEntryDialogMediatorClass {
	GTypeClass parent_class;
	void (*finalize) (MultiTextEntryDialogMediator *self);
	gboolean (*on_modify_validate) (MultiTextEntryDialogMediator* self, const gchar* text);
};

struct _MultiTextEntryDialogMediatorPrivate {
	MultiTextEntryDialog* dialog;
};

typedef gboolean (*MultiTextEntryDialogOnModifyValidateType) (const gchar* text, void* user_data);
struct _ParamSpecMultiTextEntryDialogMediator {
	GParamSpec parent_instance;
};

struct _EntryMultiCompletion {
	GtkEntryCompletion parent_instance;
	EntryMultiCompletionPrivate * priv;
};

struct _EntryMultiCompletionClass {
	GtkEntryCompletionClass parent_class;
};

struct _EntryMultiCompletionPrivate {
	gchar* delimiter;
};

struct _SetBackgroundPhotoDialog {
	GtkDialog parent_instance;
	SetBackgroundPhotoDialogPrivate * priv;
};

struct _SetBackgroundPhotoDialogClass {
	GtkDialogClass parent_class;
};

struct _SetBackgroundPhotoDialogPrivate {
	GtkCheckButton* desktop_background_checkbox;
	GtkCheckButton* screensaver_checkbox;
};

struct _SetBackgroundSlideshowDialog {
	GtkDialog parent_instance;
	SetBackgroundSlideshowDialogPrivate * priv;
};

struct _SetBackgroundSlideshowDialogClass {
	GtkDialogClass parent_class;
};

struct _SetBackgroundSlideshowDialogPrivate {
	GtkCheckButton* desktop_background_checkbox;
	GtkCheckButton* screensaver_checkbox;
	GtkScale* delay_scale;
	GtkLabel* delay_value_label;
	gint delay_value;
};

struct _TextEntryDialog {
	GtkDialog parent_instance;
	TextEntryDialogPrivate * priv;
};

struct _TextEntryDialogClass {
	GtkDialogClass parent_class;
};

struct _TextEntryDialogPrivate {
	TextEntryDialogOnModifyValidateType on_modify_validate;
	gpointer on_modify_validate_target;
	GtkEntry* entry;
	GtkBuilder* builder;
	GtkButton* button1;
	GtkButton* button2;
};

struct _MultiTextEntryDialog {
	GtkDialog parent_instance;
	MultiTextEntryDialogPrivate * priv;
};

struct _MultiTextEntryDialogClass {
	GtkDialogClass parent_class;
};

struct _MultiTextEntryDialogPrivate {
	MultiTextEntryDialogOnModifyValidateType on_modify_validate;
	gpointer on_modify_validate_target;
	GtkTextView* entry;
	GtkBuilder* builder;
	GtkButton* button1;
	GtkButton* button2;
};

struct _EventRenameDialog {
	TextEntryDialogMediator parent_instance;
	EventRenameDialogPrivate * priv;
};

struct _EventRenameDialogClass {
	TextEntryDialogMediatorClass parent_class;
	gchar* (*execute) (EventRenameDialog* self);
};

struct _EditTitleDialog {
	TextEntryDialogMediator parent_instance;
	EditTitleDialogPrivate * priv;
};

struct _EditTitleDialogClass {
	TextEntryDialogMediatorClass parent_class;
	gchar* (*execute) (EditTitleDialog* self);
};

struct _EditCommentDialog {
	MultiTextEntryDialogMediator parent_instance;
	EditCommentDialogPrivate * priv;
};

struct _EditCommentDialogClass {
	MultiTextEntryDialogMediatorClass parent_class;
	gchar* (*execute) (EditCommentDialog* self);
};

struct _ProgressDialog {
	GtkWindow parent_instance;
	ProgressDialogPrivate * priv;
};

struct _ProgressDialogClass {
	GtkWindowClass parent_class;
};

struct _ProgressDialogPrivate {
	GtkProgressBar* progress_bar;
	GtkButton* cancel_button;
	GCancellable* cancellable;
	guint64 last_count;
	gint update_every;
	gint minimum_on_screen_time_msec;
	gulong time_started;
};

struct _AdjustDateTimeDialog {
	GtkDialog parent_instance;
	AdjustDateTimeDialogPrivate * priv;
};

struct _AdjustDateTimeDialogClass {
	GtkDialogClass parent_class;
};

typedef enum  {
	ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_AM,
	ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM,
	ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR
} AdjustDateTimeDialogTimeSystem;

struct _AdjustDateTimeDialogPrivate {
	gboolean no_original_time;
	time_t original_time;
	GtkLabel* original_time_label;
	GtkCalendar* calendar;
	GtkSpinButton* hour;
	GtkSpinButton* minute;
	GtkSpinButton* second;
	GtkComboBoxText* system;
	GtkRadioButton* relativity_radio_button;
	GtkRadioButton* batch_radio_button;
	GtkCheckButton* modify_originals_check_button;
	GtkLabel* notification;
	AdjustDateTimeDialogTimeSystem previous_time_system;
};

struct _DateableIface {
	GTypeInterface parent_iface;
	void (*set_exposure_time) (Dateable* self, time_t target_time);
	time_t (*get_exposure_time) (Dateable* self);
};

struct _TagsDialog {
	TextEntryDialogMediator parent_instance;
	TagsDialogPrivate * priv;
};

struct _TagsDialogClass {
	TextEntryDialogMediatorClass parent_class;
};

struct _AddTagsDialog {
	TagsDialog parent_instance;
	AddTagsDialogPrivate * priv;
};

struct _AddTagsDialogClass {
	TagsDialogClass parent_class;
};

struct _ModifyTagsDialog {
	TagsDialog parent_instance;
	ModifyTagsDialogPrivate * priv;
};

struct _ModifyTagsDialogClass {
	TagsDialogClass parent_class;
};

struct _WelcomeServiceEntryIface {
	GTypeInterface parent_iface;
	gchar* (*get_service_name) (WelcomeServiceEntry* self);
	void (*execute) (WelcomeServiceEntry* self);
};

struct _WelcomeDialog {
	GtkDialog parent_instance;
	WelcomeDialogPrivate * priv;
};

struct _WelcomeDialogClass {
	GtkDialogClass parent_class;
};

struct _WelcomeDialogPrivate {
	GtkCheckButton* hide_button;
	GtkCheckButton* system_pictures_import_check;
	GtkCheckButton** external_import_checks;
	gint external_import_checks_length1;
	gint _external_import_checks_size_;
	WelcomeServiceEntry** external_import_entries;
	gint external_import_entries_length1;
	gint _external_import_entries_size_;
	GtkLabel* secondary_text;
	GtkLabel* instruction_header;
	GtkBox* import_content;
	GtkBox* import_action_checkbox_packer;
	GtkBox* external_import_action_checkbox_packer;
	SpitDataImportsWelcomeImportMetaHost* import_meta_host;
	gboolean import_content_already_installed;
	gboolean ok_clicked;
};

struct _PreferencesDialog {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PreferencesDialogPrivate * priv;
};

struct _PreferencesDialogClass {
	GTypeClass parent_class;
	void (*finalize) (PreferencesDialog *self);
};

struct _PreferencesDialogPrivate {
	GtkDialog* dialog;
	GtkBuilder* builder;
	GtkAdjustment* bg_color_adjustment;
	GtkScale* bg_color_slider;
	GtkComboBox* photo_editor_combo;
	GtkComboBox* raw_editor_combo;
	SortedList* external_raw_apps;
	SortedList* external_photo_apps;
	GtkFileChooserButton* library_dir_button;
	GtkComboBoxText* dir_pattern_combo;
	GtkEntry* dir_pattern_entry;
	GtkLabel* dir_pattern_example;
	gboolean allow_closing;
	gchar* lib_dir;
	GeeArrayList* path_formats;
	GDateTime* example_date;
	GtkCheckButton* lowercase;
	PluginsManifestWidgetMediator* plugins_mediator;
	GtkComboBoxText* default_raw_developer_combo;
};

typedef enum  {
	RAW_DEVELOPER_SHOTWELL = 0,
	RAW_DEVELOPER_CAMERA,
	RAW_DEVELOPER_EMBEDDED
} RawDeveloper;

struct _PreferencesDialogPathFormat {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PreferencesDialogPathFormatPrivate * priv;
	gchar* name;
	gchar* pattern;
};

struct _PreferencesDialogPathFormatClass {
	GTypeClass parent_class;
	void (*finalize) (PreferencesDialogPathFormat *self);
};

struct _PreferencesDialogParamSpecPathFormat {
	GParamSpec parent_instance;
};

struct _ParamSpecPreferencesDialog {
	GParamSpec parent_instance;
};

typedef gboolean (*ProgressMonitor) (guint64 current, guint64 total, gboolean do_event_loop, void* user_data);

extern GFile* export_ui_current_export_dir;
GFile* export_ui_current_export_dir = NULL;
static gpointer export_dialog_parent_class = NULL;
static ScaleConstraint export_dialog_current_constraint;
static ScaleConstraint export_dialog_current_constraint = SCALE_CONSTRAINT_ORIGINAL;
static ExportFormatParameters export_dialog_current_parameters;
static ExportFormatParameters export_dialog_current_parameters = {0};
static gint export_dialog_current_scale;
static gint export_dialog_current_scale = 0;
static gpointer import_ui_question_params_parent_class = NULL;
static gpointer text_entry_dialog_mediator_parent_class = NULL;
static gpointer multi_text_entry_dialog_mediator_parent_class = NULL;
static gpointer entry_multi_completion_parent_class = NULL;
static gpointer set_background_photo_dialog_parent_class = NULL;
static gpointer set_background_slideshow_dialog_parent_class = NULL;
static gpointer text_entry_dialog_parent_class = NULL;
static gpointer multi_text_entry_dialog_parent_class = NULL;
static gpointer event_rename_dialog_parent_class = NULL;
static gpointer edit_title_dialog_parent_class = NULL;
static gpointer edit_comment_dialog_parent_class = NULL;
static gpointer progress_dialog_parent_class = NULL;
static gpointer adjust_date_time_dialog_parent_class = NULL;
static gpointer tags_dialog_parent_class = NULL;
static gpointer add_tags_dialog_parent_class = NULL;
static gpointer modify_tags_dialog_parent_class = NULL;
extern TagSourceCollection* tag_global;
static gpointer welcome_dialog_parent_class = NULL;
static gpointer preferences_dialog_parent_class = NULL;
static PreferencesDialog* preferences_dialog_preferences_dialog;
static PreferencesDialog* preferences_dialog_preferences_dialog = NULL;
static gpointer preferences_dialog_path_format_parent_class = NULL;
extern LibraryPhotoSourceCollection* library_photo_global;
extern VideoSourceCollection* video_global;

GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType tag_get_type (void) G_GNUC_CONST;
gboolean dialogs_confirm_delete_tag (Tag* tag);
gint tag_get_sources_count (Tag* self);
gchar* tag_get_user_visible_name (Tag* self);
gboolean app_window_negate_affirm_question (const gchar* message, const gchar* negative, const gchar* affirmative, const gchar* title, GtkWindow* parent);
#define RESOURCES_DELETE_TAG_TITLE _ ("Delete Tag")
GType saved_search_get_type (void) G_GNUC_CONST;
gboolean dialogs_confirm_delete_saved_search (SavedSearch* search);
gchar* data_object_get_name (DataObject* self);
#define RESOURCES_DELETE_SAVED_SEARCH_DIALOG_TITLE _ ("Delete Search")
gboolean dialogs_confirm_warn_developer_changed (gint number);
GType page_window_get_type (void) G_GNUC_CONST;
GType app_window_get_type (void) G_GNUC_CONST;
AppWindow* app_window_get_instance (void);
#define RESOURCES_CANCEL_LABEL _ ("_Cancel")
GFile* export_ui_choose_file (const gchar* current_file_basename);
gboolean video_reader_is_supported_video_filename (const gchar* filename);
#define RESOURCES_SAVE_LABEL _ ("_Save")
GFile* export_ui_choose_dir (const gchar* user_title);
#define RESOURCES_OK_LABEL _ ("_OK")
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
GType photo_source_get_type (void) G_GNUC_CONST;
GType photo_get_type (void) G_GNUC_CONST;
void open_external_editor_error_dialog (GError* err, Photo* photo);
void app_window_error_message (const gchar* message, GtkWindow* parent);
GFile* media_source_get_master_file (MediaSource* self);
gchar* resources_launch_editor_failed (GError* err);
GtkResponseType export_error_dialog (GFile* dest, gboolean photos_remaining);
GtkResponseType app_window_affirm_cancel_question (const gchar* message, const gchar* affirmative, const gchar* title, GtkWindow* parent);
GType export_dialog_get_type (void) G_GNUC_CONST;
#define EXPORT_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_EXPORT_DIALOG, ExportDialogPrivate))
enum  {
	EXPORT_DIALOG_DUMMY_PROPERTY
};
GType scale_constraint_get_type (void) G_GNUC_CONST;
GType export_format_parameters_get_type (void) G_GNUC_CONST;
GType export_format_mode_get_type (void) G_GNUC_CONST;
GType photo_file_format_get_type (void) G_GNUC_CONST;
GType jpeg_quality_get_type (void) G_GNUC_CONST;
ExportFormatParameters* export_format_parameters_dup (const ExportFormatParameters* self);
void export_format_parameters_free (ExportFormatParameters* self);
void export_format_parameters_current (ExportFormatParameters* result);
#define EXPORT_DIALOG_DEFAULT_SCALE 1200
#define EXPORT_DIALOG_NUM_SPECIAL_FORMATS 2
#define EXPORT_DIALOG_UNMODIFIED_FORMAT_LABEL _ ("Unmodified")
#define EXPORT_DIALOG_CURRENT_FORMAT_LABEL _ ("Current")
ExportDialog* export_dialog_new (const gchar* title);
ExportDialog* export_dialog_construct (GType object_type, const gchar* title);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
ExportFormatMode configuration_facade_get_export_export_format_mode (ConfigurationFacade* self);
PhotoFileFormat configuration_facade_get_export_photo_file_format (ConfigurationFacade* self);
JpegQuality configuration_facade_get_export_quality (ConfigurationFacade* self);
gboolean configuration_facade_get_export_export_metadata (ConfigurationFacade* self);
ScaleConstraint configuration_facade_get_export_constraint (ConfigurationFacade* self);
gint configuration_facade_get_export_scale (ConfigurationFacade* self);
gchar* jpeg_quality_to_string (JpegQuality self);
gchar* scale_constraint_to_string (ScaleConstraint self);
static void export_dialog_format_add_option (ExportDialog* self, const gchar* format_name);
PhotoFileFormat* photo_file_format_get_writeable (int* result_length1);
gpointer photo_file_format_properties_ref (gpointer instance);
void photo_file_format_properties_unref (gpointer instance);
GParamSpec* param_spec_photo_file_format_properties (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_photo_file_format_properties (GValue* value, gpointer v_object);
void value_take_photo_file_format_properties (GValue* value, gpointer v_object);
gpointer value_get_photo_file_format_properties (const GValue* value);
GType photo_file_format_properties_get_type (void) G_GNUC_CONST;
PhotoFileFormatProperties* photo_file_format_get_properties (PhotoFileFormat self);
gchar* photo_file_format_properties_get_user_visible_name (PhotoFileFormatProperties* self);
static void export_dialog_on_constraint_changed (ExportDialog* self);
static void _export_dialog_on_constraint_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void export_dialog_on_format_changed (ExportDialog* self);
static void _export_dialog_on_format_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void export_dialog_on_pixels_changed (ExportDialog* self);
static void _export_dialog_on_pixels_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void export_dialog_on_pixels_insert_text (ExportDialog* self, const gchar* text, gint length, gint* position);
static void _export_dialog_on_pixels_insert_text_gtk_editable_insert_text (GtkEditable* _sender, const gchar* new_text, gint new_text_length, gint* position, gpointer self);
static void export_dialog_on_activate (ExportDialog* self);
static void _export_dialog_on_activate_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void export_dialog_add_label (ExportDialog* self, const gchar* text, gint x, gint y, GtkWidget* widget);
static void export_dialog_add_control (ExportDialog* self, GtkWidget* widget, gint x, gint y);
static void export_dialog_format_set_active_text (ExportDialog* self, const gchar* text);
static PhotoFileFormat export_dialog_get_specified_format (ExportDialog* self);
static gchar* export_dialog_get_label_for_parameters (ExportDialog* self, ExportFormatParameters* params);
gboolean export_dialog_execute (ExportDialog* self, gint* scale, ScaleConstraint* constraint, ExportFormatParameters* parameters);
gboolean photo_file_format_can_write (PhotoFileFormat self);
PhotoFileFormat photo_file_format_get_system_default_format (void);
void configuration_facade_set_export_export_format_mode (ConfigurationFacade* self, ExportFormatMode export_format_mode);
void configuration_facade_set_export_photo_file_format (ConfigurationFacade* self, PhotoFileFormat photo_file_format);
void configuration_facade_set_export_quality (ConfigurationFacade* self, JpegQuality quality);
void configuration_facade_set_export_export_metadata (ConfigurationFacade* self, gboolean export_metadata);
void configuration_facade_set_export_constraint (ConfigurationFacade* self, ScaleConstraint constraint);
void configuration_facade_set_export_scale (ConfigurationFacade* self, gint scale);
static void export_dialog_finalize (GObject * obj);
#define IMPORT_UI_REPORT_FAILURE_COUNT 4
#define IMPORT_UI_SAVE_RESULTS_BUTTON_NAME _ ("Save Details…")
#define IMPORT_UI_SAVE_RESULTS_FILE_CHOOSER_TITLE _ ("Save Details")
#define IMPORT_UI_SAVE_RESULTS_RESPONSE_ID 1024
gpointer batch_import_result_ref (gpointer instance);
void batch_import_result_unref (gpointer instance);
GParamSpec* param_spec_batch_import_result (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_result (GValue* value, gpointer v_object);
void value_take_batch_import_result (GValue* value, gpointer v_object);
gpointer value_get_batch_import_result (const GValue* value);
GType batch_import_result_get_type (void) G_GNUC_CONST;
gchar* import_ui_generate_import_failure_list (GeeList* failed, gboolean show_dest_id);
gpointer batch_import_job_ref (gpointer instance);
void batch_import_job_unref (gpointer instance);
GParamSpec* param_spec_batch_import_job (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_batch_import_job (GValue* value, gpointer v_object);
void value_take_batch_import_job (GValue* value, gpointer v_object);
gpointer value_get_batch_import_job (const GValue* value);
GType batch_import_job_get_type (void) G_GNUC_CONST;
GType import_result_get_type (void) G_GNUC_CONST;
GType duplicated_file_get_type (void) G_GNUC_CONST;
gpointer import_ui_question_params_ref (gpointer instance);
void import_ui_question_params_unref (gpointer instance);
GParamSpec* import_ui_param_spec_question_params (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void import_ui_value_set_question_params (GValue* value, gpointer v_object);
void import_ui_value_take_question_params (GValue* value, gpointer v_object);
gpointer import_ui_value_get_question_params (const GValue* value);
GType import_ui_question_params_get_type (void) G_GNUC_CONST;
enum  {
	IMPORT_UI_QUESTION_PARAMS_DUMMY_PROPERTY
};
ImportUIQuestionParams* import_ui_question_params_new (const gchar* question, const gchar* yes_button, const gchar* no_button);
ImportUIQuestionParams* import_ui_question_params_construct (GType object_type, const gchar* question, const gchar* yes_button, const gchar* no_button);
static void import_ui_question_params_finalize (ImportUIQuestionParams * obj);
gboolean import_ui_import_has_photos (GeeCollection* import_collection);
PhotoFileFormat photo_file_format_get_by_file_extension (GFile* file);
gboolean import_ui_import_has_videos (GeeCollection* import_collection);
gboolean video_reader_is_supported_video_file (GFile* file);
gchar* import_ui_get_media_specific_string (GeeCollection* import_collection, const gchar* photos_msg, const gchar* videos_msg, const gchar* both_msg, const gchar* neither_msg);
gpointer import_manifest_ref (gpointer instance);
void import_manifest_unref (gpointer instance);
GParamSpec* param_spec_import_manifest (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_import_manifest (GValue* value, gpointer v_object);
void value_take_import_manifest (GValue* value, gpointer v_object);
gpointer value_get_import_manifest (const GValue* value);
GType import_manifest_get_type (void) G_GNUC_CONST;
gchar* import_ui_create_result_report_from_manifest (ImportManifest* manifest);
#define RESOURCES_APP_VERSION _VERSION
GFile* duplicated_file_get_file (DuplicatedFile* self);
gboolean import_ui_report_manifest (ImportManifest* manifest, gboolean show_dest_id, ImportUIQuestionParams* question);
void import_ui_save_import_results (GtkWindow* chooser_dialog_parent, const gchar* results_log);
#define RESOURCES_SAVE_AS_LABEL _ ("Save _As")
gpointer text_entry_dialog_mediator_ref (gpointer instance);
void text_entry_dialog_mediator_unref (gpointer instance);
GParamSpec* param_spec_text_entry_dialog_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_text_entry_dialog_mediator (GValue* value, gpointer v_object);
void value_take_text_entry_dialog_mediator (GValue* value, gpointer v_object);
gpointer value_get_text_entry_dialog_mediator (const GValue* value);
GType text_entry_dialog_mediator_get_type (void) G_GNUC_CONST;
GType text_entry_dialog_get_type (void) G_GNUC_CONST;
#define TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediatorPrivate))
enum  {
	TEXT_ENTRY_DIALOG_MEDIATOR_DUMMY_PROPERTY
};
TextEntryDialogMediator* text_entry_dialog_mediator_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text, GeeCollection* completion_list, const gchar* completion_delimiter);
GtkBuilder* app_window_create_builder (const gchar* glade_filename, void* user);
TextEntryDialog* text_entry_dialog_new (void);
TextEntryDialog* text_entry_dialog_construct (GType object_type);
void text_entry_dialog_set_builder (TextEntryDialog* self, GtkBuilder* builder);
void text_entry_dialog_setup (TextEntryDialog* self, TextEntryDialogOnModifyValidateType modify_validate, void* modify_validate_target, const gchar* title, const gchar* label, const gchar* initial_text, GeeCollection* completion_list, const gchar* completion_delimiter);
gboolean text_entry_dialog_mediator_on_modify_validate (TextEntryDialogMediator* self, const gchar* text);
static gboolean _text_entry_dialog_mediator_on_modify_validate_text_entry_dialog_on_modify_validate_type (const gchar* text, gpointer self);
static gboolean text_entry_dialog_mediator_real_on_modify_validate (TextEntryDialogMediator* self, const gchar* text);
gchar* _text_entry_dialog_mediator_execute (TextEntryDialogMediator* self);
gchar* text_entry_dialog_execute (TextEntryDialog* self);
static void text_entry_dialog_mediator_finalize (TextEntryDialogMediator * obj);
gpointer multi_text_entry_dialog_mediator_ref (gpointer instance);
void multi_text_entry_dialog_mediator_unref (gpointer instance);
GParamSpec* param_spec_multi_text_entry_dialog_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_multi_text_entry_dialog_mediator (GValue* value, gpointer v_object);
void value_take_multi_text_entry_dialog_mediator (GValue* value, gpointer v_object);
gpointer value_get_multi_text_entry_dialog_mediator (const GValue* value);
GType multi_text_entry_dialog_mediator_get_type (void) G_GNUC_CONST;
GType multi_text_entry_dialog_get_type (void) G_GNUC_CONST;
#define MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediatorPrivate))
enum  {
	MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_DUMMY_PROPERTY
};
MultiTextEntryDialogMediator* multi_text_entry_dialog_mediator_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text);
MultiTextEntryDialog* multi_text_entry_dialog_new (void);
MultiTextEntryDialog* multi_text_entry_dialog_construct (GType object_type);
void multi_text_entry_dialog_set_builder (MultiTextEntryDialog* self, GtkBuilder* builder);
void multi_text_entry_dialog_setup (MultiTextEntryDialog* self, MultiTextEntryDialogOnModifyValidateType modify_validate, void* modify_validate_target, const gchar* title, const gchar* label, const gchar* initial_text);
gboolean multi_text_entry_dialog_mediator_on_modify_validate (MultiTextEntryDialogMediator* self, const gchar* text);
static gboolean _multi_text_entry_dialog_mediator_on_modify_validate_multi_text_entry_dialog_on_modify_validate_type (const gchar* text, gpointer self);
static gboolean multi_text_entry_dialog_mediator_real_on_modify_validate (MultiTextEntryDialogMediator* self, const gchar* text);
gchar* _multi_text_entry_dialog_mediator_execute (MultiTextEntryDialogMediator* self);
gchar* multi_text_entry_dialog_execute (MultiTextEntryDialog* self);
static void multi_text_entry_dialog_mediator_finalize (MultiTextEntryDialogMediator * obj);
gchar* build_alert_body_text (const gchar* primary_text, const gchar* secondary_text, gboolean should_escape);
gchar* guarded_markup_escape_text (const gchar* plain);
GType entry_multi_completion_get_type (void) G_GNUC_CONST;
#define ENTRY_MULTI_COMPLETION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_ENTRY_MULTI_COMPLETION, EntryMultiCompletionPrivate))
enum  {
	ENTRY_MULTI_COMPLETION_DUMMY_PROPERTY
};
EntryMultiCompletion* entry_multi_completion_new (GeeCollection* completion_list, const gchar* delimiter);
EntryMultiCompletion* entry_multi_completion_construct (GType object_type, GeeCollection* completion_list, const gchar* delimiter);
static GtkListStore* entry_multi_completion_create_completion_store (GeeCollection* completion_list);
static gboolean entry_multi_completion_match_func (EntryMultiCompletion* self, GtkEntryCompletion* completion, const gchar* key, GtkTreeIter* iter);
static gboolean _entry_multi_completion_match_func_gtk_entry_completion_match_func (GtkEntryCompletion* completion, const gchar* key, GtkTreeIter* iter, gpointer self);
static gchar* entry_multi_completion_get_last_part (const gchar* s, const gchar* delimiter);
static gboolean entry_multi_completion_real_match_selected (GtkEntryCompletion* base, GtkTreeModel* model, GtkTreeIter* iter);
static void entry_multi_completion_finalize (GObject * obj);
GType set_background_photo_dialog_get_type (void) G_GNUC_CONST;
#define SET_BACKGROUND_PHOTO_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SET_BACKGROUND_PHOTO_DIALOG, SetBackgroundPhotoDialogPrivate))
enum  {
	SET_BACKGROUND_PHOTO_DIALOG_DUMMY_PROPERTY
};
SetBackgroundPhotoDialog* set_background_photo_dialog_new (void);
SetBackgroundPhotoDialog* set_background_photo_dialog_construct (GType object_type);
static void set_background_photo_dialog_on_checkbox_clicked (SetBackgroundPhotoDialog* self);
static void _set_background_photo_dialog_on_checkbox_clicked_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self);
gboolean set_background_photo_dialog_execute (SetBackgroundPhotoDialog* self, gboolean* desktop_background, gboolean* screensaver);
static void set_background_photo_dialog_finalize (GObject * obj);
GType set_background_slideshow_dialog_get_type (void) G_GNUC_CONST;
#define SET_BACKGROUND_SLIDESHOW_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG, SetBackgroundSlideshowDialogPrivate))
enum  {
	SET_BACKGROUND_SLIDESHOW_DIALOG_DUMMY_PROPERTY
};
SetBackgroundSlideshowDialog* set_background_slideshow_dialog_new (void);
SetBackgroundSlideshowDialog* set_background_slideshow_dialog_construct (GType object_type);
static void set_background_slideshow_dialog_real_constructed (GObject* base);
static void set_background_slideshow_dialog_on_delay_scale_value_changed (SetBackgroundSlideshowDialog* self);
static void set_background_slideshow_dialog_on_checkbox_clicked (SetBackgroundSlideshowDialog* self);
static void _set_background_slideshow_dialog_on_checkbox_clicked_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self);
static void _set_background_slideshow_dialog_on_delay_scale_value_changed_gtk_range_value_changed (GtkRange* _sender, gpointer self);
gboolean set_background_slideshow_dialog_execute (SetBackgroundSlideshowDialog* self, gint* delay_value, gboolean* desktop_background, gboolean* screensaver);
static void set_background_slideshow_dialog_finalize (GObject * obj);
#define TEXT_ENTRY_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_TEXT_ENTRY_DIALOG, TextEntryDialogPrivate))
enum  {
	TEXT_ENTRY_DIALOG_DUMMY_PROPERTY
};
void text_entry_dialog_on_entry_changed (TextEntryDialog* self);
static void _text_entry_dialog_on_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void text_entry_dialog_finalize (GObject * obj);
#define MULTI_TEXT_ENTRY_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialogPrivate))
enum  {
	MULTI_TEXT_ENTRY_DIALOG_DUMMY_PROPERTY
};
static void multi_text_entry_dialog_finalize (GObject * obj);
GType event_rename_dialog_get_type (void) G_GNUC_CONST;
enum  {
	EVENT_RENAME_DIALOG_DUMMY_PROPERTY
};
EventRenameDialog* event_rename_dialog_new (const gchar* event_name);
EventRenameDialog* event_rename_dialog_construct (GType object_type, const gchar* event_name);
gchar* event_rename_dialog_execute (EventRenameDialog* self);
static gchar* event_rename_dialog_real_execute (EventRenameDialog* self);
gchar* event_prep_event_name (const gchar* name);
GType edit_title_dialog_get_type (void) G_GNUC_CONST;
enum  {
	EDIT_TITLE_DIALOG_DUMMY_PROPERTY
};
EditTitleDialog* edit_title_dialog_new (const gchar* photo_title);
EditTitleDialog* edit_title_dialog_construct (GType object_type, const gchar* photo_title);
gchar* edit_title_dialog_execute (EditTitleDialog* self);
static gchar* edit_title_dialog_real_execute (EditTitleDialog* self);
gchar* media_source_prep_title (const gchar* title);
static gboolean edit_title_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text);
GType edit_comment_dialog_get_type (void) G_GNUC_CONST;
enum  {
	EDIT_COMMENT_DIALOG_DUMMY_PROPERTY
};
EditCommentDialog* edit_comment_dialog_new (const gchar* comment, gboolean is_event);
EditCommentDialog* edit_comment_dialog_construct (GType object_type, const gchar* comment, gboolean is_event);
gchar* edit_comment_dialog_execute (EditCommentDialog* self);
static gchar* edit_comment_dialog_real_execute (EditCommentDialog* self);
gchar* media_source_prep_comment (const gchar* comment);
static gboolean edit_comment_dialog_real_on_modify_validate (MultiTextEntryDialogMediator* base, const gchar* text);
GtkResponseType remove_from_library_dialog (GtkWindow* owner, const gchar* title, const gchar* user_message, gint count);
GtkResponseType remove_from_filesystem_dialog (GtkWindow* owner, const gchar* title, const gchar* user_message);
gboolean revert_editable_dialog (GtkWindow* owner, GeeCollection* photos);
gboolean photo_has_editable (Photo* self);
gboolean remove_offline_dialog (GtkWindow* owner, gint count);
GType progress_dialog_get_type (void) G_GNUC_CONST;
#define PROGRESS_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PROGRESS_DIALOG, ProgressDialogPrivate))
enum  {
	PROGRESS_DIALOG_DUMMY_PROPERTY
};
ProgressDialog* progress_dialog_new (GtkWindow* owner, const gchar* text, GCancellable* cancellable);
ProgressDialog* progress_dialog_construct (GType object_type, GtkWindow* owner, const gchar* text, GCancellable* cancellable);
static void progress_dialog_on_cancel (ProgressDialog* self);
static void _progress_dialog_on_cancel_gtk_button_clicked (GtkButton* _sender, gpointer self);
static gboolean progress_dialog_on_window_closed (ProgressDialog* self);
static gboolean _progress_dialog_on_window_closed_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self);
gulong now_ms (void);
static void progress_dialog_real_realize (GtkWidget* base);
void progress_dialog_update_display_every (ProgressDialog* self, gint update_every);
void progress_dialog_set_minimum_on_screen_time_msec (ProgressDialog* self, gint minimum_on_screen_time_msec);
void progress_dialog_set_fraction (ProgressDialog* self, gint current, gint total);
void progress_dialog_set_percentage (ProgressDialog* self, gdouble pct);
static void progress_dialog_maybe_show_all (ProgressDialog* self, gdouble pct);
void progress_dialog_set_status (ProgressDialog* self, const gchar* text);
gboolean progress_dialog_monitor (ProgressDialog* self, guint64 count, guint64 total, gboolean do_event_loop);
void spin_event_loop (void);
void progress_dialog_close (ProgressDialog* self);
static void progress_dialog_finalize (GObject * obj);
GType adjust_date_time_dialog_get_type (void) G_GNUC_CONST;
static GType adjust_date_time_dialog_time_system_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
#define ADJUST_DATE_TIME_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialogPrivate))
enum  {
	ADJUST_DATE_TIME_DIALOG_DUMMY_PROPERTY
};
#define ADJUST_DATE_TIME_DIALOG_SECONDS_IN_DAY ((gint64) ((60 * 60) * 24))
#define ADJUST_DATE_TIME_DIALOG_SECONDS_IN_HOUR ((gint64) (60 * 60))
#define ADJUST_DATE_TIME_DIALOG_SECONDS_IN_MINUTE ((gint64) 60)
#define ADJUST_DATE_TIME_DIALOG_YEAR_OFFSET 1900
#define ADJUST_DATE_TIME_DIALOG_CALENDAR_THUMBNAIL_SCALE 1
GType dateable_get_type (void) G_GNUC_CONST;
AdjustDateTimeDialog* adjust_date_time_dialog_new (Dateable* source, gint photo_count, gboolean display_options, gboolean contains_video, gboolean only_video);
AdjustDateTimeDialog* adjust_date_time_dialog_construct (GType object_type, Dateable* source, gint photo_count, gboolean display_options, gboolean contains_video, gboolean only_video);
#define RESOURCES_ADJUST_DATE_TIME_LABEL _ ("Adjust Date and Time")
static void adjust_date_time_dialog_on_time_changed (AdjustDateTimeDialog* self);
static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_day_selected (GtkCalendar* _sender, gpointer self);
static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_month_changed (GtkCalendar* _sender, gpointer self);
static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_next_year (GtkCalendar* _sender, gpointer self);
static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_prev_year (GtkCalendar* _sender, gpointer self);
gboolean configuration_facade_get_use_24_hour_time (ConfigurationFacade* self);
static gboolean adjust_date_time_dialog_on_spin_button_output (AdjustDateTimeDialog* self, GtkSpinButton* button);
static gboolean _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output (GtkSpinButton* _sender, gpointer self);
static void adjust_date_time_dialog_on_time_system_changed (AdjustDateTimeDialog* self);
static void _adjust_date_time_dialog_on_time_system_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
gboolean configuration_facade_get_keep_relativity (ConfigurationFacade* self);
static void _adjust_date_time_dialog_on_time_changed_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self);
gboolean configuration_facade_get_commit_metadata_to_masters (ConfigurationFacade* self);
GdkPixbuf* thumbnail_source_get_thumbnail (ThumbnailSource* self, gint scale, GError** error);
gchar* data_object_to_string (DataObject* self);
time_t dateable_get_exposure_time (Dateable* self);
static void adjust_date_time_dialog_set_time (AdjustDateTimeDialog* self, struct tm* time);
static void adjust_date_time_dialog_set_original_time_label (AdjustDateTimeDialog* self, gboolean use_24_hr_format);
static time_t adjust_date_time_dialog_get_time (AdjustDateTimeDialog* self);
gboolean adjust_date_time_dialog_execute (AdjustDateTimeDialog* self, gint64* time_shift, gboolean* keep_relativity, gboolean* modify_originals);
void configuration_facade_set_keep_relativity (ConfigurationFacade* self, gboolean keep_relativity);
void configuration_facade_set_modify_originals (ConfigurationFacade* self, gboolean modify_originals);
void configuration_facade_set_use_24_hour_time (ConfigurationFacade* self, gboolean use_24_hour_time);
static void adjust_date_time_dialog_finalize (GObject * obj);
#define MAX_OBJECTS_DISPLAYED 3
void multiple_object_error_dialog (GeeArrayList* objects, const gchar* message, const gchar* title);
GType tags_dialog_get_type (void) G_GNUC_CONST;
enum  {
	TAGS_DIALOG_DUMMY_PROPERTY
};
TagsDialog* tags_dialog_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text);
gpointer hierarchical_tag_index_ref (gpointer instance);
void hierarchical_tag_index_unref (gpointer instance);
GParamSpec* param_spec_hierarchical_tag_index (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_hierarchical_tag_index (GValue* value, gpointer v_object);
void value_take_hierarchical_tag_index (GValue* value, gpointer v_object);
gpointer value_get_hierarchical_tag_index (const GValue* value);
GType hierarchical_tag_index_get_type (void) G_GNUC_CONST;
HierarchicalTagIndex* hierarchical_tag_index_get_global_index (void);
GeeCollection* hierarchical_tag_index_get_all_tags (HierarchicalTagIndex* self);
GType add_tags_dialog_get_type (void) G_GNUC_CONST;
enum  {
	ADD_TAGS_DIALOG_DUMMY_PROPERTY
};
AddTagsDialog* add_tags_dialog_new (void);
AddTagsDialog* add_tags_dialog_construct (GType object_type);
#define RESOURCES_ADD_TAGS_TITLE NC_ ("Dialog Title", "Add Tags")
gchar** add_tags_dialog_execute (AddTagsDialog* self, int* result_length1);
gchar** tag_prep_tag_names (gchar** names, int names_length1, int* result_length1);
static gboolean add_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text);
#define TAG_PATH_SEPARATOR_STRING "/"
GType modify_tags_dialog_get_type (void) G_GNUC_CONST;
enum  {
	MODIFY_TAGS_DIALOG_DUMMY_PROPERTY
};
ModifyTagsDialog* modify_tags_dialog_new (MediaSource* source);
ModifyTagsDialog* modify_tags_dialog_construct (GType object_type, MediaSource* source);
#define RESOURCES_MODIFY_TAGS_LABEL _ ("Modify Tags")
static gchar* modify_tags_dialog_get_initial_text (MediaSource* source);
gpointer data_collection_ref (gpointer instance);
void data_collection_unref (gpointer instance);
GParamSpec* param_spec_data_collection (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_data_collection (GValue* value, gpointer v_object);
void value_take_data_collection (GValue* value, gpointer v_object);
gpointer value_get_data_collection (const GValue* value);
GType data_collection_get_type (void) G_GNUC_CONST;
GType source_collection_get_type (void) G_GNUC_CONST;
GType database_source_collection_get_type (void) G_GNUC_CONST;
GType container_source_collection_get_type (void) G_GNUC_CONST;
GType tag_source_collection_get_type (void) G_GNUC_CONST;
GeeList* tag_source_collection_fetch_for_source (TagSourceCollection* self, MediaSource* source);
GeeCollection* tag_get_terminal_tags (GeeCollection* tags);
gchar* hierarchical_tag_utilities_get_basename (const gchar* in_path);
gchar* tag_get_path (Tag* self);
GeeArrayList* modify_tags_dialog_execute (ModifyTagsDialog* self);
gboolean is_string_empty (const gchar* s);
gchar** hierarchical_tag_index_get_paths_for_names_array (HierarchicalTagIndex* self, gchar** names, int names_length1, int* result_length1);
Tag* tag_for_path (const gchar* name);
static gboolean modify_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text);
GType welcome_service_entry_get_type (void) G_GNUC_CONST;
gchar* welcome_service_entry_get_service_name (WelcomeServiceEntry* self);
void welcome_service_entry_execute (WelcomeServiceEntry* self);
GType welcome_dialog_get_type (void) G_GNUC_CONST;
GType spit_data_imports_welcome_import_meta_host_get_type (void) G_GNUC_CONST;
#define WELCOME_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_WELCOME_DIALOG, WelcomeDialogPrivate))
enum  {
	WELCOME_DIALOG_DUMMY_PROPERTY
};
WelcomeDialog* welcome_dialog_new (GtkWindow* owner);
WelcomeDialog* welcome_dialog_construct (GType object_type, GtkWindow* owner);
SpitDataImportsWelcomeImportMetaHost* spit_data_imports_welcome_import_meta_host_new (WelcomeDialog* dialog);
SpitDataImportsWelcomeImportMetaHost* spit_data_imports_welcome_import_meta_host_construct (GType object_type, WelcomeDialog* dialog);
static gboolean welcome_dialog_is_system_pictures_import_possible (void);
gchar* get_display_pathname (GFile* file);
GFile* app_dirs_get_import_dir (void);
static void welcome_dialog_install_import_content (WelcomeDialog* self);
void spit_data_imports_welcome_import_meta_host_start (SpitDataImportsWelcomeImportMetaHost* self);
void welcome_dialog_install_service_entry (WelcomeDialog* self, WelcomeServiceEntry* entry);
static void _vala_array_add109 (WelcomeServiceEntry** * array, int* length, int* size, WelcomeServiceEntry* value);
static void _vala_array_add110 (GtkCheckButton** * array, int* length, int* size, GtkCheckButton* value);
static void welcome_dialog_on_dismiss (WelcomeDialog* self, gint resp);
gboolean welcome_dialog_execute (WelcomeDialog* self, WelcomeServiceEntry*** selected_import_entries, int* selected_import_entries_length1, gboolean* do_system_pictures_import);
static void _welcome_dialog_on_dismiss_gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
static void _vala_array_add111 (WelcomeServiceEntry** * array, int* length, int* size, WelcomeServiceEntry* value);
static WelcomeServiceEntry** _vala_array_dup29 (WelcomeServiceEntry** self, int length);
static void welcome_dialog_finalize (GObject * obj);
gpointer preferences_dialog_ref (gpointer instance);
void preferences_dialog_unref (gpointer instance);
GParamSpec* param_spec_preferences_dialog (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_preferences_dialog (GValue* value, gpointer v_object);
void value_take_preferences_dialog (GValue* value, gpointer v_object);
gpointer value_get_preferences_dialog (const GValue* value);
GType preferences_dialog_get_type (void) G_GNUC_CONST;
GType sorted_list_get_type (void) G_GNUC_CONST;
static gpointer preferences_dialog_path_format_ref (gpointer instance);
static void preferences_dialog_path_format_unref (gpointer instance);
static GParamSpec* preferences_dialog_param_spec_path_format (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) G_GNUC_UNUSED;
static void preferences_dialog_value_set_path_format (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static void preferences_dialog_value_take_path_format (GValue* value, gpointer v_object) G_GNUC_UNUSED;
static gpointer preferences_dialog_value_get_path_format (const GValue* value) G_GNUC_UNUSED;
static GType preferences_dialog_path_format_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
gpointer plugins_manifest_widget_mediator_ref (gpointer instance);
void plugins_manifest_widget_mediator_unref (gpointer instance);
GParamSpec* plugins_param_spec_manifest_widget_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void plugins_value_set_manifest_widget_mediator (GValue* value, gpointer v_object);
void plugins_value_take_manifest_widget_mediator (GValue* value, gpointer v_object);
gpointer plugins_value_get_manifest_widget_mediator (const GValue* value);
GType plugins_manifest_widget_mediator_get_type (void) G_GNUC_CONST;
#define PREFERENCES_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_PREFERENCES_DIALOG, PreferencesDialogPrivate))
enum  {
	PREFERENCES_DIALOG_DUMMY_PROPERTY
};
PluginsManifestWidgetMediator* plugins_manifest_widget_mediator_new (void);
PluginsManifestWidgetMediator* plugins_manifest_widget_mediator_construct (GType object_type);
static PreferencesDialog* preferences_dialog_new (void);
static PreferencesDialog* preferences_dialog_construct (GType object_type);
static gboolean preferences_dialog_on_delete (PreferencesDialog* self);
static gboolean _preferences_dialog_on_delete_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self);
static void preferences_dialog_on_close (PreferencesDialog* self);
static void _preferences_dialog_on_close_gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self);
void config_facade_get_bg_color (ConfigFacade* self, GdkRGBA* result);
static void preferences_dialog_on_value_changed (PreferencesDialog* self);
static void _preferences_dialog_on_value_changed_gtk_adjustment_value_changed (GtkAdjustment* _sender, gpointer self);
static gboolean preferences_dialog_on_bg_color_reset (PreferencesDialog* self, GdkEventButton* event);
static gboolean _preferences_dialog_on_bg_color_reset_gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
gchar* resources_get_help_path (void);
#define RESOURCES_DIR_PATTERN_URI_SYSWIDE "help:shotwell/other-files"
static gboolean preferences_dialog_on_local_pattern_help (PreferencesDialog* self, const gchar* ignore);
static gboolean _preferences_dialog_on_local_pattern_help_gtk_label_activate_link (GtkLabel* _sender, const gchar* uri, gpointer self);
static void preferences_dialog_add_to_dir_formats (PreferencesDialog* self, const gchar* name, const gchar* pattern);
static void preferences_dialog_on_dir_pattern_combo_changed (PreferencesDialog* self);
static void _preferences_dialog_on_dir_pattern_combo_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void preferences_dialog_on_dir_pattern_entry_changed (PreferencesDialog* self);
static void _preferences_dialog_on_dir_pattern_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void preferences_dialog_on_lowercase_toggled (PreferencesDialog* self);
static void _preferences_dialog_on_lowercase_toggled_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self);
GtkWidget* plugins_manifest_widget_mediator_get_widget (PluginsManifestWidgetMediator* self);
void preferences_dialog_populate_preference_options (PreferencesDialog* self);
static void preferences_dialog_on_photo_editor_changed (PreferencesDialog* self);
static void _preferences_dialog_on_photo_editor_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void preferences_dialog_on_raw_editor_changed (PreferencesDialog* self);
static void _preferences_dialog_on_raw_editor_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
gboolean configuration_facade_get_auto_import_from_library (ConfigurationFacade* self);
GType raw_developer_get_type (void) G_GNUC_CONST;
gchar* raw_developer_get_label (RawDeveloper self);
static void preferences_dialog_set_raw_developer_combo (PreferencesDialog* self, RawDeveloper d);
RawDeveloper configuration_facade_get_default_raw_developer (ConfigurationFacade* self);
static void preferences_dialog_on_default_raw_developer_changed (PreferencesDialog* self);
static void _preferences_dialog_on_default_raw_developer_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static gboolean preferences_dialog_map_event (PreferencesDialog* self);
static gboolean _preferences_dialog_map_event_gtk_widget_map_event (GtkWidget* _sender, GdkEventAny* event, gpointer self);
static void preferences_dialog_populate_app_combo_box (PreferencesDialog* self, GtkComboBox* combo_box, gchar** mime_types, int mime_types_length1, const gchar* current_app_executable, SortedList* * external_apps);
gchar** photo_file_format_get_editable_mime_types (int* result_length1);
gchar* configuration_facade_get_external_photo_app (ConfigurationFacade* self);
gchar** photo_file_format_get_mime_types (PhotoFileFormat self, int* result_length1);
gchar* configuration_facade_get_external_raw_app (ConfigurationFacade* self);
static void preferences_dialog_setup_dir_pattern (PreferencesDialog* self, GtkComboBox* combo_box, GtkEntry* entry);
gboolean configuration_facade_get_use_lowercase_filenames (ConfigurationFacade* self);
void resources_launch_help (GdkScreen* screen, const gchar* anchor, GError** error);
SortedList* desktop_integration_get_apps_for_mime_types (gchar** mime_types, int mime_types_length1);
GdkPixbuf* scale_pixbuf (GdkPixbuf* pixbuf, gint scale, GdkInterpType interp, gboolean scale_up);
#define RESOURCES_DEFAULT_ICON_SCALE 24
gint sorted_list_index_of (SortedList* self, gconstpointer search);
gchar* configuration_facade_get_directory_pattern (ConfigurationFacade* self);
gchar* configuration_facade_get_directory_pattern_custom (ConfigurationFacade* self);
void preferences_dialog_show (void);
static void preferences_dialog_commit_on_close (PreferencesDialog* self);
void config_facade_commit_bg_color (ConfigFacade* self);
void configuration_facade_set_auto_import_from_library (ConfigurationFacade* self, gboolean auto_import);
void configuration_facade_set_commit_metadata_to_masters (ConfigurationFacade* self, gboolean commit_metadata);
void app_dirs_set_import_dir (const gchar* path);
void configuration_facade_set_directory_pattern_custom (ConfigurationFacade* self, const gchar* s);
void configuration_facade_set_directory_pattern (ConfigurationFacade* self, const gchar* s);
static gboolean preferences_dialog_get_allow_closing (PreferencesDialog* self);
static void preferences_dialog_set_background_color (PreferencesDialog* self, gdouble bg_color_value);
gboolean has_only_key_modifier (GdkModifierType field, GdkModifierType mask);
void parse_color (const gchar* spec, GdkRGBA* result);
#define CONFIG_FACADE_DEFAULT_BG_COLOR "#444"
static void preferences_dialog_set_allow_closing (PreferencesDialog* self, gboolean allow);
void config_facade_set_bg_color (ConfigFacade* self, GdkRGBA* color);
static void preferences_dialog_to_grayscale (PreferencesDialog* self, gdouble color_value, GdkRGBA* result);
gpointer sorted_list_get_at (SortedList* self, gint index);
void configuration_facade_set_external_photo_app (ConfigurationFacade* self, const gchar* external_photo_app);
gchar* desktop_integration_get_app_open_command (GAppInfo* app_info);
void configuration_facade_set_external_raw_app (ConfigurationFacade* self, const gchar* external_raw_app);
static RawDeveloper preferences_dialog_raw_developer_from_combo (PreferencesDialog* self);
void configuration_facade_set_default_raw_developer (ConfigurationFacade* self, RawDeveloper d);
static void preferences_dialog_on_current_folder_changed (PreferencesDialog* self);
static void _preferences_dialog_on_current_folder_changed_gtk_file_chooser_current_folder_changed (GtkFileChooser* _sender, gpointer self);
static PreferencesDialogPathFormat* preferences_dialog_path_format_new (const gchar* name, const gchar* pattern);
static PreferencesDialogPathFormat* preferences_dialog_path_format_construct (GType object_type, const gchar* name, const gchar* pattern);
void configuration_facade_set_use_lowercase_filenames (ConfigurationFacade* self, gboolean b);
enum  {
	PREFERENCES_DIALOG_PATH_FORMAT_DUMMY_PROPERTY
};
static void preferences_dialog_path_format_finalize (PreferencesDialogPathFormat * obj);
static void preferences_dialog_finalize (PreferencesDialog * obj);
GtkResponseType copy_files_dialog (void);
GType library_photo_get_type (void) G_GNUC_CONST;
void remove_photos_from_library (GeeCollection* photos);
void remove_from_app (GeeCollection* sources, const gchar* dialog_title, const gchar* progress_dialog_text);
GType video_source_get_type (void) G_GNUC_CONST;
GType video_get_type (void) G_GNUC_CONST;
void media_source_collection_filter_media (GeeCollection* media, GeeCollection* photos, GeeCollection* videos);
void page_window_set_busy_cursor (PageWindow* self);
static gboolean _progress_dialog_monitor_progress_monitor (guint64 current, guint64 total, gboolean do_event_loop, gpointer self);
GType media_source_collection_get_type (void) G_GNUC_CONST;
GType library_photo_source_collection_get_type (void) G_GNUC_CONST;
void media_source_collection_remove_from_app (MediaSourceCollection* self, GeeCollection* sources, gboolean delete_backing, ProgressMonitor monitor, void* monitor_target, GeeList* not_removed);
GType video_source_collection_get_type (void) G_GNUC_CONST;
void media_source_collection_delete_backing_files (MediaSourceCollection* self, GeeCollection* sources, ProgressMonitor monitor, void* monitor_target, GeeList* not_deleted);
void app_window_error_message_with_title (const gchar* title, const gchar* message, GtkWindow* parent, gboolean should_escape);
void page_window_set_normal_cursor (PageWindow* self);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

const ScaleConstraint EXPORT_DIALOG_CONSTRAINT_ARRAY[4] = {SCALE_CONSTRAINT_ORIGINAL, SCALE_CONSTRAINT_DIMENSIONS, SCALE_CONSTRAINT_WIDTH, SCALE_CONSTRAINT_HEIGHT};
const JpegQuality EXPORT_DIALOG_QUALITY_ARRAY[4] = {JPEG_QUALITY_LOW, JPEG_QUALITY_MEDIUM, JPEG_QUALITY_HIGH, JPEG_QUALITY_MAXIMUM};

gboolean dialogs_confirm_delete_tag (Tag* tag) {
	gboolean result = FALSE;
	gint count = 0;
	Tag* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	gchar* msg = NULL;
	gint _tmp3_;
	Tag* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gint _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	gboolean _tmp11_;
#line 11 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TAG (tag), FALSE);
#line 12 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = tag;
#line 12 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = tag_get_sources_count (_tmp0_);
#line 12 "/home/jens/Source/shotwell/src/Dialogs.vala"
	count = _tmp1_;
#line 13 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = count;
#line 13 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ == 0) {
#line 14 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = TRUE;
#line 14 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 1716 "Dialogs.c"
	}
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = count;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = tag;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = tag_get_user_visible_name (_tmp4_);
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = count;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = g_strdup_printf (ngettext ("This will remove the tag “%s” from one photo. Continue?", "This will remove the tag “%s” from %d photos. Continue?", (gulong) _tmp3_), _tmp6_, _tmp7_);
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp6_);
#line 15 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp9_;
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = msg;
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = app_window_negate_affirm_question (_tmp10_, _ ("_Cancel"), _ ("_Delete"), RESOURCES_DELETE_TAG_TITLE, NULL);
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp11_;
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 20 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1746 "Dialogs.c"
}


gboolean dialogs_confirm_delete_saved_search (SavedSearch* search) {
	gboolean result = FALSE;
	gchar* msg = NULL;
	SavedSearch* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gboolean _tmp5_;
#line 24 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_SAVED_SEARCH (search), FALSE);
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = search;
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = data_object_get_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, TYPE_DATA_OBJECT, DataObject));
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup_printf (_ ("This will remove the saved search “%s”. Continue?"), _tmp2_);
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp2_);
#line 25 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp4_;
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = app_window_negate_affirm_question (msg, _ ("_Cancel"), _ ("_Delete"), RESOURCES_DELETE_SAVED_SEARCH_DIALOG_TITLE, NULL);
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp5_;
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 28 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1783 "Dialogs.c"
}


gboolean dialogs_confirm_warn_developer_changed (gint number) {
	gboolean result = FALSE;
	GtkMessageDialog* dialog = NULL;
	AppWindow* _tmp0_;
	AppWindow* _tmp1_;
	gint _tmp2_;
	GtkMessageDialog* _tmp3_;
	GtkMessageDialog* _tmp4_;
	gint response = 0;
	gint _tmp5_;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_window_get_instance ();
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = number;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = (GtkMessageDialog*) gtk_message_dialog_new_with_markup (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "<span weight=\"bold\" size=\"larger\">%s</span>", ngettext ("Switching developers will undo all changes you have made to this photo" \
" in Shotwell", "Switching developers will undo all changes you have made to these phot" \
"os in Shotwell", (gulong) _tmp2_));
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp3_);
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 33 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp4_;
#line 39 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, NULL);
#line 40 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Switch Developer"), GTK_RESPONSE_YES, NULL);
#line 42 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 42 "/home/jens/Source/shotwell/src/Dialogs.vala"
	response = _tmp5_;
#line 44 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 46 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = response == ((gint) GTK_RESPONSE_YES);
#line 46 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 46 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1829 "Dialogs.c"
}


GFile* export_ui_choose_file (const gchar* current_file_basename) {
	GFile* result = NULL;
	GFile* _tmp0_;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_;
	gboolean _tmp5_;
	gchar* file_chooser_title = NULL;
	gchar* _tmp6_;
	GtkFileChooserDialog* chooser = NULL;
	const gchar* _tmp7_;
	AppWindow* _tmp8_;
	AppWindow* _tmp9_;
	GtkFileChooserDialog* _tmp10_;
	GtkFileChooserDialog* _tmp11_;
	GtkFileChooserDialog* _tmp12_;
	GtkFileChooserDialog* _tmp13_;
	GFile* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	GtkFileChooserDialog* _tmp17_;
	const gchar* _tmp18_;
	GtkFileChooserDialog* _tmp19_;
	GFile* file = NULL;
	GtkFileChooserDialog* _tmp20_;
	gint _tmp21_;
	GtkFileChooserDialog* _tmp28_;
#line 54 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (current_file_basename != NULL, NULL);
#line 55 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = export_ui_current_export_dir;
#line 55 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == NULL) {
#line 1865 "Dialogs.c"
		const gchar* _tmp1_;
		GFile* _tmp2_;
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = g_get_home_dir ();
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = g_file_new_for_path (_tmp1_);
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 56 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp2_;
#line 1876 "Dialogs.c"
	}
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = current_file_basename;
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = video_reader_is_supported_video_filename (_tmp4_);
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_) {
#line 59 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _ ("Export Video");
#line 1886 "Dialogs.c"
	} else {
#line 59 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _ ("Export Photo");
#line 1890 "Dialogs.c"
	}
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = g_strdup (_tmp3_);
#line 58 "/home/jens/Source/shotwell/src/Dialogs.vala"
	file_chooser_title = _tmp6_;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = file_chooser_title;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = app_window_get_instance ();
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp7_, G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_window_get_type (), GtkWindow), GTK_FILE_CHOOSER_ACTION_SAVE, RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_SAVE_LABEL, GTK_RESPONSE_ACCEPT, NULL, NULL);
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp10_);
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp9_);
#line 61 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chooser = _tmp11_;
#line 64 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = chooser;
#line 64 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_do_overwrite_confirmation (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), TRUE);
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = chooser;
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = export_ui_current_export_dir;
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = g_file_get_path (_tmp14_);
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = _tmp15_;
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp16_);
#line 65 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp16_);
#line 66 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = chooser;
#line 66 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = current_file_basename;
#line 66 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp18_);
#line 67 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = chooser;
#line 67 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_local_only (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), FALSE);
#line 69 "/home/jens/Source/shotwell/src/Dialogs.vala"
	file = NULL;
#line 70 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = chooser;
#line 70 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_dialog_get_type (), GtkDialog));
#line 70 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp21_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 1946 "Dialogs.c"
		GtkFileChooserDialog* _tmp22_;
		gchar* _tmp23_;
		gchar* _tmp24_;
		GFile* _tmp25_;
		GFile* _tmp26_;
		GFile* _tmp27_;
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = chooser;
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = gtk_file_chooser_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = _tmp23_;
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = g_file_new_for_path (_tmp24_);
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (file);
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		file = _tmp25_;
#line 71 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp24_);
#line 72 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = file;
#line 72 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = g_file_get_parent (_tmp26_);
#line 72 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 72 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp27_;
#line 1975 "Dialogs.c"
	}
#line 74 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = chooser;
#line 74 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, gtk_widget_get_type (), GtkWidget));
#line 76 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = file;
#line 76 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chooser);
#line 76 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (file_chooser_title);
#line 76 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 1989 "Dialogs.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self ? g_object_ref (self) : NULL;
#line 1996 "Dialogs.c"
}


GFile* export_ui_choose_dir (const gchar* user_title) {
	GFile* result = NULL;
	GFile* _tmp0_;
	const gchar* _tmp3_;
	GtkFileChooserDialog* chooser = NULL;
	const gchar* _tmp4_;
	AppWindow* _tmp5_;
	AppWindow* _tmp6_;
	GtkFileChooserDialog* _tmp7_;
	GtkFileChooserDialog* _tmp8_;
	GtkFileChooserDialog* _tmp9_;
	GFile* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	GtkFileChooserDialog* _tmp13_;
	GFile* dir = NULL;
	GtkFileChooserDialog* _tmp14_;
	gint _tmp15_;
	GtkFileChooserDialog* _tmp22_;
#line 80 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = export_ui_current_export_dir;
#line 80 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == NULL) {
#line 2023 "Dialogs.c"
		const gchar* _tmp1_;
		GFile* _tmp2_;
#line 81 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = g_get_home_dir ();
#line 81 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = g_file_new_for_path (_tmp1_);
#line 81 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 81 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp2_;
#line 2034 "Dialogs.c"
	}
#line 83 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = user_title;
#line 83 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ == NULL) {
#line 84 "/home/jens/Source/shotwell/src/Dialogs.vala"
		user_title = _ ("Export Photos");
#line 2042 "Dialogs.c"
	}
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = user_title;
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = app_window_get_instance ();
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp4_, G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_window_get_type (), GtkWindow), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER, RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_OK_LABEL, GTK_RESPONSE_ACCEPT, NULL, NULL);
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp7_);
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp6_);
#line 86 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chooser = _tmp8_;
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = chooser;
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = export_ui_current_export_dir;
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = g_file_get_path (_tmp10_);
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = _tmp11_;
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp12_);
#line 89 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp12_);
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = chooser;
#line 90 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_local_only (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), FALSE);
#line 92 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dir = NULL;
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = chooser;
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_dialog_get_type (), GtkDialog));
#line 93 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp15_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 2084 "Dialogs.c"
		GtkFileChooserDialog* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		GFile* _tmp19_;
		GFile* _tmp20_;
		GFile* _tmp21_;
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = chooser;
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = gtk_file_chooser_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = _tmp17_;
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = g_file_new_for_path (_tmp18_);
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dir);
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dir = _tmp19_;
#line 94 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp18_);
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = dir;
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = _g_object_ref0 (_tmp20_);
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (export_ui_current_export_dir);
#line 95 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_ui_current_export_dir = _tmp21_;
#line 2113 "Dialogs.c"
	}
#line 98 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = chooser;
#line 98 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_widget_get_type (), GtkWidget));
#line 100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = dir;
#line 100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chooser);
#line 100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 2125 "Dialogs.c"
}


void open_external_editor_error_dialog (GError* err, Photo* photo) {
	gboolean _tmp0_ = FALSE;
	GError* _tmp1_;
#line 107 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PHOTO (photo));
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = err;
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_error_matches (_tmp1_, G_IO_ERROR, G_IO_ERROR_PERMISSION_DENIED)) {
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = TRUE;
#line 2140 "Dialogs.c"
	} else {
		GError* _tmp2_;
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = err;
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = g_error_matches (_tmp2_, G_FILE_ERROR, G_FILE_ERROR_PERM);
#line 2147 "Dialogs.c"
	}
#line 109 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 2151 "Dialogs.c"
		Photo* _tmp3_;
		GFile* _tmp4_;
		GFile* _tmp5_;
		GFile* _tmp6_;
		GFile* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = photo;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = media_source_get_master_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_MEDIA_SOURCE, MediaSource));
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = _tmp4_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = g_file_get_parent (_tmp5_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp6_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = g_file_get_path (_tmp7_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = _tmp8_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = g_strdup_printf (_ ("Shotwell couldn’t create a file for editing this photo because you do " \
"not have permission to write to %s."), _tmp9_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = _tmp10_;
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_window_error_message (_tmp11_, NULL);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp11_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp9_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp7_);
#line 111 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp5_);
#line 2189 "Dialogs.c"
	} else {
		GError* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = err;
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = resources_launch_editor_failed (_tmp12_);
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = _tmp13_;
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_window_error_message (_tmp14_, NULL);
#line 116 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp14_);
#line 2204 "Dialogs.c"
	}
}


GtkResponseType export_error_dialog (GFile* dest, gboolean photos_remaining) {
	GtkResponseType result = 0;
	gchar* message = NULL;
	GFile* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GtkResponseType response = 0;
	gboolean _tmp5_;
#line 120 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_IS_FILE (dest), 0);
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = dest;
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_file_get_path (_tmp0_);
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strconcat (_ ("Unable to export the following photo due to a file error.\n\n"), _tmp2_, NULL);
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp2_);
#line 121 "/home/jens/Source/shotwell/src/Dialogs.vala"
	message = _tmp4_;
#line 124 "/home/jens/Source/shotwell/src/Dialogs.vala"
	response = GTK_RESPONSE_NONE;
#line 126 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = photos_remaining;
#line 126 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_) {
#line 2241 "Dialogs.c"
		const gchar* _tmp6_;
		gchar* _tmp7_;
		const gchar* _tmp8_;
		GtkResponseType _tmp9_;
#line 127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = message;
#line 127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = g_strconcat (_tmp6_, _ ("\n\nWould you like to continue exporting?"), NULL);
#line 127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 127 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp7_;
#line 128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = message;
#line 128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = app_window_affirm_cancel_question (_tmp8_, _ ("Con_tinue"), NULL, NULL);
#line 128 "/home/jens/Source/shotwell/src/Dialogs.vala"
		response = _tmp9_;
#line 2260 "Dialogs.c"
	} else {
		const gchar* _tmp10_;
#line 130 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = message;
#line 130 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_window_error_message (_tmp10_, NULL);
#line 2267 "Dialogs.c"
	}
#line 133 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = response;
#line 133 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (message);
#line 133 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 2275 "Dialogs.c"
}


static void _export_dialog_on_constraint_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_on_constraint_changed ((ExportDialog*) self);
#line 2282 "Dialogs.c"
}


static void _export_dialog_on_format_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_on_format_changed ((ExportDialog*) self);
#line 2289 "Dialogs.c"
}


static void _export_dialog_on_pixels_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 216 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_on_pixels_changed ((ExportDialog*) self);
#line 2296 "Dialogs.c"
}


static void _export_dialog_on_pixels_insert_text_gtk_editable_insert_text (GtkEditable* _sender, const gchar* new_text, gint new_text_length, gint* position, gpointer self) {
#line 217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_on_pixels_insert_text ((ExportDialog*) self, new_text, new_text_length, position);
#line 2303 "Dialogs.c"
}


static void _export_dialog_on_activate_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_on_activate ((ExportDialog*) self);
#line 2310 "Dialogs.c"
}


ExportDialog* export_dialog_construct (GType object_type, const gchar* title) {
	ExportDialog * self = NULL;
	gboolean use_header = FALSE;
	GtkSettings* _tmp0_;
	gint _tmp1_ = 0;
	gboolean _tmp2_;
	const gchar* _tmp3_;
	ConfigFacade* config = NULL;
	ConfigFacade* _tmp4_;
	ConfigFacade* _tmp5_;
	ExportFormatMode _tmp6_;
	ConfigFacade* _tmp7_;
	PhotoFileFormat _tmp8_;
	ConfigFacade* _tmp9_;
	JpegQuality _tmp10_;
	ConfigFacade* _tmp11_;
	gboolean _tmp12_;
	ConfigFacade* _tmp13_;
	ScaleConstraint _tmp14_;
	ConfigFacade* _tmp15_;
	gint _tmp16_;
	GtkComboBoxText* _tmp17_;
	gint ctr = 0;
	GtkComboBoxText* _tmp28_;
	GtkComboBoxText* _tmp38_;
	gint _tmp39_;
	PhotoFileFormat* _tmp40_;
	GtkEntry* _tmp46_;
	GtkEntry* _tmp47_;
	GtkEntry* _tmp48_;
	gint _tmp49_;
	gchar* _tmp50_;
	gchar* _tmp51_;
	GtkComboBoxText* _tmp52_;
	GtkComboBoxText* _tmp53_;
	GtkEntry* _tmp54_;
	GtkEntry* _tmp55_;
	GtkEntry* _tmp56_;
	GtkComboBoxText* _tmp57_;
	GtkComboBoxText* _tmp58_;
	GtkComboBoxText* _tmp59_;
	GtkComboBoxText* _tmp60_;
	GtkComboBoxText* _tmp61_;
	GtkComboBoxText* _tmp62_;
	GtkEntry* _tmp63_;
	GtkEntry* _tmp64_;
	GtkSwitch* _tmp65_;
	GtkSwitch* _tmp66_;
	GtkSwitch* _tmp67_;
	GtkSwitch* _tmp68_;
	GtkSwitch* _tmp69_;
	GtkGrid* _tmp70_;
	GtkGrid* _tmp71_;
	GtkGrid* _tmp72_;
	GtkBox* _tmp73_;
	GtkGrid* _tmp74_;
	GtkWidget* _tmp75_;
	GtkWidget* _tmp76_;
	GtkWidget* _tmp77_;
	GtkWidget* _tmp78_;
	GtkWidget* _tmp79_;
	ScaleConstraint _tmp80_;
	GtkWidget* _tmp83_;
#line 167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 169 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_settings_get_default ();
#line 169 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 170 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = use_header;
#line 170 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_) {
#line 170 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 1;
#line 2389 "Dialogs.c"
	} else {
#line 170 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 0;
#line 2393 "Dialogs.c"
	}
#line 170 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (ExportDialog*) g_object_new (object_type, "use-header-bar", _tmp1_, NULL);
#line 172 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = title;
#line 172 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp3_);
#line 173 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 176 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = config_facade_get_instance ();
#line 176 "/home/jens/Source/shotwell/src/Dialogs.vala"
	config = _tmp4_;
#line 177 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = config;
#line 177 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = configuration_facade_get_export_export_format_mode (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 177 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_current_parameters.mode = _tmp6_;
#line 178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = config;
#line 178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = configuration_facade_get_export_photo_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_current_parameters.specified_format = _tmp8_;
#line 179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = config;
#line 179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = configuration_facade_get_export_quality (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_current_parameters.quality = _tmp10_;
#line 180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = config;
#line 180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = configuration_facade_get_export_export_metadata (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_current_parameters.export_metadata = _tmp12_;
#line 181 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = config;
#line 181 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = configuration_facade_get_export_constraint (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 181 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_current_constraint = _tmp14_;
#line 182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = config;
#line 182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = configuration_facade_get_export_scale (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_current_scale = _tmp16_;
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp17_);
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->quality_combo);
#line 184 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->quality_combo = _tmp17_;
#line 185 "/home/jens/Source/shotwell/src/Dialogs.vala"
	ctr = 0;
#line 2453 "Dialogs.c"
	{
		JpegQuality* quality_collection = NULL;
		gint quality_collection_length1 = 0;
		gint _quality_collection_size_ = 0;
		gint quality_it = 0;
#line 186 "/home/jens/Source/shotwell/src/Dialogs.vala"
		quality_collection = EXPORT_DIALOG_QUALITY_ARRAY;
#line 186 "/home/jens/Source/shotwell/src/Dialogs.vala"
		quality_collection_length1 = G_N_ELEMENTS (EXPORT_DIALOG_QUALITY_ARRAY);
#line 186 "/home/jens/Source/shotwell/src/Dialogs.vala"
		for (quality_it = 0; quality_it < G_N_ELEMENTS (EXPORT_DIALOG_QUALITY_ARRAY); quality_it = quality_it + 1) {
#line 2465 "Dialogs.c"
			JpegQuality quality = 0;
#line 186 "/home/jens/Source/shotwell/src/Dialogs.vala"
			quality = quality_collection[quality_it];
#line 2469 "Dialogs.c"
			{
				GtkComboBoxText* _tmp18_;
				JpegQuality _tmp19_;
				gchar* _tmp20_;
				gchar* _tmp21_;
				JpegQuality _tmp22_;
				ExportFormatParameters _tmp23_;
				JpegQuality _tmp24_;
				gint _tmp27_;
#line 187 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp18_ = self->priv->quality_combo;
#line 187 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp19_ = quality;
#line 187 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp20_ = jpeg_quality_to_string (_tmp19_);
#line 187 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp21_ = _tmp20_;
#line 187 "/home/jens/Source/shotwell/src/Dialogs.vala"
				gtk_combo_box_text_append_text (_tmp18_, _tmp21_);
#line 187 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp21_);
#line 188 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp22_ = quality;
#line 188 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp23_ = export_dialog_current_parameters;
#line 188 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp24_ = _tmp23_.quality;
#line 188 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp22_ == _tmp24_) {
#line 2499 "Dialogs.c"
					GtkComboBoxText* _tmp25_;
					gint _tmp26_;
#line 189 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp25_ = self->priv->quality_combo;
#line 189 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp26_ = ctr;
#line 189 "/home/jens/Source/shotwell/src/Dialogs.vala"
					gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, gtk_combo_box_get_type (), GtkComboBox), _tmp26_);
#line 2508 "Dialogs.c"
				}
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp27_ = ctr;
#line 190 "/home/jens/Source/shotwell/src/Dialogs.vala"
				ctr = _tmp27_ + 1;
#line 2514 "Dialogs.c"
			}
		}
	}
#line 193 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 193 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp28_);
#line 193 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->constraint_combo);
#line 193 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->constraint_combo = _tmp28_;
#line 194 "/home/jens/Source/shotwell/src/Dialogs.vala"
	ctr = 0;
#line 2528 "Dialogs.c"
	{
		ScaleConstraint* constraint_collection = NULL;
		gint constraint_collection_length1 = 0;
		gint _constraint_collection_size_ = 0;
		gint constraint_it = 0;
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
		constraint_collection = EXPORT_DIALOG_CONSTRAINT_ARRAY;
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
		constraint_collection_length1 = G_N_ELEMENTS (EXPORT_DIALOG_CONSTRAINT_ARRAY);
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
		for (constraint_it = 0; constraint_it < G_N_ELEMENTS (EXPORT_DIALOG_CONSTRAINT_ARRAY); constraint_it = constraint_it + 1) {
#line 2540 "Dialogs.c"
			ScaleConstraint constraint = 0;
#line 195 "/home/jens/Source/shotwell/src/Dialogs.vala"
			constraint = constraint_collection[constraint_it];
#line 2544 "Dialogs.c"
			{
				GtkComboBoxText* _tmp29_;
				ScaleConstraint _tmp30_;
				gchar* _tmp31_;
				gchar* _tmp32_;
				ScaleConstraint _tmp33_;
				ScaleConstraint _tmp34_;
				gint _tmp37_;
#line 196 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp29_ = self->priv->constraint_combo;
#line 196 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp30_ = constraint;
#line 196 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp31_ = scale_constraint_to_string (_tmp30_);
#line 196 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp32_ = _tmp31_;
#line 196 "/home/jens/Source/shotwell/src/Dialogs.vala"
				gtk_combo_box_text_append_text (_tmp29_, _tmp32_);
#line 196 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp32_);
#line 197 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp33_ = constraint;
#line 197 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp34_ = export_dialog_current_constraint;
#line 197 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp33_ == _tmp34_) {
#line 2571 "Dialogs.c"
					GtkComboBoxText* _tmp35_;
					gint _tmp36_;
#line 198 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp35_ = self->priv->constraint_combo;
#line 198 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp36_ = ctr;
#line 198 "/home/jens/Source/shotwell/src/Dialogs.vala"
					gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, gtk_combo_box_get_type (), GtkComboBox), _tmp36_);
#line 2580 "Dialogs.c"
				}
#line 199 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp37_ = ctr;
#line 199 "/home/jens/Source/shotwell/src/Dialogs.vala"
				ctr = _tmp37_ + 1;
#line 2586 "Dialogs.c"
			}
		}
	}
#line 202 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 202 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp38_);
#line 202 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->format_combo);
#line 202 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->format_combo = _tmp38_;
#line 203 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_format_add_option (self, EXPORT_DIALOG_UNMODIFIED_FORMAT_LABEL);
#line 204 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_format_add_option (self, EXPORT_DIALOG_CURRENT_FORMAT_LABEL);
#line 205 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = photo_file_format_get_writeable (&_tmp39_);
#line 2604 "Dialogs.c"
	{
		PhotoFileFormat* format_collection = NULL;
		gint format_collection_length1 = 0;
		gint _format_collection_size_ = 0;
		gint format_it = 0;
#line 205 "/home/jens/Source/shotwell/src/Dialogs.vala"
		format_collection = _tmp40_;
#line 205 "/home/jens/Source/shotwell/src/Dialogs.vala"
		format_collection_length1 = _tmp39_;
#line 205 "/home/jens/Source/shotwell/src/Dialogs.vala"
		for (format_it = 0; format_it < _tmp39_; format_it = format_it + 1) {
#line 2616 "Dialogs.c"
			PhotoFileFormat format = 0;
#line 205 "/home/jens/Source/shotwell/src/Dialogs.vala"
			format = format_collection[format_it];
#line 2620 "Dialogs.c"
			{
				PhotoFileFormat _tmp41_;
				PhotoFileFormatProperties* _tmp42_;
				PhotoFileFormatProperties* _tmp43_;
				gchar* _tmp44_;
				gchar* _tmp45_;
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp41_ = format;
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp42_ = photo_file_format_get_properties (_tmp41_);
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp43_ = _tmp42_;
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp44_ = photo_file_format_properties_get_user_visible_name (_tmp43_);
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp45_ = _tmp44_;
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
				export_dialog_format_add_option (self, _tmp45_);
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp45_);
#line 206 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_photo_file_format_properties_unref0 (_tmp43_);
#line 2643 "Dialogs.c"
			}
		}
#line 205 "/home/jens/Source/shotwell/src/Dialogs.vala"
		format_collection = (g_free (format_collection), NULL);
#line 2648 "Dialogs.c"
	}
#line 209 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp46_ = (GtkEntry*) gtk_entry_new ();
#line 209 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp46_);
#line 209 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->pixels_entry);
#line 209 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->pixels_entry = _tmp46_;
#line 210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp47_ = self->priv->pixels_entry;
#line 210 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_max_length (_tmp47_, 6);
#line 211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp48_ = self->priv->pixels_entry;
#line 211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp49_ = export_dialog_current_scale;
#line 211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp50_ = g_strdup_printf ("%d", _tmp49_);
#line 211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp51_ = _tmp50_;
#line 211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_text (_tmp48_, _tmp51_);
#line 211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp51_);
#line 214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp52_ = self->priv->constraint_combo;
#line 214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp52_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _export_dialog_on_constraint_changed_gtk_combo_box_changed, self, 0);
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp53_ = self->priv->format_combo;
#line 215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _export_dialog_on_format_changed_gtk_combo_box_changed, self, 0);
#line 216 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp54_ = self->priv->pixels_entry;
#line 216 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _export_dialog_on_pixels_changed_gtk_editable_changed, self, 0);
#line 217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp55_ = self->priv->pixels_entry;
#line 217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, GTK_TYPE_EDITABLE, GtkEditable), "insert-text", (GCallback) _export_dialog_on_pixels_insert_text_gtk_editable_insert_text, self, 0);
#line 218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp56_ = self->priv->pixels_entry;
#line 218 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp56_, "activate", (GCallback) _export_dialog_on_activate_gtk_entry_activate, self, 0);
#line 221 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp57_ = self->priv->format_combo;
#line 221 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_label (self, _ ("_Format:"), 0, 0, G_TYPE_CHECK_INSTANCE_CAST (_tmp57_, gtk_widget_get_type (), GtkWidget));
#line 222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp58_ = self->priv->format_combo;
#line 222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_control (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, gtk_widget_get_type (), GtkWidget), 1, 0);
#line 224 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp59_ = self->priv->quality_combo;
#line 224 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_label (self, _ ("_Quality:"), 0, 1, G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, gtk_widget_get_type (), GtkWidget));
#line 225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp60_ = self->priv->quality_combo;
#line 225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_control (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, gtk_widget_get_type (), GtkWidget), 1, 1);
#line 227 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp61_ = self->priv->constraint_combo;
#line 227 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_label (self, _ ("_Scaling constraint:"), 0, 2, G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, gtk_widget_get_type (), GtkWidget));
#line 228 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp62_ = self->priv->constraint_combo;
#line 228 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_control (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp62_, gtk_widget_get_type (), GtkWidget), 1, 2);
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp63_ = self->priv->pixels_entry;
#line 230 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_label (self, _ ("_Pixels:"), 0, 3, G_TYPE_CHECK_INSTANCE_CAST (_tmp63_, gtk_widget_get_type (), GtkWidget));
#line 231 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp64_ = self->priv->pixels_entry;
#line 231 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_control (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, gtk_widget_get_type (), GtkWidget), 1, 3);
#line 233 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp65_ = (GtkSwitch*) gtk_switch_new ();
#line 233 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp65_);
#line 233 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->export_metadata);
#line 233 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->export_metadata = _tmp65_;
#line 234 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp66_ = self->priv->export_metadata;
#line 234 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_label (self, _ ("Export _metadata:"), 0, 4, G_TYPE_CHECK_INSTANCE_CAST (_tmp66_, gtk_widget_get_type (), GtkWidget));
#line 235 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp67_ = self->priv->export_metadata;
#line 235 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_add_control (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp67_, gtk_widget_get_type (), GtkWidget), 1, 4);
#line 236 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp68_ = self->priv->export_metadata;
#line 236 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_switch_set_active (_tmp68_, TRUE);
#line 237 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp69_ = self->priv->export_metadata;
#line 237 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp69_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_START);
#line 239 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp70_ = self->priv->table;
#line 239 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_grid_set_row_spacing (_tmp70_, (guint) 6);
#line 240 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp71_ = self->priv->table;
#line 240 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_grid_set_column_spacing (_tmp71_, (guint) 12);
#line 241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp72_ = self->priv->table;
#line 241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, gtk_container_get_type (), GtkContainer), (guint) 18);
#line 243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp73_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp74_ = self->priv->table;
#line 243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp73_, gtk_box_get_type (), GtkBox), gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp74_, gtk_widget_get_type (), GtkWidget));
#line 246 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_CANCEL_LABEL, (gint) GTK_RESPONSE_CANCEL);
#line 247 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp75_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_OK_LABEL, (gint) GTK_RESPONSE_OK);
#line 247 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp76_ = _g_object_ref0 (_tmp75_);
#line 247 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->ok_button);
#line 247 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->ok_button = _tmp76_;
#line 248 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK);
#line 250 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp77_ = self->priv->ok_button;
#line 250 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_can_default (_tmp77_, TRUE);
#line 251 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp78_ = self->priv->ok_button;
#line 251 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_set (_tmp78_, "has-default", TRUE, NULL);
#line 252 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp79_ = self->priv->ok_button;
#line 252 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_default (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp79_);
#line 254 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp80_ = export_dialog_current_constraint;
#line 254 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp80_ == SCALE_CONSTRAINT_ORIGINAL) {
#line 2796 "Dialogs.c"
		GtkEntry* _tmp81_;
		GtkComboBoxText* _tmp82_;
#line 255 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp81_ = self->priv->pixels_entry;
#line 255 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp81_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp82_ = self->priv->quality_combo;
#line 256 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp82_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 2807 "Dialogs.c"
	}
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp83_ = self->priv->ok_button;
#line 259 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_grab_focus (_tmp83_);
#line 167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (config);
#line 167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 2817 "Dialogs.c"
}


ExportDialog* export_dialog_new (const gchar* title) {
#line 167 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return export_dialog_construct (TYPE_EXPORT_DIALOG, title);
#line 2824 "Dialogs.c"
}


static void export_dialog_format_add_option (ExportDialog* self, const gchar* format_name) {
	GeeArrayList* _tmp0_;
	const gchar* _tmp1_;
	GtkComboBoxText* _tmp2_;
	const gchar* _tmp3_;
#line 262 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 262 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (format_name != NULL);
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->format_options;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = format_name;
#line 263 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp1_);
#line 264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->format_combo;
#line 264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = format_name;
#line 264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp2_, _tmp3_);
#line 2849 "Dialogs.c"
}


static void export_dialog_format_set_active_text (ExportDialog* self, const gchar* text) {
	gint selection_ticker = 0;
	const gchar* _tmp16_;
#line 267 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 267 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (text != NULL);
#line 268 "/home/jens/Source/shotwell/src/Dialogs.vala"
	selection_ticker = 0;
#line 2862 "Dialogs.c"
	{
		GeeArrayList* _current_text_list = NULL;
		GeeArrayList* _tmp0_;
		GeeArrayList* _tmp1_;
		gint _current_text_size = 0;
		GeeArrayList* _tmp2_;
		gint _tmp3_;
		gint _tmp4_;
		gint _current_text_index = 0;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = self->priv->format_options;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_text_list = _tmp1_;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = _current_text_list;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp3_;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_text_size = _tmp4_;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_text_index = -1;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 2890 "Dialogs.c"
			gint _tmp5_;
			gint _tmp6_;
			gint _tmp7_;
			gchar* current_text = NULL;
			GeeArrayList* _tmp8_;
			gint _tmp9_;
			gpointer _tmp10_;
			const gchar* _tmp11_;
			const gchar* _tmp12_;
			gint _tmp15_;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = _current_text_index;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_current_text_index = _tmp5_ + 1;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = _current_text_index;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = _current_text_size;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!(_tmp6_ < _tmp7_)) {
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 2913 "Dialogs.c"
			}
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = _current_text_list;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = _current_text_index;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp10_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp9_);
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
			current_text = (gchar*) _tmp10_;
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = current_text;
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = text;
#line 271 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (g_strcmp0 (_tmp11_, _tmp12_) == 0) {
#line 2929 "Dialogs.c"
				GtkComboBoxText* _tmp13_;
				gint _tmp14_;
#line 272 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = self->priv->format_combo;
#line 272 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp14_ = selection_ticker;
#line 272 "/home/jens/Source/shotwell/src/Dialogs.vala"
				gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_combo_box_get_type (), GtkComboBox), _tmp14_);
#line 273 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_text);
#line 273 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_current_text_list);
#line 273 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return;
#line 2944 "Dialogs.c"
			}
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp15_ = selection_ticker;
#line 275 "/home/jens/Source/shotwell/src/Dialogs.vala"
			selection_ticker = _tmp15_ + 1;
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (current_text);
#line 2952 "Dialogs.c"
		}
#line 270 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_current_text_list);
#line 2956 "Dialogs.c"
	}
#line 278 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = text;
#line 278 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_error ("Dialogs.vala:278: format_set_active_text: text '%s' isn't in combo box", _tmp16_);
#line 2962 "Dialogs.c"
}


static PhotoFileFormat export_dialog_get_specified_format (ExportDialog* self) {
	PhotoFileFormat result = 0;
	gint index = 0;
	GtkComboBoxText* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	PhotoFileFormat* writeable_formats = NULL;
	gint _tmp4_;
	PhotoFileFormat* _tmp5_;
	gint writeable_formats_length1;
	gint _writeable_formats_size_;
	gint _tmp6_;
	PhotoFileFormat _tmp7_;
#line 281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EXPORT_DIALOG (self), 0);
#line 282 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->format_combo;
#line 282 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_combo_box_get_type (), GtkComboBox));
#line 282 "/home/jens/Source/shotwell/src/Dialogs.vala"
	index = _tmp1_;
#line 283 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = index;
#line 283 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ < EXPORT_DIALOG_NUM_SPECIAL_FORMATS) {
#line 284 "/home/jens/Source/shotwell/src/Dialogs.vala"
		index = EXPORT_DIALOG_NUM_SPECIAL_FORMATS;
#line 2994 "Dialogs.c"
	}
#line 286 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = index;
#line 286 "/home/jens/Source/shotwell/src/Dialogs.vala"
	index = _tmp3_ - EXPORT_DIALOG_NUM_SPECIAL_FORMATS;
#line 287 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = photo_file_format_get_writeable (&_tmp4_);
#line 287 "/home/jens/Source/shotwell/src/Dialogs.vala"
	writeable_formats = _tmp5_;
#line 287 "/home/jens/Source/shotwell/src/Dialogs.vala"
	writeable_formats_length1 = _tmp4_;
#line 287 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_writeable_formats_size_ = writeable_formats_length1;
#line 288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = index;
#line 288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = writeable_formats[_tmp6_];
#line 288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp7_;
#line 288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	writeable_formats = (g_free (writeable_formats), NULL);
#line 288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 3018 "Dialogs.c"
}


static gchar* export_dialog_get_label_for_parameters (ExportDialog* self, ExportFormatParameters* params) {
	gchar* result = NULL;
	ExportFormatParameters _tmp0_;
	ExportFormatMode _tmp1_;
#line 291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EXPORT_DIALOG (self), NULL);
#line 291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (params != NULL, NULL);
#line 292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = *params;
#line 292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_.mode;
#line 292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	switch (_tmp1_) {
#line 292 "/home/jens/Source/shotwell/src/Dialogs.vala"
		case EXPORT_FORMAT_MODE_UNMODIFIED:
#line 3038 "Dialogs.c"
		{
			gchar* _tmp2_;
#line 294 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = g_strdup (EXPORT_DIALOG_UNMODIFIED_FORMAT_LABEL);
#line 294 "/home/jens/Source/shotwell/src/Dialogs.vala"
			result = _tmp2_;
#line 294 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return result;
#line 3047 "Dialogs.c"
		}
#line 292 "/home/jens/Source/shotwell/src/Dialogs.vala"
		case EXPORT_FORMAT_MODE_CURRENT:
#line 3051 "Dialogs.c"
		{
			gchar* _tmp3_;
#line 297 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = g_strdup (EXPORT_DIALOG_CURRENT_FORMAT_LABEL);
#line 297 "/home/jens/Source/shotwell/src/Dialogs.vala"
			result = _tmp3_;
#line 297 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return result;
#line 3060 "Dialogs.c"
		}
#line 292 "/home/jens/Source/shotwell/src/Dialogs.vala"
		case EXPORT_FORMAT_MODE_SPECIFIED:
#line 3064 "Dialogs.c"
		{
			ExportFormatParameters _tmp4_;
			PhotoFileFormat _tmp5_;
			PhotoFileFormatProperties* _tmp6_;
			PhotoFileFormatProperties* _tmp7_;
			gchar* _tmp8_;
			gchar* _tmp9_;
#line 300 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = *params;
#line 300 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = _tmp4_.specified_format;
#line 300 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = photo_file_format_get_properties (_tmp5_);
#line 300 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = _tmp6_;
#line 300 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = photo_file_format_properties_get_user_visible_name (_tmp7_);
#line 300 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = _tmp8_;
#line 300 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_photo_file_format_properties_unref0 (_tmp7_);
#line 300 "/home/jens/Source/shotwell/src/Dialogs.vala"
			result = _tmp9_;
#line 300 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return result;
#line 3090 "Dialogs.c"
		}
		default:
		{
#line 303 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_error ("Dialogs.vala:303: get_label_for_parameters: unrecognized export format" \
" mode");
#line 3096 "Dialogs.c"
		}
	}
}


gboolean export_dialog_execute (ExportDialog* self, gint* scale, ScaleConstraint* constraint, ExportFormatParameters* parameters) {
	gint _vala_scale = 0;
	ScaleConstraint _vala_constraint = 0;
	gboolean result = FALSE;
	ExportFormatParameters _tmp0_;
	ExportFormatMode _tmp1_;
	ExportFormatParameters _tmp4_;
	ExportFormatMode _tmp5_;
	ExportFormatParameters _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gboolean ok = FALSE;
	gint _tmp17_;
	gboolean _tmp18_;
#line 310 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EXPORT_DIALOG (self), FALSE);
#line 310 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (parameters != NULL, FALSE);
#line 312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = *parameters;
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_.mode;
#line 316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ != EXPORT_FORMAT_MODE_LAST) {
#line 3128 "Dialogs.c"
		ScaleConstraint _tmp2_;
		GtkComboBoxText* _tmp3_;
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_constraint = SCALE_CONSTRAINT_ORIGINAL;
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = _vala_constraint;
#line 317 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_dialog_current_constraint = _tmp2_;
#line 318 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = self->priv->constraint_combo;
#line 318 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 3141 "Dialogs.c"
	}
#line 321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = *parameters;
#line 321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_.mode;
#line 321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_ == EXPORT_FORMAT_MODE_LAST) {
#line 3149 "Dialogs.c"
		ExportFormatParameters _tmp6_;
#line 322 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = export_dialog_current_parameters;
#line 322 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*parameters = _tmp6_;
#line 3155 "Dialogs.c"
	} else {
		gboolean _tmp7_ = FALSE;
		ExportFormatParameters _tmp8_;
		ExportFormatMode _tmp9_;
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = *parameters;
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = _tmp8_.mode;
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp9_ == EXPORT_FORMAT_MODE_SPECIFIED) {
#line 3166 "Dialogs.c"
			ExportFormatParameters _tmp10_;
			PhotoFileFormat _tmp11_;
			gboolean _tmp12_;
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp10_ = *parameters;
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = _tmp10_.specified_format;
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = photo_file_format_can_write (_tmp11_);
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = !_tmp12_;
#line 3178 "Dialogs.c"
		} else {
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = FALSE;
#line 3182 "Dialogs.c"
		}
#line 323 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp7_) {
#line 3186 "Dialogs.c"
			PhotoFileFormat _tmp13_;
#line 324 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp13_ = photo_file_format_get_system_default_format ();
#line 324 "/home/jens/Source/shotwell/src/Dialogs.vala"
			(*parameters).specified_format = _tmp13_;
#line 3192 "Dialogs.c"
		}
	}
#line 326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = *parameters;
#line 326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = export_dialog_get_label_for_parameters (self, &_tmp14_);
#line 326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = _tmp15_;
#line 326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_format_set_active_text (self, _tmp16_);
#line 326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp16_);
#line 327 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_on_format_changed (self);
#line 329 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 329 "/home/jens/Source/shotwell/src/Dialogs.vala"
	ok = _tmp17_ == ((gint) GTK_RESPONSE_OK);
#line 330 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = ok;
#line 330 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp18_) {
#line 3215 "Dialogs.c"
		gint index = 0;
		GtkComboBoxText* _tmp19_;
		gint _tmp20_;
		gint _tmp21_;
		gint _tmp22_;
		ScaleConstraint _tmp23_;
		ScaleConstraint _tmp24_;
		GtkEntry* _tmp25_;
		const gchar* _tmp26_;
		gint _tmp27_;
		ScaleConstraint _tmp28_;
		gint _tmp30_;
		gboolean _tmp31_ = FALSE;
		GtkSwitch* _tmp32_;
		gboolean _tmp33_;
		gboolean _tmp34_;
		GtkComboBoxText* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		gboolean _tmp41_;
		ConfigFacade* config = NULL;
		ConfigFacade* _tmp57_;
		ConfigFacade* _tmp58_;
		ExportFormatParameters _tmp59_;
		ExportFormatMode _tmp60_;
		ConfigFacade* _tmp61_;
		ExportFormatParameters _tmp62_;
		PhotoFileFormat _tmp63_;
		ConfigFacade* _tmp64_;
		ExportFormatParameters _tmp65_;
		JpegQuality _tmp66_;
		ConfigFacade* _tmp67_;
		ExportFormatParameters _tmp68_;
		gboolean _tmp69_;
		ConfigFacade* _tmp70_;
		ScaleConstraint _tmp71_;
		ConfigFacade* _tmp72_;
		gint _tmp73_;
#line 331 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = self->priv->constraint_combo;
#line 331 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_combo_box_get_type (), GtkComboBox));
#line 331 "/home/jens/Source/shotwell/src/Dialogs.vala"
		index = _tmp20_;
#line 332 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = index;
#line 332 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_assert (_tmp21_ >= 0, "index >= 0");
#line 333 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = index;
#line 333 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = EXPORT_DIALOG_CONSTRAINT_ARRAY[_tmp22_];
#line 333 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_constraint = _tmp23_;
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = _vala_constraint;
#line 334 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_dialog_current_constraint = _tmp24_;
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = self->priv->pixels_entry;
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = gtk_entry_get_text (_tmp25_);
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = atoi (_tmp26_);
#line 336 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_scale = _tmp27_;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = _vala_constraint;
#line 337 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp28_ != SCALE_CONSTRAINT_ORIGINAL) {
#line 3286 "Dialogs.c"
			gint _tmp29_;
#line 338 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp29_ = _vala_scale;
#line 338 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_vala_assert (_tmp29_ > 0, "scale > 0");
#line 3292 "Dialogs.c"
		}
#line 339 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = _vala_scale;
#line 339 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_dialog_current_scale = _tmp30_;
#line 341 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = self->priv->export_metadata;
#line 341 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_widget_get_type (), GtkWidget));
#line 341 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = _tmp33_;
#line 341 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp34_) {
#line 3306 "Dialogs.c"
			GtkSwitch* _tmp35_;
			gboolean _tmp36_;
			gboolean _tmp37_;
#line 341 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp35_ = self->priv->export_metadata;
#line 341 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp36_ = gtk_switch_get_active (_tmp35_);
#line 341 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp37_ = _tmp36_;
#line 341 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp31_ = _tmp37_;
#line 3318 "Dialogs.c"
		} else {
#line 341 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp31_ = FALSE;
#line 3322 "Dialogs.c"
		}
#line 341 "/home/jens/Source/shotwell/src/Dialogs.vala"
		(*parameters).export_metadata = _tmp31_;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp38_ = self->priv->format_combo;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp39_ = gtk_combo_box_text_get_active_text (_tmp38_);
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp40_ = _tmp39_;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp41_ = g_strcmp0 (_tmp40_, EXPORT_DIALOG_UNMODIFIED_FORMAT_LABEL) == 0;
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp40_);
#line 343 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp41_) {
#line 3338 "Dialogs.c"
			ExportFormatMode _tmp42_;
#line 344 "/home/jens/Source/shotwell/src/Dialogs.vala"
			export_dialog_current_parameters.mode = EXPORT_FORMAT_MODE_UNMODIFIED;
#line 344 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp42_ = export_dialog_current_parameters.mode;
#line 344 "/home/jens/Source/shotwell/src/Dialogs.vala"
			(*parameters).mode = _tmp42_;
#line 3346 "Dialogs.c"
		} else {
			GtkComboBoxText* _tmp43_;
			gchar* _tmp44_;
			gchar* _tmp45_;
			gboolean _tmp46_;
#line 345 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp43_ = self->priv->format_combo;
#line 345 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp44_ = gtk_combo_box_text_get_active_text (_tmp43_);
#line 345 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp45_ = _tmp44_;
#line 345 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp46_ = g_strcmp0 (_tmp45_, EXPORT_DIALOG_CURRENT_FORMAT_LABEL) == 0;
#line 345 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp45_);
#line 345 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp46_) {
#line 3364 "Dialogs.c"
				ExportFormatMode _tmp47_;
#line 346 "/home/jens/Source/shotwell/src/Dialogs.vala"
				export_dialog_current_parameters.mode = EXPORT_FORMAT_MODE_CURRENT;
#line 346 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp47_ = export_dialog_current_parameters.mode;
#line 346 "/home/jens/Source/shotwell/src/Dialogs.vala"
				(*parameters).mode = _tmp47_;
#line 3372 "Dialogs.c"
			} else {
				ExportFormatMode _tmp48_;
				PhotoFileFormat _tmp49_;
				PhotoFileFormat _tmp50_;
				ExportFormatParameters _tmp51_;
				PhotoFileFormat _tmp52_;
#line 348 "/home/jens/Source/shotwell/src/Dialogs.vala"
				export_dialog_current_parameters.mode = EXPORT_FORMAT_MODE_SPECIFIED;
#line 348 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp48_ = export_dialog_current_parameters.mode;
#line 348 "/home/jens/Source/shotwell/src/Dialogs.vala"
				(*parameters).mode = _tmp48_;
#line 349 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp49_ = export_dialog_get_specified_format (self);
#line 349 "/home/jens/Source/shotwell/src/Dialogs.vala"
				export_dialog_current_parameters.specified_format = _tmp49_;
#line 349 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp50_ = export_dialog_current_parameters.specified_format;
#line 349 "/home/jens/Source/shotwell/src/Dialogs.vala"
				(*parameters).specified_format = _tmp50_;
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp51_ = export_dialog_current_parameters;
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp52_ = _tmp51_.specified_format;
#line 350 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp52_ == PHOTO_FILE_FORMAT_JFIF) {
#line 3399 "Dialogs.c"
					GtkComboBoxText* _tmp53_;
					gint _tmp54_;
					JpegQuality _tmp55_;
					JpegQuality _tmp56_;
#line 351 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp53_ = self->priv->quality_combo;
#line 351 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp54_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, gtk_combo_box_get_type (), GtkComboBox));
#line 351 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp55_ = EXPORT_DIALOG_QUALITY_ARRAY[_tmp54_];
#line 351 "/home/jens/Source/shotwell/src/Dialogs.vala"
					export_dialog_current_parameters.quality = _tmp55_;
#line 351 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp56_ = export_dialog_current_parameters.quality;
#line 351 "/home/jens/Source/shotwell/src/Dialogs.vala"
					(*parameters).quality = _tmp56_;
#line 3416 "Dialogs.c"
				}
			}
		}
#line 355 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp57_ = config_facade_get_instance ();
#line 355 "/home/jens/Source/shotwell/src/Dialogs.vala"
		config = _tmp57_;
#line 356 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp58_ = config;
#line 356 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp59_ = export_dialog_current_parameters;
#line 356 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp60_ = _tmp59_.mode;
#line 356 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_export_export_format_mode (G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp60_);
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp61_ = config;
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp62_ = export_dialog_current_parameters;
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp63_ = _tmp62_.specified_format;
#line 357 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_export_photo_file_format (G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp63_);
#line 358 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp64_ = config;
#line 358 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp65_ = export_dialog_current_parameters;
#line 358 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp66_ = _tmp65_.quality;
#line 358 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_export_quality (G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp66_);
#line 359 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp67_ = config;
#line 359 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp68_ = export_dialog_current_parameters;
#line 359 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp69_ = _tmp68_.export_metadata;
#line 359 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_export_export_metadata (G_TYPE_CHECK_INSTANCE_CAST (_tmp67_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp69_);
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp70_ = config;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp71_ = export_dialog_current_constraint;
#line 360 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_export_constraint (G_TYPE_CHECK_INSTANCE_CAST (_tmp70_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp71_);
#line 361 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp72_ = config;
#line 361 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp73_ = export_dialog_current_scale;
#line 361 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_export_scale (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp73_);
#line 330 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (config);
#line 3470 "Dialogs.c"
	} else {
#line 363 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_scale = 0;
#line 364 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_constraint = SCALE_CONSTRAINT_ORIGINAL;
#line 3476 "Dialogs.c"
	}
#line 367 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 369 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = ok;
#line 369 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (scale) {
#line 369 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*scale = _vala_scale;
#line 3486 "Dialogs.c"
	}
#line 369 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (constraint) {
#line 369 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*constraint = _vala_constraint;
#line 3492 "Dialogs.c"
	}
#line 369 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 3496 "Dialogs.c"
}


static void export_dialog_add_label (ExportDialog* self, const gchar* text, gint x, gint y, GtkWidget* widget) {
	GtkLabel* new_label = NULL;
	const gchar* _tmp0_;
	GtkLabel* _tmp1_;
	GtkLabel* _tmp2_;
	GtkLabel* _tmp3_;
	GtkLabel* _tmp4_;
	GtkWidget* _tmp5_;
	GtkGrid* _tmp8_;
	GtkLabel* _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
#line 372 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 372 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (text != NULL);
#line 372 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail ((widget == NULL) || GTK_IS_WIDGET (widget));
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = text;
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = (GtkLabel*) gtk_label_new_with_mnemonic (_tmp0_);
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp1_);
#line 373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	new_label = _tmp1_;
#line 374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = new_label;
#line 374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_END);
#line 375 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = new_label;
#line 375 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_CENTER);
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = new_label;
#line 376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_use_underline (_tmp4_, TRUE);
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = widget;
#line 378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_ != NULL) {
#line 3542 "Dialogs.c"
		GtkLabel* _tmp6_;
		GtkWidget* _tmp7_;
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = new_label;
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = widget;
#line 379 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_mnemonic_widget (_tmp6_, _tmp7_);
#line 3551 "Dialogs.c"
	}
#line 381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = self->priv->table;
#line 381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = new_label;
#line 381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = x;
#line 381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = y;
#line 381 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_grid_attach (_tmp8_, G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget), _tmp10_, _tmp11_, 1, 1);
#line 372 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (new_label);
#line 3565 "Dialogs.c"
}


static void export_dialog_add_control (ExportDialog* self, GtkWidget* widget, gint x, gint y) {
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
	GtkWidget* _tmp3_;
	GtkGrid* _tmp4_;
	GtkWidget* _tmp5_;
	gint _tmp6_;
	gint _tmp7_;
#line 384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 384 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GTK_IS_WIDGET (widget));
#line 385 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = widget;
#line 385 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_halign (_tmp0_, GTK_ALIGN_FILL);
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = widget;
#line 386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_valign (_tmp1_, GTK_ALIGN_CENTER);
#line 387 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = widget;
#line 387 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_hexpand (_tmp2_, TRUE);
#line 388 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = widget;
#line 388 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_vexpand (_tmp3_, TRUE);
#line 390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = self->priv->table;
#line 390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = widget;
#line 390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = x;
#line 390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = y;
#line 390 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_grid_attach (_tmp4_, _tmp5_, _tmp6_, _tmp7_, 1, 1);
#line 3608 "Dialogs.c"
}


static void export_dialog_on_constraint_changed (ExportDialog* self) {
	gboolean original = FALSE;
	GtkComboBoxText* _tmp0_;
	gint _tmp1_;
	ScaleConstraint _tmp2_;
	gboolean jpeg = FALSE;
	GtkComboBoxText* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	PhotoFileFormatProperties* _tmp6_;
	PhotoFileFormatProperties* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gboolean _tmp10_;
	GtkEntry* _tmp11_;
	gboolean _tmp12_;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_;
	GtkComboBoxText* _tmp16_;
	gboolean _tmp17_;
#line 393 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 394 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->constraint_combo;
#line 394 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_combo_box_get_type (), GtkComboBox));
#line 394 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = EXPORT_DIALOG_CONSTRAINT_ARRAY[_tmp1_];
#line 394 "/home/jens/Source/shotwell/src/Dialogs.vala"
	original = _tmp2_ == SCALE_CONSTRAINT_ORIGINAL;
#line 395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->priv->format_combo;
#line 395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gtk_combo_box_text_get_active_text (_tmp3_);
#line 395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = photo_file_format_get_properties (PHOTO_FILE_FORMAT_JFIF);
#line 395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = photo_file_format_properties_get_user_visible_name (_tmp7_);
#line 395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = g_strcmp0 (_tmp5_, _tmp9_) == 0;
#line 395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp9_);
#line 395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_photo_file_format_properties_unref0 (_tmp7_);
#line 395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp5_);
#line 395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	jpeg = _tmp10_;
#line 397 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = self->priv->pixels_entry;
#line 397 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = original;
#line 397 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_widget_get_type (), GtkWidget), !_tmp12_);
#line 398 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = original;
#line 398 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp14_) {
#line 3676 "Dialogs.c"
		gboolean _tmp15_;
#line 398 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = jpeg;
#line 398 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = _tmp15_;
#line 3682 "Dialogs.c"
	} else {
#line 398 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = FALSE;
#line 3686 "Dialogs.c"
	}
#line 398 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = self->priv->quality_combo;
#line 398 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_widget_get_type (), GtkWidget), _tmp13_);
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = original;
#line 399 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp17_) {
#line 3696 "Dialogs.c"
		GtkWidget* _tmp18_;
#line 400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = self->priv->ok_button;
#line 400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (_tmp18_, TRUE);
#line 3702 "Dialogs.c"
	} else {
#line 402 "/home/jens/Source/shotwell/src/Dialogs.vala"
		export_dialog_on_pixels_changed (self);
#line 3706 "Dialogs.c"
	}
}


static void export_dialog_on_format_changed (ExportDialog* self) {
	gboolean original = FALSE;
	GtkComboBoxText* _tmp0_;
	gint _tmp1_;
	ScaleConstraint _tmp2_;
	GtkComboBoxText* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gboolean _tmp6_;
#line 405 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->constraint_combo;
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_combo_box_get_type (), GtkComboBox));
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = EXPORT_DIALOG_CONSTRAINT_ARRAY[_tmp1_];
#line 406 "/home/jens/Source/shotwell/src/Dialogs.vala"
	original = _tmp2_ == SCALE_CONSTRAINT_ORIGINAL;
#line 408 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->priv->format_combo;
#line 408 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gtk_combo_box_text_get_active_text (_tmp3_);
#line 408 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 408 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = g_strcmp0 (_tmp5_, EXPORT_DIALOG_UNMODIFIED_FORMAT_LABEL) == 0;
#line 408 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp5_);
#line 408 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp6_) {
#line 3742 "Dialogs.c"
		GtkComboBoxText* _tmp7_;
		GtkComboBoxText* _tmp8_;
		GtkComboBoxText* _tmp9_;
		GtkEntry* _tmp10_;
		GtkSwitch* _tmp11_;
		GtkSwitch* _tmp12_;
#line 413 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = self->priv->constraint_combo;
#line 413 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 414 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = self->priv->constraint_combo;
#line 414 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 415 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = self->priv->quality_combo;
#line 415 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = self->priv->pixels_entry;
#line 416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 417 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = self->priv->export_metadata;
#line 417 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_switch_set_active (_tmp11_, FALSE);
#line 418 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = self->priv->export_metadata;
#line 418 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 3773 "Dialogs.c"
	} else {
		GtkComboBoxText* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gboolean _tmp16_;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = self->priv->format_combo;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = gtk_combo_box_text_get_active_text (_tmp13_);
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = _tmp14_;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = g_strcmp0 (_tmp15_, EXPORT_DIALOG_CURRENT_FORMAT_LABEL) == 0;
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp15_);
#line 419 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp16_) {
#line 3791 "Dialogs.c"
			GtkComboBoxText* _tmp17_;
			GtkComboBoxText* _tmp18_;
			GtkEntry* _tmp19_;
			gboolean _tmp20_;
			GtkSwitch* _tmp21_;
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = self->priv->constraint_combo;
#line 426 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 427 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = self->priv->quality_combo;
#line 427 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 428 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp19_ = self->priv->pixels_entry;
#line 428 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = original;
#line 428 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_widget_get_type (), GtkWidget), !_tmp20_);
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = self->priv->export_metadata;
#line 429 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 3815 "Dialogs.c"
		} else {
			GtkComboBoxText* _tmp22_;
			gboolean jpeg = FALSE;
			PhotoFileFormat _tmp23_;
			gboolean _tmp24_ = FALSE;
			gboolean _tmp25_;
			GtkComboBoxText* _tmp27_;
			GtkSwitch* _tmp28_;
#line 434 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = self->priv->constraint_combo;
#line 434 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = export_dialog_get_specified_format (self);
#line 435 "/home/jens/Source/shotwell/src/Dialogs.vala"
			jpeg = _tmp23_ == PHOTO_FILE_FORMAT_JFIF;
#line 436 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = original;
#line 436 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp25_) {
#line 3836 "Dialogs.c"
				gboolean _tmp26_;
#line 436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp26_ = jpeg;
#line 436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp24_ = _tmp26_;
#line 3842 "Dialogs.c"
			} else {
#line 436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp24_ = FALSE;
#line 3846 "Dialogs.c"
			}
#line 436 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = self->priv->quality_combo;
#line 436 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_widget_get_type (), GtkWidget), _tmp24_);
#line 437 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp28_ = self->priv->export_metadata;
#line 437 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 3856 "Dialogs.c"
		}
	}
}


static void export_dialog_on_activate (ExportDialog* self) {
#line 441 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 442 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK);
#line 3867 "Dialogs.c"
}


static void export_dialog_on_pixels_changed (ExportDialog* self) {
	gboolean _tmp0_ = FALSE;
	GtkEntry* _tmp1_;
	guint16 _tmp2_;
	GtkWidget* _tmp6_;
#line 445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->pixels_entry;
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_entry_get_text_length (_tmp1_);
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (((gint) _tmp2_) > 0) {
#line 3884 "Dialogs.c"
		GtkEntry* _tmp3_;
		const gchar* _tmp4_;
		gint _tmp5_;
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = self->priv->pixels_entry;
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = gtk_entry_get_text (_tmp3_);
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = atoi (_tmp4_);
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp5_ > 0;
#line 3896 "Dialogs.c"
	} else {
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = FALSE;
#line 3900 "Dialogs.c"
	}
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = self->priv->ok_button;
#line 446 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (_tmp6_, _tmp0_);
#line 3906 "Dialogs.c"
}


static gchar string_get (const gchar* self, glong index) {
	gchar result = '\0';
	glong _tmp0_;
	gchar _tmp1_;
#line 1110 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, '\0');
#line 1111 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = index;
#line 1111 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = ((gchar*) self)[_tmp0_];
#line 1111 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp1_;
#line 1111 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 3924 "Dialogs.c"
}


static void export_dialog_on_pixels_insert_text (ExportDialog* self, const gchar* text, gint length, gint* position) {
	gboolean _tmp0_;
	gint _tmp1_;
	gchar* new_text = NULL;
	gchar* _tmp5_;
	const gchar* _tmp21_;
	gint _tmp22_;
	gint _tmp23_;
	GtkEntry* _tmp29_;
#line 449 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_EXPORT_DIALOG (self));
#line 449 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (text != NULL);
#line 451 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->in_insert;
#line 451 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 452 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 3947 "Dialogs.c"
	}
#line 454 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->in_insert = TRUE;
#line 456 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = length;
#line 456 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == -1) {
#line 3955 "Dialogs.c"
		const gchar* _tmp2_;
		gint _tmp3_;
		gint _tmp4_;
#line 457 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = text;
#line 457 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = strlen (_tmp2_);
#line 457 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp3_;
#line 457 "/home/jens/Source/shotwell/src/Dialogs.vala"
		length = (gint) _tmp4_;
#line 3967 "Dialogs.c"
	}
#line 460 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = g_strdup ("");
#line 460 "/home/jens/Source/shotwell/src/Dialogs.vala"
	new_text = _tmp5_;
#line 3973 "Dialogs.c"
	{
		gint ctr = 0;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
		ctr = 0;
#line 3978 "Dialogs.c"
		{
			gboolean _tmp6_ = FALSE;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = TRUE;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 3985 "Dialogs.c"
				gint _tmp8_;
				gint _tmp9_;
				const gchar* _tmp10_;
				gint _tmp11_;
				gchar _tmp12_;
				gboolean _tmp13_;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp6_) {
#line 3994 "Dialogs.c"
					gint _tmp7_;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp7_ = ctr;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
					ctr = _tmp7_ + 1;
#line 4000 "Dialogs.c"
				}
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = FALSE;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp8_ = ctr;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9_ = length;
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp8_ < _tmp9_)) {
#line 461 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 4012 "Dialogs.c"
				}
#line 462 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = text;
#line 462 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = ctr;
#line 462 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp12_ = string_get (_tmp10_, (glong) _tmp11_);
#line 462 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = g_ascii_isdigit (_tmp12_);
#line 462 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp13_) {
#line 4024 "Dialogs.c"
					const gchar* _tmp14_;
					const gchar* _tmp15_;
					gint _tmp16_;
					gchar _tmp17_;
					gchar* _tmp18_;
					gchar* _tmp19_;
					gchar* _tmp20_;
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp14_ = new_text;
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp15_ = text;
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp16_ = ctr;
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp17_ = string_get (_tmp15_, (glong) _tmp16_);
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp18_ = g_strdup_printf ("%c", (gchar) _tmp17_);
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp19_ = _tmp18_;
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp20_ = g_strconcat (_tmp14_, _tmp19_, NULL);
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_g_free0 (new_text);
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
					new_text = _tmp20_;
#line 463 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_g_free0 (_tmp19_);
#line 4052 "Dialogs.c"
				}
			}
		}
	}
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = new_text;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = strlen (_tmp21_);
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = _tmp22_;
#line 467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp23_ > 0) {
#line 4065 "Dialogs.c"
		GtkEntry* _tmp24_;
		const gchar* _tmp25_;
		const gchar* _tmp26_;
		gint _tmp27_;
		gint _tmp28_;
#line 468 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = self->priv->pixels_entry;
#line 468 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = new_text;
#line 468 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = new_text;
#line 468 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = strlen (_tmp26_);
#line 468 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = _tmp27_;
#line 468 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_editable_insert_text (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, GTK_TYPE_EDITABLE, GtkEditable), _tmp25_, (gint) _tmp28_, position);
#line 4083 "Dialogs.c"
	}
#line 470 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = self->priv->pixels_entry;
#line 470 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_stop_emission_by_name (_tmp29_, "insert-text");
#line 472 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->in_insert = FALSE;
#line 449 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (new_text);
#line 4093 "Dialogs.c"
}


static void export_dialog_class_init (ExportDialogClass * klass) {
	ExportFormatParameters _tmp0_ = {0};
#line 137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_parent_class = g_type_class_peek_parent (klass);
#line 137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (ExportDialogPrivate));
#line 137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = export_dialog_finalize;
#line 154 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_format_parameters_current (&_tmp0_);
#line 154 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_current_parameters = _tmp0_;
#line 155 "/home/jens/Source/shotwell/src/Dialogs.vala"
	export_dialog_current_scale = EXPORT_DIALOG_DEFAULT_SCALE;
#line 4111 "Dialogs.c"
}


static void export_dialog_instance_init (ExportDialog * self) {
	GtkGrid* _tmp0_;
	GeeArrayList* _tmp1_;
#line 137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = EXPORT_DIALOG_GET_PRIVATE (self);
#line 157 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = (GtkGrid*) gtk_grid_new ();
#line 157 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp0_);
#line 157 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->table = _tmp0_;
#line 162 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL);
#line 162 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->format_options = _tmp1_;
#line 165 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->in_insert = FALSE;
#line 4132 "Dialogs.c"
}


static void export_dialog_finalize (GObject * obj) {
	ExportDialog * self;
#line 137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_EXPORT_DIALOG, ExportDialog);
#line 157 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->table);
#line 158 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->quality_combo);
#line 159 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->constraint_combo);
#line 160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->format_combo);
#line 161 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->export_metadata);
#line 162 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->format_options);
#line 163 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->pixels_entry);
#line 164 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->ok_button);
#line 137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (export_dialog_parent_class)->finalize (obj);
#line 4158 "Dialogs.c"
}


GType export_dialog_get_type (void) {
	static volatile gsize export_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&export_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ExportDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) export_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ExportDialog), 0, (GInstanceInitFunc) export_dialog_instance_init, NULL };
		GType export_dialog_type_id;
		export_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "ExportDialog", &g_define_type_info, 0);
		g_once_init_leave (&export_dialog_type_id__volatile, export_dialog_type_id);
	}
	return export_dialog_type_id__volatile;
}


gchar* import_ui_generate_import_failure_list (GeeList* failed, gboolean show_dest_id) {
	gchar* result = NULL;
	GeeList* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	gchar* list = NULL;
	gchar* _tmp3_;
	gint remaining = 0;
	GeeList* _tmp28_;
	gint _tmp29_;
	gint _tmp30_;
	gint _tmp31_;
#line 482 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_LIST (failed), NULL);
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = failed;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_COLLECTION, GeeCollection));
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 483 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ == 0) {
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = NULL;
#line 484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 4200 "Dialogs.c"
	}
#line 486 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup ("");
#line 486 "/home/jens/Source/shotwell/src/Dialogs.vala"
	list = _tmp3_;
#line 4206 "Dialogs.c"
	{
		gint ctr = 0;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
		ctr = 0;
#line 4211 "Dialogs.c"
		{
			gboolean _tmp4_ = FALSE;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = TRUE;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 4218 "Dialogs.c"
				gboolean _tmp6_ = FALSE;
				gint _tmp7_;
				const gchar* _tmp12_ = NULL;
				gboolean _tmp13_;
				const gchar* _tmp24_;
				gchar* _tmp25_;
				gchar* _tmp26_;
				gchar* _tmp27_;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp4_) {
#line 4229 "Dialogs.c"
					gint _tmp5_;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp5_ = ctr;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
					ctr = _tmp5_ + 1;
#line 4235 "Dialogs.c"
				}
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp4_ = FALSE;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp7_ = ctr;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp7_ < IMPORT_UI_REPORT_FAILURE_COUNT) {
#line 4243 "Dialogs.c"
					gint _tmp8_;
					GeeList* _tmp9_;
					gint _tmp10_;
					gint _tmp11_;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp8_ = ctr;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp9_ = failed;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp10_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_COLLECTION, GeeCollection));
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp11_ = _tmp10_;
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp6_ = _tmp8_ < _tmp11_;
#line 4258 "Dialogs.c"
				} else {
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp6_ = FALSE;
#line 4262 "Dialogs.c"
				}
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp6_) {
#line 487 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 4268 "Dialogs.c"
				}
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = show_dest_id;
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp13_) {
#line 4274 "Dialogs.c"
					GeeList* _tmp14_;
					gint _tmp15_;
					gpointer _tmp16_;
					BatchImportResult* _tmp17_;
					const gchar* _tmp18_;
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp14_ = failed;
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp15_ = ctr;
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp16_ = gee_list_get (_tmp14_, _tmp15_);
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp17_ = (BatchImportResult*) _tmp16_;
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp18_ = _tmp17_->dest_identifier;
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp12_ = _tmp18_;
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_batch_import_result_unref0 (_tmp17_);
#line 4294 "Dialogs.c"
				} else {
					GeeList* _tmp19_;
					gint _tmp20_;
					gpointer _tmp21_;
					BatchImportResult* _tmp22_;
					const gchar* _tmp23_;
#line 489 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp19_ = failed;
#line 489 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp20_ = ctr;
#line 489 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp21_ = gee_list_get (_tmp19_, _tmp20_);
#line 489 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp22_ = (BatchImportResult*) _tmp21_;
#line 489 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp23_ = _tmp22_->src_identifier;
#line 489 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp12_ = _tmp23_;
#line 489 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_batch_import_result_unref0 (_tmp22_);
#line 4315 "Dialogs.c"
				}
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp24_ = list;
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp25_ = g_strdup_printf ("%s\n", _tmp12_);
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp26_ = _tmp25_;
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp27_ = g_strconcat (_tmp24_, _tmp26_, NULL);
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (list);
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
				list = _tmp27_;
#line 488 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp26_);
#line 4331 "Dialogs.c"
			}
		}
	}
#line 492 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = failed;
#line 492 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, GEE_TYPE_COLLECTION, GeeCollection));
#line 492 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = _tmp29_;
#line 492 "/home/jens/Source/shotwell/src/Dialogs.vala"
	remaining = _tmp30_ - IMPORT_UI_REPORT_FAILURE_COUNT;
#line 493 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = remaining;
#line 493 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp31_ > 0) {
#line 4347 "Dialogs.c"
		const gchar* _tmp32_;
		gint _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = list;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = remaining;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = g_strdup_printf (_ ("(and %d more)\n"), _tmp33_);
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp35_ = _tmp34_;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp36_ = g_strconcat (_tmp32_, _tmp35_, NULL);
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (list);
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		list = _tmp36_;
#line 494 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp35_);
#line 4369 "Dialogs.c"
	}
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = list;
#line 496 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 4375 "Dialogs.c"
}


ImportUIQuestionParams* import_ui_question_params_construct (GType object_type, const gchar* question, const gchar* yes_button, const gchar* no_button) {
	ImportUIQuestionParams* self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (question != NULL, NULL);
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (yes_button != NULL, NULL);
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (no_button != NULL, NULL);
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (ImportUIQuestionParams*) g_type_create_instance (object_type);
#line 505 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = question;
#line 505 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 505 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->question);
#line 505 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->question = _tmp1_;
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = yes_button;
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->yes_button);
#line 506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->yes_button = _tmp3_;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = no_button;
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->no_button);
#line 507 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->no_button = _tmp5_;
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 4421 "Dialogs.c"
}


ImportUIQuestionParams* import_ui_question_params_new (const gchar* question, const gchar* yes_button, const gchar* no_button) {
#line 504 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return import_ui_question_params_construct (IMPORT_UI_TYPE_QUESTION_PARAMS, question, yes_button, no_button);
#line 4428 "Dialogs.c"
}


static void import_ui_value_question_params_init (GValue* value) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 4435 "Dialogs.c"
}


static void import_ui_value_question_params_free_value (GValue* value) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_unref (value->data[0].v_pointer);
#line 4444 "Dialogs.c"
	}
}


static void import_ui_value_question_params_copy_value (const GValue* src_value, GValue* dest_value) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = import_ui_question_params_ref (src_value->data[0].v_pointer);
#line 4454 "Dialogs.c"
	} else {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 4458 "Dialogs.c"
	}
}


static gpointer import_ui_value_question_params_peek_pointer (const GValue* value) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 4466 "Dialogs.c"
}


static gchar* import_ui_value_question_params_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 4473 "Dialogs.c"
		ImportUIQuestionParams * object;
		object = collect_values[0].v_pointer;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 4480 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 4484 "Dialogs.c"
		}
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = import_ui_question_params_ref (object);
#line 4488 "Dialogs.c"
	} else {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 4492 "Dialogs.c"
	}
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 4496 "Dialogs.c"
}


static gchar* import_ui_value_question_params_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	ImportUIQuestionParams ** object_p;
	object_p = collect_values[0].v_pointer;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 4507 "Dialogs.c"
	}
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 4513 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 4517 "Dialogs.c"
	} else {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = import_ui_question_params_ref (value->data[0].v_pointer);
#line 4521 "Dialogs.c"
	}
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 4525 "Dialogs.c"
}


GParamSpec* import_ui_param_spec_question_params (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ImportUIParamSpecQuestionParams* spec;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, IMPORT_UI_TYPE_QUESTION_PARAMS), NULL);
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 4539 "Dialogs.c"
}


gpointer import_ui_value_get_question_params (const GValue* value) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, IMPORT_UI_TYPE_QUESTION_PARAMS), NULL);
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 4548 "Dialogs.c"
}


void import_ui_value_set_question_params (GValue* value, gpointer v_object) {
	ImportUIQuestionParams * old;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_ref (value->data[0].v_pointer);
#line 4568 "Dialogs.c"
	} else {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 4572 "Dialogs.c"
	}
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_unref (old);
#line 4578 "Dialogs.c"
	}
}


void import_ui_value_take_question_params (GValue* value, gpointer v_object) {
	ImportUIQuestionParams * old;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, IMPORT_UI_TYPE_QUESTION_PARAMS));
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 4597 "Dialogs.c"
	} else {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 4601 "Dialogs.c"
	}
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		import_ui_question_params_unref (old);
#line 4607 "Dialogs.c"
	}
}


static void import_ui_question_params_class_init (ImportUIQuestionParamsClass * klass) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	import_ui_question_params_parent_class = g_type_class_peek_parent (klass);
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((ImportUIQuestionParamsClass *) klass)->finalize = import_ui_question_params_finalize;
#line 4617 "Dialogs.c"
}


static void import_ui_question_params_instance_init (ImportUIQuestionParams * self) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 4624 "Dialogs.c"
}


static void import_ui_question_params_finalize (ImportUIQuestionParams * obj) {
	ImportUIQuestionParams * self;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, IMPORT_UI_TYPE_QUESTION_PARAMS, ImportUIQuestionParams);
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 500 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->question);
#line 501 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->yes_button);
#line 502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->no_button);
#line 4640 "Dialogs.c"
}


GType import_ui_question_params_get_type (void) {
	static volatile gsize import_ui_question_params_type_id__volatile = 0;
	if (g_once_init_enter (&import_ui_question_params_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { import_ui_value_question_params_init, import_ui_value_question_params_free_value, import_ui_value_question_params_copy_value, import_ui_value_question_params_peek_pointer, "p", import_ui_value_question_params_collect_value, "p", import_ui_value_question_params_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (ImportUIQuestionParamsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) import_ui_question_params_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ImportUIQuestionParams), 0, (GInstanceInitFunc) import_ui_question_params_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType import_ui_question_params_type_id;
		import_ui_question_params_type_id = g_type_register_fundamental (g_type_fundamental_next (), "ImportUIQuestionParams", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&import_ui_question_params_type_id__volatile, import_ui_question_params_type_id);
	}
	return import_ui_question_params_type_id__volatile;
}


gpointer import_ui_question_params_ref (gpointer instance) {
	ImportUIQuestionParams * self;
	self = instance;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 4665 "Dialogs.c"
}


void import_ui_question_params_unref (gpointer instance) {
	ImportUIQuestionParams * self;
	self = instance;
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		IMPORT_UI_QUESTION_PARAMS_GET_CLASS (self)->finalize (self);
#line 499 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 4678 "Dialogs.c"
	}
}


gboolean import_ui_import_has_photos (GeeCollection* import_collection) {
	gboolean result = FALSE;
#line 511 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (import_collection), FALSE);
#line 4687 "Dialogs.c"
	{
		GeeIterator* _current_result_it = NULL;
		GeeCollection* _tmp0_;
		GeeIterator* _tmp1_;
#line 512 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = import_collection;
#line 512 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ITERABLE, GeeIterable));
#line 512 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_result_it = _tmp1_;
#line 512 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 4700 "Dialogs.c"
			GeeIterator* _tmp2_;
			gboolean _tmp3_;
			BatchImportResult* current_result = NULL;
			GeeIterator* _tmp4_;
			gpointer _tmp5_;
			gboolean _tmp6_ = FALSE;
			BatchImportResult* _tmp7_;
			GFile* _tmp8_;
#line 512 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = _current_result_it;
#line 512 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 512 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp3_) {
#line 512 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 4717 "Dialogs.c"
			}
#line 512 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = _current_result_it;
#line 512 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 512 "/home/jens/Source/shotwell/src/Dialogs.vala"
			current_result = (BatchImportResult*) _tmp5_;
#line 513 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = current_result;
#line 513 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = _tmp7_->file;
#line 513 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp8_ != NULL) {
#line 4731 "Dialogs.c"
				BatchImportResult* _tmp9_;
				GFile* _tmp10_;
				PhotoFileFormat _tmp11_;
#line 514 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9_ = current_result;
#line 514 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = _tmp9_->file;
#line 514 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = photo_file_format_get_by_file_extension (_tmp10_);
#line 514 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = _tmp11_ != PHOTO_FILE_FORMAT_UNKNOWN;
#line 4743 "Dialogs.c"
			} else {
#line 513 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = FALSE;
#line 4747 "Dialogs.c"
			}
#line 513 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp6_) {
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = TRUE;
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (current_result);
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_current_result_it);
#line 515 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 4759 "Dialogs.c"
			}
#line 512 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_batch_import_result_unref0 (current_result);
#line 4763 "Dialogs.c"
		}
#line 512 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_current_result_it);
#line 4767 "Dialogs.c"
	}
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = FALSE;
#line 518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 4773 "Dialogs.c"
}


gboolean import_ui_import_has_videos (GeeCollection* import_collection) {
	gboolean result = FALSE;
#line 521 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (import_collection), FALSE);
#line 4781 "Dialogs.c"
	{
		GeeIterator* _current_result_it = NULL;
		GeeCollection* _tmp0_;
		GeeIterator* _tmp1_;
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = import_collection;
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ITERABLE, GeeIterable));
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_current_result_it = _tmp1_;
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 4794 "Dialogs.c"
			GeeIterator* _tmp2_;
			gboolean _tmp3_;
			BatchImportResult* current_result = NULL;
			GeeIterator* _tmp4_;
			gpointer _tmp5_;
			gboolean _tmp6_ = FALSE;
			BatchImportResult* _tmp7_;
			GFile* _tmp8_;
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = _current_result_it;
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp3_) {
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 4811 "Dialogs.c"
			}
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = _current_result_it;
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
			current_result = (BatchImportResult*) _tmp5_;
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = current_result;
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = _tmp7_->file;
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp8_ != NULL) {
#line 4825 "Dialogs.c"
				BatchImportResult* _tmp9_;
				GFile* _tmp10_;
				gboolean _tmp11_;
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9_ = current_result;
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = _tmp9_->file;
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = video_reader_is_supported_video_file (_tmp10_);
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = _tmp11_;
#line 4837 "Dialogs.c"
			} else {
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = FALSE;
#line 4841 "Dialogs.c"
			}
#line 523 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp6_) {
#line 524 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = TRUE;
#line 524 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (current_result);
#line 524 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_current_result_it);
#line 524 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 4853 "Dialogs.c"
			}
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_batch_import_result_unref0 (current_result);
#line 4857 "Dialogs.c"
		}
#line 522 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_current_result_it);
#line 4861 "Dialogs.c"
	}
#line 526 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = FALSE;
#line 526 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 4867 "Dialogs.c"
}


gchar* import_ui_get_media_specific_string (GeeCollection* import_collection, const gchar* photos_msg, const gchar* videos_msg, const gchar* both_msg, const gchar* neither_msg) {
	gchar* result = NULL;
	gboolean has_photos = FALSE;
	GeeCollection* _tmp0_;
	gboolean _tmp1_;
	gboolean has_videos = FALSE;
	GeeCollection* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_;
#line 529 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (import_collection), NULL);
#line 529 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (photos_msg != NULL, NULL);
#line 529 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (videos_msg != NULL, NULL);
#line 529 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (both_msg != NULL, NULL);
#line 529 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (neither_msg != NULL, NULL);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = import_collection;
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = import_ui_import_has_photos (_tmp0_);
#line 531 "/home/jens/Source/shotwell/src/Dialogs.vala"
	has_photos = _tmp1_;
#line 532 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = import_collection;
#line 532 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = import_ui_import_has_videos (_tmp2_);
#line 532 "/home/jens/Source/shotwell/src/Dialogs.vala"
	has_videos = _tmp3_;
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = has_photos;
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_) {
#line 4907 "Dialogs.c"
		gboolean _tmp6_;
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = has_videos;
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp6_;
#line 4913 "Dialogs.c"
	} else {
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = FALSE;
#line 4917 "Dialogs.c"
	}
#line 534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_) {
#line 4921 "Dialogs.c"
		const gchar* _tmp7_;
		gchar* _tmp8_;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = both_msg;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = g_strdup (_tmp7_);
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp8_;
#line 535 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 4932 "Dialogs.c"
	} else {
		gboolean _tmp9_;
#line 536 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = has_photos;
#line 536 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp9_) {
#line 4939 "Dialogs.c"
			const gchar* _tmp10_;
			gchar* _tmp11_;
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp10_ = photos_msg;
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = g_strdup (_tmp10_);
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
			result = _tmp11_;
#line 537 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return result;
#line 4950 "Dialogs.c"
		} else {
			gboolean _tmp12_;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = has_videos;
#line 538 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp12_) {
#line 4957 "Dialogs.c"
				const gchar* _tmp13_;
				gchar* _tmp14_;
#line 539 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = videos_msg;
#line 539 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp14_ = g_strdup (_tmp13_);
#line 539 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = _tmp14_;
#line 539 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 4968 "Dialogs.c"
			} else {
				const gchar* _tmp15_;
				gchar* _tmp16_;
#line 541 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp15_ = neither_msg;
#line 541 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp16_ = g_strdup (_tmp15_);
#line 541 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = _tmp16_;
#line 541 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 4980 "Dialogs.c"
			}
		}
	}
}


gchar* import_ui_create_result_report_from_manifest (ImportManifest* manifest) {
	gchar* result = NULL;
	GString* builder = NULL;
	GString* _tmp0_;
	gchar* header = NULL;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GTimeVal _tmp7_ = {0};
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	GString* _tmp14_;
	const gchar* _tmp15_;
	gchar* subhead = NULL;
	ImportManifest* _tmp16_;
	GeeList* _tmp17_;
	gint _tmp18_;
	gint _tmp19_;
	ImportManifest* _tmp20_;
	GeeList* _tmp21_;
	gint _tmp22_;
	gint _tmp23_;
	gchar* _tmp24_;
	const gchar* _tmp25_;
	gchar* _tmp26_;
	const gchar* _tmp27_;
	ImportManifest* _tmp28_;
	GeeList* _tmp29_;
	gint _tmp30_;
	gint _tmp31_;
	ImportManifest* _tmp32_;
	GeeList* _tmp33_;
	gint _tmp34_;
	gint _tmp35_;
	gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
	const gchar* _tmp39_;
	gchar* _tmp40_;
	GString* _tmp41_;
	const gchar* _tmp42_;
	gchar* current_file_summary = NULL;
	gchar* _tmp43_;
	ImportManifest* _tmp44_;
	GeeList* _tmp45_;
	gint _tmp46_;
	gint _tmp47_;
	ImportManifest* _tmp82_;
	GeeList* _tmp83_;
	gint _tmp84_;
	gint _tmp85_;
	ImportManifest* _tmp116_;
	GeeList* _tmp117_;
	gint _tmp118_;
	gint _tmp119_;
	ImportManifest* _tmp150_;
	GeeList* _tmp151_;
	gint _tmp152_;
	gint _tmp153_;
	ImportManifest* _tmp184_;
	GeeList* _tmp185_;
	gint _tmp186_;
	gint _tmp187_;
	ImportManifest* _tmp222_;
	GeeList* _tmp223_;
	gint _tmp224_;
	gint _tmp225_;
	ImportManifest* _tmp256_;
	GeeList* _tmp257_;
	gint _tmp258_;
	gint _tmp259_;
	GString* _tmp290_;
	const gchar* _tmp291_;
	gchar* _tmp292_;
#line 544 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_IMPORT_MANIFEST (manifest), NULL);
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_string_new ("");
#line 545 "/home/jens/Source/shotwell/src/Dialogs.vala"
	builder = _tmp0_;
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strconcat (_ ("Import Results Report"), " (Shotwell ", NULL);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strconcat (_tmp2_, RESOURCES_APP_VERSION, NULL);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = g_strconcat (_tmp4_, " @ ", NULL);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_get_current_time (&_tmp7_);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = g_time_val_to_iso8601 (&_tmp7_);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = g_strconcat (_tmp6_, _tmp9_, NULL);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = g_strconcat (_tmp11_, ")\n\n", NULL);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _tmp12_;
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp11_);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp9_);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp6_);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp4_);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp2_);
#line 547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	header = _tmp13_;
#line 549 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = builder;
#line 549 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = header;
#line 549 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_string_append (_tmp14_, _tmp15_);
#line 551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = manifest;
#line 551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = _tmp16_->all;
#line 551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GEE_TYPE_COLLECTION, GeeCollection));
#line 551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = _tmp18_;
#line 551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = manifest;
#line 551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = _tmp20_->all;
#line 551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GEE_TYPE_COLLECTION, GeeCollection));
#line 551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = _tmp22_;
#line 551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = g_strdup_printf (ngettext ("Attempted to import %d file.", "Attempted to import %d files.", (gulong) _tmp19_), _tmp23_);
#line 551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp24_;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = subhead;
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = g_strconcat (_tmp25_, " ", NULL);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 553 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp26_;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = subhead;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = manifest;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = _tmp28_->success;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, GEE_TYPE_COLLECTION, GeeCollection));
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = _tmp30_;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = manifest;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = _tmp32_->success;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, GEE_TYPE_COLLECTION, GeeCollection));
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = _tmp34_;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = g_strdup_printf (ngettext ("Of these, %d file was successfully imported.", "Of these, %d files were successfully imported.", (gulong) _tmp31_), _tmp35_);
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = _tmp36_;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = g_strconcat (_tmp27_, _tmp37_, NULL);
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp38_;
#line 554 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp37_);
#line 557 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = subhead;
#line 557 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = g_strconcat (_tmp39_, "\n\n", NULL);
#line 557 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 557 "/home/jens/Source/shotwell/src/Dialogs.vala"
	subhead = _tmp40_;
#line 558 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = builder;
#line 558 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = subhead;
#line 558 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_string_append (_tmp41_, _tmp42_);
#line 560 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = g_strdup ("");
#line 560 "/home/jens/Source/shotwell/src/Dialogs.vala"
	current_file_summary = _tmp43_;
#line 565 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = manifest;
#line 565 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp45_ = _tmp44_->already_imported;
#line 565 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp46_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, GEE_TYPE_COLLECTION, GeeCollection));
#line 565 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp47_ = _tmp46_;
#line 565 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp47_ > 0) {
#line 5204 "Dialogs.c"
		GString* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
#line 566 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp48_ = builder;
#line 566 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp49_ = g_strconcat (_ ("Duplicate Photos/Videos Not Imported:"), "\n\n", NULL);
#line 566 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp50_ = _tmp49_;
#line 566 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp48_, _tmp50_);
#line 566 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp50_);
#line 5218 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp51_;
			GeeList* _tmp52_;
			GeeList* _tmp53_;
			gint _result_size = 0;
			GeeList* _tmp54_;
			gint _tmp55_;
			gint _tmp56_;
			gint _result_index = 0;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp51_ = manifest;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp52_ = _tmp51_->already_imported;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp53_ = _g_object_ref0 (_tmp52_);
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp53_;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp54_ = _result_list;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp55_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, GEE_TYPE_COLLECTION, GeeCollection));
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp56_ = _tmp55_;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp56_;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 5249 "Dialogs.c"
				gint _tmp57_;
				gint _tmp58_;
				gint _tmp59_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp60_;
				gint _tmp61_;
				gpointer _tmp62_;
				BatchImportResult* _tmp63_;
				const gchar* _tmp64_;
				gchar* _tmp65_;
				gchar* _tmp66_;
				gchar* _tmp67_;
				gchar* _tmp68_;
				gchar* _tmp69_;
				gchar* _tmp70_;
				BatchImportResult* _tmp71_;
				DuplicatedFile* _tmp72_;
				GFile* _tmp73_;
				GFile* _tmp74_;
				gchar* _tmp75_;
				gchar* _tmp76_;
				gchar* _tmp77_;
				gchar* _tmp78_;
				gchar* _tmp79_;
				GString* _tmp80_;
				const gchar* _tmp81_;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp57_ = _result_index;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp57_ + 1;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp58_ = _result_index;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp59_ = _result_size;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp58_ < _tmp59_)) {
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 5288 "Dialogs.c"
				}
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp60_ = _result_list;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp61_ = _result_index;
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp62_ = gee_list_get (_tmp60_, _tmp61_);
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp62_;
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp63_ = _result_;
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp64_ = _tmp63_->src_identifier;
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp65_ = g_strconcat (_tmp64_, " ", NULL);
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp66_ = _tmp65_;
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp67_ = g_strconcat (_tmp66_, _ ("duplicates existing media item"), NULL);
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp68_ = _tmp67_;
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp69_ = g_strconcat (_tmp68_, "\n\t", NULL);
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp70_ = _tmp69_;
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp71_ = _result_;
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp72_ = _tmp71_->duplicate_of;
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp73_ = duplicated_file_get_file (_tmp72_);
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp74_ = _tmp73_;
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp75_ = g_file_get_path (_tmp74_);
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp76_ = _tmp75_;
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp77_ = g_strconcat (_tmp70_, _tmp76_, NULL);
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp78_ = _tmp77_;
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp79_ = g_strconcat (_tmp78_, "\n\n", NULL);
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp79_;
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp78_);
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp76_);
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp74_);
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp70_);
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp68_);
#line 569 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp66_);
#line 573 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp80_ = builder;
#line 573 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp81_ = current_file_summary;
#line 573 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp80_, _tmp81_);
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 5356 "Dialogs.c"
			}
#line 568 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 5360 "Dialogs.c"
		}
	}
#line 580 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp82_ = manifest;
#line 580 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp83_ = _tmp82_->camera_failed;
#line 580 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp84_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp83_, GEE_TYPE_COLLECTION, GeeCollection));
#line 580 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp85_ = _tmp84_;
#line 580 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp85_ > 0) {
#line 5373 "Dialogs.c"
		GString* _tmp86_;
		gchar* _tmp87_;
		gchar* _tmp88_;
#line 581 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp86_ = builder;
#line 581 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp87_ = g_strconcat (_ ("Photos/Videos Not Imported Due to Camera Errors:"), "\n\n", NULL);
#line 581 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp88_ = _tmp87_;
#line 581 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp86_, _tmp88_);
#line 581 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp88_);
#line 5387 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp89_;
			GeeList* _tmp90_;
			GeeList* _tmp91_;
			gint _result_size = 0;
			GeeList* _tmp92_;
			gint _tmp93_;
			gint _tmp94_;
			gint _result_index = 0;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp89_ = manifest;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp90_ = _tmp89_->camera_failed;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp91_ = _g_object_ref0 (_tmp90_);
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp91_;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp92_ = _result_list;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp93_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp92_, GEE_TYPE_COLLECTION, GeeCollection));
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp94_ = _tmp93_;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp94_;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 5418 "Dialogs.c"
				gint _tmp95_;
				gint _tmp96_;
				gint _tmp97_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp98_;
				gint _tmp99_;
				gpointer _tmp100_;
				BatchImportResult* _tmp101_;
				const gchar* _tmp102_;
				gchar* _tmp103_;
				gchar* _tmp104_;
				gchar* _tmp105_;
				gchar* _tmp106_;
				gchar* _tmp107_;
				gchar* _tmp108_;
				BatchImportResult* _tmp109_;
				const gchar* _tmp110_;
				gchar* _tmp111_;
				gchar* _tmp112_;
				gchar* _tmp113_;
				GString* _tmp114_;
				const gchar* _tmp115_;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp95_ = _result_index;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp95_ + 1;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp96_ = _result_index;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp97_ = _result_size;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp96_ < _tmp97_)) {
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 5453 "Dialogs.c"
				}
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp98_ = _result_list;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp99_ = _result_index;
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp100_ = gee_list_get (_tmp98_, _tmp99_);
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp100_;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp101_ = _result_;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp102_ = _tmp101_->src_identifier;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp103_ = g_strconcat (_tmp102_, "\n\t", NULL);
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp104_ = _tmp103_;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp105_ = g_strconcat (_tmp104_, _ ("error message:"), NULL);
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp106_ = _tmp105_;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp107_ = g_strconcat (_tmp106_, " ", NULL);
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp108_ = _tmp107_;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp109_ = _result_;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp110_ = _tmp109_->errmsg;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp111_ = g_strconcat (_tmp108_, _tmp110_, NULL);
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp112_ = _tmp111_;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp113_ = g_strconcat (_tmp112_, "\n\n", NULL);
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp113_;
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp112_);
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp108_);
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp106_);
#line 584 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp104_);
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp114_ = builder;
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp115_ = current_file_summary;
#line 587 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp114_, _tmp115_);
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 5509 "Dialogs.c"
			}
#line 583 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 5513 "Dialogs.c"
		}
	}
#line 594 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp116_ = manifest;
#line 594 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp117_ = _tmp116_->skipped_files;
#line 594 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp118_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp117_, GEE_TYPE_COLLECTION, GeeCollection));
#line 594 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp119_ = _tmp118_;
#line 594 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp119_ > 0) {
#line 5526 "Dialogs.c"
		GString* _tmp120_;
		gchar* _tmp121_;
		gchar* _tmp122_;
#line 595 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp120_ = builder;
#line 595 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp121_ = g_strconcat (_ ("Files Not Imported Because They Weren’t Recognized as Photos or Videos" \
":"), "\n\n", NULL);
#line 595 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp122_ = _tmp121_;
#line 595 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp120_, _tmp122_);
#line 595 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp122_);
#line 5540 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp123_;
			GeeList* _tmp124_;
			GeeList* _tmp125_;
			gint _result_size = 0;
			GeeList* _tmp126_;
			gint _tmp127_;
			gint _tmp128_;
			gint _result_index = 0;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp123_ = manifest;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp124_ = _tmp123_->skipped_files;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp125_ = _g_object_ref0 (_tmp124_);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp125_;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp126_ = _result_list;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp127_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp126_, GEE_TYPE_COLLECTION, GeeCollection));
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp128_ = _tmp127_;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp128_;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 5571 "Dialogs.c"
				gint _tmp129_;
				gint _tmp130_;
				gint _tmp131_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp132_;
				gint _tmp133_;
				gpointer _tmp134_;
				BatchImportResult* _tmp135_;
				const gchar* _tmp136_;
				gchar* _tmp137_;
				gchar* _tmp138_;
				gchar* _tmp139_;
				gchar* _tmp140_;
				gchar* _tmp141_;
				gchar* _tmp142_;
				BatchImportResult* _tmp143_;
				const gchar* _tmp144_;
				gchar* _tmp145_;
				gchar* _tmp146_;
				gchar* _tmp147_;
				GString* _tmp148_;
				const gchar* _tmp149_;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp129_ = _result_index;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp129_ + 1;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp130_ = _result_index;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp131_ = _result_size;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp130_ < _tmp131_)) {
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 5606 "Dialogs.c"
				}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp132_ = _result_list;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp133_ = _result_index;
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp134_ = gee_list_get (_tmp132_, _tmp133_);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp134_;
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp135_ = _result_;
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp136_ = _tmp135_->src_identifier;
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp137_ = g_strconcat (_tmp136_, "\n\t", NULL);
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp138_ = _tmp137_;
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp139_ = g_strconcat (_tmp138_, _ ("error message:"), NULL);
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp140_ = _tmp139_;
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp141_ = g_strconcat (_tmp140_, " ", NULL);
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp142_ = _tmp141_;
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp143_ = _result_;
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp144_ = _tmp143_->errmsg;
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp145_ = g_strconcat (_tmp142_, _tmp144_, NULL);
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp146_ = _tmp145_;
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp147_ = g_strconcat (_tmp146_, "\n\n", NULL);
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp147_;
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp146_);
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp142_);
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp140_);
#line 599 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp138_);
#line 602 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp148_ = builder;
#line 602 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp149_ = current_file_summary;
#line 602 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp148_, _tmp149_);
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 5662 "Dialogs.c"
			}
#line 598 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 5666 "Dialogs.c"
		}
	}
#line 609 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp150_ = manifest;
#line 609 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp151_ = _tmp150_->skipped_photos;
#line 609 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp152_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp151_, GEE_TYPE_COLLECTION, GeeCollection));
#line 609 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp153_ = _tmp152_;
#line 609 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp153_ > 0) {
#line 5679 "Dialogs.c"
		GString* _tmp154_;
		gchar* _tmp155_;
		gchar* _tmp156_;
#line 610 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp154_ = builder;
#line 610 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp155_ = g_strconcat (_ ("Photos/Videos Not Imported Because They Weren’t in a Format Shotwell U" \
"nderstands:"), "\n\n", NULL);
#line 610 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp156_ = _tmp155_;
#line 610 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp154_, _tmp156_);
#line 610 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp156_);
#line 5693 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp157_;
			GeeList* _tmp158_;
			GeeList* _tmp159_;
			gint _result_size = 0;
			GeeList* _tmp160_;
			gint _tmp161_;
			gint _tmp162_;
			gint _result_index = 0;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp157_ = manifest;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp158_ = _tmp157_->skipped_photos;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp159_ = _g_object_ref0 (_tmp158_);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp159_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp160_ = _result_list;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp161_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp160_, GEE_TYPE_COLLECTION, GeeCollection));
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp162_ = _tmp161_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp162_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 5724 "Dialogs.c"
				gint _tmp163_;
				gint _tmp164_;
				gint _tmp165_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp166_;
				gint _tmp167_;
				gpointer _tmp168_;
				BatchImportResult* _tmp169_;
				const gchar* _tmp170_;
				gchar* _tmp171_;
				gchar* _tmp172_;
				gchar* _tmp173_;
				gchar* _tmp174_;
				gchar* _tmp175_;
				gchar* _tmp176_;
				BatchImportResult* _tmp177_;
				const gchar* _tmp178_;
				gchar* _tmp179_;
				gchar* _tmp180_;
				gchar* _tmp181_;
				GString* _tmp182_;
				const gchar* _tmp183_;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp163_ = _result_index;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp163_ + 1;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp164_ = _result_index;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp165_ = _result_size;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp164_ < _tmp165_)) {
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 5759 "Dialogs.c"
				}
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp166_ = _result_list;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp167_ = _result_index;
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp168_ = gee_list_get (_tmp166_, _tmp167_);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp168_;
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp169_ = _result_;
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp170_ = _tmp169_->src_identifier;
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp171_ = g_strconcat (_tmp170_, "\n\t", NULL);
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp172_ = _tmp171_;
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp173_ = g_strconcat (_tmp172_, _ ("error message:"), NULL);
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp174_ = _tmp173_;
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp175_ = g_strconcat (_tmp174_, " ", NULL);
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp176_ = _tmp175_;
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp177_ = _result_;
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp178_ = _tmp177_->errmsg;
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp179_ = g_strconcat (_tmp176_, _tmp178_, NULL);
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp180_ = _tmp179_;
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp181_ = g_strconcat (_tmp180_, "\n\n", NULL);
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp181_;
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp180_);
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp176_);
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp174_);
#line 614 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp172_);
#line 617 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp182_ = builder;
#line 617 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp183_ = current_file_summary;
#line 617 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp182_, _tmp183_);
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 5815 "Dialogs.c"
			}
#line 613 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 5819 "Dialogs.c"
		}
	}
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp184_ = manifest;
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp185_ = _tmp184_->write_failed;
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp186_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp185_, GEE_TYPE_COLLECTION, GeeCollection));
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp187_ = _tmp186_;
#line 624 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp187_ > 0) {
#line 5832 "Dialogs.c"
		GString* _tmp188_;
		gchar* _tmp189_;
		gchar* _tmp190_;
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp188_ = builder;
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp189_ = g_strconcat (_ ("Photos/Videos Not Imported Because Shotwell Couldn’t Copy Them into it" \
"s Library:"), "\n\n", NULL);
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp190_ = _tmp189_;
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp188_, _tmp190_);
#line 625 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp190_);
#line 5846 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp191_;
			GeeList* _tmp192_;
			GeeList* _tmp193_;
			gint _result_size = 0;
			GeeList* _tmp194_;
			gint _tmp195_;
			gint _tmp196_;
			gint _result_index = 0;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp191_ = manifest;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp192_ = _tmp191_->write_failed;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp193_ = _g_object_ref0 (_tmp192_);
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp193_;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp194_ = _result_list;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp195_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp194_, GEE_TYPE_COLLECTION, GeeCollection));
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp196_ = _tmp195_;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp196_;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 5877 "Dialogs.c"
				gint _tmp197_;
				gint _tmp198_;
				gint _tmp199_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp200_;
				gint _tmp201_;
				gpointer _tmp202_;
				BatchImportResult* _tmp203_;
				const gchar* _tmp204_;
				BatchImportResult* _tmp205_;
				const gchar* _tmp206_;
				gchar* _tmp207_;
				gchar* _tmp208_;
				gchar* _tmp209_;
				gchar* _tmp210_;
				gchar* _tmp211_;
				gchar* _tmp212_;
				gchar* _tmp213_;
				gchar* _tmp214_;
				BatchImportResult* _tmp215_;
				const gchar* _tmp216_;
				gchar* _tmp217_;
				gchar* _tmp218_;
				gchar* _tmp219_;
				GString* _tmp220_;
				const gchar* _tmp221_;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp197_ = _result_index;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp197_ + 1;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp198_ = _result_index;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp199_ = _result_size;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp198_ < _tmp199_)) {
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 5916 "Dialogs.c"
				}
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp200_ = _result_list;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp201_ = _result_index;
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp202_ = gee_list_get (_tmp200_, _tmp201_);
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp202_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp203_ = _result_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp204_ = _tmp203_->src_identifier;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp205_ = _result_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp206_ = _tmp205_->dest_identifier;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp207_ = g_strdup_printf (_ ("couldn’t copy %s\n\tto %s"), _tmp204_, _tmp206_);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp208_ = _tmp207_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp209_ = g_strconcat (_tmp208_, "\n\t", NULL);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp210_ = _tmp209_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp211_ = g_strconcat (_tmp210_, _ ("error message:"), NULL);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp212_ = _tmp211_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp213_ = g_strconcat (_tmp212_, " ", NULL);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp214_ = _tmp213_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp215_ = _result_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp216_ = _tmp215_->errmsg;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp217_ = g_strconcat (_tmp214_, _tmp216_, NULL);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp218_ = _tmp217_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp219_ = g_strconcat (_tmp218_, "\n\n", NULL);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp219_;
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp218_);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp214_);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp212_);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp210_);
#line 629 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp208_);
#line 633 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp220_ = builder;
#line 633 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp221_ = current_file_summary;
#line 633 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp220_, _tmp221_);
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 5982 "Dialogs.c"
			}
#line 628 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 5986 "Dialogs.c"
		}
	}
#line 640 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp222_ = manifest;
#line 640 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp223_ = _tmp222_->corrupt_files;
#line 640 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp224_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp223_, GEE_TYPE_COLLECTION, GeeCollection));
#line 640 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp225_ = _tmp224_;
#line 640 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp225_ > 0) {
#line 5999 "Dialogs.c"
		GString* _tmp226_;
		gchar* _tmp227_;
		gchar* _tmp228_;
#line 641 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp226_ = builder;
#line 641 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp227_ = g_strconcat (_ ("Photos/Videos Not Imported Because Files Are Corrupt:"), "\n\n", NULL);
#line 641 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp228_ = _tmp227_;
#line 641 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp226_, _tmp228_);
#line 641 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp228_);
#line 6013 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp229_;
			GeeList* _tmp230_;
			GeeList* _tmp231_;
			gint _result_size = 0;
			GeeList* _tmp232_;
			gint _tmp233_;
			gint _tmp234_;
			gint _result_index = 0;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp229_ = manifest;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp230_ = _tmp229_->corrupt_files;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp231_ = _g_object_ref0 (_tmp230_);
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp231_;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp232_ = _result_list;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp233_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp232_, GEE_TYPE_COLLECTION, GeeCollection));
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp234_ = _tmp233_;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp234_;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 6044 "Dialogs.c"
				gint _tmp235_;
				gint _tmp236_;
				gint _tmp237_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp238_;
				gint _tmp239_;
				gpointer _tmp240_;
				BatchImportResult* _tmp241_;
				const gchar* _tmp242_;
				gchar* _tmp243_;
				gchar* _tmp244_;
				gchar* _tmp245_;
				gchar* _tmp246_;
				gchar* _tmp247_;
				gchar* _tmp248_;
				BatchImportResult* _tmp249_;
				const gchar* _tmp250_;
				gchar* _tmp251_;
				gchar* _tmp252_;
				gchar* _tmp253_;
				GString* _tmp254_;
				const gchar* _tmp255_;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp235_ = _result_index;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp235_ + 1;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp236_ = _result_index;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp237_ = _result_size;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp236_ < _tmp237_)) {
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 6079 "Dialogs.c"
				}
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp238_ = _result_list;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp239_ = _result_index;
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp240_ = gee_list_get (_tmp238_, _tmp239_);
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp240_;
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp241_ = _result_;
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp242_ = _tmp241_->src_identifier;
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp243_ = g_strconcat (_tmp242_, "\n\t", NULL);
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp244_ = _tmp243_;
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp245_ = g_strconcat (_tmp244_, _ ("error message:"), NULL);
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp246_ = _tmp245_;
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp247_ = g_strconcat (_tmp246_, " |", NULL);
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp248_ = _tmp247_;
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp249_ = _result_;
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp250_ = _tmp249_->errmsg;
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp251_ = g_strconcat (_tmp248_, _tmp250_, NULL);
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp252_ = _tmp251_;
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp253_ = g_strconcat (_tmp252_, "|\n\n", NULL);
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp253_;
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp252_);
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp248_);
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp246_);
#line 645 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp244_);
#line 648 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp254_ = builder;
#line 648 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp255_ = current_file_summary;
#line 648 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp254_, _tmp255_);
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 6135 "Dialogs.c"
			}
#line 644 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 6139 "Dialogs.c"
		}
	}
#line 655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp256_ = manifest;
#line 655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp257_ = _tmp256_->failed;
#line 655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp258_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp257_, GEE_TYPE_COLLECTION, GeeCollection));
#line 655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp259_ = _tmp258_;
#line 655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp259_ > 0) {
#line 6152 "Dialogs.c"
		GString* _tmp260_;
		gchar* _tmp261_;
		gchar* _tmp262_;
#line 656 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp260_ = builder;
#line 656 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp261_ = g_strconcat (_ ("Photos/Videos Not Imported for Other Reasons:"), "\n\n", NULL);
#line 656 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp262_ = _tmp261_;
#line 656 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_string_append (_tmp260_, _tmp262_);
#line 656 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp262_);
#line 6166 "Dialogs.c"
		{
			GeeList* _result_list = NULL;
			ImportManifest* _tmp263_;
			GeeList* _tmp264_;
			GeeList* _tmp265_;
			gint _result_size = 0;
			GeeList* _tmp266_;
			gint _tmp267_;
			gint _tmp268_;
			gint _result_index = 0;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp263_ = manifest;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp264_ = _tmp263_->failed;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp265_ = _g_object_ref0 (_tmp264_);
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_list = _tmp265_;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp266_ = _result_list;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp267_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp266_, GEE_TYPE_COLLECTION, GeeCollection));
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp268_ = _tmp267_;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_size = _tmp268_;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_result_index = -1;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 6197 "Dialogs.c"
				gint _tmp269_;
				gint _tmp270_;
				gint _tmp271_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp272_;
				gint _tmp273_;
				gpointer _tmp274_;
				BatchImportResult* _tmp275_;
				const gchar* _tmp276_;
				gchar* _tmp277_;
				gchar* _tmp278_;
				gchar* _tmp279_;
				gchar* _tmp280_;
				gchar* _tmp281_;
				gchar* _tmp282_;
				BatchImportResult* _tmp283_;
				const gchar* _tmp284_;
				gchar* _tmp285_;
				gchar* _tmp286_;
				gchar* _tmp287_;
				GString* _tmp288_;
				const gchar* _tmp289_;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp269_ = _result_index;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_index = _tmp269_ + 1;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp270_ = _result_index;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp271_ = _result_size;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp270_ < _tmp271_)) {
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 6232 "Dialogs.c"
				}
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp272_ = _result_list;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp273_ = _result_index;
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp274_ = gee_list_get (_tmp272_, _tmp273_);
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_result_ = (BatchImportResult*) _tmp274_;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp275_ = _result_;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp276_ = _tmp275_->src_identifier;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp277_ = g_strconcat (_tmp276_, "\n\t", NULL);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp278_ = _tmp277_;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp279_ = g_strconcat (_tmp278_, _ ("error message:"), NULL);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp280_ = _tmp279_;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp281_ = g_strconcat (_tmp280_, " ", NULL);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp282_ = _tmp281_;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp283_ = _result_;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp284_ = _tmp283_->errmsg;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp285_ = g_strconcat (_tmp282_, _tmp284_, NULL);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp286_ = _tmp285_;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp287_ = g_strconcat (_tmp286_, "\n\n", NULL);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (current_file_summary);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_file_summary = _tmp287_;
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp286_);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp282_);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp280_);
#line 659 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp278_);
#line 662 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp288_ = builder;
#line 662 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp289_ = current_file_summary;
#line 662 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_string_append (_tmp288_, _tmp289_);
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_batch_import_result_unref0 (_result_);
#line 6288 "Dialogs.c"
			}
#line 658 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_result_list);
#line 6292 "Dialogs.c"
		}
	}
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp290_ = builder;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp291_ = _tmp290_->str;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp292_ = g_strdup (_tmp291_);
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp292_;
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (current_file_summary);
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (subhead);
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (header);
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_string_free0 (builder);
#line 666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 6313 "Dialogs.c"
}


gboolean import_ui_report_manifest (ImportManifest* manifest, gboolean show_dest_id, ImportUIQuestionParams* question) {
	gboolean result = FALSE;
	gchar* message = NULL;
	gchar* _tmp0_;
	ImportManifest* _tmp1_;
	GeeList* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	ImportManifest* _tmp49_;
	GeeList* _tmp50_;
	gint _tmp51_;
	gint _tmp52_;
	ImportManifest* _tmp111_;
	GeeList* _tmp112_;
	gint _tmp113_;
	gint _tmp114_;
	ImportManifest* _tmp173_;
	GeeList* _tmp174_;
	gint _tmp175_;
	gint _tmp176_;
	ImportManifest* _tmp235_;
	GeeList* _tmp236_;
	gint _tmp237_;
	gint _tmp238_;
	ImportManifest* _tmp297_;
	GeeList* _tmp298_;
	gint _tmp299_;
	gint _tmp300_;
	ImportManifest* _tmp325_;
	GeeList* _tmp326_;
	gint _tmp327_;
	gint _tmp328_;
	ImportManifest* _tmp346_;
	GeeList* _tmp347_;
	gint _tmp348_;
	gint _tmp349_;
	ImportManifest* _tmp408_;
	GeeList* _tmp409_;
	gint _tmp410_;
	gint _tmp411_;
	gint total = 0;
	ImportManifest* _tmp453_;
	GeeList* _tmp454_;
	gint _tmp455_;
	gint _tmp456_;
	ImportManifest* _tmp457_;
	GeeList* _tmp458_;
	gint _tmp459_;
	gint _tmp460_;
	ImportManifest* _tmp461_;
	GeeList* _tmp462_;
	gint _tmp463_;
	gint _tmp464_;
	ImportManifest* _tmp465_;
	GeeList* _tmp466_;
	gint _tmp467_;
	gint _tmp468_;
	ImportManifest* _tmp469_;
	GeeList* _tmp470_;
	gint _tmp471_;
	gint _tmp472_;
	ImportManifest* _tmp473_;
	GeeList* _tmp474_;
	gint _tmp475_;
	gint _tmp476_;
	ImportManifest* _tmp477_;
	GeeList* _tmp478_;
	gint _tmp479_;
	gint _tmp480_;
	ImportManifest* _tmp481_;
	GeeList* _tmp482_;
	gint _tmp483_;
	gint _tmp484_;
	ImportManifest* _tmp485_;
	GeeList* _tmp486_;
	gint _tmp487_;
	gint _tmp488_;
	gint _tmp489_;
	ImportManifest* _tmp490_;
	GeeList* _tmp491_;
	gint _tmp492_;
	gint _tmp493_;
	gint _tmp494_;
	GtkMessageDialog* dialog = NULL;
	gint dialog_response = 0;
	ImportUIQuestionParams* _tmp497_;
	gint _tmp575_;
#line 671 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_IMPORT_MANIFEST (manifest), FALSE);
#line 671 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail ((question == NULL) || IMPORT_UI_IS_QUESTION_PARAMS (question), FALSE);
#line 673 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strdup ("");
#line 673 "/home/jens/Source/shotwell/src/Dialogs.vala"
	message = _tmp0_;
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = manifest;
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_->already_imported;
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection));
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_ > 0) {
#line 6422 "Dialogs.c"
		gchar* photos_message = NULL;
		ImportManifest* _tmp5_;
		GeeList* _tmp6_;
		gint _tmp7_;
		gint _tmp8_;
		ImportManifest* _tmp9_;
		GeeList* _tmp10_;
		gint _tmp11_;
		gint _tmp12_;
		gchar* _tmp13_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp14_;
		GeeList* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		ImportManifest* _tmp18_;
		GeeList* _tmp19_;
		gint _tmp20_;
		gint _tmp21_;
		gchar* _tmp22_;
		gchar* both_message = NULL;
		ImportManifest* _tmp23_;
		GeeList* _tmp24_;
		gint _tmp25_;
		gint _tmp26_;
		ImportManifest* _tmp27_;
		GeeList* _tmp28_;
		gint _tmp29_;
		gint _tmp30_;
		gchar* _tmp31_;
		const gchar* _tmp32_;
		ImportManifest* _tmp33_;
		GeeList* _tmp34_;
		const gchar* _tmp35_;
		const gchar* _tmp36_;
		const gchar* _tmp37_;
		const gchar* _tmp38_;
		gchar* _tmp39_;
		gchar* _tmp40_;
		gchar* _tmp41_;
		const gchar* _tmp42_;
		ImportManifest* _tmp43_;
		GeeList* _tmp44_;
		gboolean _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = manifest;
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _tmp5_->already_imported;
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_COLLECTION, GeeCollection));
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = _tmp7_;
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = manifest;
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp9_->already_imported;
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_COLLECTION, GeeCollection));
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = _tmp11_;
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = g_strdup_printf (ngettext ("1 duplicate photo was not imported:\n", "%d duplicate photos were not imported:\n", (gulong) _tmp8_), _tmp12_);
#line 676 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp13_;
#line 679 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = manifest;
#line 679 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = _tmp14_->already_imported;
#line 679 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GEE_TYPE_COLLECTION, GeeCollection));
#line 679 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = _tmp16_;
#line 679 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = manifest;
#line 679 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = _tmp18_->already_imported;
#line 679 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_COLLECTION, GeeCollection));
#line 679 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = _tmp20_;
#line 679 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = g_strdup_printf (ngettext ("1 duplicate video was not imported:\n", "%d duplicate videos were not imported:\n", (gulong) _tmp17_), _tmp21_);
#line 679 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp22_;
#line 682 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = manifest;
#line 682 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = _tmp23_->already_imported;
#line 682 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, GEE_TYPE_COLLECTION, GeeCollection));
#line 682 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = _tmp25_;
#line 682 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = manifest;
#line 682 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = _tmp27_->already_imported;
#line 682 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, GEE_TYPE_COLLECTION, GeeCollection));
#line 682 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = _tmp29_;
#line 682 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp31_ = g_strdup_printf (ngettext ("1 duplicate photo/video was not imported:\n", "%d duplicate photos/videos were not imported:\n", (gulong) _tmp26_), _tmp30_);
#line 682 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp31_;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = message;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = manifest;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = _tmp33_->already_imported;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp35_ = photos_message;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp36_ = videos_message;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp37_ = both_message;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp38_ = both_message;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp39_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, GEE_TYPE_COLLECTION, GeeCollection), _tmp35_, _tmp36_, _tmp37_, _tmp38_);
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp40_ = _tmp39_;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp41_ = g_strconcat (_tmp32_, _tmp40_, NULL);
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp41_;
#line 686 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp40_);
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp42_ = message;
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp43_ = manifest;
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp44_ = _tmp43_->already_imported;
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp45_ = show_dest_id;
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp46_ = import_ui_generate_import_failure_list (_tmp44_, _tmp45_);
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp47_ = _tmp46_;
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp48_ = g_strconcat (_tmp42_, _tmp47_, NULL);
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp48_;
#line 689 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp47_);
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 675 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 6582 "Dialogs.c"
	}
#line 692 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp49_ = manifest;
#line 692 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp50_ = _tmp49_->failed;
#line 692 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp51_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, GEE_TYPE_COLLECTION, GeeCollection));
#line 692 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp52_ = _tmp51_;
#line 692 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp52_ > 0) {
#line 6594 "Dialogs.c"
		const gchar* _tmp53_;
		gint _tmp54_;
		gint _tmp55_;
		gchar* photos_message = NULL;
		ImportManifest* _tmp58_;
		GeeList* _tmp59_;
		gint _tmp60_;
		gint _tmp61_;
		ImportManifest* _tmp62_;
		GeeList* _tmp63_;
		gint _tmp64_;
		gint _tmp65_;
		gchar* _tmp66_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp67_;
		GeeList* _tmp68_;
		gint _tmp69_;
		gint _tmp70_;
		ImportManifest* _tmp71_;
		GeeList* _tmp72_;
		gint _tmp73_;
		gint _tmp74_;
		gchar* _tmp75_;
		gchar* both_message = NULL;
		ImportManifest* _tmp76_;
		GeeList* _tmp77_;
		gint _tmp78_;
		gint _tmp79_;
		ImportManifest* _tmp80_;
		GeeList* _tmp81_;
		gint _tmp82_;
		gint _tmp83_;
		gchar* _tmp84_;
		gchar* neither_message = NULL;
		ImportManifest* _tmp85_;
		GeeList* _tmp86_;
		gint _tmp87_;
		gint _tmp88_;
		ImportManifest* _tmp89_;
		GeeList* _tmp90_;
		gint _tmp91_;
		gint _tmp92_;
		gchar* _tmp93_;
		const gchar* _tmp94_;
		ImportManifest* _tmp95_;
		GeeList* _tmp96_;
		const gchar* _tmp97_;
		const gchar* _tmp98_;
		const gchar* _tmp99_;
		const gchar* _tmp100_;
		gchar* _tmp101_;
		gchar* _tmp102_;
		gchar* _tmp103_;
		const gchar* _tmp104_;
		ImportManifest* _tmp105_;
		GeeList* _tmp106_;
		gboolean _tmp107_;
		gchar* _tmp108_;
		gchar* _tmp109_;
		gchar* _tmp110_;
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp53_ = message;
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp54_ = strlen (_tmp53_);
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp55_ = _tmp54_;
#line 693 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp55_ > 0) {
#line 6663 "Dialogs.c"
			const gchar* _tmp56_;
			gchar* _tmp57_;
#line 694 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp56_ = message;
#line 694 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp57_ = g_strconcat (_tmp56_, "\n", NULL);
#line 694 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 694 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp57_;
#line 6674 "Dialogs.c"
		}
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp58_ = manifest;
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp59_ = _tmp58_->failed;
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp60_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp59_, GEE_TYPE_COLLECTION, GeeCollection));
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp61_ = _tmp60_;
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp62_ = manifest;
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp63_ = _tmp62_->failed;
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp64_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp63_, GEE_TYPE_COLLECTION, GeeCollection));
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp65_ = _tmp64_;
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp66_ = g_strdup_printf (ngettext ("1 photo failed to import due to a file or hardware error:\n", "%d photos failed to import due to a file or hardware error:\n", (gulong) _tmp61_), _tmp65_);
#line 696 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp66_;
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp67_ = manifest;
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp68_ = _tmp67_->failed;
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp69_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, GEE_TYPE_COLLECTION, GeeCollection));
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp70_ = _tmp69_;
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp71_ = manifest;
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp72_ = _tmp71_->failed;
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp73_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, GEE_TYPE_COLLECTION, GeeCollection));
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp74_ = _tmp73_;
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp75_ = g_strdup_printf (ngettext ("1 video failed to import due to a file or hardware error:\n", "%d videos failed to import due to a file or hardware error:\n", (gulong) _tmp70_), _tmp74_);
#line 699 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp75_;
#line 702 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp76_ = manifest;
#line 702 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp77_ = _tmp76_->failed;
#line 702 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp78_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp77_, GEE_TYPE_COLLECTION, GeeCollection));
#line 702 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp79_ = _tmp78_;
#line 702 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp80_ = manifest;
#line 702 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp81_ = _tmp80_->failed;
#line 702 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp82_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp81_, GEE_TYPE_COLLECTION, GeeCollection));
#line 702 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp83_ = _tmp82_;
#line 702 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp84_ = g_strdup_printf (ngettext ("1 photo/video failed to import due to a file or hardware error:\n", "%d photos/videos failed to import due to a file or hardware error:\n", (gulong) _tmp79_), _tmp83_);
#line 702 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp84_;
#line 705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp85_ = manifest;
#line 705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp86_ = _tmp85_->failed;
#line 705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp87_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp86_, GEE_TYPE_COLLECTION, GeeCollection));
#line 705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp88_ = _tmp87_;
#line 705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp89_ = manifest;
#line 705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp90_ = _tmp89_->failed;
#line 705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp91_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp90_, GEE_TYPE_COLLECTION, GeeCollection));
#line 705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp92_ = _tmp91_;
#line 705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp93_ = g_strdup_printf (ngettext ("1 file failed to import due to a file or hardware error:\n", "%d files failed to import due to a file or hardware error:\n", (gulong) _tmp88_), _tmp92_);
#line 705 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp93_;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp94_ = message;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp95_ = manifest;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp96_ = _tmp95_->failed;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp97_ = photos_message;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp98_ = videos_message;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp99_ = both_message;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp100_ = neither_message;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp101_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp96_, GEE_TYPE_COLLECTION, GeeCollection), _tmp97_, _tmp98_, _tmp99_, _tmp100_);
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp102_ = _tmp101_;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp103_ = g_strconcat (_tmp94_, _tmp102_, NULL);
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp103_;
#line 709 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp102_);
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp104_ = message;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp105_ = manifest;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp106_ = _tmp105_->failed;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp107_ = show_dest_id;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp108_ = import_ui_generate_import_failure_list (_tmp106_, _tmp107_);
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp109_ = _tmp108_;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp110_ = g_strconcat (_tmp104_, _tmp109_, NULL);
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp110_;
#line 712 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp109_);
#line 692 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 692 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 692 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 692 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 6810 "Dialogs.c"
	}
#line 715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp111_ = manifest;
#line 715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp112_ = _tmp111_->write_failed;
#line 715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp113_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp112_, GEE_TYPE_COLLECTION, GeeCollection));
#line 715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp114_ = _tmp113_;
#line 715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp114_ > 0) {
#line 6822 "Dialogs.c"
		const gchar* _tmp115_;
		gint _tmp116_;
		gint _tmp117_;
		gchar* photos_message = NULL;
		ImportManifest* _tmp120_;
		GeeList* _tmp121_;
		gint _tmp122_;
		gint _tmp123_;
		ImportManifest* _tmp124_;
		GeeList* _tmp125_;
		gint _tmp126_;
		gint _tmp127_;
		gchar* _tmp128_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp129_;
		GeeList* _tmp130_;
		gint _tmp131_;
		gint _tmp132_;
		ImportManifest* _tmp133_;
		GeeList* _tmp134_;
		gint _tmp135_;
		gint _tmp136_;
		gchar* _tmp137_;
		gchar* both_message = NULL;
		ImportManifest* _tmp138_;
		GeeList* _tmp139_;
		gint _tmp140_;
		gint _tmp141_;
		ImportManifest* _tmp142_;
		GeeList* _tmp143_;
		gint _tmp144_;
		gint _tmp145_;
		gchar* _tmp146_;
		gchar* neither_message = NULL;
		ImportManifest* _tmp147_;
		GeeList* _tmp148_;
		gint _tmp149_;
		gint _tmp150_;
		ImportManifest* _tmp151_;
		GeeList* _tmp152_;
		gint _tmp153_;
		gint _tmp154_;
		gchar* _tmp155_;
		const gchar* _tmp156_;
		ImportManifest* _tmp157_;
		GeeList* _tmp158_;
		const gchar* _tmp159_;
		const gchar* _tmp160_;
		const gchar* _tmp161_;
		const gchar* _tmp162_;
		gchar* _tmp163_;
		gchar* _tmp164_;
		gchar* _tmp165_;
		const gchar* _tmp166_;
		ImportManifest* _tmp167_;
		GeeList* _tmp168_;
		gboolean _tmp169_;
		gchar* _tmp170_;
		gchar* _tmp171_;
		gchar* _tmp172_;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp115_ = message;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp116_ = strlen (_tmp115_);
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp117_ = _tmp116_;
#line 716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp117_ > 0) {
#line 6891 "Dialogs.c"
			const gchar* _tmp118_;
			gchar* _tmp119_;
#line 717 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp118_ = message;
#line 717 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp119_ = g_strconcat (_tmp118_, "\n", NULL);
#line 717 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 717 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp119_;
#line 6902 "Dialogs.c"
		}
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp120_ = manifest;
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp121_ = _tmp120_->write_failed;
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp122_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp121_, GEE_TYPE_COLLECTION, GeeCollection));
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp123_ = _tmp122_;
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp124_ = manifest;
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp125_ = _tmp124_->write_failed;
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp126_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp125_, GEE_TYPE_COLLECTION, GeeCollection));
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp127_ = _tmp126_;
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp128_ = g_strdup_printf (ngettext ("1 photo failed to import because the photo library folder was not writ" \
"able:\n", "%d photos failed to import because the photo library folder was not wr" \
"itable:\n", (gulong) _tmp123_), _tmp127_);
#line 719 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp128_;
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp129_ = manifest;
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp130_ = _tmp129_->write_failed;
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp131_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp130_, GEE_TYPE_COLLECTION, GeeCollection));
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp132_ = _tmp131_;
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp133_ = manifest;
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp134_ = _tmp133_->write_failed;
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp135_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp134_, GEE_TYPE_COLLECTION, GeeCollection));
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp136_ = _tmp135_;
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp137_ = g_strdup_printf (ngettext ("1 video failed to import because the photo library folder was not writ" \
"able:\n", "%d videos failed to import because the photo library folder was not wr" \
"itable:\n", (gulong) _tmp132_), _tmp136_);
#line 722 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp137_;
#line 725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp138_ = manifest;
#line 725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp139_ = _tmp138_->write_failed;
#line 725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp140_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp139_, GEE_TYPE_COLLECTION, GeeCollection));
#line 725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp141_ = _tmp140_;
#line 725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp142_ = manifest;
#line 725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp143_ = _tmp142_->write_failed;
#line 725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp144_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp143_, GEE_TYPE_COLLECTION, GeeCollection));
#line 725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp145_ = _tmp144_;
#line 725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp146_ = g_strdup_printf (ngettext ("1 photo/video failed to import because the photo library folder was no" \
"t writable:\n", "%d photos/videos failed to import because the photo library folder was" \
" not writable:\n", (gulong) _tmp141_), _tmp145_);
#line 725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp146_;
#line 728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp147_ = manifest;
#line 728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp148_ = _tmp147_->write_failed;
#line 728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp149_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp148_, GEE_TYPE_COLLECTION, GeeCollection));
#line 728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp150_ = _tmp149_;
#line 728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp151_ = manifest;
#line 728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp152_ = _tmp151_->write_failed;
#line 728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp153_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp152_, GEE_TYPE_COLLECTION, GeeCollection));
#line 728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp154_ = _tmp153_;
#line 728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp155_ = g_strdup_printf (ngettext ("1 file failed to import because the photo library folder was not writa" \
"ble:\n", "%d files failed to import because the photo library folder was not wri" \
"table:\n", (gulong) _tmp150_), _tmp154_);
#line 728 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp155_;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp156_ = message;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp157_ = manifest;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp158_ = _tmp157_->write_failed;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp159_ = photos_message;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp160_ = videos_message;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp161_ = both_message;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp162_ = neither_message;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp163_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp158_, GEE_TYPE_COLLECTION, GeeCollection), _tmp159_, _tmp160_, _tmp161_, _tmp162_);
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp164_ = _tmp163_;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp165_ = g_strconcat (_tmp156_, _tmp164_, NULL);
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp165_;
#line 732 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp164_);
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp166_ = message;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp167_ = manifest;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp168_ = _tmp167_->write_failed;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp169_ = show_dest_id;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp170_ = import_ui_generate_import_failure_list (_tmp168_, _tmp169_);
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp171_ = _tmp170_;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp172_ = g_strconcat (_tmp166_, _tmp171_, NULL);
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp172_;
#line 735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp171_);
#line 715 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 715 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 715 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 715 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 7038 "Dialogs.c"
	}
#line 738 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp173_ = manifest;
#line 738 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp174_ = _tmp173_->camera_failed;
#line 738 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp175_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp174_, GEE_TYPE_COLLECTION, GeeCollection));
#line 738 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp176_ = _tmp175_;
#line 738 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp176_ > 0) {
#line 7050 "Dialogs.c"
		const gchar* _tmp177_;
		gint _tmp178_;
		gint _tmp179_;
		gchar* photos_message = NULL;
		ImportManifest* _tmp182_;
		GeeList* _tmp183_;
		gint _tmp184_;
		gint _tmp185_;
		ImportManifest* _tmp186_;
		GeeList* _tmp187_;
		gint _tmp188_;
		gint _tmp189_;
		gchar* _tmp190_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp191_;
		GeeList* _tmp192_;
		gint _tmp193_;
		gint _tmp194_;
		ImportManifest* _tmp195_;
		GeeList* _tmp196_;
		gint _tmp197_;
		gint _tmp198_;
		gchar* _tmp199_;
		gchar* both_message = NULL;
		ImportManifest* _tmp200_;
		GeeList* _tmp201_;
		gint _tmp202_;
		gint _tmp203_;
		ImportManifest* _tmp204_;
		GeeList* _tmp205_;
		gint _tmp206_;
		gint _tmp207_;
		gchar* _tmp208_;
		gchar* neither_message = NULL;
		ImportManifest* _tmp209_;
		GeeList* _tmp210_;
		gint _tmp211_;
		gint _tmp212_;
		ImportManifest* _tmp213_;
		GeeList* _tmp214_;
		gint _tmp215_;
		gint _tmp216_;
		gchar* _tmp217_;
		const gchar* _tmp218_;
		ImportManifest* _tmp219_;
		GeeList* _tmp220_;
		const gchar* _tmp221_;
		const gchar* _tmp222_;
		const gchar* _tmp223_;
		const gchar* _tmp224_;
		gchar* _tmp225_;
		gchar* _tmp226_;
		gchar* _tmp227_;
		const gchar* _tmp228_;
		ImportManifest* _tmp229_;
		GeeList* _tmp230_;
		gboolean _tmp231_;
		gchar* _tmp232_;
		gchar* _tmp233_;
		gchar* _tmp234_;
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp177_ = message;
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp178_ = strlen (_tmp177_);
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp179_ = _tmp178_;
#line 739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp179_ > 0) {
#line 7119 "Dialogs.c"
			const gchar* _tmp180_;
			gchar* _tmp181_;
#line 740 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp180_ = message;
#line 740 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp181_ = g_strconcat (_tmp180_, "\n", NULL);
#line 740 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 740 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp181_;
#line 7130 "Dialogs.c"
		}
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp182_ = manifest;
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp183_ = _tmp182_->camera_failed;
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp184_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp183_, GEE_TYPE_COLLECTION, GeeCollection));
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp185_ = _tmp184_;
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp186_ = manifest;
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp187_ = _tmp186_->camera_failed;
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp188_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp187_, GEE_TYPE_COLLECTION, GeeCollection));
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp189_ = _tmp188_;
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp190_ = g_strdup_printf (ngettext ("1 photo failed to import due to a camera error:\n", "%d photos failed to import due to a camera error:\n", (gulong) _tmp185_), _tmp189_);
#line 742 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp190_;
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp191_ = manifest;
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp192_ = _tmp191_->camera_failed;
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp193_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp192_, GEE_TYPE_COLLECTION, GeeCollection));
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp194_ = _tmp193_;
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp195_ = manifest;
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp196_ = _tmp195_->camera_failed;
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp197_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp196_, GEE_TYPE_COLLECTION, GeeCollection));
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp198_ = _tmp197_;
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp199_ = g_strdup_printf (ngettext ("1 video failed to import due to a camera error:\n", "%d videos failed to import due to a camera error:\n", (gulong) _tmp194_), _tmp198_);
#line 745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp199_;
#line 748 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp200_ = manifest;
#line 748 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp201_ = _tmp200_->camera_failed;
#line 748 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp202_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp201_, GEE_TYPE_COLLECTION, GeeCollection));
#line 748 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp203_ = _tmp202_;
#line 748 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp204_ = manifest;
#line 748 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp205_ = _tmp204_->camera_failed;
#line 748 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp206_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp205_, GEE_TYPE_COLLECTION, GeeCollection));
#line 748 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp207_ = _tmp206_;
#line 748 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp208_ = g_strdup_printf (ngettext ("1 photo/video failed to import due to a camera error:\n", "%d photos/videos failed to import due to a camera error:\n", (gulong) _tmp203_), _tmp207_);
#line 748 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp208_;
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp209_ = manifest;
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp210_ = _tmp209_->camera_failed;
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp211_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp210_, GEE_TYPE_COLLECTION, GeeCollection));
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp212_ = _tmp211_;
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp213_ = manifest;
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp214_ = _tmp213_->camera_failed;
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp215_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp214_, GEE_TYPE_COLLECTION, GeeCollection));
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp216_ = _tmp215_;
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp217_ = g_strdup_printf (ngettext ("1 file failed to import due to a camera error:\n", "%d files failed to import due to a camera error:\n", (gulong) _tmp212_), _tmp216_);
#line 751 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp217_;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp218_ = message;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp219_ = manifest;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp220_ = _tmp219_->camera_failed;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp221_ = photos_message;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp222_ = videos_message;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp223_ = both_message;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp224_ = neither_message;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp225_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp220_, GEE_TYPE_COLLECTION, GeeCollection), _tmp221_, _tmp222_, _tmp223_, _tmp224_);
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp226_ = _tmp225_;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp227_ = g_strconcat (_tmp218_, _tmp226_, NULL);
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp227_;
#line 755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp226_);
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp228_ = message;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp229_ = manifest;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp230_ = _tmp229_->camera_failed;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp231_ = show_dest_id;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp232_ = import_ui_generate_import_failure_list (_tmp230_, _tmp231_);
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp233_ = _tmp232_;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp234_ = g_strconcat (_tmp228_, _tmp233_, NULL);
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp234_;
#line 758 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp233_);
#line 738 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 738 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 738 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 738 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 7266 "Dialogs.c"
	}
#line 761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp235_ = manifest;
#line 761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp236_ = _tmp235_->corrupt_files;
#line 761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp237_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp236_, GEE_TYPE_COLLECTION, GeeCollection));
#line 761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp238_ = _tmp237_;
#line 761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp238_ > 0) {
#line 7278 "Dialogs.c"
		const gchar* _tmp239_;
		gint _tmp240_;
		gint _tmp241_;
		gchar* photos_message = NULL;
		ImportManifest* _tmp244_;
		GeeList* _tmp245_;
		gint _tmp246_;
		gint _tmp247_;
		ImportManifest* _tmp248_;
		GeeList* _tmp249_;
		gint _tmp250_;
		gint _tmp251_;
		gchar* _tmp252_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp253_;
		GeeList* _tmp254_;
		gint _tmp255_;
		gint _tmp256_;
		ImportManifest* _tmp257_;
		GeeList* _tmp258_;
		gint _tmp259_;
		gint _tmp260_;
		gchar* _tmp261_;
		gchar* both_message = NULL;
		ImportManifest* _tmp262_;
		GeeList* _tmp263_;
		gint _tmp264_;
		gint _tmp265_;
		ImportManifest* _tmp266_;
		GeeList* _tmp267_;
		gint _tmp268_;
		gint _tmp269_;
		gchar* _tmp270_;
		gchar* neither_message = NULL;
		ImportManifest* _tmp271_;
		GeeList* _tmp272_;
		gint _tmp273_;
		gint _tmp274_;
		ImportManifest* _tmp275_;
		GeeList* _tmp276_;
		gint _tmp277_;
		gint _tmp278_;
		gchar* _tmp279_;
		const gchar* _tmp280_;
		ImportManifest* _tmp281_;
		GeeList* _tmp282_;
		const gchar* _tmp283_;
		const gchar* _tmp284_;
		const gchar* _tmp285_;
		const gchar* _tmp286_;
		gchar* _tmp287_;
		gchar* _tmp288_;
		gchar* _tmp289_;
		const gchar* _tmp290_;
		ImportManifest* _tmp291_;
		GeeList* _tmp292_;
		gboolean _tmp293_;
		gchar* _tmp294_;
		gchar* _tmp295_;
		gchar* _tmp296_;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp239_ = message;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp240_ = strlen (_tmp239_);
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp241_ = _tmp240_;
#line 762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp241_ > 0) {
#line 7347 "Dialogs.c"
			const gchar* _tmp242_;
			gchar* _tmp243_;
#line 763 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp242_ = message;
#line 763 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp243_ = g_strconcat (_tmp242_, "\n", NULL);
#line 763 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 763 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp243_;
#line 7358 "Dialogs.c"
		}
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp244_ = manifest;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp245_ = _tmp244_->corrupt_files;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp246_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp245_, GEE_TYPE_COLLECTION, GeeCollection));
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp247_ = _tmp246_;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp248_ = manifest;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp249_ = _tmp248_->corrupt_files;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp250_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp249_, GEE_TYPE_COLLECTION, GeeCollection));
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp251_ = _tmp250_;
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp252_ = g_strdup_printf (ngettext ("1 photo failed to import because it was corrupt:\n", "%d photos failed to import because they were corrupt:\n", (gulong) _tmp247_), _tmp251_);
#line 765 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp252_;
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp253_ = manifest;
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp254_ = _tmp253_->corrupt_files;
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp255_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp254_, GEE_TYPE_COLLECTION, GeeCollection));
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp256_ = _tmp255_;
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp257_ = manifest;
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp258_ = _tmp257_->corrupt_files;
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp259_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp258_, GEE_TYPE_COLLECTION, GeeCollection));
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp260_ = _tmp259_;
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp261_ = g_strdup_printf (ngettext ("1 video failed to import because it was corrupt:\n", "%d videos failed to import because they were corrupt:\n", (gulong) _tmp256_), _tmp260_);
#line 768 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp261_;
#line 771 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp262_ = manifest;
#line 771 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp263_ = _tmp262_->corrupt_files;
#line 771 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp264_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp263_, GEE_TYPE_COLLECTION, GeeCollection));
#line 771 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp265_ = _tmp264_;
#line 771 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp266_ = manifest;
#line 771 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp267_ = _tmp266_->corrupt_files;
#line 771 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp268_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp267_, GEE_TYPE_COLLECTION, GeeCollection));
#line 771 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp269_ = _tmp268_;
#line 771 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp270_ = g_strdup_printf (ngettext ("1 photo/video failed to import because it was corrupt:\n", "%d photos/videos failed to import because they were corrupt:\n", (gulong) _tmp265_), _tmp269_);
#line 771 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp270_;
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp271_ = manifest;
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp272_ = _tmp271_->corrupt_files;
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp273_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp272_, GEE_TYPE_COLLECTION, GeeCollection));
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp274_ = _tmp273_;
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp275_ = manifest;
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp276_ = _tmp275_->corrupt_files;
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp277_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp276_, GEE_TYPE_COLLECTION, GeeCollection));
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp278_ = _tmp277_;
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp279_ = g_strdup_printf (ngettext ("1 file failed to import because it was corrupt:\n", "%d files failed to import because it was corrupt:\n", (gulong) _tmp274_), _tmp278_);
#line 774 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp279_;
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp280_ = message;
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp281_ = manifest;
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp282_ = _tmp281_->corrupt_files;
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp283_ = photos_message;
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp284_ = videos_message;
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp285_ = both_message;
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp286_ = neither_message;
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp287_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp282_, GEE_TYPE_COLLECTION, GeeCollection), _tmp283_, _tmp284_, _tmp285_, _tmp286_);
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp288_ = _tmp287_;
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp289_ = g_strconcat (_tmp280_, _tmp288_, NULL);
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp289_;
#line 778 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp288_);
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp290_ = message;
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp291_ = manifest;
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp292_ = _tmp291_->corrupt_files;
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp293_ = show_dest_id;
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp294_ = import_ui_generate_import_failure_list (_tmp292_, _tmp293_);
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp295_ = _tmp294_;
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp296_ = g_strconcat (_tmp290_, _tmp295_, NULL);
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp296_;
#line 781 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp295_);
#line 761 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 761 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 761 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 761 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 7494 "Dialogs.c"
	}
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp297_ = manifest;
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp298_ = _tmp297_->skipped_photos;
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp299_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp298_, GEE_TYPE_COLLECTION, GeeCollection));
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp300_ = _tmp299_;
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp300_ > 0) {
#line 7506 "Dialogs.c"
		const gchar* _tmp301_;
		gint _tmp302_;
		gint _tmp303_;
		gchar* skipped_photos_message = NULL;
		ImportManifest* _tmp306_;
		GeeList* _tmp307_;
		gint _tmp308_;
		gint _tmp309_;
		ImportManifest* _tmp310_;
		GeeList* _tmp311_;
		gint _tmp312_;
		gint _tmp313_;
		gchar* _tmp314_;
		const gchar* _tmp315_;
		const gchar* _tmp316_;
		gchar* _tmp317_;
		const gchar* _tmp318_;
		ImportManifest* _tmp319_;
		GeeList* _tmp320_;
		gboolean _tmp321_;
		gchar* _tmp322_;
		gchar* _tmp323_;
		gchar* _tmp324_;
#line 785 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp301_ = message;
#line 785 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp302_ = strlen (_tmp301_);
#line 785 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp303_ = _tmp302_;
#line 785 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp303_ > 0) {
#line 7538 "Dialogs.c"
			const gchar* _tmp304_;
			gchar* _tmp305_;
#line 786 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp304_ = message;
#line 786 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp305_ = g_strconcat (_tmp304_, "\n", NULL);
#line 786 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 786 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp305_;
#line 7549 "Dialogs.c"
		}
#line 791 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp306_ = manifest;
#line 791 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp307_ = _tmp306_->skipped_photos;
#line 791 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp308_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp307_, GEE_TYPE_COLLECTION, GeeCollection));
#line 791 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp309_ = _tmp308_;
#line 791 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp310_ = manifest;
#line 791 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp311_ = _tmp310_->skipped_photos;
#line 791 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp312_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp311_, GEE_TYPE_COLLECTION, GeeCollection));
#line 791 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp313_ = _tmp312_;
#line 791 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp314_ = g_strdup_printf (ngettext ("1 unsupported photo skipped:\n", "%d unsupported photos skipped:\n", (gulong) _tmp309_), _tmp313_);
#line 791 "/home/jens/Source/shotwell/src/Dialogs.vala"
		skipped_photos_message = _tmp314_;
#line 795 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp315_ = message;
#line 795 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp316_ = skipped_photos_message;
#line 795 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp317_ = g_strconcat (_tmp315_, _tmp316_, NULL);
#line 795 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 795 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp317_;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp318_ = message;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp319_ = manifest;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp320_ = _tmp319_->skipped_photos;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp321_ = show_dest_id;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp322_ = import_ui_generate_import_failure_list (_tmp320_, _tmp321_);
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp323_ = _tmp322_;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp324_ = g_strconcat (_tmp318_, _tmp323_, NULL);
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp324_;
#line 797 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp323_);
#line 784 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (skipped_photos_message);
#line 7603 "Dialogs.c"
	}
#line 800 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp325_ = manifest;
#line 800 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp326_ = _tmp325_->skipped_files;
#line 800 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp327_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp326_, GEE_TYPE_COLLECTION, GeeCollection));
#line 800 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp328_ = _tmp327_;
#line 800 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp328_ > 0) {
#line 7615 "Dialogs.c"
		const gchar* _tmp329_;
		gint _tmp330_;
		gint _tmp331_;
		gchar* skipped_files_message = NULL;
		ImportManifest* _tmp334_;
		GeeList* _tmp335_;
		gint _tmp336_;
		gint _tmp337_;
		ImportManifest* _tmp338_;
		GeeList* _tmp339_;
		gint _tmp340_;
		gint _tmp341_;
		gchar* _tmp342_;
		const gchar* _tmp343_;
		const gchar* _tmp344_;
		gchar* _tmp345_;
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp329_ = message;
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp330_ = strlen (_tmp329_);
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp331_ = _tmp330_;
#line 801 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp331_ > 0) {
#line 7640 "Dialogs.c"
			const gchar* _tmp332_;
			gchar* _tmp333_;
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp332_ = message;
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp333_ = g_strconcat (_tmp332_, "\n", NULL);
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 802 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp333_;
#line 7651 "Dialogs.c"
		}
#line 806 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp334_ = manifest;
#line 806 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp335_ = _tmp334_->skipped_files;
#line 806 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp336_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp335_, GEE_TYPE_COLLECTION, GeeCollection));
#line 806 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp337_ = _tmp336_;
#line 806 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp338_ = manifest;
#line 806 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp339_ = _tmp338_->skipped_files;
#line 806 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp340_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp339_, GEE_TYPE_COLLECTION, GeeCollection));
#line 806 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp341_ = _tmp340_;
#line 806 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp342_ = g_strdup_printf (ngettext ("1 non-image file skipped.\n", "%d non-image files skipped.\n", (gulong) _tmp337_), _tmp341_);
#line 806 "/home/jens/Source/shotwell/src/Dialogs.vala"
		skipped_files_message = _tmp342_;
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp343_ = message;
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp344_ = skipped_files_message;
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp345_ = g_strconcat (_tmp343_, _tmp344_, NULL);
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 810 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp345_;
#line 800 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (skipped_files_message);
#line 7685 "Dialogs.c"
	}
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp346_ = manifest;
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp347_ = _tmp346_->aborted;
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp348_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp347_, GEE_TYPE_COLLECTION, GeeCollection));
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp349_ = _tmp348_;
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp349_ > 0) {
#line 7697 "Dialogs.c"
		const gchar* _tmp350_;
		gint _tmp351_;
		gint _tmp352_;
		gchar* photos_message = NULL;
		ImportManifest* _tmp355_;
		GeeList* _tmp356_;
		gint _tmp357_;
		gint _tmp358_;
		ImportManifest* _tmp359_;
		GeeList* _tmp360_;
		gint _tmp361_;
		gint _tmp362_;
		gchar* _tmp363_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp364_;
		GeeList* _tmp365_;
		gint _tmp366_;
		gint _tmp367_;
		ImportManifest* _tmp368_;
		GeeList* _tmp369_;
		gint _tmp370_;
		gint _tmp371_;
		gchar* _tmp372_;
		gchar* both_message = NULL;
		ImportManifest* _tmp373_;
		GeeList* _tmp374_;
		gint _tmp375_;
		gint _tmp376_;
		ImportManifest* _tmp377_;
		GeeList* _tmp378_;
		gint _tmp379_;
		gint _tmp380_;
		gchar* _tmp381_;
		gchar* neither_message = NULL;
		ImportManifest* _tmp382_;
		GeeList* _tmp383_;
		gint _tmp384_;
		gint _tmp385_;
		ImportManifest* _tmp386_;
		GeeList* _tmp387_;
		gint _tmp388_;
		gint _tmp389_;
		gchar* _tmp390_;
		const gchar* _tmp391_;
		ImportManifest* _tmp392_;
		GeeList* _tmp393_;
		const gchar* _tmp394_;
		const gchar* _tmp395_;
		const gchar* _tmp396_;
		const gchar* _tmp397_;
		gchar* _tmp398_;
		gchar* _tmp399_;
		gchar* _tmp400_;
		const gchar* _tmp401_;
		ImportManifest* _tmp402_;
		GeeList* _tmp403_;
		gboolean _tmp404_;
		gchar* _tmp405_;
		gchar* _tmp406_;
		gchar* _tmp407_;
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp350_ = message;
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp351_ = strlen (_tmp350_);
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp352_ = _tmp351_;
#line 814 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp352_ > 0) {
#line 7766 "Dialogs.c"
			const gchar* _tmp353_;
			gchar* _tmp354_;
#line 815 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp353_ = message;
#line 815 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp354_ = g_strconcat (_tmp353_, "\n", NULL);
#line 815 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 815 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp354_;
#line 7777 "Dialogs.c"
		}
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp355_ = manifest;
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp356_ = _tmp355_->aborted;
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp357_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp356_, GEE_TYPE_COLLECTION, GeeCollection));
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp358_ = _tmp357_;
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp359_ = manifest;
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp360_ = _tmp359_->aborted;
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp361_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp360_, GEE_TYPE_COLLECTION, GeeCollection));
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp362_ = _tmp361_;
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp363_ = g_strdup_printf (ngettext ("1 photo skipped due to user cancel:\n", "%d photos skipped due to user cancel:\n", (gulong) _tmp358_), _tmp362_);
#line 817 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp363_;
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp364_ = manifest;
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp365_ = _tmp364_->aborted;
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp366_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp365_, GEE_TYPE_COLLECTION, GeeCollection));
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp367_ = _tmp366_;
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp368_ = manifest;
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp369_ = _tmp368_->aborted;
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp370_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp369_, GEE_TYPE_COLLECTION, GeeCollection));
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp371_ = _tmp370_;
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp372_ = g_strdup_printf (ngettext ("1 video skipped due to user cancel:\n", "%d videos skipped due to user cancel:\n", (gulong) _tmp367_), _tmp371_);
#line 820 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp372_;
#line 823 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp373_ = manifest;
#line 823 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp374_ = _tmp373_->aborted;
#line 823 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp375_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp374_, GEE_TYPE_COLLECTION, GeeCollection));
#line 823 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp376_ = _tmp375_;
#line 823 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp377_ = manifest;
#line 823 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp378_ = _tmp377_->aborted;
#line 823 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp379_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp378_, GEE_TYPE_COLLECTION, GeeCollection));
#line 823 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp380_ = _tmp379_;
#line 823 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp381_ = g_strdup_printf (ngettext ("1 photo/video skipped due to user cancel:\n", "%d photos/videos skipped due to user cancel:\n", (gulong) _tmp376_), _tmp380_);
#line 823 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp381_;
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp382_ = manifest;
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp383_ = _tmp382_->aborted;
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp384_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp383_, GEE_TYPE_COLLECTION, GeeCollection));
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp385_ = _tmp384_;
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp386_ = manifest;
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp387_ = _tmp386_->aborted;
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp388_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp387_, GEE_TYPE_COLLECTION, GeeCollection));
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp389_ = _tmp388_;
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp390_ = g_strdup_printf (ngettext ("1 file skipped due to user cancel:\n", "%d file skipped due to user cancel:\n", (gulong) _tmp385_), _tmp389_);
#line 826 "/home/jens/Source/shotwell/src/Dialogs.vala"
		neither_message = _tmp390_;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp391_ = message;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp392_ = manifest;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp393_ = _tmp392_->aborted;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp394_ = photos_message;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp395_ = videos_message;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp396_ = both_message;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp397_ = neither_message;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp398_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp393_, GEE_TYPE_COLLECTION, GeeCollection), _tmp394_, _tmp395_, _tmp396_, _tmp397_);
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp399_ = _tmp398_;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp400_ = g_strconcat (_tmp391_, _tmp399_, NULL);
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp400_;
#line 830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp399_);
#line 833 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp401_ = message;
#line 833 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp402_ = manifest;
#line 833 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp403_ = _tmp402_->aborted;
#line 833 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp404_ = show_dest_id;
#line 833 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp405_ = import_ui_generate_import_failure_list (_tmp403_, _tmp404_);
#line 833 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp406_ = _tmp405_;
#line 833 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp407_ = g_strconcat (_tmp401_, _tmp406_, NULL);
#line 833 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 833 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp407_;
#line 833 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp406_);
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (neither_message);
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 813 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 7913 "Dialogs.c"
	}
#line 836 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp408_ = manifest;
#line 836 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp409_ = _tmp408_->success;
#line 836 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp410_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp409_, GEE_TYPE_COLLECTION, GeeCollection));
#line 836 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp411_ = _tmp410_;
#line 836 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp411_ > 0) {
#line 7925 "Dialogs.c"
		const gchar* _tmp412_;
		gint _tmp413_;
		gint _tmp414_;
		gchar* photos_message = NULL;
		ImportManifest* _tmp417_;
		GeeList* _tmp418_;
		gint _tmp419_;
		gint _tmp420_;
		ImportManifest* _tmp421_;
		GeeList* _tmp422_;
		gint _tmp423_;
		gint _tmp424_;
		gchar* _tmp425_;
		gchar* videos_message = NULL;
		ImportManifest* _tmp426_;
		GeeList* _tmp427_;
		gint _tmp428_;
		gint _tmp429_;
		ImportManifest* _tmp430_;
		GeeList* _tmp431_;
		gint _tmp432_;
		gint _tmp433_;
		gchar* _tmp434_;
		gchar* both_message = NULL;
		ImportManifest* _tmp435_;
		GeeList* _tmp436_;
		gint _tmp437_;
		gint _tmp438_;
		ImportManifest* _tmp439_;
		GeeList* _tmp440_;
		gint _tmp441_;
		gint _tmp442_;
		gchar* _tmp443_;
		const gchar* _tmp444_;
		ImportManifest* _tmp445_;
		GeeList* _tmp446_;
		const gchar* _tmp447_;
		const gchar* _tmp448_;
		const gchar* _tmp449_;
		gchar* _tmp450_;
		gchar* _tmp451_;
		gchar* _tmp452_;
#line 837 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp412_ = message;
#line 837 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp413_ = strlen (_tmp412_);
#line 837 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp414_ = _tmp413_;
#line 837 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp414_ > 0) {
#line 7976 "Dialogs.c"
			const gchar* _tmp415_;
			gchar* _tmp416_;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp415_ = message;
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp416_ = g_strconcat (_tmp415_, "\n", NULL);
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (message);
#line 838 "/home/jens/Source/shotwell/src/Dialogs.vala"
			message = _tmp416_;
#line 7987 "Dialogs.c"
		}
#line 840 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp417_ = manifest;
#line 840 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp418_ = _tmp417_->success;
#line 840 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp419_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp418_, GEE_TYPE_COLLECTION, GeeCollection));
#line 840 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp420_ = _tmp419_;
#line 840 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp421_ = manifest;
#line 840 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp422_ = _tmp421_->success;
#line 840 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp423_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp422_, GEE_TYPE_COLLECTION, GeeCollection));
#line 840 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp424_ = _tmp423_;
#line 840 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp425_ = g_strdup_printf (ngettext ("1 photo successfully imported.\n", "%d photos successfully imported.\n", (gulong) _tmp420_), _tmp424_);
#line 840 "/home/jens/Source/shotwell/src/Dialogs.vala"
		photos_message = _tmp425_;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp426_ = manifest;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp427_ = _tmp426_->success;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp428_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp427_, GEE_TYPE_COLLECTION, GeeCollection));
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp429_ = _tmp428_;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp430_ = manifest;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp431_ = _tmp430_->success;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp432_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp431_, GEE_TYPE_COLLECTION, GeeCollection));
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp433_ = _tmp432_;
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp434_ = g_strdup_printf (ngettext ("1 video successfully imported.\n", "%d videos successfully imported.\n", (gulong) _tmp429_), _tmp433_);
#line 843 "/home/jens/Source/shotwell/src/Dialogs.vala"
		videos_message = _tmp434_;
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp435_ = manifest;
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp436_ = _tmp435_->success;
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp437_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp436_, GEE_TYPE_COLLECTION, GeeCollection));
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp438_ = _tmp437_;
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp439_ = manifest;
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp440_ = _tmp439_->success;
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp441_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp440_, GEE_TYPE_COLLECTION, GeeCollection));
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp442_ = _tmp441_;
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp443_ = g_strdup_printf (ngettext ("1 photo/video successfully imported.\n", "%d photos/videos successfully imported.\n", (gulong) _tmp438_), _tmp442_);
#line 846 "/home/jens/Source/shotwell/src/Dialogs.vala"
		both_message = _tmp443_;
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp444_ = message;
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp445_ = manifest;
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp446_ = _tmp445_->success;
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp447_ = photos_message;
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp448_ = videos_message;
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp449_ = both_message;
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp450_ = import_ui_get_media_specific_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp446_, GEE_TYPE_COLLECTION, GeeCollection), _tmp447_, _tmp448_, _tmp449_, "");
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp451_ = _tmp450_;
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp452_ = g_strconcat (_tmp444_, _tmp451_, NULL);
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp452_;
#line 850 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp451_);
#line 836 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (both_message);
#line 836 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (videos_message);
#line 836 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (photos_message);
#line 8079 "Dialogs.c"
	}
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp453_ = manifest;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp454_ = _tmp453_->success;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp455_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp454_, GEE_TYPE_COLLECTION, GeeCollection));
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp456_ = _tmp455_;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp457_ = manifest;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp458_ = _tmp457_->failed;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp459_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp458_, GEE_TYPE_COLLECTION, GeeCollection));
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp460_ = _tmp459_;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp461_ = manifest;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp462_ = _tmp461_->camera_failed;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp463_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp462_, GEE_TYPE_COLLECTION, GeeCollection));
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp464_ = _tmp463_;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp465_ = manifest;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp466_ = _tmp465_->skipped_photos;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp467_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp466_, GEE_TYPE_COLLECTION, GeeCollection));
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp468_ = _tmp467_;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp469_ = manifest;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp470_ = _tmp469_->skipped_files;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp471_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp470_, GEE_TYPE_COLLECTION, GeeCollection));
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp472_ = _tmp471_;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp473_ = manifest;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp474_ = _tmp473_->corrupt_files;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp475_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp474_, GEE_TYPE_COLLECTION, GeeCollection));
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp476_ = _tmp475_;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp477_ = manifest;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp478_ = _tmp477_->already_imported;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp479_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp478_, GEE_TYPE_COLLECTION, GeeCollection));
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp480_ = _tmp479_;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp481_ = manifest;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp482_ = _tmp481_->aborted;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp483_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp482_, GEE_TYPE_COLLECTION, GeeCollection));
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp484_ = _tmp483_;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp485_ = manifest;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp486_ = _tmp485_->write_failed;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp487_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp486_, GEE_TYPE_COLLECTION, GeeCollection));
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp488_ = _tmp487_;
#line 854 "/home/jens/Source/shotwell/src/Dialogs.vala"
	total = (((((((_tmp456_ + _tmp460_) + _tmp464_) + _tmp468_) + _tmp472_) + _tmp476_) + _tmp480_) + _tmp484_) + _tmp488_;
#line 857 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp489_ = total;
#line 857 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp490_ = manifest;
#line 857 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp491_ = _tmp490_->all;
#line 857 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp492_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp491_, GEE_TYPE_COLLECTION, GeeCollection));
#line 857 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp493_ = _tmp492_;
#line 857 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_assert (_tmp489_ == _tmp493_, "total == manifest.all.size");
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp494_ = total;
#line 861 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp494_ == 0) {
#line 8171 "Dialogs.c"
		const gchar* _tmp495_;
		gchar* _tmp496_;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp495_ = message;
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp496_ = g_strconcat (_tmp495_, _ ("No photos or videos imported.\n"), NULL);
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 862 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp496_;
#line 8182 "Dialogs.c"
	}
#line 864 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = NULL;
#line 865 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog_response = (gint) GTK_RESPONSE_NONE;
#line 866 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp497_ = question;
#line 866 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp497_ == NULL) {
#line 8192 "Dialogs.c"
		AppWindow* _tmp498_;
		AppWindow* _tmp499_;
		const gchar* _tmp500_;
		GtkMessageDialog* _tmp501_;
		GtkMessageDialog* _tmp502_;
		GtkWidget* save_results_button = NULL;
		GtkMessageDialog* _tmp503_;
		GtkWidget* _tmp504_;
		GtkWidget* _tmp505_;
		GtkWidget* _tmp506_;
		ImportManifest* _tmp507_;
		GeeList* _tmp508_;
		gint _tmp509_;
		gint _tmp510_;
		ImportManifest* _tmp511_;
		GeeList* _tmp512_;
		gint _tmp513_;
		gint _tmp514_;
		GtkWidget* ok_button = NULL;
		GtkMessageDialog* _tmp515_;
		GtkWidget* _tmp516_;
		GtkWidget* _tmp517_;
		GtkMessageDialog* _tmp518_;
		GtkWidget* _tmp519_;
		GtkWindow* dialog_parent = NULL;
		GtkMessageDialog* _tmp520_;
		GtkContainer* _tmp521_;
		GtkWindow* _tmp522_;
		GtkMessageDialog* _tmp523_;
		gint _tmp524_;
		GtkMessageDialog* _tmp525_;
		gint _tmp526_;
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp498_ = app_window_get_instance ();
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp499_ = _tmp498_;
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp500_ = message;
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp501_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp499_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_NONE, "%s", _tmp500_);
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp501_);
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dialog);
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog = _tmp501_;
#line 867 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp499_);
#line 869 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp502_ = dialog;
#line 869 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp502_, gtk_window_get_type (), GtkWindow), _ ("Import Complete"));
#line 870 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp503_ = dialog;
#line 870 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp504_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp503_, gtk_dialog_get_type (), GtkDialog), IMPORT_UI_SAVE_RESULTS_BUTTON_NAME, IMPORT_UI_SAVE_RESULTS_RESPONSE_ID);
#line 870 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp505_ = _g_object_ref0 (_tmp504_);
#line 870 "/home/jens/Source/shotwell/src/Dialogs.vala"
		save_results_button = _tmp505_;
#line 872 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp506_ = save_results_button;
#line 872 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp507_ = manifest;
#line 872 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp508_ = _tmp507_->success;
#line 872 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp509_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp508_, GEE_TYPE_COLLECTION, GeeCollection));
#line 872 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp510_ = _tmp509_;
#line 872 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp511_ = manifest;
#line 872 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp512_ = _tmp511_->all;
#line 872 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp513_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp512_, GEE_TYPE_COLLECTION, GeeCollection));
#line 872 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp514_ = _tmp513_;
#line 872 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_visible (_tmp506_, _tmp510_ < _tmp514_);
#line 873 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp515_ = dialog;
#line 873 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp516_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp515_, gtk_dialog_get_type (), GtkDialog), RESOURCES_OK_LABEL, (gint) GTK_RESPONSE_OK);
#line 873 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp517_ = _g_object_ref0 (_tmp516_);
#line 873 "/home/jens/Source/shotwell/src/Dialogs.vala"
		ok_button = _tmp517_;
#line 874 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp518_ = dialog;
#line 874 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp519_ = ok_button;
#line 874 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp518_, gtk_window_get_type (), GtkWindow), _tmp519_);
#line 876 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp520_ = dialog;
#line 876 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp521_ = (GtkContainer*) gtk_widget_get_parent (G_TYPE_CHECK_INSTANCE_CAST (_tmp520_, gtk_widget_get_type (), GtkWidget));
#line 876 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp522_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp521_, gtk_window_get_type (), GtkWindow));
#line 876 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_parent = _tmp522_;
#line 877 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp523_ = dialog;
#line 877 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp524_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp523_, gtk_dialog_get_type (), GtkDialog));
#line 877 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_response = _tmp524_;
#line 878 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp525_ = dialog;
#line 878 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp525_, gtk_widget_get_type (), GtkWidget));
#line 880 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp526_ = dialog_response;
#line 880 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp526_ == IMPORT_UI_SAVE_RESULTS_RESPONSE_ID) {
#line 8309 "Dialogs.c"
			GtkWindow* _tmp527_;
			ImportManifest* _tmp528_;
			gchar* _tmp529_;
			gchar* _tmp530_;
#line 881 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp527_ = dialog_parent;
#line 881 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp528_ = manifest;
#line 881 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp529_ = import_ui_create_result_report_from_manifest (_tmp528_);
#line 881 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp530_ = _tmp529_;
#line 881 "/home/jens/Source/shotwell/src/Dialogs.vala"
			import_ui_save_import_results (_tmp527_, _tmp530_);
#line 881 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp530_);
#line 8326 "Dialogs.c"
		}
#line 866 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dialog_parent);
#line 866 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (ok_button);
#line 866 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (save_results_button);
#line 8334 "Dialogs.c"
	} else {
		const gchar* _tmp531_;
		ImportUIQuestionParams* _tmp532_;
		const gchar* _tmp533_;
		gchar* _tmp534_;
		gchar* _tmp535_;
		gchar* _tmp536_;
		AppWindow* _tmp537_;
		AppWindow* _tmp538_;
		const gchar* _tmp539_;
		GtkMessageDialog* _tmp540_;
		GtkMessageDialog* _tmp541_;
		GtkWidget* save_results_button = NULL;
		GtkMessageDialog* _tmp542_;
		GtkWidget* _tmp543_;
		GtkWidget* _tmp544_;
		GtkWidget* _tmp545_;
		ImportManifest* _tmp546_;
		GeeList* _tmp547_;
		gint _tmp548_;
		gint _tmp549_;
		ImportManifest* _tmp550_;
		GeeList* _tmp551_;
		gint _tmp552_;
		gint _tmp553_;
		GtkWidget* no_button = NULL;
		GtkMessageDialog* _tmp554_;
		ImportUIQuestionParams* _tmp555_;
		const gchar* _tmp556_;
		GtkWidget* _tmp557_;
		GtkWidget* _tmp558_;
		GtkMessageDialog* _tmp559_;
		ImportUIQuestionParams* _tmp560_;
		const gchar* _tmp561_;
		GtkMessageDialog* _tmp562_;
		GtkWidget* _tmp563_;
		GtkMessageDialog* _tmp564_;
		gint _tmp565_;
		GtkMessageDialog* _tmp573_;
		GtkMessageDialog* _tmp574_;
#line 884 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp531_ = message;
#line 884 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp532_ = question;
#line 884 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp533_ = _tmp532_->question;
#line 884 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp534_ = g_strconcat ("\n", _tmp533_, NULL);
#line 884 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp535_ = _tmp534_;
#line 884 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp536_ = g_strconcat (_tmp531_, _tmp535_, NULL);
#line 884 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (message);
#line 884 "/home/jens/Source/shotwell/src/Dialogs.vala"
		message = _tmp536_;
#line 884 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp535_);
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp537_ = app_window_get_instance ();
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp538_ = _tmp537_;
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp539_ = message;
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp540_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp538_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", _tmp539_);
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp540_);
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (dialog);
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog = _tmp540_;
#line 886 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp538_);
#line 888 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp541_ = dialog;
#line 888 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp541_, gtk_window_get_type (), GtkWindow), _ ("Import Complete"));
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp542_ = dialog;
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp543_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp542_, gtk_dialog_get_type (), GtkDialog), IMPORT_UI_SAVE_RESULTS_BUTTON_NAME, IMPORT_UI_SAVE_RESULTS_RESPONSE_ID);
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp544_ = _g_object_ref0 (_tmp543_);
#line 889 "/home/jens/Source/shotwell/src/Dialogs.vala"
		save_results_button = _tmp544_;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp545_ = save_results_button;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp546_ = manifest;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp547_ = _tmp546_->success;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp548_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp547_, GEE_TYPE_COLLECTION, GeeCollection));
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp549_ = _tmp548_;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp550_ = manifest;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp551_ = _tmp550_->all;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp552_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp551_, GEE_TYPE_COLLECTION, GeeCollection));
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp553_ = _tmp552_;
#line 891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_visible (_tmp545_, _tmp549_ < _tmp553_);
#line 892 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp554_ = dialog;
#line 892 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp555_ = question;
#line 892 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp556_ = _tmp555_->no_button;
#line 892 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp557_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp554_, gtk_dialog_get_type (), GtkDialog), _tmp556_, (gint) GTK_RESPONSE_NO);
#line 892 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp558_ = _g_object_ref0 (_tmp557_);
#line 892 "/home/jens/Source/shotwell/src/Dialogs.vala"
		no_button = _tmp558_;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp559_ = dialog;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp560_ = question;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp561_ = _tmp560_->yes_button;
#line 893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp559_, gtk_dialog_get_type (), GtkDialog), _tmp561_, (gint) GTK_RESPONSE_YES);
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp562_ = dialog;
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp563_ = no_button;
#line 894 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp562_, gtk_window_get_type (), GtkWindow), _tmp563_);
#line 896 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp564_ = dialog;
#line 896 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp565_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp564_, gtk_dialog_get_type (), GtkDialog));
#line 896 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_response = _tmp565_;
#line 897 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 8475 "Dialogs.c"
			gint _tmp566_;
			GtkMessageDialog* _tmp567_;
			ImportManifest* _tmp568_;
			gchar* _tmp569_;
			gchar* _tmp570_;
			GtkMessageDialog* _tmp571_;
			gint _tmp572_;
#line 897 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp566_ = dialog_response;
#line 897 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!(_tmp566_ == IMPORT_UI_SAVE_RESULTS_RESPONSE_ID)) {
#line 897 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 8489 "Dialogs.c"
			}
#line 898 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp567_ = dialog;
#line 898 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp568_ = manifest;
#line 898 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp569_ = import_ui_create_result_report_from_manifest (_tmp568_);
#line 898 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp570_ = _tmp569_;
#line 898 "/home/jens/Source/shotwell/src/Dialogs.vala"
			import_ui_save_import_results (G_TYPE_CHECK_INSTANCE_CAST (_tmp567_, gtk_window_get_type (), GtkWindow), _tmp570_);
#line 898 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp570_);
#line 899 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp571_ = dialog;
#line 899 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp572_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp571_, gtk_dialog_get_type (), GtkDialog));
#line 899 "/home/jens/Source/shotwell/src/Dialogs.vala"
			dialog_response = _tmp572_;
#line 8509 "Dialogs.c"
		}
#line 902 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp573_ = dialog;
#line 902 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp573_, gtk_widget_get_type (), GtkWidget));
#line 903 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp574_ = dialog;
#line 903 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp574_, gtk_widget_get_type (), GtkWidget));
#line 866 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (no_button);
#line 866 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (save_results_button);
#line 8523 "Dialogs.c"
	}
#line 906 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp575_ = dialog_response;
#line 906 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp575_ == ((gint) GTK_RESPONSE_YES);
#line 906 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 906 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (message);
#line 906 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8535 "Dialogs.c"
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1;
	gint _res_size_;
	gint _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	guint8* _tmp3_;
	gint _tmp3__length1;
	guint8* _tmp4_;
	gint _tmp4__length1;
#line 1428 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1429 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1429 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1429 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1430 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 8579 "Dialogs.c"
	}
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1431 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 8585 "Dialogs.c"
}


void import_ui_save_import_results (GtkWindow* chooser_dialog_parent, const gchar* results_log) {
	GtkFileChooserDialog* chooser_dialog = NULL;
	GtkWindow* _tmp0_;
	GtkFileChooserDialog* _tmp1_;
	GtkFileChooserDialog* _tmp2_;
	GtkFileChooserDialog* _tmp3_;
	const gchar* _tmp4_;
	GtkFileChooserDialog* _tmp5_;
	GtkFileChooserDialog* _tmp6_;
	gint dialog_result = 0;
	GtkFileChooserDialog* _tmp7_;
	gint _tmp8_;
	GFile* chosen_file = NULL;
	GtkFileChooserDialog* _tmp9_;
	GFile* _tmp10_;
	GtkFileChooserDialog* _tmp11_;
	GtkFileChooserDialog* _tmp12_;
	gboolean _tmp13_ = FALSE;
	gint _tmp14_;
	GError * _inner_error_ = NULL;
#line 909 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail ((chooser_dialog_parent == NULL) || GTK_IS_WINDOW (chooser_dialog_parent));
#line 909 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (results_log != NULL);
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = chooser_dialog_parent;
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (IMPORT_UI_SAVE_RESULTS_FILE_CHOOSER_TITLE, _tmp0_, GTK_FILE_CHOOSER_ACTION_SAVE, RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_SAVE_AS_LABEL, GTK_RESPONSE_ACCEPT, NULL, NULL);
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp1_);
#line 910 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chooser_dialog = _tmp1_;
#line 913 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = chooser_dialog;
#line 913 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_do_overwrite_confirmation (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), TRUE);
#line 914 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = chooser_dialog;
#line 914 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = g_get_home_dir ();
#line 914 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp4_);
#line 915 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = chooser_dialog;
#line 915 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), "Shotwell Import Log.txt");
#line 916 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = chooser_dialog;
#line 916 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_local_only (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), FALSE);
#line 918 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = chooser_dialog;
#line 918 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_dialog_get_type (), GtkDialog));
#line 918 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog_result = _tmp8_;
#line 919 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = chooser_dialog;
#line 919 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = gtk_file_chooser_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 919 "/home/jens/Source/shotwell/src/Dialogs.vala"
	chosen_file = _tmp10_;
#line 920 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = chooser_dialog;
#line 920 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_widget_get_type (), GtkWidget));
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = chooser_dialog;
#line 921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_widget_get_type (), GtkWidget));
#line 923 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = dialog_result;
#line 923 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp14_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 8663 "Dialogs.c"
		GFile* _tmp15_;
#line 923 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = chosen_file;
#line 923 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = _tmp15_ != NULL;
#line 8669 "Dialogs.c"
	} else {
#line 923 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = FALSE;
#line 8673 "Dialogs.c"
	}
#line 923 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp13_) {
#line 8677 "Dialogs.c"
		{
			GFileOutputStream* outstream = NULL;
			GFile* _tmp16_;
			GFileOutputStream* _tmp17_;
			GFileOutputStream* _tmp18_;
			const gchar* _tmp19_;
			guint8* _tmp20_;
			gint _tmp20__length1;
			guint8* _tmp21_;
			gint _tmp21__length1;
			GFileOutputStream* _tmp22_;
#line 925 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp16_ = chosen_file;
#line 925 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = g_file_replace (_tmp16_, NULL, FALSE, G_FILE_CREATE_NONE, NULL, &_inner_error_);
#line 925 "/home/jens/Source/shotwell/src/Dialogs.vala"
			outstream = _tmp17_;
#line 925 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 8697 "Dialogs.c"
				goto __catch425_g_error;
			}
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = outstream;
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp19_ = results_log;
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = string_get_data (_tmp19_, &_tmp20__length1);
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = _tmp20_;
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21__length1 = _tmp20__length1;
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_output_stream_write (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, g_output_stream_get_type (), GOutputStream), _tmp21_, (gsize) _tmp21__length1, NULL, &_inner_error_);
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 926 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (outstream);
#line 8716 "Dialogs.c"
				goto __catch425_g_error;
			}
#line 927 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = outstream;
#line 927 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_output_stream_close (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, g_output_stream_get_type (), GOutputStream), NULL, &_inner_error_);
#line 927 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 927 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (outstream);
#line 8727 "Dialogs.c"
				goto __catch425_g_error;
			}
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (outstream);
#line 8732 "Dialogs.c"
		}
		goto __finally425;
		__catch425_g_error:
		{
			GError* err = NULL;
			GFile* _tmp23_;
			gchar* _tmp24_;
			gchar* _tmp25_;
			GError* _tmp26_;
			const gchar* _tmp27_;
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
			err = _inner_error_;
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_inner_error_ = NULL;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = chosen_file;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = g_file_get_path (_tmp23_);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = _tmp24_;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp26_ = err;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = _tmp26_->message;
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_critical ("Dialogs.vala:929: couldn't save import results to log file %s: %s", _tmp25_, _tmp27_);
#line 929 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp25_);
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_error_free0 (err);
#line 8763 "Dialogs.c"
		}
		__finally425:
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (chosen_file);
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (chooser_dialog);
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_clear_error (&_inner_error_);
#line 924 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return;
#line 8778 "Dialogs.c"
		}
	}
#line 909 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chosen_file);
#line 909 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (chooser_dialog);
#line 8785 "Dialogs.c"
}


static gboolean _text_entry_dialog_mediator_on_modify_validate_text_entry_dialog_on_modify_validate_type (const gchar* text, gpointer self) {
	gboolean result;
	result = text_entry_dialog_mediator_on_modify_validate ((TextEntryDialogMediator*) self, text);
#line 946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8794 "Dialogs.c"
}


TextEntryDialogMediator* text_entry_dialog_mediator_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text, GeeCollection* completion_list, const gchar* completion_delimiter) {
	TextEntryDialogMediator* self = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_;
	TextEntryDialog* _tmp1_;
	TextEntryDialog* _tmp2_;
	GtkBox* _tmp3_;
	GObject* _tmp4_;
	TextEntryDialog* _tmp5_;
	TextEntryDialog* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	GeeCollection* _tmp10_;
	const gchar* _tmp11_;
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail ((completion_list == NULL) || GEE_IS_COLLECTION (completion_list), NULL);
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (TextEntryDialogMediator*) g_type_create_instance (object_type);
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_window_create_builder ("shotwell.ui", NULL);
#line 942 "/home/jens/Source/shotwell/src/Dialogs.vala"
	builder = _tmp0_;
#line 943 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text_entry_dialog_new ();
#line 943 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp1_);
#line 943 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 943 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dialog = _tmp1_;
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->dialog;
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_dialog_get_type (), GtkDialog));
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gtk_builder_get_object (builder, "dialog-vbox2");
#line 944 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_box_get_type (), GtkBox), gtk_widget_get_type (), GtkWidget));
#line 945 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->dialog;
#line 945 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_set_builder (_tmp5_, builder);
#line 946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = self->priv->dialog;
#line 946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = title;
#line 946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = label;
#line 946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = initial_text;
#line 946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = completion_list;
#line 946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = completion_delimiter;
#line 946 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_setup (_tmp6_, _text_entry_dialog_mediator_on_modify_validate_text_entry_dialog_on_modify_validate_type, self, _tmp7_, _tmp8_, _tmp9_, _tmp10_, _tmp11_);
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (builder);
#line 940 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 8863 "Dialogs.c"
}


static gboolean text_entry_dialog_mediator_real_on_modify_validate (TextEntryDialogMediator* self, const gchar* text) {
	gboolean result = FALSE;
#line 949 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 950 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 950 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8875 "Dialogs.c"
}


gboolean text_entry_dialog_mediator_on_modify_validate (TextEntryDialogMediator* self, const gchar* text) {
#line 949 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TEXT_ENTRY_DIALOG_MEDIATOR (self), FALSE);
#line 949 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->on_modify_validate (self, text);
#line 8884 "Dialogs.c"
}


gchar* _text_entry_dialog_mediator_execute (TextEntryDialogMediator* self) {
	gchar* result = NULL;
	TextEntryDialog* _tmp0_;
	gchar* _tmp1_;
#line 953 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TEXT_ENTRY_DIALOG_MEDIATOR (self), NULL);
#line 954 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->dialog;
#line 954 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text_entry_dialog_execute (_tmp0_);
#line 954 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp1_;
#line 954 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 8902 "Dialogs.c"
}


static void value_text_entry_dialog_mediator_init (GValue* value) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 8909 "Dialogs.c"
}


static void value_text_entry_dialog_mediator_free_value (GValue* value) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_unref (value->data[0].v_pointer);
#line 8918 "Dialogs.c"
	}
}


static void value_text_entry_dialog_mediator_copy_value (const GValue* src_value, GValue* dest_value) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = text_entry_dialog_mediator_ref (src_value->data[0].v_pointer);
#line 8928 "Dialogs.c"
	} else {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 8932 "Dialogs.c"
	}
}


static gpointer value_text_entry_dialog_mediator_peek_pointer (const GValue* value) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 8940 "Dialogs.c"
}


static gchar* value_text_entry_dialog_mediator_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 8947 "Dialogs.c"
		TextEntryDialogMediator * object;
		object = collect_values[0].v_pointer;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 8954 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 8958 "Dialogs.c"
		}
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = text_entry_dialog_mediator_ref (object);
#line 8962 "Dialogs.c"
	} else {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 8966 "Dialogs.c"
	}
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 8970 "Dialogs.c"
}


static gchar* value_text_entry_dialog_mediator_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	TextEntryDialogMediator ** object_p;
	object_p = collect_values[0].v_pointer;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 8981 "Dialogs.c"
	}
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 8987 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 8991 "Dialogs.c"
	} else {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 8995 "Dialogs.c"
	}
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 8999 "Dialogs.c"
}


GParamSpec* param_spec_text_entry_dialog_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecTextEntryDialogMediator* spec;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 9013 "Dialogs.c"
}


gpointer value_get_text_entry_dialog_mediator (const GValue* value) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 9022 "Dialogs.c"
}


void value_set_text_entry_dialog_mediator (GValue* value, gpointer v_object) {
	TextEntryDialogMediator * old;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 9042 "Dialogs.c"
	} else {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 9046 "Dialogs.c"
	}
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_unref (old);
#line 9052 "Dialogs.c"
	}
}


void value_take_text_entry_dialog_mediator (GValue* value, gpointer v_object) {
	TextEntryDialogMediator * old;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 9071 "Dialogs.c"
	} else {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 9075 "Dialogs.c"
	}
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text_entry_dialog_mediator_unref (old);
#line 9081 "Dialogs.c"
	}
}


static void text_entry_dialog_mediator_class_init (TextEntryDialogMediatorClass * klass) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_mediator_parent_class = g_type_class_peek_parent (klass);
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->finalize = text_entry_dialog_mediator_finalize;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (TextEntryDialogMediatorPrivate));
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (TextEntryDialogMediator *, const gchar*)) text_entry_dialog_mediator_real_on_modify_validate;
#line 9095 "Dialogs.c"
}


static void text_entry_dialog_mediator_instance_init (TextEntryDialogMediator * self) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE (self);
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 9104 "Dialogs.c"
}


static void text_entry_dialog_mediator_finalize (TextEntryDialogMediator * obj) {
	TextEntryDialogMediator * self;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator);
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 938 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 9116 "Dialogs.c"
}


GType text_entry_dialog_mediator_get_type (void) {
	static volatile gsize text_entry_dialog_mediator_type_id__volatile = 0;
	if (g_once_init_enter (&text_entry_dialog_mediator_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_text_entry_dialog_mediator_init, value_text_entry_dialog_mediator_free_value, value_text_entry_dialog_mediator_copy_value, value_text_entry_dialog_mediator_peek_pointer, "p", value_text_entry_dialog_mediator_collect_value, "p", value_text_entry_dialog_mediator_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (TextEntryDialogMediatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) text_entry_dialog_mediator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TextEntryDialogMediator), 0, (GInstanceInitFunc) text_entry_dialog_mediator_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType text_entry_dialog_mediator_type_id;
		text_entry_dialog_mediator_type_id = g_type_register_fundamental (g_type_fundamental_next (), "TextEntryDialogMediator", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&text_entry_dialog_mediator_type_id__volatile, text_entry_dialog_mediator_type_id);
	}
	return text_entry_dialog_mediator_type_id__volatile;
}


gpointer text_entry_dialog_mediator_ref (gpointer instance) {
	TextEntryDialogMediator * self;
	self = instance;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 9141 "Dialogs.c"
}


void text_entry_dialog_mediator_unref (gpointer instance) {
	TextEntryDialogMediator * self;
	self = instance;
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->finalize (self);
#line 937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 9154 "Dialogs.c"
	}
}


static gboolean _multi_text_entry_dialog_mediator_on_modify_validate_multi_text_entry_dialog_on_modify_validate_type (const gchar* text, gpointer self) {
	gboolean result;
	result = multi_text_entry_dialog_mediator_on_modify_validate ((MultiTextEntryDialogMediator*) self, text);
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 9164 "Dialogs.c"
}


MultiTextEntryDialogMediator* multi_text_entry_dialog_mediator_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text) {
	MultiTextEntryDialogMediator* self = NULL;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_;
	MultiTextEntryDialog* _tmp1_;
	MultiTextEntryDialog* _tmp2_;
	GtkBox* _tmp3_;
	GObject* _tmp4_;
	MultiTextEntryDialog* _tmp5_;
	MultiTextEntryDialog* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
#line 961 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 961 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 961 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (MultiTextEntryDialogMediator*) g_type_create_instance (object_type);
#line 962 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_window_create_builder ("shotwell.ui", NULL);
#line 962 "/home/jens/Source/shotwell/src/Dialogs.vala"
	builder = _tmp0_;
#line 963 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = multi_text_entry_dialog_new ();
#line 963 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp1_);
#line 963 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 963 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dialog = _tmp1_;
#line 964 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->dialog;
#line 964 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_dialog_get_type (), GtkDialog));
#line 964 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gtk_builder_get_object (builder, "dialog-vbox4");
#line 964 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_box_get_type (), GtkBox), gtk_widget_get_type (), GtkWidget));
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->dialog;
#line 965 "/home/jens/Source/shotwell/src/Dialogs.vala"
	multi_text_entry_dialog_set_builder (_tmp5_, builder);
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = self->priv->dialog;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = title;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = label;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = initial_text;
#line 966 "/home/jens/Source/shotwell/src/Dialogs.vala"
	multi_text_entry_dialog_setup (_tmp6_, _multi_text_entry_dialog_mediator_on_modify_validate_multi_text_entry_dialog_on_modify_validate_type, self, _tmp7_, _tmp8_, _tmp9_);
#line 961 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (builder);
#line 961 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 9225 "Dialogs.c"
}


static gboolean multi_text_entry_dialog_mediator_real_on_modify_validate (MultiTextEntryDialogMediator* self, const gchar* text) {
	gboolean result = FALSE;
#line 969 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 970 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 970 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 9237 "Dialogs.c"
}


gboolean multi_text_entry_dialog_mediator_on_modify_validate (MultiTextEntryDialogMediator* self, const gchar* text) {
#line 969 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR (self), FALSE);
#line 969 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->on_modify_validate (self, text);
#line 9246 "Dialogs.c"
}


gchar* _multi_text_entry_dialog_mediator_execute (MultiTextEntryDialogMediator* self) {
	gchar* result = NULL;
	MultiTextEntryDialog* _tmp0_;
	gchar* _tmp1_;
#line 973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR (self), NULL);
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->dialog;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = multi_text_entry_dialog_execute (_tmp0_);
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp1_;
#line 974 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 9264 "Dialogs.c"
}


static void value_multi_text_entry_dialog_mediator_init (GValue* value) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 9271 "Dialogs.c"
}


static void value_multi_text_entry_dialog_mediator_free_value (GValue* value) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_unref (value->data[0].v_pointer);
#line 9280 "Dialogs.c"
	}
}


static void value_multi_text_entry_dialog_mediator_copy_value (const GValue* src_value, GValue* dest_value) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = multi_text_entry_dialog_mediator_ref (src_value->data[0].v_pointer);
#line 9290 "Dialogs.c"
	} else {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 9294 "Dialogs.c"
	}
}


static gpointer value_multi_text_entry_dialog_mediator_peek_pointer (const GValue* value) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 9302 "Dialogs.c"
}


static gchar* value_multi_text_entry_dialog_mediator_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 9309 "Dialogs.c"
		MultiTextEntryDialogMediator * object;
		object = collect_values[0].v_pointer;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 9316 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 9320 "Dialogs.c"
		}
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = multi_text_entry_dialog_mediator_ref (object);
#line 9324 "Dialogs.c"
	} else {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 9328 "Dialogs.c"
	}
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 9332 "Dialogs.c"
}


static gchar* value_multi_text_entry_dialog_mediator_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	MultiTextEntryDialogMediator ** object_p;
	object_p = collect_values[0].v_pointer;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 9343 "Dialogs.c"
	}
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 9349 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 9353 "Dialogs.c"
	} else {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = multi_text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 9357 "Dialogs.c"
	}
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 9361 "Dialogs.c"
}


GParamSpec* param_spec_multi_text_entry_dialog_mediator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecMultiTextEntryDialogMediator* spec;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 9375 "Dialogs.c"
}


gpointer value_get_multi_text_entry_dialog_mediator (const GValue* value) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR), NULL);
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 9384 "Dialogs.c"
}


void value_set_multi_text_entry_dialog_mediator (GValue* value, gpointer v_object) {
	MultiTextEntryDialogMediator * old;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_ref (value->data[0].v_pointer);
#line 9404 "Dialogs.c"
	} else {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 9408 "Dialogs.c"
	}
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_unref (old);
#line 9414 "Dialogs.c"
	}
}


void value_take_multi_text_entry_dialog_mediator (GValue* value, gpointer v_object) {
	MultiTextEntryDialogMediator * old;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR));
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 9433 "Dialogs.c"
	} else {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 9437 "Dialogs.c"
	}
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		multi_text_entry_dialog_mediator_unref (old);
#line 9443 "Dialogs.c"
	}
}


static void multi_text_entry_dialog_mediator_class_init (MultiTextEntryDialogMediatorClass * klass) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	multi_text_entry_dialog_mediator_parent_class = g_type_class_peek_parent (klass);
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((MultiTextEntryDialogMediatorClass *) klass)->finalize = multi_text_entry_dialog_mediator_finalize;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (MultiTextEntryDialogMediatorPrivate));
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((MultiTextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (MultiTextEntryDialogMediator *, const gchar*)) multi_text_entry_dialog_mediator_real_on_modify_validate;
#line 9457 "Dialogs.c"
}


static void multi_text_entry_dialog_mediator_instance_init (MultiTextEntryDialogMediator * self) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_PRIVATE (self);
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 9466 "Dialogs.c"
}


static void multi_text_entry_dialog_mediator_finalize (MultiTextEntryDialogMediator * obj) {
	MultiTextEntryDialogMediator * self;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediator);
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 959 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 9478 "Dialogs.c"
}


GType multi_text_entry_dialog_mediator_get_type (void) {
	static volatile gsize multi_text_entry_dialog_mediator_type_id__volatile = 0;
	if (g_once_init_enter (&multi_text_entry_dialog_mediator_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_multi_text_entry_dialog_mediator_init, value_multi_text_entry_dialog_mediator_free_value, value_multi_text_entry_dialog_mediator_copy_value, value_multi_text_entry_dialog_mediator_peek_pointer, "p", value_multi_text_entry_dialog_mediator_collect_value, "p", value_multi_text_entry_dialog_mediator_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (MultiTextEntryDialogMediatorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) multi_text_entry_dialog_mediator_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MultiTextEntryDialogMediator), 0, (GInstanceInitFunc) multi_text_entry_dialog_mediator_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType multi_text_entry_dialog_mediator_type_id;
		multi_text_entry_dialog_mediator_type_id = g_type_register_fundamental (g_type_fundamental_next (), "MultiTextEntryDialogMediator", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&multi_text_entry_dialog_mediator_type_id__volatile, multi_text_entry_dialog_mediator_type_id);
	}
	return multi_text_entry_dialog_mediator_type_id__volatile;
}


gpointer multi_text_entry_dialog_mediator_ref (gpointer instance) {
	MultiTextEntryDialogMediator * self;
	self = instance;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 9503 "Dialogs.c"
}


void multi_text_entry_dialog_mediator_unref (gpointer instance) {
	MultiTextEntryDialogMediator * self;
	self = instance;
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		MULTI_TEXT_ENTRY_DIALOG_MEDIATOR_GET_CLASS (self)->finalize (self);
#line 958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 9516 "Dialogs.c"
	}
}


gchar* build_alert_body_text (const gchar* primary_text, const gchar* secondary_text, gboolean should_escape) {
	gchar* result = NULL;
	gboolean _tmp0_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = should_escape;
#line 983 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 9534 "Dialogs.c"
		const gchar* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
		const gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
#line 984 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = primary_text;
#line 984 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = guarded_markup_escape_text (_tmp1_);
#line 984 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _tmp2_;
#line 984 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = secondary_text;
#line 984 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = guarded_markup_escape_text (_tmp4_);
#line 984 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _tmp5_;
#line 984 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = g_strdup_printf ("<span weight=\"Bold\" size=\"larger\">%s</span>\n%s", _tmp3_, _tmp6_);
#line 984 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = _tmp7_;
#line 984 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp6_);
#line 984 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp3_);
#line 984 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp8_;
#line 984 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 9567 "Dialogs.c"
	}
#line 988 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = primary_text;
#line 988 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = guarded_markup_escape_text (_tmp9_);
#line 988 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 988 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = secondary_text;
#line 988 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = g_strdup_printf ("<span weight=\"Bold\" size=\"larger\">%s</span>\n%s", _tmp11_, _tmp12_);
#line 988 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 988 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp11_);
#line 988 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp14_;
#line 988 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 9587 "Dialogs.c"
}


static gboolean _entry_multi_completion_match_func_gtk_entry_completion_match_func (GtkEntryCompletion* completion, const gchar* key, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = entry_multi_completion_match_func ((EntryMultiCompletion*) self, completion, key, iter);
#line 1003 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 9596 "Dialogs.c"
}


EntryMultiCompletion* entry_multi_completion_construct (GType object_type, GeeCollection* completion_list, const gchar* delimiter) {
	EntryMultiCompletion * self = NULL;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	GeeCollection* _tmp7_;
	GtkListStore* _tmp8_;
	GtkListStore* _tmp9_;
#line 997 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (completion_list), NULL);
#line 997 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EntryMultiCompletion*) g_object_new (object_type, NULL);
#line 998 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = delimiter;
#line 998 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == NULL) {
#line 998 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = TRUE;
#line 9619 "Dialogs.c"
	} else {
		const gchar* _tmp2_;
		gint _tmp3_;
		gint _tmp4_;
#line 998 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = delimiter;
#line 998 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = strlen (_tmp2_);
#line 998 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp3_;
#line 998 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp4_ == 1;
#line 9632 "Dialogs.c"
	}
#line 998 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_assert (_tmp0_, "delimiter == null || delimiter.length == 1");
#line 999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = delimiter;
#line 999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->priv->delimiter);
#line 999 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->delimiter = _tmp6_;
#line 1001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = completion_list;
#line 1001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = entry_multi_completion_create_completion_store (_tmp7_);
#line 1001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 1001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_completion_set_model (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_entry_completion_get_type (), GtkEntryCompletion), G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GTK_TYPE_TREE_MODEL, GtkTreeModel));
#line 1001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp9_);
#line 1002 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_completion_set_text_column (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_entry_completion_get_type (), GtkEntryCompletion), 0);
#line 1003 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_completion_set_match_func (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_entry_completion_get_type (), GtkEntryCompletion), _entry_multi_completion_match_func_gtk_entry_completion_match_func, g_object_ref (self), g_object_unref);
#line 997 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 9660 "Dialogs.c"
}


EntryMultiCompletion* entry_multi_completion_new (GeeCollection* completion_list, const gchar* delimiter) {
#line 997 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return entry_multi_completion_construct (TYPE_ENTRY_MULTI_COMPLETION, completion_list, delimiter);
#line 9667 "Dialogs.c"
}


static GtkListStore* entry_multi_completion_create_completion_store (GeeCollection* completion_list) {
	GtkListStore* result = NULL;
	GtkListStore* completion_store = NULL;
	GtkListStore* _tmp0_;
	GtkTreeIter store_iter = {0};
	GeeIterator* completion_iter = NULL;
	GeeCollection* _tmp1_;
	GeeIterator* _tmp2_;
#line 1006 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (completion_list), NULL);
#line 1007 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_list_store_new (1, G_TYPE_STRING, -1);
#line 1007 "/home/jens/Source/shotwell/src/Dialogs.vala"
	completion_store = _tmp0_;
#line 1009 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = completion_list;
#line 1009 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ITERABLE, GeeIterable));
#line 1009 "/home/jens/Source/shotwell/src/Dialogs.vala"
	completion_iter = _tmp2_;
#line 1010 "/home/jens/Source/shotwell/src/Dialogs.vala"
	while (TRUE) {
#line 9693 "Dialogs.c"
		GeeIterator* _tmp3_;
		gboolean _tmp4_;
		GtkListStore* _tmp5_;
		GtkTreeIter _tmp6_ = {0};
		GtkListStore* _tmp7_;
		GtkTreeIter _tmp8_;
		GeeIterator* _tmp9_;
		gpointer _tmp10_;
		gchar* _tmp11_;
#line 1010 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = completion_iter;
#line 1010 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = gee_iterator_next (_tmp3_);
#line 1010 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (!_tmp4_) {
#line 1010 "/home/jens/Source/shotwell/src/Dialogs.vala"
			break;
#line 9711 "Dialogs.c"
		}
#line 1011 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = completion_store;
#line 1011 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_list_store_append (_tmp5_, &_tmp6_);
#line 1011 "/home/jens/Source/shotwell/src/Dialogs.vala"
		store_iter = _tmp6_;
#line 1012 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = completion_store;
#line 1012 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = store_iter;
#line 1012 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = completion_iter;
#line 1012 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = gee_iterator_get (_tmp9_);
#line 1012 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = (gchar*) _tmp10_;
#line 1012 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_list_store_set (_tmp7_, &_tmp8_, 0, _tmp11_, -1, -1);
#line 1012 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp11_);
#line 9733 "Dialogs.c"
	}
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = completion_store;
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (completion_iter);
#line 1015 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 9741 "Dialogs.c"
}


static gchar* string_strip (const gchar* self) {
	gchar* result = NULL;
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
#line 1234 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1235 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = g_strdup (self);
#line 1235 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1236 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1236 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_strstrip (_tmp1_);
#line 1237 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _result_;
#line 1237 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 9764 "Dialogs.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1403 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1403 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1404 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1404 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1404 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1404 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 9784 "Dialogs.c"
}


static gint string_last_index_of_char (const gchar* self, gunichar c, gint start_index) {
	gint result = 0;
	gchar* _result_ = NULL;
	gint _tmp0_;
	gunichar _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 1041 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 1042 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = start_index;
#line 1042 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = c;
#line 1042 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp2_ = g_utf8_strrchr (((gchar*) self) + _tmp0_, (gssize) -1, _tmp1_);
#line 1042 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_result_ = _tmp2_;
#line 1044 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = _result_;
#line 1044 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 9809 "Dialogs.c"
		gchar* _tmp4_;
#line 1045 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = _result_;
#line 1045 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = (gint) (_tmp4_ - ((gchar*) self));
#line 1045 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 9817 "Dialogs.c"
	} else {
#line 1047 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = -1;
#line 1047 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 9823 "Dialogs.c"
	}
}


static gboolean entry_multi_completion_match_func (EntryMultiCompletion* self, GtkEntryCompletion* completion, const gchar* key, GtkTreeIter* iter) {
	gboolean result = FALSE;
	GtkTreeModel* model = NULL;
	GtkEntryCompletion* _tmp0_;
	GtkTreeModel* _tmp1_;
	GtkTreeModel* _tmp2_;
	gchar* possible_match = NULL;
	GtkTreeModel* _tmp3_;
	GtkTreeIter _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* normed_key = NULL;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	const gchar* _tmp11_;
#line 1018 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_ENTRY_MULTI_COMPLETION (self), FALSE);
#line 1018 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_ENTRY_COMPLETION (completion), FALSE);
#line 1018 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (key != NULL, FALSE);
#line 1018 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 1019 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = completion;
#line 1019 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_entry_completion_get_model (_tmp0_);
#line 1019 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 1019 "/home/jens/Source/shotwell/src/Dialogs.vala"
	model = _tmp2_;
#line 1021 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = model;
#line 1021 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = *iter;
#line 1021 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_tree_model_get (_tmp3_, &_tmp4_, 0, &possible_match, -1);
#line 1027 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = possible_match;
#line 1027 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = g_utf8_casefold (_tmp5_, (gssize) -1);
#line 1027 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 1027 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = g_utf8_normalize (_tmp7_, (gssize) -1, G_NORMALIZE_ALL_COMPOSE);
#line 1027 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (possible_match);
#line 1027 "/home/jens/Source/shotwell/src/Dialogs.vala"
	possible_match = _tmp8_;
#line 1027 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp7_);
#line 1028 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = key;
#line 1028 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = g_utf8_normalize (_tmp9_, (gssize) -1, G_NORMALIZE_ALL_COMPOSE);
#line 1028 "/home/jens/Source/shotwell/src/Dialogs.vala"
	normed_key = _tmp10_;
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = self->priv->delimiter;
#line 1030 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp11_ == NULL) {
#line 9891 "Dialogs.c"
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gboolean _tmp16_;
		gboolean _tmp17_;
#line 1031 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = possible_match;
#line 1031 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = normed_key;
#line 1031 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = string_strip (_tmp13_);
#line 1031 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = _tmp14_;
#line 1031 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = g_str_has_prefix (_tmp12_, _tmp15_);
#line 1031 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = _tmp16_;
#line 1031 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp15_);
#line 1031 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp17_;
#line 1031 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (normed_key);
#line 1031 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (possible_match);
#line 1031 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (model);
#line 1031 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 9922 "Dialogs.c"
	} else {
		const gchar* _tmp18_;
		const gchar* _tmp19_;
		gboolean _tmp20_;
		gchar* last_part = NULL;
		const gchar* _tmp31_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		const gchar* _tmp34_;
		gchar* _tmp35_;
		gchar* _tmp36_;
		const gchar* _tmp37_;
		gint _tmp38_;
		gint _tmp39_;
		const gchar* _tmp40_;
		const gchar* _tmp41_;
		gchar* _tmp42_;
		gchar* _tmp43_;
		gboolean _tmp44_;
		gboolean _tmp45_;
#line 1033 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = normed_key;
#line 1033 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = self->priv->delimiter;
#line 1033 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = string_contains (_tmp18_, _tmp19_);
#line 1033 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp20_) {
#line 9951 "Dialogs.c"
			gint offset = 0;
			const gchar* _tmp21_;
			const gchar* _tmp22_;
			const gchar* _tmp23_;
			gchar _tmp24_;
			gint _tmp25_;
			gint _tmp26_;
			gint position = 0;
			GtkWidget* _tmp27_;
			gint _tmp28_;
			gint _tmp29_;
			gint _tmp30_;
#line 1035 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = normed_key;
#line 1035 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = normed_key;
#line 1035 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = self->priv->delimiter;
#line 1035 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = string_get (_tmp23_, (glong) 0);
#line 1035 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = string_last_index_of_char (_tmp22_, (gunichar) _tmp24_, 0);
#line 1035 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp26_ = g_utf8_strlen (_tmp21_, (gssize) _tmp25_);
#line 1035 "/home/jens/Source/shotwell/src/Dialogs.vala"
			offset = _tmp26_;
#line 1036 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = gtk_entry_completion_get_entry (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_entry_completion_get_type (), GtkEntryCompletion));
#line 1036 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp28_ = gtk_editable_get_position (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_entry_get_type (), GtkEntry), GTK_TYPE_EDITABLE, GtkEditable));
#line 1036 "/home/jens/Source/shotwell/src/Dialogs.vala"
			position = _tmp28_;
#line 1037 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp29_ = position;
#line 1037 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp30_ = offset;
#line 1037 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp29_ <= _tmp30_) {
#line 1038 "/home/jens/Source/shotwell/src/Dialogs.vala"
				result = FALSE;
#line 1038 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (normed_key);
#line 1038 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (possible_match);
#line 1038 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (model);
#line 1038 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return result;
#line 10000 "Dialogs.c"
			}
		}
#line 1041 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp31_ = normed_key;
#line 1041 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = string_strip (_tmp31_);
#line 1041 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = _tmp32_;
#line 1041 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = self->priv->delimiter;
#line 1041 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp35_ = entry_multi_completion_get_last_part (_tmp33_, _tmp34_);
#line 1041 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp36_ = _tmp35_;
#line 1041 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp33_);
#line 1041 "/home/jens/Source/shotwell/src/Dialogs.vala"
		last_part = _tmp36_;
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp37_ = last_part;
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp38_ = strlen (_tmp37_);
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp39_ = _tmp38_;
#line 1043 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp39_ == 0) {
#line 1044 "/home/jens/Source/shotwell/src/Dialogs.vala"
			result = FALSE;
#line 1044 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (last_part);
#line 1044 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (normed_key);
#line 1044 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (possible_match);
#line 1044 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (model);
#line 1044 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return result;
#line 10039 "Dialogs.c"
		}
#line 1046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp40_ = possible_match;
#line 1046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp41_ = last_part;
#line 1046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp42_ = string_strip (_tmp41_);
#line 1046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp43_ = _tmp42_;
#line 1046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp44_ = g_str_has_prefix (_tmp40_, _tmp43_);
#line 1046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp45_ = _tmp44_;
#line 1046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp43_);
#line 1046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp45_;
#line 1046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (last_part);
#line 1046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (normed_key);
#line 1046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (possible_match);
#line 1046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (model);
#line 1046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 10067 "Dialogs.c"
	}
#line 1018 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (normed_key);
#line 1018 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (possible_match);
#line 1018 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (model);
#line 10075 "Dialogs.c"
}


static glong string_strnlen (gchar* str, glong maxlen) {
	glong result = 0L;
	gchar* end = NULL;
	gchar* _tmp0_;
	glong _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 1322 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = str;
#line 1322 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = maxlen;
#line 1322 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp2_ = memchr (_tmp0_, 0, (gsize) _tmp1_);
#line 1322 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	end = _tmp2_;
#line 1323 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = end;
#line 1323 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp3_ == NULL) {
#line 10098 "Dialogs.c"
		glong _tmp4_;
#line 1324 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = maxlen;
#line 1324 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = _tmp4_;
#line 1324 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 10106 "Dialogs.c"
	} else {
		gchar* _tmp5_;
		gchar* _tmp6_;
#line 1326 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp5_ = end;
#line 1326 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6_ = str;
#line 1326 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = (glong) (_tmp5_ - _tmp6_);
#line 1326 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 10118 "Dialogs.c"
	}
}


static gchar* string_substring (const gchar* self, glong offset, glong len) {
	gchar* result = NULL;
	glong string_length = 0L;
	gboolean _tmp0_ = FALSE;
	glong _tmp1_;
	glong _tmp8_;
	glong _tmp14_;
	glong _tmp17_;
	glong _tmp18_;
	glong _tmp19_;
	glong _tmp20_;
	glong _tmp21_;
	gchar* _tmp22_;
#line 1333 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = offset;
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp1_ >= ((glong) 0)) {
#line 10142 "Dialogs.c"
		glong _tmp2_;
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp2_ = len;
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp0_ = _tmp2_ >= ((glong) 0);
#line 10148 "Dialogs.c"
	} else {
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp0_ = FALSE;
#line 10152 "Dialogs.c"
	}
#line 1335 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp0_) {
#line 10156 "Dialogs.c"
		glong _tmp3_;
		glong _tmp4_;
		glong _tmp5_;
#line 1337 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp3_ = offset;
#line 1337 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = len;
#line 1337 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp5_ = string_strnlen ((gchar*) self, _tmp3_ + _tmp4_);
#line 1337 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		string_length = _tmp5_;
#line 10168 "Dialogs.c"
	} else {
		gint _tmp6_;
		gint _tmp7_;
#line 1339 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6_ = strlen (self);
#line 1339 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp7_ = _tmp6_;
#line 1339 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		string_length = (glong) _tmp7_;
#line 10178 "Dialogs.c"
	}
#line 1342 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp8_ = offset;
#line 1342 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp8_ < ((glong) 0)) {
#line 10184 "Dialogs.c"
		glong _tmp9_;
		glong _tmp10_;
		glong _tmp11_;
#line 1343 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp9_ = string_length;
#line 1343 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp10_ = offset;
#line 1343 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		offset = _tmp9_ + _tmp10_;
#line 1344 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp11_ = offset;
#line 1344 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp11_ >= ((glong) 0), NULL);
#line 10198 "Dialogs.c"
	} else {
		glong _tmp12_;
		glong _tmp13_;
#line 1346 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp12_ = offset;
#line 1346 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp13_ = string_length;
#line 1346 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		g_return_val_if_fail (_tmp12_ <= _tmp13_, NULL);
#line 10208 "Dialogs.c"
	}
#line 1348 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp14_ = len;
#line 1348 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp14_ < ((glong) 0)) {
#line 10214 "Dialogs.c"
		glong _tmp15_;
		glong _tmp16_;
#line 1349 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1349 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp16_ = offset;
#line 1349 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		len = _tmp15_ - _tmp16_;
#line 10223 "Dialogs.c"
	}
#line 1351 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp17_ = offset;
#line 1351 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp18_ = len;
#line 1351 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp19_ = string_length;
#line 1351 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail ((_tmp17_ + _tmp18_) <= _tmp19_, NULL);
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp20_ = offset;
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp21_ = len;
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp22_ = g_strndup (((gchar*) self) + _tmp20_, (gsize) _tmp21_);
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp22_;
#line 1352 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 10243 "Dialogs.c"
}


static gboolean entry_multi_completion_real_match_selected (GtkEntryCompletion* base, GtkTreeModel* model, GtkTreeIter* iter) {
	EntryMultiCompletion * self;
	gboolean result = FALSE;
	gchar* match = NULL;
	GtkTreeModel* _tmp0_;
	GtkTreeIter _tmp1_;
	GtkEntry* entry = NULL;
	GtkWidget* _tmp2_;
	GtkEntry* _tmp3_;
	gchar* old_text = NULL;
	GtkEntry* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	const gchar* _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	const gchar* _tmp24_ = NULL;
	const gchar* _tmp25_;
	gchar* new_text = NULL;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	const gchar* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	GtkEntry* _tmp35_;
	GtkEntry* _tmp36_;
	gint _tmp37_;
	gint _tmp38_;
#line 1050 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_ENTRY_MULTI_COMPLETION, EntryMultiCompletion);
#line 1050 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_TREE_MODEL (model), FALSE);
#line 1050 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 1052 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = model;
#line 1052 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = *iter;
#line 1052 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, 0, &match, -1);
#line 1054 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_entry_completion_get_entry (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_entry_completion_get_type (), GtkEntryCompletion));
#line 1054 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_entry_get_type (), GtkEntry));
#line 1054 "/home/jens/Source/shotwell/src/Dialogs.vala"
	entry = _tmp3_;
#line 1056 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = entry;
#line 1056 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = gtk_entry_get_text (_tmp4_);
#line 1056 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = g_utf8_normalize (_tmp5_, (gssize) -1, G_NORMALIZE_ALL_COMPOSE);
#line 1056 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old_text = _tmp6_;
#line 1057 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = old_text;
#line 1057 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = strlen (_tmp7_);
#line 1057 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 1057 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp9_ > 0) {
#line 10313 "Dialogs.c"
		const gchar* _tmp10_;
		const gchar* _tmp11_;
		gboolean _tmp12_;
#line 1058 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = old_text;
#line 1058 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = self->priv->delimiter;
#line 1058 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = string_contains (_tmp10_, _tmp11_);
#line 1058 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp12_) {
#line 10325 "Dialogs.c"
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_;
			const gchar* _tmp15_;
			const gchar* _tmp16_;
			const gchar* _tmp17_;
			gchar _tmp18_;
			gint _tmp19_;
			gchar* _tmp20_;
			gchar* _tmp21_;
			gchar* _tmp22_;
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp14_ = self->priv->delimiter;
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (g_strcmp0 (_tmp14_, " ") != 0) {
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = " ";
#line 10342 "Dialogs.c"
			} else {
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = "";
#line 10346 "Dialogs.c"
			}
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp15_ = old_text;
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp16_ = old_text;
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = self->priv->delimiter;
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = string_get (_tmp17_, (glong) 0);
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp19_ = string_last_index_of_char (_tmp16_, (gunichar) _tmp18_, 0);
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = string_substring (_tmp15_, (glong) 0, (glong) (_tmp19_ + 1));
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = _tmp20_;
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = g_strconcat (_tmp21_, _tmp13_, NULL);
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (old_text);
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
			old_text = _tmp22_;
#line 1059 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp21_);
#line 10370 "Dialogs.c"
		} else {
			gchar* _tmp23_;
#line 1061 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = g_strdup ("");
#line 1061 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (old_text);
#line 1061 "/home/jens/Source/shotwell/src/Dialogs.vala"
			old_text = _tmp23_;
#line 10379 "Dialogs.c"
		}
	}
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = self->priv->delimiter;
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_strcmp0 (_tmp25_, " ") != 0) {
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = " ";
#line 10388 "Dialogs.c"
	} else {
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = "";
#line 10392 "Dialogs.c"
	}
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = old_text;
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = match;
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = g_strconcat (_tmp26_, _tmp27_, NULL);
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = _tmp28_;
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = self->priv->delimiter;
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = g_strconcat (_tmp29_, _tmp30_, NULL);
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = _tmp31_;
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = g_strconcat (_tmp32_, _tmp24_, NULL);
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = _tmp33_;
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp32_);
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp29_);
#line 1064 "/home/jens/Source/shotwell/src/Dialogs.vala"
	new_text = _tmp34_;
#line 1065 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = entry;
#line 1065 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_text (_tmp35_, new_text);
#line 1066 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = entry;
#line 1066 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = strlen (new_text);
#line 1066 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = _tmp37_;
#line 1066 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_editable_set_position (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, GTK_TYPE_EDITABLE, GtkEditable), (gint) _tmp38_);
#line 1068 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 1068 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (new_text);
#line 1068 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (old_text);
#line 1068 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (entry);
#line 1068 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (match);
#line 1068 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 10442 "Dialogs.c"
}


static gchar* entry_multi_completion_get_last_part (const gchar* s, const gchar* delimiter) {
	gchar* result = NULL;
	gchar** split = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar** _tmp2_;
	gchar** _tmp3_;
	gint split_length1;
	gint _split_size_;
	gboolean _tmp4_ = FALSE;
	gchar** _tmp5_;
	gint _tmp5__length1;
#line 1072 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (s != NULL, NULL);
#line 1072 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (delimiter != NULL, NULL);
#line 1073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = s;
#line 1073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = delimiter;
#line 1073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_ = g_strsplit (_tmp0_, _tmp1_, 0);
#line 1073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	split = _tmp3_;
#line 1073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	split_length1 = _vala_array_length (_tmp2_);
#line 1073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_split_size_ = split_length1;
#line 1075 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = split;
#line 1075 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5__length1 = split_length1;
#line 1075 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_ != NULL) {
#line 10480 "Dialogs.c"
		gchar** _tmp6_;
		gint _tmp6__length1;
		const gchar* _tmp7_;
#line 1075 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = split;
#line 1075 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6__length1 = split_length1;
#line 1075 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp6_[0];
#line 1075 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp7_ != NULL;
#line 10492 "Dialogs.c"
	} else {
#line 1075 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = FALSE;
#line 10496 "Dialogs.c"
	}
#line 1075 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_) {
#line 10500 "Dialogs.c"
		gchar** _tmp8_;
		gint _tmp8__length1;
		gchar** _tmp9_;
		gint _tmp9__length1;
		const gchar* _tmp10_;
		gchar* _tmp11_;
#line 1076 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = split;
#line 1076 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8__length1 = split_length1;
#line 1076 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = split;
#line 1076 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9__length1 = split_length1;
#line 1076 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp8_[_tmp9__length1 - 1];
#line 1076 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = g_strdup (_tmp10_);
#line 1076 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp11_;
#line 1076 "/home/jens/Source/shotwell/src/Dialogs.vala"
		split = (_vala_array_free (split, split_length1, (GDestroyNotify) g_free), NULL);
#line 1076 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 10525 "Dialogs.c"
	} else {
		gchar* _tmp12_;
#line 1078 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = g_strdup ("");
#line 1078 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp12_;
#line 1078 "/home/jens/Source/shotwell/src/Dialogs.vala"
		split = (_vala_array_free (split, split_length1, (GDestroyNotify) g_free), NULL);
#line 1078 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 10536 "Dialogs.c"
	}
#line 1072 "/home/jens/Source/shotwell/src/Dialogs.vala"
	split = (_vala_array_free (split, split_length1, (GDestroyNotify) g_free), NULL);
#line 10540 "Dialogs.c"
}


static void entry_multi_completion_class_init (EntryMultiCompletionClass * klass) {
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
	entry_multi_completion_parent_class = g_type_class_peek_parent (klass);
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (EntryMultiCompletionPrivate));
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((GtkEntryCompletionClass *) klass)->match_selected = (gboolean (*) (GtkEntryCompletion *, GtkTreeModel*, GtkTreeIter*)) entry_multi_completion_real_match_selected;
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = entry_multi_completion_finalize;
#line 10553 "Dialogs.c"
}


static void entry_multi_completion_instance_init (EntryMultiCompletion * self) {
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = ENTRY_MULTI_COMPLETION_GET_PRIVATE (self);
#line 10560 "Dialogs.c"
}


static void entry_multi_completion_finalize (GObject * obj) {
	EntryMultiCompletion * self;
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_ENTRY_MULTI_COMPLETION, EntryMultiCompletion);
#line 995 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->priv->delimiter);
#line 994 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (entry_multi_completion_parent_class)->finalize (obj);
#line 10572 "Dialogs.c"
}


GType entry_multi_completion_get_type (void) {
	static volatile gsize entry_multi_completion_type_id__volatile = 0;
	if (g_once_init_enter (&entry_multi_completion_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EntryMultiCompletionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) entry_multi_completion_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EntryMultiCompletion), 0, (GInstanceInitFunc) entry_multi_completion_instance_init, NULL };
		GType entry_multi_completion_type_id;
		entry_multi_completion_type_id = g_type_register_static (gtk_entry_completion_get_type (), "EntryMultiCompletion", &g_define_type_info, 0);
		g_once_init_leave (&entry_multi_completion_type_id__volatile, entry_multi_completion_type_id);
	}
	return entry_multi_completion_type_id__volatile;
}


SetBackgroundPhotoDialog* set_background_photo_dialog_construct (GType object_type) {
	SetBackgroundPhotoDialog * self = NULL;
	gboolean use_header = FALSE;
	GtkSettings* _tmp0_;
	gint _tmp1_ = 0;
	gboolean _tmp2_;
	AppWindow* _tmp3_;
	AppWindow* _tmp4_;
#line 1092 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_settings_get_default ();
#line 1092 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 1093 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = use_header;
#line 1093 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_) {
#line 1093 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 1;
#line 10606 "Dialogs.c"
	} else {
#line 1093 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 0;
#line 10610 "Dialogs.c"
	}
#line 1093 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (SetBackgroundPhotoDialog*) g_object_new (object_type, "use-header-bar", _tmp1_, NULL);
#line 1094 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = app_window_get_instance ();
#line 1094 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 1094 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_window_get_type (), GtkWindow));
#line 1094 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp4_);
#line 1090 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 10624 "Dialogs.c"
}


SetBackgroundPhotoDialog* set_background_photo_dialog_new (void) {
#line 1090 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return set_background_photo_dialog_construct (TYPE_SET_BACKGROUND_PHOTO_DIALOG);
#line 10631 "Dialogs.c"
}


static void set_background_photo_dialog_on_checkbox_clicked (SetBackgroundPhotoDialog* self) {
	gboolean _tmp0_ = FALSE;
	GtkCheckButton* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
#line 1098 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_SET_BACKGROUND_PHOTO_DIALOG (self));
#line 1100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->desktop_background_checkbox;
#line 1100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 1100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_) {
#line 1100 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = TRUE;
#line 10652 "Dialogs.c"
	} else {
		GtkCheckButton* _tmp4_;
		gboolean _tmp5_;
		gboolean _tmp6_;
#line 1101 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = self->priv->screensaver_checkbox;
#line 1101 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1101 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _tmp5_;
#line 1101 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp6_;
#line 10665 "Dialogs.c"
	}
#line 1099 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_response_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK, _tmp0_);
#line 10669 "Dialogs.c"
}


static void _set_background_photo_dialog_on_checkbox_clicked_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self) {
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	set_background_photo_dialog_on_checkbox_clicked ((SetBackgroundPhotoDialog*) self);
#line 10676 "Dialogs.c"
}


gboolean set_background_photo_dialog_execute (SetBackgroundPhotoDialog* self, gboolean* desktop_background, gboolean* screensaver) {
	gboolean _vala_desktop_background = FALSE;
	gboolean _vala_screensaver = FALSE;
	gboolean result = FALSE;
	gboolean _result_ = FALSE;
	gint _tmp0_;
	GtkCheckButton* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	GtkCheckButton* _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
#line 1104 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_SET_BACKGROUND_PHOTO_DIALOG (self), FALSE);
#line 1105 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1106 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1106 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = _tmp0_ == ((gint) GTK_RESPONSE_OK);
#line 1107 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1109 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->desktop_background_checkbox;
#line 1109 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1109 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 1109 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_desktop_background = _tmp3_;
#line 1110 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = self->priv->screensaver_checkbox;
#line 1110 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1110 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 1110 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_screensaver = _tmp6_;
#line 1112 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1113 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 1113 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (desktop_background) {
#line 1113 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*desktop_background = _vala_desktop_background;
#line 10726 "Dialogs.c"
	}
#line 1113 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (screensaver) {
#line 1113 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*screensaver = _vala_screensaver;
#line 10732 "Dialogs.c"
	}
#line 1113 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 10736 "Dialogs.c"
}


static void set_background_photo_dialog_class_init (SetBackgroundPhotoDialogClass * klass) {
	gint SetBackgroundPhotoDialog_private_offset;
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	set_background_photo_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (SetBackgroundPhotoDialogPrivate));
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = set_background_photo_dialog_finalize;
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	SetBackgroundPhotoDialog_private_offset = g_type_class_get_instance_private_offset (klass);
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Shotwell/ui/set_background_dialog.ui");
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "desktop_background_checkbox", FALSE, SetBackgroundPhotoDialog_private_offset + G_STRUCT_OFFSET (SetBackgroundPhotoDialogPrivate, desktop_background_checkbox));
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "screensaver_checkbox", FALSE, SetBackgroundPhotoDialog_private_offset + G_STRUCT_OFFSET (SetBackgroundPhotoDialogPrivate, screensaver_checkbox));
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_checkbox_clicked", G_CALLBACK(_set_background_photo_dialog_on_checkbox_clicked_gtk_toggle_button_toggled));
#line 10758 "Dialogs.c"
}


static void set_background_photo_dialog_instance_init (SetBackgroundPhotoDialog * self) {
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = SET_BACKGROUND_PHOTO_DIALOG_GET_PRIVATE (self);
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 10767 "Dialogs.c"
}


static void set_background_photo_dialog_finalize (GObject * obj) {
	SetBackgroundPhotoDialog * self;
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SET_BACKGROUND_PHOTO_DIALOG, SetBackgroundPhotoDialog);
#line 1086 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->desktop_background_checkbox);
#line 1088 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->screensaver_checkbox);
#line 1084 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (set_background_photo_dialog_parent_class)->finalize (obj);
#line 10781 "Dialogs.c"
}


GType set_background_photo_dialog_get_type (void) {
	static volatile gsize set_background_photo_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&set_background_photo_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SetBackgroundPhotoDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_background_photo_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetBackgroundPhotoDialog), 0, (GInstanceInitFunc) set_background_photo_dialog_instance_init, NULL };
		GType set_background_photo_dialog_type_id;
		set_background_photo_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "SetBackgroundPhotoDialog", &g_define_type_info, 0);
		g_once_init_leave (&set_background_photo_dialog_type_id__volatile, set_background_photo_dialog_type_id);
	}
	return set_background_photo_dialog_type_id__volatile;
}


SetBackgroundSlideshowDialog* set_background_slideshow_dialog_construct (GType object_type) {
	SetBackgroundSlideshowDialog * self = NULL;
	gboolean use_header = FALSE;
	GtkSettings* _tmp0_;
	gint _tmp1_ = 0;
	gboolean _tmp2_;
	AppWindow* _tmp3_;
	AppWindow* _tmp4_;
#line 1132 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_settings_get_default ();
#line 1132 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 1133 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = use_header;
#line 1133 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_) {
#line 1133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 1;
#line 10815 "Dialogs.c"
	} else {
#line 1133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 0;
#line 10819 "Dialogs.c"
	}
#line 1133 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (SetBackgroundSlideshowDialog*) g_object_new (object_type, "use-header-bar", _tmp1_, NULL);
#line 1134 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = app_window_get_instance ();
#line 1134 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 1134 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_window_get_type (), GtkWindow));
#line 1134 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp4_);
#line 1130 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 10833 "Dialogs.c"
}


SetBackgroundSlideshowDialog* set_background_slideshow_dialog_new (void) {
#line 1130 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return set_background_slideshow_dialog_construct (TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG);
#line 10840 "Dialogs.c"
}


static void set_background_slideshow_dialog_real_constructed (GObject* base) {
	SetBackgroundSlideshowDialog * self;
#line 1137 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG, SetBackgroundSlideshowDialog);
#line 1138 "/home/jens/Source/shotwell/src/Dialogs.vala"
	set_background_slideshow_dialog_on_delay_scale_value_changed (self);
#line 10850 "Dialogs.c"
}


static void set_background_slideshow_dialog_on_checkbox_clicked (SetBackgroundSlideshowDialog* self) {
	gboolean _tmp0_ = FALSE;
	GtkCheckButton* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
#line 1142 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_SET_BACKGROUND_SLIDESHOW_DIALOG (self));
#line 1144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->desktop_background_checkbox;
#line 1144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 1144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_) {
#line 1144 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = TRUE;
#line 10871 "Dialogs.c"
	} else {
		GtkCheckButton* _tmp4_;
		gboolean _tmp5_;
		gboolean _tmp6_;
#line 1145 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = self->priv->screensaver_checkbox;
#line 1145 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1145 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _tmp5_;
#line 1145 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp6_;
#line 10884 "Dialogs.c"
	}
#line 1143 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_response_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK, _tmp0_);
#line 10888 "Dialogs.c"
}


static void _set_background_slideshow_dialog_on_checkbox_clicked_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self) {
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	set_background_slideshow_dialog_on_checkbox_clicked ((SetBackgroundSlideshowDialog*) self);
#line 10895 "Dialogs.c"
}


static void set_background_slideshow_dialog_on_delay_scale_value_changed (SetBackgroundSlideshowDialog* self) {
	gdouble value = 0.0;
	GtkScale* _tmp0_;
	GtkAdjustment* _tmp1_;
	GtkAdjustment* _tmp2_;
	gdouble _tmp3_;
	gdouble _tmp4_;
	gdouble _tmp5_;
	gdouble _tmp6_;
	gdouble _tmp7_;
	gchar* text = NULL;
	gint _tmp8_;
	GtkLabel* _tmp25_;
	const gchar* _tmp26_;
#line 1149 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_SET_BACKGROUND_SLIDESHOW_DIALOG (self));
#line 1150 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->delay_scale;
#line 1150 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_range_get_adjustment (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_range_get_type (), GtkRange));
#line 1150 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 1150 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_adjustment_get_value (_tmp2_);
#line 1150 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 1150 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value = _tmp4_;
#line 1155 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = value;
#line 1155 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = pow (_tmp5_, (gdouble) 5);
#line 1155 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = pow ((gdouble) 90, (gdouble) 5);
#line 1155 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->delay_value = (gint) (((((_tmp6_ / _tmp7_) * 60) * 60) * 24) + 5);
#line 1159 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = self->priv->delay_value;
#line 1159 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp8_ < 60) {
#line 10939 "Dialogs.c"
		gint _tmp9_;
		gint _tmp10_;
		gchar* _tmp11_;
#line 1160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = self->priv->delay_value;
#line 1160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = self->priv->delay_value;
#line 1160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = g_strdup_printf (ngettext ("%d second", "%d seconds", (gulong) _tmp9_), _tmp10_);
#line 1160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 1160 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text = _tmp11_;
#line 10953 "Dialogs.c"
	} else {
		gint _tmp12_;
#line 1161 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = self->priv->delay_value;
#line 1161 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp12_ < (60 * 60)) {
#line 10960 "Dialogs.c"
			gint minutes = 0;
			gint _tmp13_;
			gint _tmp14_;
			gint _tmp15_;
			gchar* _tmp16_;
			gint _tmp17_;
#line 1162 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp13_ = self->priv->delay_value;
#line 1162 "/home/jens/Source/shotwell/src/Dialogs.vala"
			minutes = _tmp13_ / 60;
#line 1163 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp14_ = minutes;
#line 1163 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp15_ = minutes;
#line 1163 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp16_ = g_strdup_printf (ngettext ("%d minute", "%d minutes", (gulong) _tmp14_), _tmp15_);
#line 1163 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (text);
#line 1163 "/home/jens/Source/shotwell/src/Dialogs.vala"
			text = _tmp16_;
#line 1164 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = minutes;
#line 1164 "/home/jens/Source/shotwell/src/Dialogs.vala"
			self->priv->delay_value = _tmp17_ * 60;
#line 10985 "Dialogs.c"
		} else {
			gint _tmp18_;
#line 1165 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = self->priv->delay_value;
#line 1165 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp18_ < ((60 * 60) * 24)) {
#line 10992 "Dialogs.c"
				gint hours = 0;
				gint _tmp19_;
				gint _tmp20_;
				gint _tmp21_;
				gchar* _tmp22_;
				gint _tmp23_;
#line 1166 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp19_ = self->priv->delay_value;
#line 1166 "/home/jens/Source/shotwell/src/Dialogs.vala"
				hours = _tmp19_ / (60 * 60);
#line 1167 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp20_ = hours;
#line 1167 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp21_ = hours;
#line 1167 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp22_ = g_strdup_printf (ngettext ("%d hour", "%d hours", (gulong) _tmp20_), _tmp21_);
#line 1167 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (text);
#line 1167 "/home/jens/Source/shotwell/src/Dialogs.vala"
				text = _tmp22_;
#line 1168 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp23_ = hours;
#line 1168 "/home/jens/Source/shotwell/src/Dialogs.vala"
				self->priv->delay_value = _tmp23_ * (60 * 60);
#line 11017 "Dialogs.c"
			} else {
				gchar* _tmp24_;
#line 1170 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp24_ = g_strdup (_ ("1 day"));
#line 1170 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (text);
#line 1170 "/home/jens/Source/shotwell/src/Dialogs.vala"
				text = _tmp24_;
#line 1171 "/home/jens/Source/shotwell/src/Dialogs.vala"
				self->priv->delay_value = (60 * 60) * 24;
#line 11028 "Dialogs.c"
			}
		}
	}
#line 1174 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = self->priv->delay_value_label;
#line 1174 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = text;
#line 1174 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_label (_tmp25_, _tmp26_);
#line 1149 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (text);
#line 11040 "Dialogs.c"
}


static void _set_background_slideshow_dialog_on_delay_scale_value_changed_gtk_range_value_changed (GtkRange* _sender, gpointer self) {
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	set_background_slideshow_dialog_on_delay_scale_value_changed ((SetBackgroundSlideshowDialog*) self);
#line 11047 "Dialogs.c"
}


gboolean set_background_slideshow_dialog_execute (SetBackgroundSlideshowDialog* self, gint* delay_value, gboolean* desktop_background, gboolean* screensaver) {
	gint _vala_delay_value = 0;
	gboolean _vala_desktop_background = FALSE;
	gboolean _vala_screensaver = FALSE;
	gboolean result = FALSE;
	gboolean _result_ = FALSE;
	gint _tmp0_;
	gint _tmp1_;
	GtkCheckButton* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	GtkCheckButton* _tmp5_;
	gboolean _tmp6_;
	gboolean _tmp7_;
#line 1177 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_SET_BACKGROUND_SLIDESHOW_DIALOG (self), FALSE);
#line 1178 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1179 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = _tmp0_ == ((gint) GTK_RESPONSE_OK);
#line 1180 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->delay_value;
#line 1182 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_delay_value = _tmp1_;
#line 1183 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->desktop_background_checkbox;
#line 1183 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1183 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 1183 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_desktop_background = _tmp4_;
#line 1184 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->screensaver_checkbox;
#line 1184 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1184 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 1184 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_screensaver = _tmp7_;
#line 1186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 1187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (delay_value) {
#line 1187 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*delay_value = _vala_delay_value;
#line 11103 "Dialogs.c"
	}
#line 1187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (desktop_background) {
#line 1187 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*desktop_background = _vala_desktop_background;
#line 11109 "Dialogs.c"
	}
#line 1187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (screensaver) {
#line 1187 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*screensaver = _vala_screensaver;
#line 11115 "Dialogs.c"
	}
#line 1187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 11119 "Dialogs.c"
}


static void set_background_slideshow_dialog_class_init (SetBackgroundSlideshowDialogClass * klass) {
	gint SetBackgroundSlideshowDialog_private_offset;
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	set_background_slideshow_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (SetBackgroundSlideshowDialogPrivate));
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((GObjectClass *) klass)->constructed = (void (*) (GObject *)) set_background_slideshow_dialog_real_constructed;
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = set_background_slideshow_dialog_finalize;
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	SetBackgroundSlideshowDialog_private_offset = g_type_class_get_instance_private_offset (klass);
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Shotwell/ui/set_background_slideshow_dialog.ui");
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "desktop_background_checkbox", FALSE, SetBackgroundSlideshowDialog_private_offset + G_STRUCT_OFFSET (SetBackgroundSlideshowDialogPrivate, desktop_background_checkbox));
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "screensaver_checkbox", FALSE, SetBackgroundSlideshowDialog_private_offset + G_STRUCT_OFFSET (SetBackgroundSlideshowDialogPrivate, screensaver_checkbox));
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "delay_scale", FALSE, SetBackgroundSlideshowDialog_private_offset + G_STRUCT_OFFSET (SetBackgroundSlideshowDialogPrivate, delay_scale));
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "delay_value_label", FALSE, SetBackgroundSlideshowDialog_private_offset + G_STRUCT_OFFSET (SetBackgroundSlideshowDialogPrivate, delay_value_label));
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_checkbox_clicked", G_CALLBACK(_set_background_slideshow_dialog_on_checkbox_clicked_gtk_toggle_button_toggled));
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_delay_scale_value_changed", G_CALLBACK(_set_background_slideshow_dialog_on_delay_scale_value_changed_gtk_range_value_changed));
#line 11149 "Dialogs.c"
}


static void set_background_slideshow_dialog_instance_init (SetBackgroundSlideshowDialog * self) {
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = SET_BACKGROUND_SLIDESHOW_DIALOG_GET_PRIVATE (self);
#line 1128 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->delay_value = 0;
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 11160 "Dialogs.c"
}


static void set_background_slideshow_dialog_finalize (GObject * obj) {
	SetBackgroundSlideshowDialog * self;
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_SET_BACKGROUND_SLIDESHOW_DIALOG, SetBackgroundSlideshowDialog);
#line 1120 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->desktop_background_checkbox);
#line 1122 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->screensaver_checkbox);
#line 1124 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->delay_scale);
#line 1126 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->delay_value_label);
#line 1118 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (set_background_slideshow_dialog_parent_class)->finalize (obj);
#line 11178 "Dialogs.c"
}


GType set_background_slideshow_dialog_get_type (void) {
	static volatile gsize set_background_slideshow_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&set_background_slideshow_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SetBackgroundSlideshowDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) set_background_slideshow_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SetBackgroundSlideshowDialog), 0, (GInstanceInitFunc) set_background_slideshow_dialog_instance_init, NULL };
		GType set_background_slideshow_dialog_type_id;
		set_background_slideshow_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "SetBackgroundSlideshowDialog", &g_define_type_info, 0);
		g_once_init_leave (&set_background_slideshow_dialog_type_id__volatile, set_background_slideshow_dialog_type_id);
	}
	return set_background_slideshow_dialog_type_id__volatile;
}


TextEntryDialog* text_entry_dialog_construct (GType object_type) {
	TextEntryDialog * self = NULL;
	gboolean use_header = FALSE;
	GtkSettings* _tmp0_;
	gint _tmp1_ = 0;
	gboolean _tmp2_;
#line 1203 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_settings_get_default ();
#line 1203 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 1204 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = use_header;
#line 1204 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_) {
#line 1204 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 1;
#line 11210 "Dialogs.c"
	} else {
#line 1204 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 0;
#line 11214 "Dialogs.c"
	}
#line 1204 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (TextEntryDialog*) g_object_new (object_type, "use-header-bar", _tmp1_, NULL);
#line 1201 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 11220 "Dialogs.c"
}


TextEntryDialog* text_entry_dialog_new (void) {
#line 1201 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return text_entry_dialog_construct (TYPE_TEXT_ENTRY_DIALOG);
#line 11227 "Dialogs.c"
}


void text_entry_dialog_set_builder (TextEntryDialog* self, GtkBuilder* builder) {
	GtkBuilder* _tmp0_;
	GtkBuilder* _tmp1_;
#line 1207 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_TEXT_ENTRY_DIALOG (self));
#line 1207 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GTK_IS_BUILDER (builder));
#line 1208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = builder;
#line 1208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->builder);
#line 1208 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->builder = _tmp1_;
#line 11246 "Dialogs.c"
}


static void _text_entry_dialog_on_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 1225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_on_entry_changed ((TextEntryDialog*) self);
#line 11253 "Dialogs.c"
}


void text_entry_dialog_setup (TextEntryDialog* self, TextEntryDialogOnModifyValidateType modify_validate, void* modify_validate_target, const gchar* title, const gchar* label, const gchar* initial_text, GeeCollection* completion_list, const gchar* completion_delimiter) {
	const gchar* _tmp0_;
	AppWindow* _tmp1_;
	AppWindow* _tmp2_;
	GdkWindow* _tmp3_;
	AppWindow* _tmp4_;
	AppWindow* _tmp5_;
	TextEntryDialogOnModifyValidateType _tmp6_;
	void* _tmp6__target;
	GtkLabel* name_label = NULL;
	GtkBuilder* _tmp7_;
	GObject* _tmp8_;
	GtkLabel* _tmp9_;
	GtkLabel* _tmp10_;
	const gchar* _tmp11_;
	GtkBuilder* _tmp12_;
	GObject* _tmp13_;
	GtkEntry* _tmp14_;
	const gchar* _tmp15_ = NULL;
	const gchar* _tmp16_;
	GtkEntry* _tmp18_;
	GtkEntry* _tmp19_;
	GtkEntry* _tmp20_;
	GtkWidget* _tmp21_;
	GtkButton* _tmp22_;
	GtkWidget* _tmp23_;
	GtkButton* _tmp24_;
	GeeCollection* _tmp25_;
#line 1211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_TEXT_ENTRY_DIALOG (self));
#line 1211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (title != NULL);
#line 1211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (label != NULL);
#line 1211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail ((completion_list == NULL) || GEE_IS_COLLECTION (completion_list));
#line 1213 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = title;
#line 1213 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp0_);
#line 1214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 1215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = app_window_get_instance ();
#line 1215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 1215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_widget_get_parent_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 1215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_parent_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), _tmp3_);
#line 1215 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp2_);
#line 1216 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = app_window_get_instance ();
#line 1216 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 1216 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_window_get_type (), GtkWindow));
#line 1216 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp5_);
#line 1217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = modify_validate;
#line 1217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6__target = modify_validate_target;
#line 1217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->on_modify_validate = _tmp6_;
#line 1217 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->on_modify_validate_target = _tmp6__target;
#line 1219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = self->priv->builder;
#line 1219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = gtk_builder_get_object (_tmp7_, "label");
#line 1219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp8_) : NULL);
#line 1219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	name_label = _tmp9_;
#line 1220 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = name_label;
#line 1220 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = label;
#line 1220 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_text (_tmp10_, _tmp11_);
#line 1222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = self->priv->builder;
#line 1222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = gtk_builder_get_object (_tmp12_, "entry");
#line 1222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp13_) : NULL);
#line 1222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->entry);
#line 1222 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->entry = _tmp14_;
#line 1223 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = initial_text;
#line 1223 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp16_ != NULL) {
#line 11353 "Dialogs.c"
		const gchar* _tmp17_;
#line 1223 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = initial_text;
#line 1223 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = _tmp17_;
#line 11359 "Dialogs.c"
	} else {
#line 1223 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = "";
#line 11363 "Dialogs.c"
	}
#line 1223 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = self->priv->entry;
#line 1223 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_text (_tmp18_, _tmp15_);
#line 1224 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = self->priv->entry;
#line 1224 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_widget_get_type (), GtkWidget));
#line 1225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = self->priv->entry;
#line 1225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _text_entry_dialog_on_entry_changed_gtk_editable_changed, self, 0);
#line 1227 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_CANCEL_LABEL, (gint) GTK_RESPONSE_CANCEL);
#line 1227 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_button_get_type (), GtkButton));
#line 1227 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button1);
#line 1227 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->button1 = _tmp22_;
#line 1228 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_SAVE_LABEL, (gint) GTK_RESPONSE_OK);
#line 1228 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_button_get_type (), GtkButton));
#line 1228 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button2);
#line 1228 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->button2 = _tmp24_;
#line 1229 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK);
#line 1231 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = completion_list;
#line 1231 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp25_ != NULL) {
#line 11399 "Dialogs.c"
		EntryMultiCompletion* completion = NULL;
		GeeCollection* _tmp26_;
		const gchar* _tmp27_;
		EntryMultiCompletion* _tmp28_;
		GtkEntry* _tmp29_;
		EntryMultiCompletion* _tmp30_;
#line 1232 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = completion_list;
#line 1232 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = completion_delimiter;
#line 1232 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = entry_multi_completion_new (_tmp26_, _tmp27_);
#line 1232 "/home/jens/Source/shotwell/src/Dialogs.vala"
		completion = _tmp28_;
#line 1234 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = self->priv->entry;
#line 1234 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = completion;
#line 1234 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_entry_set_completion (_tmp29_, G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, gtk_entry_completion_get_type (), GtkEntryCompletion));
#line 1231 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (completion);
#line 11422 "Dialogs.c"
	}
#line 1237 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK);
#line 1211 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (name_label);
#line 11428 "Dialogs.c"
}


gchar* text_entry_dialog_execute (TextEntryDialog* self) {
	gchar* result = NULL;
	gchar* text = NULL;
	TextEntryDialogOnModifyValidateType _tmp0_;
	void* _tmp0__target;
	GtkEntry* _tmp1_;
	const gchar* _tmp2_;
	gboolean _tmp3_;
	gint _tmp4_;
	GtkEntry* _tmp8_;
	guint _tmp9_;
#line 1240 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_TEXT_ENTRY_DIALOG (self), NULL);
#line 1241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = NULL;
#line 1244 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->on_modify_validate;
#line 1244 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0__target = self->priv->on_modify_validate_target;
#line 1244 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->entry;
#line 1244 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_entry_get_text (_tmp1_);
#line 1244 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp0_ (_tmp2_, _tmp0__target);
#line 1244 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_response_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK, _tmp3_);
#line 1246 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1248 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1248 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_ == ((gint) GTK_RESPONSE_OK)) {
#line 11465 "Dialogs.c"
		GtkEntry* _tmp5_;
		const gchar* _tmp6_;
		gchar* _tmp7_;
#line 1249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = self->priv->entry;
#line 1249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = gtk_entry_get_text (_tmp5_);
#line 1249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = g_strdup (_tmp6_);
#line 1249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 1249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text = _tmp7_;
#line 11479 "Dialogs.c"
	}
#line 1251 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = self->priv->entry;
#line 1251 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_parse_name ("changed", GTK_TYPE_EDITABLE, &_tmp9_, NULL, FALSE);
#line 1251 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GTK_TYPE_EDITABLE, GtkEditable), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp9_, 0, NULL, (GCallback) _text_entry_dialog_on_entry_changed_gtk_editable_changed, self);
#line 1252 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1254 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = text;
#line 1254 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 11493 "Dialogs.c"
}


void text_entry_dialog_on_entry_changed (TextEntryDialog* self) {
	TextEntryDialogOnModifyValidateType _tmp0_;
	void* _tmp0__target;
	GtkEntry* _tmp1_;
	const gchar* _tmp2_;
	gboolean _tmp3_;
#line 1257 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_TEXT_ENTRY_DIALOG (self));
#line 1258 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->on_modify_validate;
#line 1258 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0__target = self->priv->on_modify_validate_target;
#line 1258 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->entry;
#line 1258 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_entry_get_text (_tmp1_);
#line 1258 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp0_ (_tmp2_, _tmp0__target);
#line 1258 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_response_sensitive (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK, _tmp3_);
#line 11517 "Dialogs.c"
}


static void text_entry_dialog_class_init (TextEntryDialogClass * klass) {
#line 1192 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_entry_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1192 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (TextEntryDialogPrivate));
#line 1192 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = text_entry_dialog_finalize;
#line 11528 "Dialogs.c"
}


static void text_entry_dialog_instance_init (TextEntryDialog * self) {
#line 1192 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = TEXT_ENTRY_DIALOG_GET_PRIVATE (self);
#line 11535 "Dialogs.c"
}


static void text_entry_dialog_finalize (GObject * obj) {
	TextEntryDialog * self;
#line 1192 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_TEXT_ENTRY_DIALOG, TextEntryDialog);
#line 1196 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->entry);
#line 1197 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->builder);
#line 1198 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button1);
#line 1199 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button2);
#line 1192 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (text_entry_dialog_parent_class)->finalize (obj);
#line 11553 "Dialogs.c"
}


GType text_entry_dialog_get_type (void) {
	static volatile gsize text_entry_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&text_entry_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TextEntryDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) text_entry_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TextEntryDialog), 0, (GInstanceInitFunc) text_entry_dialog_instance_init, NULL };
		GType text_entry_dialog_type_id;
		text_entry_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "TextEntryDialog", &g_define_type_info, 0);
		g_once_init_leave (&text_entry_dialog_type_id__volatile, text_entry_dialog_type_id);
	}
	return text_entry_dialog_type_id__volatile;
}


MultiTextEntryDialog* multi_text_entry_dialog_construct (GType object_type) {
	MultiTextEntryDialog * self = NULL;
	gboolean use_header = FALSE;
	GtkSettings* _tmp0_;
	gint _tmp1_ = 0;
	gboolean _tmp2_;
#line 1273 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_settings_get_default ();
#line 1273 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 1274 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = use_header;
#line 1274 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_) {
#line 1274 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 1;
#line 11585 "Dialogs.c"
	} else {
#line 1274 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = 0;
#line 11589 "Dialogs.c"
	}
#line 1274 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (MultiTextEntryDialog*) g_object_new (object_type, "use-header-bar", _tmp1_, NULL);
#line 1271 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 11595 "Dialogs.c"
}


MultiTextEntryDialog* multi_text_entry_dialog_new (void) {
#line 1271 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return multi_text_entry_dialog_construct (TYPE_MULTI_TEXT_ENTRY_DIALOG);
#line 11602 "Dialogs.c"
}


void multi_text_entry_dialog_set_builder (MultiTextEntryDialog* self, GtkBuilder* builder) {
	GtkBuilder* _tmp0_;
	GtkBuilder* _tmp1_;
#line 1277 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG (self));
#line 1277 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GTK_IS_BUILDER (builder));
#line 1278 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = builder;
#line 1278 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1278 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->builder);
#line 1278 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->builder = _tmp1_;
#line 11621 "Dialogs.c"
}


void multi_text_entry_dialog_setup (MultiTextEntryDialog* self, MultiTextEntryDialogOnModifyValidateType modify_validate, void* modify_validate_target, const gchar* title, const gchar* label, const gchar* initial_text) {
	const gchar* _tmp0_;
	AppWindow* _tmp1_;
	AppWindow* _tmp2_;
	GdkWindow* _tmp3_;
	AppWindow* _tmp4_;
	AppWindow* _tmp5_;
	MultiTextEntryDialogOnModifyValidateType _tmp6_;
	void* _tmp6__target;
	GtkBuilder* _tmp7_;
	GObject* _tmp8_;
	GtkTextView* _tmp9_;
	GtkTextView* _tmp10_;
	GtkTextView* _tmp11_;
	GtkTextBuffer* _tmp12_;
	GtkTextBuffer* _tmp13_;
	const gchar* _tmp14_ = NULL;
	const gchar* _tmp15_;
	GtkTextView* _tmp17_;
	GtkTextBuffer* _tmp18_;
	GtkTextBuffer* _tmp19_;
	GtkTextView* _tmp20_;
	GtkWidget* _tmp21_;
	GtkButton* _tmp22_;
	GtkWidget* _tmp23_;
	GtkButton* _tmp24_;
#line 1281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG (self));
#line 1281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (title != NULL);
#line 1281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (label != NULL);
#line 1282 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = title;
#line 1282 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp0_);
#line 1283 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 1284 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_default_size (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), 500, 300);
#line 1285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = app_window_get_instance ();
#line 1285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 1285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_widget_get_parent_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget));
#line 1285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_parent_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), _tmp3_);
#line 1285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp2_);
#line 1286 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = app_window_get_instance ();
#line 1286 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 1286 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_window_get_type (), GtkWindow));
#line 1286 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp5_);
#line 1287 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = modify_validate;
#line 1287 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6__target = modify_validate_target;
#line 1287 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->on_modify_validate = _tmp6_;
#line 1287 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->on_modify_validate_target = _tmp6__target;
#line 1289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = self->priv->builder;
#line 1289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = gtk_builder_get_object (_tmp7_, "textview1");
#line 1289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, gtk_text_view_get_type ()) ? ((GtkTextView*) _tmp8_) : NULL);
#line 1289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->entry);
#line 1289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->entry = _tmp9_;
#line 1290 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = self->priv->entry;
#line 1290 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_text_view_set_wrap_mode (_tmp10_, GTK_WRAP_WORD);
#line 1291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = self->priv->entry;
#line 1291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = gtk_text_buffer_new (NULL);
#line 1291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _tmp12_;
#line 1291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_text_view_set_buffer (_tmp11_, _tmp13_);
#line 1291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp13_);
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = initial_text;
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp15_ != NULL) {
#line 11719 "Dialogs.c"
		const gchar* _tmp16_;
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = initial_text;
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = _tmp16_;
#line 11725 "Dialogs.c"
	} else {
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = "";
#line 11729 "Dialogs.c"
	}
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = self->priv->entry;
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = gtk_text_view_get_buffer (_tmp17_);
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = _tmp18_;
#line 1292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_set (_tmp19_, "text", _tmp14_, NULL);
#line 1294 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = self->priv->entry;
#line 1294 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_widget_get_type (), GtkWidget));
#line 1296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_CANCEL_LABEL, (gint) GTK_RESPONSE_CANCEL);
#line 1296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_button_get_type (), GtkButton));
#line 1296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button1);
#line 1296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->button1 = _tmp22_;
#line 1297 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_SAVE_LABEL, (gint) GTK_RESPONSE_OK);
#line 1297 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_button_get_type (), GtkButton));
#line 1297 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button2);
#line 1297 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->button2 = _tmp24_;
#line 1298 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK);
#line 11761 "Dialogs.c"
}


gchar* multi_text_entry_dialog_execute (MultiTextEntryDialog* self) {
	gchar* result = NULL;
	gchar* text = NULL;
	gint _tmp0_;
#line 1301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MULTI_TEXT_ENTRY_DIALOG (self), NULL);
#line 1302 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = NULL;
#line 1304 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1306 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1306 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == ((gint) GTK_RESPONSE_OK)) {
#line 11779 "Dialogs.c"
		GtkTextView* _tmp1_;
		GtkTextBuffer* _tmp2_;
		GtkTextBuffer* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
#line 1307 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = self->priv->entry;
#line 1307 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = gtk_text_view_get_buffer (_tmp1_);
#line 1307 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = _tmp2_;
#line 1307 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_get (_tmp3_, "text", &_tmp4_, NULL);
#line 1307 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = _tmp4_;
#line 1307 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 1307 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text = _tmp5_;
#line 11799 "Dialogs.c"
	}
#line 1309 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1311 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = text;
#line 1311 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 11807 "Dialogs.c"
}


static void multi_text_entry_dialog_class_init (MultiTextEntryDialogClass * klass) {
#line 1262 "/home/jens/Source/shotwell/src/Dialogs.vala"
	multi_text_entry_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1262 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (MultiTextEntryDialogPrivate));
#line 1262 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = multi_text_entry_dialog_finalize;
#line 11818 "Dialogs.c"
}


static void multi_text_entry_dialog_instance_init (MultiTextEntryDialog * self) {
#line 1262 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = MULTI_TEXT_ENTRY_DIALOG_GET_PRIVATE (self);
#line 11825 "Dialogs.c"
}


static void multi_text_entry_dialog_finalize (GObject * obj) {
	MultiTextEntryDialog * self;
#line 1262 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_MULTI_TEXT_ENTRY_DIALOG, MultiTextEntryDialog);
#line 1266 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->entry);
#line 1267 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->builder);
#line 1268 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button1);
#line 1269 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->button2);
#line 1262 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (multi_text_entry_dialog_parent_class)->finalize (obj);
#line 11843 "Dialogs.c"
}


GType multi_text_entry_dialog_get_type (void) {
	static volatile gsize multi_text_entry_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&multi_text_entry_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (MultiTextEntryDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) multi_text_entry_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (MultiTextEntryDialog), 0, (GInstanceInitFunc) multi_text_entry_dialog_instance_init, NULL };
		GType multi_text_entry_dialog_type_id;
		multi_text_entry_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "MultiTextEntryDialog", &g_define_type_info, 0);
		g_once_init_leave (&multi_text_entry_dialog_type_id__volatile, multi_text_entry_dialog_type_id);
	}
	return multi_text_entry_dialog_type_id__volatile;
}


EventRenameDialog* event_rename_dialog_construct (GType object_type, const gchar* event_name) {
	EventRenameDialog* self = NULL;
	const gchar* _tmp0_;
#line 1317 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = event_name;
#line 1317 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EventRenameDialog*) text_entry_dialog_mediator_construct (object_type, _ ("Rename Event"), _ ("Name:"), _tmp0_, NULL, NULL);
#line 1316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 11868 "Dialogs.c"
}


EventRenameDialog* event_rename_dialog_new (const gchar* event_name) {
#line 1316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return event_rename_dialog_construct (TYPE_EVENT_RENAME_DIALOG, event_name);
#line 11875 "Dialogs.c"
}


static gchar* event_rename_dialog_real_execute (EventRenameDialog* self) {
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 1321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 1321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 1321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = event_prep_event_name (_tmp1_);
#line 1321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 1321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 1321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp3_;
#line 1321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 11899 "Dialogs.c"
}


gchar* event_rename_dialog_execute (EventRenameDialog* self) {
#line 1320 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EVENT_RENAME_DIALOG (self), NULL);
#line 1320 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return EVENT_RENAME_DIALOG_GET_CLASS (self)->execute (self);
#line 11908 "Dialogs.c"
}


static void event_rename_dialog_class_init (EventRenameDialogClass * klass) {
#line 1315 "/home/jens/Source/shotwell/src/Dialogs.vala"
	event_rename_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1315 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((EventRenameDialogClass *) klass)->execute = (gchar* (*) (EventRenameDialog *)) event_rename_dialog_real_execute;
#line 11917 "Dialogs.c"
}


static void event_rename_dialog_instance_init (EventRenameDialog * self) {
}


GType event_rename_dialog_get_type (void) {
	static volatile gsize event_rename_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&event_rename_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EventRenameDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) event_rename_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EventRenameDialog), 0, (GInstanceInitFunc) event_rename_dialog_instance_init, NULL };
		GType event_rename_dialog_type_id;
		event_rename_dialog_type_id = g_type_register_static (TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, "EventRenameDialog", &g_define_type_info, 0);
		g_once_init_leave (&event_rename_dialog_type_id__volatile, event_rename_dialog_type_id);
	}
	return event_rename_dialog_type_id__volatile;
}


EditTitleDialog* edit_title_dialog_construct (GType object_type, const gchar* photo_title) {
	EditTitleDialog* self = NULL;
	const gchar* _tmp0_;
#line 1328 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = photo_title;
#line 1328 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EditTitleDialog*) text_entry_dialog_mediator_construct (object_type, C_ ("Dialog Title", "Edit Title"), _ ("Title:"), _tmp0_, NULL, NULL);
#line 1326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 11946 "Dialogs.c"
}


EditTitleDialog* edit_title_dialog_new (const gchar* photo_title) {
#line 1326 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return edit_title_dialog_construct (TYPE_EDIT_TITLE_DIALOG, photo_title);
#line 11953 "Dialogs.c"
}


static gchar* edit_title_dialog_real_execute (EditTitleDialog* self) {
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 1333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 1333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 1333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = media_source_prep_title (_tmp1_);
#line 1333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 1333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 1333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp3_;
#line 1333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 11977 "Dialogs.c"
}


gchar* edit_title_dialog_execute (EditTitleDialog* self) {
#line 1332 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EDIT_TITLE_DIALOG (self), NULL);
#line 1332 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return EDIT_TITLE_DIALOG_GET_CLASS (self)->execute (self);
#line 11986 "Dialogs.c"
}


static gboolean edit_title_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text) {
	EditTitleDialog * self;
	gboolean result = FALSE;
#line 1336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EDIT_TITLE_DIALOG, EditTitleDialog);
#line 1336 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 1337 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 1337 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12001 "Dialogs.c"
}


static void edit_title_dialog_class_init (EditTitleDialogClass * klass) {
#line 1325 "/home/jens/Source/shotwell/src/Dialogs.vala"
	edit_title_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1325 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((EditTitleDialogClass *) klass)->execute = (gchar* (*) (EditTitleDialog *)) edit_title_dialog_real_execute;
#line 1325 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (TextEntryDialogMediator *, const gchar*)) edit_title_dialog_real_on_modify_validate;
#line 12012 "Dialogs.c"
}


static void edit_title_dialog_instance_init (EditTitleDialog * self) {
}


GType edit_title_dialog_get_type (void) {
	static volatile gsize edit_title_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&edit_title_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EditTitleDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) edit_title_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EditTitleDialog), 0, (GInstanceInitFunc) edit_title_dialog_instance_init, NULL };
		GType edit_title_dialog_type_id;
		edit_title_dialog_type_id = g_type_register_static (TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, "EditTitleDialog", &g_define_type_info, 0);
		g_once_init_leave (&edit_title_dialog_type_id__volatile, edit_title_dialog_type_id);
	}
	return edit_title_dialog_type_id__volatile;
}


EditCommentDialog* edit_comment_dialog_construct (GType object_type, const gchar* comment, gboolean is_event) {
	EditCommentDialog* self = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_;
	gchar* title_tmp = NULL;
	gchar* _tmp2_;
	const gchar* _tmp3_;
#line 1343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = is_event;
#line 1343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_) {
#line 1345 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _ ("Edit Event Comment");
#line 12045 "Dialogs.c"
	} else {
#line 1346 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _ ("Edit Photo/Video Comment");
#line 12049 "Dialogs.c"
	}
#line 1343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = g_strdup (_tmp0_);
#line 1343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	title_tmp = _tmp2_;
#line 1347 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = comment;
#line 1347 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (EditCommentDialog*) multi_text_entry_dialog_mediator_construct (object_type, title_tmp, _ ("Comment:"), _tmp3_);
#line 1342 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (title_tmp);
#line 1342 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 12063 "Dialogs.c"
}


EditCommentDialog* edit_comment_dialog_new (const gchar* comment, gboolean is_event) {
#line 1342 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return edit_comment_dialog_construct (TYPE_EDIT_COMMENT_DIALOG, comment, is_event);
#line 12070 "Dialogs.c"
}


static gchar* edit_comment_dialog_real_execute (EditCommentDialog* self) {
	gchar* result = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 1351 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _multi_text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, MultiTextEntryDialogMediator));
#line 1351 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 1351 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = media_source_prep_comment (_tmp1_);
#line 1351 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 1351 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp1_);
#line 1351 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp3_;
#line 1351 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12094 "Dialogs.c"
}


gchar* edit_comment_dialog_execute (EditCommentDialog* self) {
#line 1350 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_EDIT_COMMENT_DIALOG (self), NULL);
#line 1350 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return EDIT_COMMENT_DIALOG_GET_CLASS (self)->execute (self);
#line 12103 "Dialogs.c"
}


static gboolean edit_comment_dialog_real_on_modify_validate (MultiTextEntryDialogMediator* base, const gchar* text) {
	EditCommentDialog * self;
	gboolean result = FALSE;
#line 1354 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_EDIT_COMMENT_DIALOG, EditCommentDialog);
#line 1354 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 1355 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 1355 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12118 "Dialogs.c"
}


static void edit_comment_dialog_class_init (EditCommentDialogClass * klass) {
#line 1341 "/home/jens/Source/shotwell/src/Dialogs.vala"
	edit_comment_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1341 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((EditCommentDialogClass *) klass)->execute = (gchar* (*) (EditCommentDialog *)) edit_comment_dialog_real_execute;
#line 1341 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((MultiTextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (MultiTextEntryDialogMediator *, const gchar*)) edit_comment_dialog_real_on_modify_validate;
#line 12129 "Dialogs.c"
}


static void edit_comment_dialog_instance_init (EditCommentDialog * self) {
}


GType edit_comment_dialog_get_type (void) {
	static volatile gsize edit_comment_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&edit_comment_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (EditCommentDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) edit_comment_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EditCommentDialog), 0, (GInstanceInitFunc) edit_comment_dialog_instance_init, NULL };
		GType edit_comment_dialog_type_id;
		edit_comment_dialog_type_id = g_type_register_static (TYPE_MULTI_TEXT_ENTRY_DIALOG_MEDIATOR, "EditCommentDialog", &g_define_type_info, 0);
		g_once_init_leave (&edit_comment_dialog_type_id__volatile, edit_comment_dialog_type_id);
	}
	return edit_comment_dialog_type_id__volatile;
}


GtkResponseType remove_from_library_dialog (GtkWindow* owner, const gchar* title, const gchar* user_message, gint count) {
	GtkResponseType result = 0;
	gchar* trash_action = NULL;
	gint _tmp0_;
	gchar* _tmp1_;
	GtkMessageDialog* dialog = NULL;
	GtkWindow* _tmp2_;
	const gchar* _tmp3_;
	GtkMessageDialog* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	GtkResponseType _result_ = 0;
	gint _tmp9_;
#line 1361 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), 0);
#line 1361 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, 0);
#line 1361 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (user_message != NULL, 0);
#line 1363 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = count;
#line 1363 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strdup (ngettext ("Remove and _Trash File", "Remove and _Trash Files", (gulong) _tmp0_));
#line 1363 "/home/jens/Source/shotwell/src/Dialogs.vala"
	trash_action = _tmp1_;
#line 1365 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = owner;
#line 1365 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = user_message;
#line 1365 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp2_, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_CANCEL, "%s", _tmp3_);
#line 1365 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp4_);
#line 1365 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp4_;
#line 1367 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Remove From Library"), (gint) GTK_RESPONSE_NO);
#line 1368 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), trash_action, (gint) GTK_RESPONSE_YES);
#line 1373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = title;
#line 1373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = user_message;
#line 1373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = build_alert_body_text (_tmp5_, _tmp6_, TRUE);
#line 1373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 1373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_message_dialog_set_markup (dialog, _tmp8_);
#line 1373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp8_);
#line 1375 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 1375 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp9_;
#line 1377 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 1379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 1379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 1379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (trash_action);
#line 1379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12216 "Dialogs.c"
}


GtkResponseType remove_from_filesystem_dialog (GtkWindow* owner, const gchar* title, const gchar* user_message) {
	GtkResponseType result = 0;
	GtkMessageDialog* dialog = NULL;
	GtkWindow* _tmp0_;
	const gchar* _tmp1_;
	GtkMessageDialog* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GtkResponseType _result_ = 0;
	gint _tmp7_;
#line 1383 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), 0);
#line 1383 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, 0);
#line 1383 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (user_message != NULL, 0);
#line 1385 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = owner;
#line 1385 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = user_message;
#line 1385 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp0_, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE, "%s", _tmp1_);
#line 1385 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp2_);
#line 1385 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp2_;
#line 1387 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Keep"), (gint) GTK_RESPONSE_NO);
#line 1388 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Delete"), (gint) GTK_RESPONSE_YES);
#line 1389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_NO);
#line 1391 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = title;
#line 1391 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = user_message;
#line 1391 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = build_alert_body_text (_tmp3_, _tmp4_, TRUE);
#line 1391 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 1391 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_message_dialog_set_markup (dialog, _tmp6_);
#line 1391 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp6_);
#line 1393 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 1393 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp7_;
#line 1395 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 1397 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 1397 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 1397 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12278 "Dialogs.c"
}


gboolean revert_editable_dialog (GtkWindow* owner, GeeCollection* photos) {
	gboolean result = FALSE;
	gint count = 0;
	gint _tmp9_;
	const gchar* _tmp10_ = NULL;
	gint _tmp11_;
	gchar* headline = NULL;
	gchar* _tmp12_;
	gchar* msg = NULL;
	gint _tmp13_;
	gint _tmp14_;
	gchar* _tmp15_;
	const gchar* _tmp16_ = NULL;
	gint _tmp17_;
	gchar* action = NULL;
	gchar* _tmp18_;
	GtkMessageDialog* dialog = NULL;
	GtkWindow* _tmp19_;
	const gchar* _tmp20_;
	GtkMessageDialog* _tmp21_;
	GtkMessageDialog* _tmp22_;
	GtkMessageDialog* _tmp23_;
	const gchar* _tmp24_;
	GtkMessageDialog* _tmp25_;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	GtkResponseType _result_ = 0;
	GtkMessageDialog* _tmp30_;
	gint _tmp31_;
	GtkMessageDialog* _tmp32_;
	GtkResponseType _tmp33_;
#line 1400 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), FALSE);
#line 1400 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (photos), FALSE);
#line 1401 "/home/jens/Source/shotwell/src/Dialogs.vala"
	count = 0;
#line 12321 "Dialogs.c"
	{
		GeeIterator* _photo_it = NULL;
		GeeCollection* _tmp0_;
		GeeIterator* _tmp1_;
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = photos;
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ITERABLE, GeeIterable));
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_photo_it = _tmp1_;
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 12334 "Dialogs.c"
			GeeIterator* _tmp2_;
			gboolean _tmp3_;
			Photo* photo = NULL;
			GeeIterator* _tmp4_;
			gpointer _tmp5_;
			Photo* _tmp6_;
			gboolean _tmp7_;
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = _photo_it;
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = gee_iterator_next (_tmp2_);
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp3_) {
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 12350 "Dialogs.c"
			}
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = _photo_it;
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = gee_iterator_get (_tmp4_);
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
			photo = (Photo*) _tmp5_;
#line 1403 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = photo;
#line 1403 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = photo_has_editable (_tmp6_);
#line 1403 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp7_) {
#line 12364 "Dialogs.c"
				gint _tmp8_;
#line 1404 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp8_ = count;
#line 1404 "/home/jens/Source/shotwell/src/Dialogs.vala"
				count = _tmp8_ + 1;
#line 12370 "Dialogs.c"
			}
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (photo);
#line 12374 "Dialogs.c"
		}
#line 1402 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_photo_it);
#line 12378 "Dialogs.c"
	}
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = count;
#line 1407 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp9_ == 0) {
#line 1408 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 1408 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 12388 "Dialogs.c"
	}
#line 1410 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = count;
#line 1410 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp11_ == 1) {
#line 1410 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _ ("Revert External Edit?");
#line 12396 "Dialogs.c"
	} else {
#line 1410 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _ ("Revert External Edits?");
#line 12400 "Dialogs.c"
	}
#line 1410 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = g_strdup (_tmp10_);
#line 1410 "/home/jens/Source/shotwell/src/Dialogs.vala"
	headline = _tmp12_;
#line 1411 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = count;
#line 1411 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = count;
#line 1411 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = g_strdup_printf (ngettext ("This will destroy all changes made to the external file. Continue?", "This will destroy all changes made to %d external files. Continue?", (gulong) _tmp13_), _tmp14_);
#line 1411 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp15_;
#line 1416 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = count;
#line 1416 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp17_ == 1) {
#line 1416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = _ ("Re_vert External Edit");
#line 12420 "Dialogs.c"
	} else {
#line 1416 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = _ ("Re_vert External Edits");
#line 12424 "Dialogs.c"
	}
#line 1416 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = g_strdup (_tmp16_);
#line 1416 "/home/jens/Source/shotwell/src/Dialogs.vala"
	action = _tmp18_;
#line 1418 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = owner;
#line 1418 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = msg;
#line 1418 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp19_, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "%s", _tmp20_);
#line 1418 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp21_);
#line 1418 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp21_;
#line 1420 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = dialog;
#line 1420 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_dialog_get_type (), GtkDialog), _ ("_Cancel"), (gint) GTK_RESPONSE_CANCEL);
#line 1421 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = dialog;
#line 1421 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = action;
#line 1421 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_dialog_get_type (), GtkDialog), _tmp24_, (gint) GTK_RESPONSE_YES);
#line 1423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = dialog;
#line 1423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = headline;
#line 1423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = msg;
#line 1423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = build_alert_body_text (_tmp26_, _tmp27_, TRUE);
#line 1423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = _tmp28_;
#line 1423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_message_dialog_set_markup (_tmp25_, _tmp29_);
#line 1423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp29_);
#line 1425 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = dialog;
#line 1425 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, gtk_dialog_get_type (), GtkDialog));
#line 1425 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp31_;
#line 1427 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = dialog;
#line 1427 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_widget_get_type (), GtkWidget));
#line 1429 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = _result_;
#line 1429 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp33_ == GTK_RESPONSE_YES;
#line 1429 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 1429 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (action);
#line 1429 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 1429 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (headline);
#line 1429 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12488 "Dialogs.c"
}


gboolean remove_offline_dialog (GtkWindow* owner, gint count) {
	gboolean result = FALSE;
	gint _tmp0_;
	gchar* msg = NULL;
	gint _tmp1_;
	gint _tmp2_;
	gchar* _tmp3_;
	GtkMessageDialog* dialog = NULL;
	GtkWindow* _tmp4_;
	const gchar* _tmp5_;
	GtkMessageDialog* _tmp6_;
	GtkMessageDialog* _tmp7_;
	GtkMessageDialog* _tmp8_;
	const gchar* _tmp9_ = NULL;
	gint _tmp10_;
	GtkMessageDialog* _tmp11_;
	GtkResponseType _result_ = 0;
	GtkMessageDialog* _tmp12_;
	gint _tmp13_;
	GtkMessageDialog* _tmp14_;
	GtkResponseType _tmp15_;
#line 1432 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), FALSE);
#line 1433 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = count;
#line 1433 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == 0) {
#line 1434 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 1434 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 12523 "Dialogs.c"
	}
#line 1436 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = count;
#line 1436 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = count;
#line 1436 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup_printf (ngettext ("This will remove the photo from the library. Continue?", "This will remove %d photos from the library. Continue?", (gulong) _tmp1_), _tmp2_);
#line 1436 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp3_;
#line 1441 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = owner;
#line 1441 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = msg;
#line 1441 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = (GtkMessageDialog*) gtk_message_dialog_new (_tmp4_, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE, "%s", _tmp5_);
#line 1441 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp6_);
#line 1441 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp6_;
#line 1443 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = dialog;
#line 1443 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_dialog_get_type (), GtkDialog), _ ("_Cancel"), (gint) GTK_RESPONSE_CANCEL);
#line 1444 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = dialog;
#line 1444 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_dialog_get_type (), GtkDialog), _ ("_Remove"), (gint) GTK_RESPONSE_OK);
#line 1445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = count;
#line 1445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp10_ == 1) {
#line 1445 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = _ ("Remove Photo From Library");
#line 12557 "Dialogs.c"
	} else {
#line 1445 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = _ ("Remove Photos From Library");
#line 12561 "Dialogs.c"
	}
#line 1445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = dialog;
#line 1445 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_window_get_type (), GtkWindow), _tmp9_);
#line 1447 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = dialog;
#line 1447 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_dialog_get_type (), GtkDialog));
#line 1447 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp13_;
#line 1449 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = dialog;
#line 1449 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_widget_get_type (), GtkWidget));
#line 1451 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = _result_;
#line 1451 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp15_ == GTK_RESPONSE_OK;
#line 1451 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 1451 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 1451 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12587 "Dialogs.c"
}


static void _progress_dialog_on_cancel_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1484 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress_dialog_on_cancel ((ProgressDialog*) self);
#line 12594 "Dialogs.c"
}


static gboolean _progress_dialog_on_window_closed_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self) {
	gboolean result;
	result = progress_dialog_on_window_closed ((ProgressDialog*) self);
#line 1485 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 12603 "Dialogs.c"
}


ProgressDialog* progress_dialog_construct (GType object_type, GtkWindow* owner, const gchar* text, GCancellable* cancellable) {
	ProgressDialog * self = NULL;
	GCancellable* _tmp0_;
	GCancellable* _tmp1_;
	const gchar* _tmp2_;
	GtkWindow* _tmp3_;
	GtkProgressBar* _tmp5_;
	GtkProgressBar* _tmp6_;
	GtkBox* vbox_bar = NULL;
	GtkBox* _tmp7_;
	GtkBox* _tmp8_;
	GtkProgressBar* _tmp9_;
	GCancellable* _tmp10_;
	GtkBox* hbox = NULL;
	GtkBox* _tmp13_;
	GtkBox* _tmp14_;
	GtkBox* _tmp15_;
	GtkButton* _tmp16_;
	GtkLabel* primary_text_label = NULL;
	GtkLabel* _tmp19_;
	const gchar* _tmp20_;
	gchar* _tmp21_;
	gchar* _tmp22_;
	GtkBox* vbox = NULL;
	GtkBox* _tmp23_;
	GtkBox* _tmp24_;
	gulong _tmp25_;
#line 1466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail ((owner == NULL) || GTK_IS_WINDOW (owner), NULL);
#line 1466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, NULL);
#line 1466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail ((cancellable == NULL) || G_IS_CANCELLABLE (cancellable), NULL);
#line 1466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (ProgressDialog*) g_object_new (object_type, NULL);
#line 1467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = cancellable;
#line 1467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->cancellable);
#line 1467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->cancellable = _tmp1_;
#line 1469 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = text;
#line 1469 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp2_);
#line 1470 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 1471 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = owner;
#line 1471 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ != NULL) {
#line 12660 "Dialogs.c"
		GtkWindow* _tmp4_;
#line 1472 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = owner;
#line 1472 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp4_);
#line 12666 "Dialogs.c"
	}
#line 1473 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_modal (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 1474 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_type_hint (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), GDK_WINDOW_TYPE_HINT_DIALOG);
#line 1476 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->progress_bar;
#line 1476 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), 300, -1);
#line 1477 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = self->priv->progress_bar;
#line 1477 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_progress_bar_set_show_text (_tmp6_, TRUE);
#line 1479 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 1479 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp7_);
#line 1479 "/home/jens/Source/shotwell/src/Dialogs.vala"
	vbox_bar = _tmp7_;
#line 1480 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = vbox_bar;
#line 1480 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = self->priv->progress_bar;
#line 1480 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp8_, G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1482 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = cancellable;
#line 1482 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp10_ != NULL) {
#line 12696 "Dialogs.c"
		GtkButton* _tmp11_;
		GtkButton* _tmp12_;
#line 1483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = (GtkButton*) gtk_button_new_with_mnemonic (RESOURCES_CANCEL_LABEL);
#line 1483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp11_);
#line 1483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (self->priv->cancel_button);
#line 1483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->cancel_button = _tmp11_;
#line 1484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = self->priv->cancel_button;
#line 1484 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_signal_connect_object (_tmp12_, "clicked", (GCallback) _progress_dialog_on_cancel_gtk_button_clicked, self, 0);
#line 1485 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "delete-event", (GCallback) _progress_dialog_on_window_closed_gtk_widget_delete_event, self, 0);
#line 12713 "Dialogs.c"
	}
#line 1488 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
#line 1488 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp13_);
#line 1488 "/home/jens/Source/shotwell/src/Dialogs.vala"
	hbox = _tmp13_;
#line 1489 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = hbox;
#line 1489 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = vbox_bar;
#line 1489 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp14_, G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1490 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = self->priv->cancel_button;
#line 1490 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp16_ != NULL) {
#line 12731 "Dialogs.c"
		GtkBox* _tmp17_;
		GtkButton* _tmp18_;
#line 1491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = hbox;
#line 1491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = self->priv->cancel_button;
#line 1491 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_box_pack_end (_tmp17_, G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 12740 "Dialogs.c"
	}
#line 1493 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = (GtkLabel*) gtk_label_new ("");
#line 1493 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp19_);
#line 1493 "/home/jens/Source/shotwell/src/Dialogs.vala"
	primary_text_label = _tmp19_;
#line 1494 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = text;
#line 1494 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = g_strdup_printf ("<span weight=\"bold\">%s</span>", _tmp20_);
#line 1494 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = _tmp21_;
#line 1494 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_markup (primary_text_label, _tmp22_);
#line 1494 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp22_);
#line 1495 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_xalign (primary_text_label, 0.0f);
#line 1496 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_yalign (primary_text_label, 0.5f);
#line 1498 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
#line 1498 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp23_);
#line 1498 "/home/jens/Source/shotwell/src/Dialogs.vala"
	vbox = _tmp23_;
#line 1499 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (vbox, G_TYPE_CHECK_INSTANCE_CAST (primary_text_label, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1500 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = hbox;
#line 1500 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (vbox, G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1501 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (vbox, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_CENTER);
#line 1502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (vbox, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_CENTER);
#line 1503 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_hexpand (G_TYPE_CHECK_INSTANCE_CAST (vbox, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1504 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_vexpand (G_TYPE_CHECK_INSTANCE_CAST (vbox, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1505 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_margin_start (G_TYPE_CHECK_INSTANCE_CAST (vbox, gtk_widget_get_type (), GtkWidget), 12);
#line 1506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_margin_end (G_TYPE_CHECK_INSTANCE_CAST (vbox, gtk_widget_get_type (), GtkWidget), 12);
#line 1507 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_margin_top (G_TYPE_CHECK_INSTANCE_CAST (vbox, gtk_widget_get_type (), GtkWidget), 12);
#line 1508 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_margin_bottom (G_TYPE_CHECK_INSTANCE_CAST (vbox, gtk_widget_get_type (), GtkWidget), 12);
#line 1510 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (vbox, gtk_widget_get_type (), GtkWidget));
#line 1512 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = now_ms ();
#line 1512 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->time_started = _tmp25_;
#line 1466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (vbox);
#line 1466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (primary_text_label);
#line 1466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (hbox);
#line 1466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (vbox_bar);
#line 1466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 12806 "Dialogs.c"
}


ProgressDialog* progress_dialog_new (GtkWindow* owner, const gchar* text, GCancellable* cancellable) {
#line 1466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return progress_dialog_construct (TYPE_PROGRESS_DIALOG, owner, text, cancellable);
#line 12813 "Dialogs.c"
}


static void progress_dialog_real_realize (GtkWidget* base) {
	ProgressDialog * self;
	GCancellable* _tmp0_;
#line 1515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PROGRESS_DIALOG, ProgressDialog);
#line 1516 "/home/jens/Source/shotwell/src/Dialogs.vala"
	GTK_WIDGET_CLASS (progress_dialog_parent_class)->realize (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), gtk_widget_get_type (), GtkWidget));
#line 1519 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->cancellable;
#line 1519 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == NULL) {
#line 12828 "Dialogs.c"
		GdkWindow* _tmp1_;
#line 1520 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = gtk_widget_get_window (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1520 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gdk_window_set_functions (_tmp1_, GDK_FUNC_MOVE);
#line 12834 "Dialogs.c"
	}
}


void progress_dialog_update_display_every (ProgressDialog* self, gint update_every) {
	gint _tmp0_;
	gint _tmp1_;
#line 1523 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1524 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = update_every;
#line 1524 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_assert (_tmp0_ >= 1, "update_every >= 1");
#line 1526 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = update_every;
#line 1526 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->update_every = _tmp1_;
#line 12852 "Dialogs.c"
}


void progress_dialog_set_minimum_on_screen_time_msec (ProgressDialog* self, gint minimum_on_screen_time_msec) {
	gint _tmp0_;
#line 1529 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1530 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = minimum_on_screen_time_msec;
#line 1530 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->minimum_on_screen_time_msec = _tmp0_;
#line 12864 "Dialogs.c"
}


void progress_dialog_set_fraction (ProgressDialog* self, gint current, gint total) {
	gint _tmp0_;
	gint _tmp1_;
#line 1533 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = current;
#line 1534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = total;
#line 1534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress_dialog_set_percentage (self, ((gdouble) _tmp0_) / ((gdouble) _tmp1_));
#line 12879 "Dialogs.c"
}


void progress_dialog_set_percentage (ProgressDialog* self, gdouble pct) {
	gdouble _tmp0_;
	gdouble _tmp1_;
	gdouble _tmp2_;
	GtkProgressBar* _tmp3_;
	gdouble _tmp4_;
	GtkProgressBar* _tmp5_;
	gdouble _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
#line 1537 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = pct;
#line 1538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = CLAMP (_tmp0_, 0.0, 1.0);
#line 1538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pct = _tmp1_;
#line 1540 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = pct;
#line 1540 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress_dialog_maybe_show_all (self, _tmp2_);
#line 1542 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->priv->progress_bar;
#line 1542 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = pct;
#line 1542 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_progress_bar_set_fraction (_tmp3_, _tmp4_);
#line 1543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->progress_bar;
#line 1543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = pct;
#line 1543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = g_strdup_printf (_ ("%d%%"), (gint) (_tmp6_ * 100.0));
#line 1543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 1543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_progress_bar_set_text (_tmp5_, _tmp8_);
#line 1543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp8_);
#line 12923 "Dialogs.c"
}


void progress_dialog_set_status (ProgressDialog* self, const gchar* text) {
	GtkProgressBar* _tmp0_;
	const gchar* _tmp1_;
#line 1551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (text != NULL);
#line 1552 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->progress_bar;
#line 1552 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text;
#line 1552 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_progress_bar_set_text (_tmp0_, _tmp1_);
#line 1558 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 12942 "Dialogs.c"
}


gboolean progress_dialog_monitor (ProgressDialog* self, guint64 count, guint64 total, gboolean do_event_loop) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	guint64 _tmp1_;
	gboolean _tmp8_ = FALSE;
	GCancellable* _tmp9_;
	gboolean keep_going = FALSE;
	gboolean _tmp12_;
#line 1562 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PROGRESS_DIALOG (self), FALSE);
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->last_count;
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == G_MAXUINT64) {
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = TRUE;
#line 12962 "Dialogs.c"
	} else {
		guint64 _tmp2_;
		guint64 _tmp3_;
		gint _tmp4_;
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = count;
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = self->priv->last_count;
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = self->priv->update_every;
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = (_tmp2_ - _tmp3_) >= ((guint64) _tmp4_);
#line 12975 "Dialogs.c"
	}
#line 1563 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 12979 "Dialogs.c"
		guint64 _tmp5_;
		guint64 _tmp6_;
		guint64 _tmp7_;
#line 1564 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = count;
#line 1564 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = total;
#line 1564 "/home/jens/Source/shotwell/src/Dialogs.vala"
		progress_dialog_set_percentage (self, ((gdouble) _tmp5_) / ((gdouble) _tmp6_));
#line 1565 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = count;
#line 1565 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->last_count = _tmp7_;
#line 12993 "Dialogs.c"
	}
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = self->priv->cancellable;
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp9_ != NULL) {
#line 12999 "Dialogs.c"
		GCancellable* _tmp10_;
		gboolean _tmp11_;
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = self->priv->cancellable;
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = g_cancellable_is_cancelled (_tmp10_);
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = !_tmp11_;
#line 13008 "Dialogs.c"
	} else {
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = TRUE;
#line 13012 "Dialogs.c"
	}
#line 1568 "/home/jens/Source/shotwell/src/Dialogs.vala"
	keep_going = _tmp8_;
#line 1576 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = do_event_loop;
#line 1576 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp12_) {
#line 1577 "/home/jens/Source/shotwell/src/Dialogs.vala"
		spin_event_loop ();
#line 13022 "Dialogs.c"
	}
#line 1579 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = keep_going;
#line 1579 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 13028 "Dialogs.c"
}


void progress_dialog_close (ProgressDialog* self) {
#line 1582 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1587 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1588 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 13039 "Dialogs.c"
}


static gboolean progress_dialog_on_window_closed (ProgressDialog* self) {
	gboolean result = FALSE;
#line 1591 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PROGRESS_DIALOG (self), FALSE);
#line 1592 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress_dialog_on_cancel (self);
#line 1593 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = FALSE;
#line 1593 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 13053 "Dialogs.c"
}


static void progress_dialog_on_cancel (ProgressDialog* self) {
	GCancellable* _tmp0_;
	GtkButton* _tmp2_;
#line 1597 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->cancellable;
#line 1598 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ != NULL) {
#line 13066 "Dialogs.c"
		GCancellable* _tmp1_;
#line 1599 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = self->priv->cancellable;
#line 1599 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_cancellable_cancel (_tmp1_);
#line 13072 "Dialogs.c"
	}
#line 1601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->cancel_button;
#line 1601 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 13078 "Dialogs.c"
}


static void progress_dialog_maybe_show_all (ProgressDialog* self, gdouble pct) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 1604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PROGRESS_DIALOG (self));
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_widget_get_visible (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp2_) {
#line 13094 "Dialogs.c"
		gulong _tmp3_;
		gulong _tmp4_;
		gint _tmp5_;
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = now_ms ();
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = self->priv->time_started;
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = self->priv->minimum_on_screen_time_msec;
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = (_tmp3_ - _tmp4_) > ((gulong) _tmp5_);
#line 13106 "Dialogs.c"
	} else {
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = FALSE;
#line 13110 "Dialogs.c"
	}
#line 1607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 13114 "Dialogs.c"
		gdouble pps = 0.0;
		gdouble _tmp6_;
		gint _tmp7_;
		gdouble ttc = 0.0;
		gdouble _tmp8_;
		gdouble _tmp9_;
		gint _tmp10_;
#line 1609 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = pct;
#line 1609 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = self->priv->minimum_on_screen_time_msec;
#line 1609 "/home/jens/Source/shotwell/src/Dialogs.vala"
		pps = (_tmp6_ * 100.0) / _tmp7_;
#line 1611 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = pps;
#line 1611 "/home/jens/Source/shotwell/src/Dialogs.vala"
		ttc = 100.0 / _tmp8_;
#line 1614 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = ttc;
#line 1614 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = self->priv->minimum_on_screen_time_msec;
#line 1614 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp9_ > ((gdouble) _tmp10_)) {
#line 1619 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1620 "/home/jens/Source/shotwell/src/Dialogs.vala"
			spin_event_loop ();
#line 13142 "Dialogs.c"
		}
	}
}


static void progress_dialog_class_init (ProgressDialogClass * klass) {
#line 1454 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1454 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (ProgressDialogPrivate));
#line 1454 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((GtkWidgetClass *) klass)->realize = (void (*) (GtkWidget *)) progress_dialog_real_realize;
#line 1454 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = progress_dialog_finalize;
#line 13157 "Dialogs.c"
}


static void progress_dialog_instance_init (ProgressDialog * self) {
	GtkProgressBar* _tmp0_;
#line 1454 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = PROGRESS_DIALOG_GET_PRIVATE (self);
#line 1455 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = (GtkProgressBar*) gtk_progress_bar_new ();
#line 1455 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp0_);
#line 1455 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->progress_bar = _tmp0_;
#line 1456 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->cancel_button = NULL;
#line 1458 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->last_count = G_MAXUINT64;
#line 1459 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->update_every = 1;
#line 1460 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->minimum_on_screen_time_msec = 500;
#line 13179 "Dialogs.c"
}


static void progress_dialog_finalize (GObject * obj) {
	ProgressDialog * self;
#line 1454 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PROGRESS_DIALOG, ProgressDialog);
#line 1455 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->progress_bar);
#line 1456 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->cancel_button);
#line 1457 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->cancellable);
#line 1454 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (progress_dialog_parent_class)->finalize (obj);
#line 13195 "Dialogs.c"
}


GType progress_dialog_get_type (void) {
	static volatile gsize progress_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&progress_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ProgressDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) progress_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ProgressDialog), 0, (GInstanceInitFunc) progress_dialog_instance_init, NULL };
		GType progress_dialog_type_id;
		progress_dialog_type_id = g_type_register_static (gtk_window_get_type (), "ProgressDialog", &g_define_type_info, 0);
		g_once_init_leave (&progress_dialog_type_id__volatile, progress_dialog_type_id);
	}
	return progress_dialog_type_id__volatile;
}


static GType adjust_date_time_dialog_time_system_get_type (void) {
	static volatile gsize adjust_date_time_dialog_time_system_type_id__volatile = 0;
	if (g_once_init_enter (&adjust_date_time_dialog_time_system_type_id__volatile)) {
		static const GEnumValue values[] = {{ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_AM, "ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_AM", "am"}, {ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM, "ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM", "pm"}, {ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR, "ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR", "24hr"}, {0, NULL, NULL}};
		GType adjust_date_time_dialog_time_system_type_id;
		adjust_date_time_dialog_time_system_type_id = g_enum_register_static ("AdjustDateTimeDialogTimeSystem", values);
		g_once_init_leave (&adjust_date_time_dialog_time_system_type_id__volatile, adjust_date_time_dialog_time_system_type_id);
	}
	return adjust_date_time_dialog_time_system_type_id__volatile;
}


static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_day_selected (GtkCalendar* _sender, gpointer self) {
#line 1672 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 13226 "Dialogs.c"
}


static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_month_changed (GtkCalendar* _sender, gpointer self) {
#line 1673 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 13233 "Dialogs.c"
}


static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_next_year (GtkCalendar* _sender, gpointer self) {
#line 1674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 13240 "Dialogs.c"
}


static void _adjust_date_time_dialog_on_time_changed_gtk_calendar_prev_year (GtkCalendar* _sender, gpointer self) {
#line 1675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 13247 "Dialogs.c"
}


static gboolean _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output (GtkSpinButton* _sender, gpointer self) {
	gboolean result;
	result = adjust_date_time_dialog_on_spin_button_output ((AdjustDateTimeDialog*) self, _sender);
#line 1682 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 13256 "Dialogs.c"
}


static void _adjust_date_time_dialog_on_time_system_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 1700 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_system_changed ((AdjustDateTimeDialog*) self);
#line 13263 "Dialogs.c"
}


static void _adjust_date_time_dialog_on_time_changed_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self) {
#line 1722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed ((AdjustDateTimeDialog*) self);
#line 13270 "Dialogs.c"
}


static void g_time_local (time_t time, struct tm* result) {
	struct tm _result_ = {0};
	struct tm _tmp0_ = {0};
#line 2846 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	localtime_r (&time, &_tmp0_);
#line 2846 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 2847 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	*result = _result_;
#line 2847 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return;
#line 13285 "Dialogs.c"
}


AdjustDateTimeDialog* adjust_date_time_dialog_construct (GType object_type, Dateable* source, gint photo_count, gboolean display_options, gboolean contains_video, gboolean only_video) {
	AdjustDateTimeDialog * self = NULL;
	Dateable* _tmp0_;
	gboolean use_header = FALSE;
	GtkSettings* _tmp1_;
	gint _tmp2_ = 0;
	gboolean _tmp3_;
	AppWindow* _tmp4_;
	AppWindow* _tmp5_;
	GtkCalendar* _tmp6_;
	GtkCalendar* _tmp7_;
	GtkCalendar* _tmp8_;
	GtkCalendar* _tmp9_;
	GtkCalendar* _tmp10_;
	ConfigFacade* _tmp11_;
	ConfigFacade* _tmp12_;
	gboolean _tmp13_;
	gboolean _tmp14_;
	GtkSpinButton* _tmp17_;
	GtkSpinButton* _tmp18_;
	GtkSpinButton* _tmp19_;
	GtkSpinButton* _tmp20_;
	GtkSpinButton* _tmp21_;
	GtkSpinButton* _tmp22_;
	GtkSpinButton* _tmp23_;
	GtkSpinButton* _tmp24_;
	GtkSpinButton* _tmp25_;
	GtkSpinButton* _tmp26_;
	GtkSpinButton* _tmp27_;
	GtkComboBoxText* _tmp28_;
	GtkComboBoxText* _tmp29_;
	GtkComboBoxText* _tmp30_;
	GtkComboBoxText* _tmp31_;
	GtkComboBoxText* _tmp32_;
	GtkBox* clock = NULL;
	GtkBox* _tmp33_;
	GtkBox* _tmp34_;
	GtkSpinButton* _tmp35_;
	GtkBox* _tmp36_;
	GtkLabel* _tmp37_;
	GtkLabel* _tmp38_;
	GtkBox* _tmp39_;
	GtkSpinButton* _tmp40_;
	GtkBox* _tmp41_;
	GtkLabel* _tmp42_;
	GtkLabel* _tmp43_;
	GtkBox* _tmp44_;
	GtkSpinButton* _tmp45_;
	GtkBox* _tmp46_;
	GtkComboBoxText* _tmp47_;
	GtkRadioButton* _tmp48_;
	GtkRadioButton* _tmp49_;
	ConfigFacade* _tmp50_;
	ConfigFacade* _tmp51_;
	gboolean _tmp52_;
	gboolean _tmp53_ = FALSE;
	gboolean _tmp54_;
	GtkRadioButton* _tmp56_;
	GtkRadioButton* _tmp57_;
	GSList* _tmp58_;
	GtkRadioButton* _tmp59_;
	GtkRadioButton* _tmp60_;
	ConfigFacade* _tmp61_;
	ConfigFacade* _tmp62_;
	gboolean _tmp63_;
	gboolean _tmp64_ = FALSE;
	gboolean _tmp65_;
	GtkRadioButton* _tmp67_;
	GtkRadioButton* _tmp68_;
	gboolean _tmp69_;
	gboolean _tmp78_ = FALSE;
	ConfigFacade* _tmp79_;
	ConfigFacade* _tmp80_;
	gboolean _tmp81_;
	gboolean _tmp82_;
	GtkCheckButton* _tmp84_;
	gboolean _tmp85_ = FALSE;
	gboolean _tmp86_;
	GtkCheckButton* _tmp93_;
	GtkBox* time_content = NULL;
	GtkBox* _tmp94_;
	GtkBox* _tmp95_;
	GtkCalendar* _tmp96_;
	GtkBox* _tmp97_;
	GtkBox* _tmp98_;
	gboolean _tmp99_;
	GdkPixbuf* preview = NULL;
	GtkBox* image_content = NULL;
	GtkBox* _tmp113_;
	GtkBox* _tmp114_;
	GtkBox* _tmp115_;
	GtkImage* _tmp116_ = NULL;
	GdkPixbuf* _tmp117_;
	GtkImage* image = NULL;
	GtkImage* _tmp121_;
	GtkLabel* _tmp122_;
	GtkBox* _tmp123_;
	GtkImage* _tmp124_;
	GtkBox* _tmp125_;
	GtkLabel* _tmp126_;
	GtkBox* hbox = NULL;
	GtkBox* _tmp127_;
	GtkBox* _tmp128_;
	GtkBox* _tmp129_;
	GtkBox* _tmp130_;
	GtkBox* _tmp131_;
	GtkBox* _tmp132_;
	GtkBox* _tmp133_;
	GtkBox* _tmp134_;
	GtkBox* _tmp135_;
	GtkBox* _tmp136_;
	GtkBox* _tmp137_;
	GtkBox* _tmp138_;
	GtkLabel* _tmp139_;
	GtkLabel* _tmp140_;
	GtkLabel* _tmp141_;
	GtkBox* _tmp142_;
	GtkLabel* _tmp143_;
	Dateable* _tmp144_;
	time_t _tmp145_;
	time_t _tmp146_;
	time_t _tmp148_;
	struct tm _tmp149_ = {0};
	ConfigFacade* _tmp150_;
	ConfigFacade* _tmp151_;
	gboolean _tmp152_;
	GError * _inner_error_ = NULL;
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_DATEABLE (source), NULL);
#line 1657 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = source;
#line 1657 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_assert (_tmp0_ != NULL, "source != null");
#line 1660 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_settings_get_default ();
#line 1660 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 1661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = use_header;
#line 1661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_) {
#line 1661 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = 1;
#line 13432 "Dialogs.c"
	} else {
#line 1661 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = 0;
#line 13436 "Dialogs.c"
	}
#line 1661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (AdjustDateTimeDialog*) g_object_new (object_type, "use-header-bar", _tmp2_, NULL);
#line 1663 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_modal (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 1664 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 1665 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = app_window_get_instance ();
#line 1665 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 1665 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_window_get_type (), GtkWindow));
#line 1665 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp5_);
#line 1667 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_buttons (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_CANCEL_LABEL, GTK_RESPONSE_CANCEL, RESOURCES_OK_LABEL, GTK_RESPONSE_OK, NULL);
#line 1669 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), RESOURCES_ADJUST_DATE_TIME_LABEL);
#line 1671 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = (GtkCalendar*) gtk_calendar_new ();
#line 1671 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp6_);
#line 1671 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->calendar);
#line 1671 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->calendar = _tmp6_;
#line 1672 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = self->priv->calendar;
#line 1672 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp7_, "day-selected", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_calendar_day_selected, self, 0);
#line 1673 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = self->priv->calendar;
#line 1673 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp8_, "month-changed", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_calendar_month_changed, self, 0);
#line 1674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = self->priv->calendar;
#line 1674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp9_, "next-year", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_calendar_next_year, self, 0);
#line 1675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = self->priv->calendar;
#line 1675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp10_, "prev-year", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_calendar_prev_year, self, 0);
#line 1677 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = config_facade_get_instance ();
#line 1677 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = _tmp11_;
#line 1677 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = configuration_facade_get_use_24_hour_time (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1677 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 1677 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp12_);
#line 1677 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp14_) {
#line 13492 "Dialogs.c"
		GtkSpinButton* _tmp15_;
#line 1678 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 0, (gdouble) 23, (gdouble) 1);
#line 1678 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp15_);
#line 1678 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (self->priv->hour);
#line 1678 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->hour = _tmp15_;
#line 13502 "Dialogs.c"
	} else {
		GtkSpinButton* _tmp16_;
#line 1680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 1, (gdouble) 12, (gdouble) 1);
#line 1680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp16_);
#line 1680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (self->priv->hour);
#line 1680 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->hour = _tmp16_;
#line 13513 "Dialogs.c"
	}
#line 1682 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = self->priv->hour;
#line 1682 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp17_, "output", (GCallback) _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output, self, 0);
#line 1683 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = self->priv->hour;
#line 1683 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_entry_get_type (), GtkEntry), 2);
#line 1684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = self->priv->hour;
#line 1684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_max_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_entry_get_type (), GtkEntry), 2);
#line 1686 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 0, (gdouble) 59, (gdouble) 1);
#line 1686 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp20_);
#line 1686 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->minute);
#line 1686 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->minute = _tmp20_;
#line 1687 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = self->priv->minute;
#line 1687 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_entry_get_type (), GtkEntry), 2);
#line 1688 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = self->priv->minute;
#line 1688 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_max_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_entry_get_type (), GtkEntry), 2);
#line 1689 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = self->priv->minute;
#line 1689 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp23_, "output", (GCallback) _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output, self, 0);
#line 1691 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = (GtkSpinButton*) gtk_spin_button_new_with_range ((gdouble) 0, (gdouble) 59, (gdouble) 1);
#line 1691 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp24_);
#line 1691 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->second);
#line 1691 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->second = _tmp24_;
#line 1692 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = self->priv->second;
#line 1692 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, gtk_entry_get_type (), GtkEntry), 2);
#line 1693 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = self->priv->second;
#line 1693 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_max_width_chars (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_entry_get_type (), GtkEntry), 2);
#line 1694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = self->priv->second;
#line 1694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (_tmp27_, "output", (GCallback) _adjust_date_time_dialog_on_spin_button_output_gtk_spin_button_output, self, 0);
#line 1696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = (GtkComboBoxText*) gtk_combo_box_text_new ();
#line 1696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp28_);
#line 1696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->system);
#line 1696 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->system = _tmp28_;
#line 1697 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = self->priv->system;
#line 1697 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp29_, _ ("AM"));
#line 1698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = self->priv->system;
#line 1698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp30_, _ ("PM"));
#line 1699 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = self->priv->system;
#line 1699 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp31_, _ ("24 Hr"));
#line 1700 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = self->priv->system;
#line 1700 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _adjust_date_time_dialog_on_time_system_changed_gtk_combo_box_changed, self, 0);
#line 1702 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
#line 1702 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp33_);
#line 1702 "/home/jens/Source/shotwell/src/Dialogs.vala"
	clock = _tmp33_;
#line 1704 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = clock;
#line 1704 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = self->priv->hour;
#line 1704 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp34_, G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = clock;
#line 1705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = (GtkLabel*) gtk_label_new (":");
#line 1705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp37_);
#line 1705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = _tmp37_;
#line 1705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp36_, G_TYPE_CHECK_INSTANCE_CAST (_tmp38_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp38_);
#line 1706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = clock;
#line 1706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = self->priv->minute;
#line 1706 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp39_, G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1707 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = clock;
#line 1707 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = (GtkLabel*) gtk_label_new (":");
#line 1707 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp42_);
#line 1707 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = _tmp42_;
#line 1707 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp41_, G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1707 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp43_);
#line 1708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = clock;
#line 1708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp45_ = self->priv->second;
#line 1708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp44_, G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1709 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp46_ = clock;
#line 1709 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp47_ = self->priv->system;
#line 1709 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp46_, G_TYPE_CHECK_INSTANCE_CAST (_tmp47_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 1711 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_set_default_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_OK);
#line 1713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp48_ = (GtkRadioButton*) gtk_radio_button_new_with_mnemonic (NULL, _ ("_Shift photos/videos by the same amount"));
#line 1713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp48_);
#line 1713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->relativity_radio_button);
#line 1713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->relativity_radio_button = _tmp48_;
#line 1715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp49_ = self->priv->relativity_radio_button;
#line 1715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp50_ = config_facade_get_instance ();
#line 1715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp51_ = _tmp50_;
#line 1715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp52_ = configuration_facade_get_keep_relativity (G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp52_);
#line 1715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp51_);
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp54_ = display_options;
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp54_) {
#line 13671 "Dialogs.c"
		gint _tmp55_;
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp55_ = photo_count;
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp53_ = _tmp55_ > 1;
#line 13677 "Dialogs.c"
	} else {
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp53_ = FALSE;
#line 13681 "Dialogs.c"
	}
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp56_ = self->priv->relativity_radio_button;
#line 1716 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, gtk_widget_get_type (), GtkWidget), _tmp53_);
#line 1718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp57_ = self->priv->relativity_radio_button;
#line 1718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp58_ = gtk_radio_button_get_group (_tmp57_);
#line 1718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp59_ = (GtkRadioButton*) gtk_radio_button_new_with_mnemonic (_tmp58_, _ ("Set _all photos/videos to this time"));
#line 1718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp59_);
#line 1718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->batch_radio_button);
#line 1718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->batch_radio_button = _tmp59_;
#line 1720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp60_ = self->priv->batch_radio_button;
#line 1720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp61_ = config_facade_get_instance ();
#line 1720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp62_ = _tmp61_;
#line 1720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp63_ = configuration_facade_get_keep_relativity (G_TYPE_CHECK_INSTANCE_CAST (_tmp62_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp60_, gtk_toggle_button_get_type (), GtkToggleButton), !_tmp63_);
#line 1720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp62_);
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp65_ = display_options;
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp65_) {
#line 13715 "Dialogs.c"
		gint _tmp66_;
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp66_ = photo_count;
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp64_ = _tmp66_ > 1;
#line 13721 "Dialogs.c"
	} else {
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp64_ = FALSE;
#line 13725 "Dialogs.c"
	}
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp67_ = self->priv->batch_radio_button;
#line 1721 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp67_, gtk_widget_get_type (), GtkWidget), _tmp64_);
#line 1722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp68_ = self->priv->batch_radio_button;
#line 1722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, gtk_toggle_button_get_type (), GtkToggleButton), "toggled", (GCallback) _adjust_date_time_dialog_on_time_changed_gtk_toggle_button_toggled, self, 0);
#line 1724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp69_ = contains_video;
#line 1724 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp69_) {
#line 13739 "Dialogs.c"
		gchar* text = NULL;
		gint _tmp70_;
		gchar* _tmp71_;
		const gchar* _tmp72_;
		GtkCheckButton* _tmp73_;
#line 1725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp70_ = photo_count;
#line 1725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp71_ = g_strdup (ngettext ("_Modify original photo file", "_Modify original photo files", (gulong) _tmp70_));
#line 1725 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text = _tmp71_;
#line 1727 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp72_ = text;
#line 1727 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp73_ = (GtkCheckButton*) gtk_check_button_new_with_mnemonic (_tmp72_);
#line 1727 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp73_);
#line 1727 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (self->priv->modify_originals_check_button);
#line 1727 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->modify_originals_check_button = _tmp73_;
#line 1724 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 13763 "Dialogs.c"
	} else {
		gchar* text = NULL;
		gint _tmp74_;
		gchar* _tmp75_;
		const gchar* _tmp76_;
		GtkCheckButton* _tmp77_;
#line 1729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp74_ = photo_count;
#line 1729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp75_ = g_strdup (ngettext ("_Modify original file", "_Modify original files", (gulong) _tmp74_));
#line 1729 "/home/jens/Source/shotwell/src/Dialogs.vala"
		text = _tmp75_;
#line 1730 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp76_ = text;
#line 1730 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp77_ = (GtkCheckButton*) gtk_check_button_new_with_mnemonic (_tmp76_);
#line 1730 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp77_);
#line 1730 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (self->priv->modify_originals_check_button);
#line 1730 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->modify_originals_check_button = _tmp77_;
#line 1724 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 13788 "Dialogs.c"
	}
#line 1733 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp79_ = config_facade_get_instance ();
#line 1733 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp80_ = _tmp79_;
#line 1733 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp81_ = configuration_facade_get_commit_metadata_to_masters (G_TYPE_CHECK_INSTANCE_CAST (_tmp80_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1733 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp82_ = _tmp81_;
#line 1733 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp80_);
#line 1733 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp82_) {
#line 13802 "Dialogs.c"
		gboolean _tmp83_;
#line 1734 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp83_ = display_options;
#line 1734 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp78_ = _tmp83_;
#line 13808 "Dialogs.c"
	} else {
#line 1733 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp78_ = FALSE;
#line 13812 "Dialogs.c"
	}
#line 1733 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp84_ = self->priv->modify_originals_check_button;
#line 1733 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp84_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp78_);
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp86_ = only_video;
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp86_) {
#line 13822 "Dialogs.c"
		gboolean _tmp87_ = FALSE;
		ConfigFacade* _tmp88_;
		ConfigFacade* _tmp89_;
		gboolean _tmp90_;
		gboolean _tmp91_;
#line 1736 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp88_ = config_facade_get_instance ();
#line 1736 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp89_ = _tmp88_;
#line 1736 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp90_ = configuration_facade_get_commit_metadata_to_masters (G_TYPE_CHECK_INSTANCE_CAST (_tmp89_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1736 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp91_ = !_tmp90_;
#line 1736 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp89_);
#line 1736 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp91_) {
#line 13840 "Dialogs.c"
			gboolean _tmp92_;
#line 1736 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp92_ = display_options;
#line 1736 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp87_ = _tmp92_;
#line 13846 "Dialogs.c"
		} else {
#line 1736 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp87_ = FALSE;
#line 13850 "Dialogs.c"
		}
#line 1736 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp85_ = _tmp87_;
#line 13854 "Dialogs.c"
	} else {
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp85_ = FALSE;
#line 13858 "Dialogs.c"
	}
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp93_ = self->priv->modify_originals_check_button;
#line 1735 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp93_, gtk_widget_get_type (), GtkWidget), _tmp85_);
#line 1738 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp94_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 5);
#line 1738 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp94_);
#line 1738 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time_content = _tmp94_;
#line 1740 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp95_ = time_content;
#line 1740 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp96_ = self->priv->calendar;
#line 1740 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp95_, G_TYPE_CHECK_INSTANCE_CAST (_tmp96_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1741 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp97_ = time_content;
#line 1741 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp98_ = clock;
#line 1741 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp97_, G_TYPE_CHECK_INSTANCE_CAST (_tmp98_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp99_ = display_options;
#line 1743 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp99_) {
#line 13886 "Dialogs.c"
		GtkBox* _tmp100_;
		GtkRadioButton* _tmp101_;
		GtkBox* _tmp102_;
		GtkRadioButton* _tmp103_;
		GtkBox* _tmp104_;
		GtkCheckButton* _tmp105_;
#line 1744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp100_ = time_content;
#line 1744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp101_ = self->priv->relativity_radio_button;
#line 1744 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_box_pack_start (_tmp100_, G_TYPE_CHECK_INSTANCE_CAST (_tmp101_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp102_ = time_content;
#line 1745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp103_ = self->priv->batch_radio_button;
#line 1745 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_box_pack_start (_tmp102_, G_TYPE_CHECK_INSTANCE_CAST (_tmp103_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1746 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp104_ = time_content;
#line 1746 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp105_ = self->priv->modify_originals_check_button;
#line 1746 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_box_pack_start (_tmp104_, G_TYPE_CHECK_INSTANCE_CAST (_tmp105_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 13911 "Dialogs.c"
	}
#line 1749 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preview = NULL;
#line 13915 "Dialogs.c"
	{
		GdkPixbuf* _tmp106_ = NULL;
		Dateable* _tmp107_;
		GdkPixbuf* _tmp108_;
		GdkPixbuf* _tmp109_;
#line 1753 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp107_ = source;
#line 1753 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp108_ = thumbnail_source_get_thumbnail (G_TYPE_CHECK_INSTANCE_CAST (_tmp107_, TYPE_THUMBNAIL_SOURCE, ThumbnailSource), ADJUST_DATE_TIME_DIALOG_CALENDAR_THUMBNAIL_SCALE, &_inner_error_);
#line 1753 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp106_ = _tmp108_;
#line 1753 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 13929 "Dialogs.c"
			goto __catch426_g_error;
		}
#line 1753 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp109_ = _tmp106_;
#line 1753 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp106_ = NULL;
#line 1753 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (preview);
#line 1753 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preview = _tmp109_;
#line 1750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp106_);
#line 13942 "Dialogs.c"
	}
	goto __finally426;
	__catch426_g_error:
	{
		GError* err = NULL;
		Dateable* _tmp110_;
		gchar* _tmp111_;
		gchar* _tmp112_;
#line 1750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		err = _inner_error_;
#line 1750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_inner_error_ = NULL;
#line 1755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp110_ = source;
#line 1755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp111_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp110_, TYPE_DATA_OBJECT, DataObject));
#line 1755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp112_ = _tmp111_;
#line 1755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_warning ("Dialogs.vala:1755: Unable to fetch preview for %s", _tmp112_);
#line 1755 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp112_);
#line 1750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_error_free0 (err);
#line 13967 "Dialogs.c"
	}
	__finally426:
#line 1750 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (preview);
#line 1750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (time_content);
#line 1750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (clock);
#line 1750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_clear_error (&_inner_error_);
#line 1750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return NULL;
#line 13984 "Dialogs.c"
	}
#line 1758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp113_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 1758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp113_);
#line 1758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	image_content = _tmp113_;
#line 1759 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp114_ = image_content;
#line 1759 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp114_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_START);
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp115_ = image_content;
#line 1760 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_set_homogeneous (_tmp115_, TRUE);
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp117_ = preview;
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp117_ != NULL) {
#line 14004 "Dialogs.c"
		GdkPixbuf* _tmp118_;
		GtkImage* _tmp119_;
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp118_ = preview;
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp119_ = (GtkImage*) gtk_image_new_from_pixbuf (_tmp118_);
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp119_);
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp116_);
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp116_ = _tmp119_;
#line 14017 "Dialogs.c"
	} else {
		GtkImage* _tmp120_;
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp120_ = (GtkImage*) gtk_image_new ();
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp120_);
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp116_);
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp116_ = _tmp120_;
#line 14028 "Dialogs.c"
	}
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp121_ = _g_object_ref0 (_tmp116_);
#line 1761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	image = _tmp121_;
#line 1762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp122_ = (GtkLabel*) gtk_label_new (NULL);
#line 1762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp122_);
#line 1762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->original_time_label);
#line 1762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->original_time_label = _tmp122_;
#line 1763 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp123_ = image_content;
#line 1763 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp124_ = image;
#line 1763 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp123_, G_TYPE_CHECK_INSTANCE_CAST (_tmp124_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1764 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp125_ = image_content;
#line 1764 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp126_ = self->priv->original_time_label;
#line 1764 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp125_, G_TYPE_CHECK_INSTANCE_CAST (_tmp126_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1766 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp127_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 10);
#line 1766 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp127_);
#line 1766 "/home/jens/Source/shotwell/src/Dialogs.vala"
	hbox = _tmp127_;
#line 1767 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp128_ = hbox;
#line 1767 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (_tmp128_, gtk_container_get_type (), GtkContainer), (guint) 3);
#line 1768 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp129_ = hbox;
#line 1768 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp130_ = image_content;
#line 1768 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp129_, G_TYPE_CHECK_INSTANCE_CAST (_tmp130_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1769 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp131_ = hbox;
#line 1769 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp132_ = time_content;
#line 1769 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp131_, G_TYPE_CHECK_INSTANCE_CAST (_tmp132_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1770 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp133_ = hbox;
#line 1770 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp133_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_CENTER);
#line 1771 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp134_ = hbox;
#line 1771 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp134_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_CENTER);
#line 1772 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp135_ = hbox;
#line 1772 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_hexpand (G_TYPE_CHECK_INSTANCE_CAST (_tmp135_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1773 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp136_ = hbox;
#line 1773 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_vexpand (G_TYPE_CHECK_INSTANCE_CAST (_tmp136_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1775 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp137_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1775 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp138_ = hbox;
#line 1775 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp137_, gtk_box_get_type (), GtkBox), G_TYPE_CHECK_INSTANCE_CAST (_tmp138_, gtk_widget_get_type (), GtkWidget), TRUE, FALSE, (guint) 0);
#line 1777 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp139_ = (GtkLabel*) gtk_label_new ("");
#line 1777 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp139_);
#line 1777 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->notification);
#line 1777 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->notification = _tmp139_;
#line 1778 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp140_ = self->priv->notification;
#line 1778 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_line_wrap (_tmp140_, TRUE);
#line 1779 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp141_ = self->priv->notification;
#line 1779 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_justify (_tmp141_, GTK_JUSTIFY_CENTER);
#line 1781 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp142_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1781 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp143_ = self->priv->notification;
#line 1781 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp142_, gtk_box_get_type (), GtkBox), G_TYPE_CHECK_INSTANCE_CAST (_tmp143_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 1783 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp144_ = source;
#line 1783 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp145_ = dateable_get_exposure_time (_tmp144_);
#line 1783 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->original_time = _tmp145_;
#line 1785 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp146_ = self->priv->original_time;
#line 1785 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp146_ == ((time_t) 0)) {
#line 14130 "Dialogs.c"
		time_t _tmp147_;
#line 1786 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp147_ = time (NULL);
#line 1786 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->original_time = _tmp147_;
#line 1787 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->no_original_time = TRUE;
#line 14138 "Dialogs.c"
	}
#line 1790 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp148_ = self->priv->original_time;
#line 1790 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_time_local (_tmp148_, &_tmp149_);
#line 1790 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_set_time (self, &_tmp149_);
#line 1791 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp150_ = config_facade_get_instance ();
#line 1791 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp151_ = _tmp150_;
#line 1791 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp152_ = configuration_facade_get_use_24_hour_time (G_TYPE_CHECK_INSTANCE_CAST (_tmp151_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1791 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_set_original_time_label (self, _tmp152_);
#line 1791 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp151_);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (hbox);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (image);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp116_);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (image_content);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (preview);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (time_content);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (clock);
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 14172 "Dialogs.c"
}


AdjustDateTimeDialog* adjust_date_time_dialog_new (Dateable* source, gint photo_count, gboolean display_options, gboolean contains_video, gboolean only_video) {
#line 1655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return adjust_date_time_dialog_construct (TYPE_ADJUST_DATE_TIME_DIALOG, source, photo_count, display_options, contains_video, only_video);
#line 14179 "Dialogs.c"
}


static void adjust_date_time_dialog_set_time (AdjustDateTimeDialog* self, struct tm* time) {
	GtkCalendar* _tmp0_;
	struct tm _tmp1_;
	gint _tmp2_;
	struct tm _tmp3_;
	gint _tmp4_;
	GtkCalendar* _tmp5_;
	struct tm _tmp6_;
	gint _tmp7_;
	ConfigFacade* _tmp8_;
	ConfigFacade* _tmp9_;
	gboolean _tmp10_;
	gboolean _tmp11_;
	GtkSpinButton* _tmp26_;
	struct tm _tmp27_;
	gint _tmp28_;
	GtkSpinButton* _tmp29_;
	struct tm _tmp30_;
	gint _tmp31_;
	GtkComboBoxText* _tmp32_;
	gint _tmp33_;
#line 1794 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self));
#line 1794 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (time != NULL);
#line 1795 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->calendar;
#line 1795 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = *time;
#line 1795 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_.tm_mon;
#line 1795 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = *time;
#line 1795 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_.tm_year;
#line 1795 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_calendar_select_month (_tmp0_, (guint) _tmp2_, (guint) (_tmp4_ + ADJUST_DATE_TIME_DIALOG_YEAR_OFFSET));
#line 1796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->calendar;
#line 1796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = *time;
#line 1796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_.tm_mday;
#line 1796 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_calendar_select_day (_tmp5_, (guint) _tmp7_);
#line 1798 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = config_facade_get_instance ();
#line 1798 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 1798 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = configuration_facade_get_use_24_hour_time (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 1798 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 1798 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp9_);
#line 1798 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp11_) {
#line 14240 "Dialogs.c"
		GtkComboBoxText* _tmp12_;
		GtkSpinButton* _tmp13_;
		struct tm _tmp14_;
		gint _tmp15_;
#line 1799 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = self->priv->system;
#line 1799 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_combo_box_get_type (), GtkComboBox), (gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR);
#line 1800 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = self->priv->hour;
#line 1800 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = *time;
#line 1800 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = _tmp14_.tm_hour;
#line 1800 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_spin_button_set_value (_tmp13_, (gdouble) _tmp15_);
#line 14257 "Dialogs.c"
	} else {
		gint AMPM_hour = 0;
		struct tm _tmp16_;
		gint _tmp17_;
		gint _tmp18_ = 0;
		gint _tmp19_;
		GtkSpinButton* _tmp21_;
		AdjustDateTimeDialogTimeSystem _tmp22_ = 0;
		struct tm _tmp23_;
		gint _tmp24_;
		GtkComboBoxText* _tmp25_;
#line 1802 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = *time;
#line 1802 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = _tmp16_.tm_hour;
#line 1802 "/home/jens/Source/shotwell/src/Dialogs.vala"
		AMPM_hour = _tmp17_ % 12;
#line 1803 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = AMPM_hour;
#line 1803 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp19_ == 0) {
#line 1803 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = 12;
#line 14281 "Dialogs.c"
		} else {
			gint _tmp20_;
#line 1803 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = AMPM_hour;
#line 1803 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = _tmp20_;
#line 14288 "Dialogs.c"
		}
#line 1803 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = self->priv->hour;
#line 1803 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_spin_button_set_value (_tmp21_, (gdouble) _tmp18_);
#line 1804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = *time;
#line 1804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = _tmp23_.tm_hour;
#line 1804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp24_ >= 12) {
#line 1804 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM;
#line 14302 "Dialogs.c"
		} else {
#line 1804 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_AM;
#line 14306 "Dialogs.c"
		}
#line 1804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = self->priv->system;
#line 1804 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, gtk_combo_box_get_type (), GtkComboBox), (gint) _tmp22_);
#line 14312 "Dialogs.c"
	}
#line 1807 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = self->priv->minute;
#line 1807 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = *time;
#line 1807 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = _tmp27_.tm_min;
#line 1807 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_spin_button_set_value (_tmp26_, (gdouble) _tmp28_);
#line 1808 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = self->priv->second;
#line 1808 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = *time;
#line 1808 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = _tmp30_.tm_sec;
#line 1808 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_spin_button_set_value (_tmp29_, (gdouble) _tmp31_);
#line 1810 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = self->priv->system;
#line 1810 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, gtk_combo_box_get_type (), GtkComboBox));
#line 1810 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->previous_time_system = (AdjustDateTimeDialogTimeSystem) _tmp33_;
#line 14336 "Dialogs.c"
}


static gchar* g_time_format (struct tm *self, const gchar* format) {
	gchar* result = NULL;
	gchar* buffer = NULL;
	gchar* _tmp0_;
	gint buffer_length1;
	gint _buffer_size_;
	gchar* _tmp1_;
	gint _tmp1__length1;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gint _tmp3__length1;
	gchar* _tmp4_;
#line 2854 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (format != NULL, NULL);
#line 2855 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = g_new0 (gchar, 64);
#line 2855 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	buffer = _tmp0_;
#line 2855 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	buffer_length1 = 64;
#line 2855 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_buffer_size_ = buffer_length1;
#line 2856 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = buffer;
#line 2856 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1__length1 = buffer_length1;
#line 2856 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp2_ = format;
#line 2856 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	strftime (_tmp1_, _tmp1__length1, _tmp2_, &(*self));
#line 2857 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = buffer;
#line 2857 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3__length1 = buffer_length1;
#line 2857 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp4_ = g_strdup ((const gchar*) _tmp3_);
#line 2857 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 2857 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	buffer = (g_free (buffer), NULL);
#line 2857 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 14382 "Dialogs.c"
}


static void adjust_date_time_dialog_set_original_time_label (AdjustDateTimeDialog* self, gboolean use_24_hr_format) {
	gboolean _tmp0_;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_;
	GtkLabel* _tmp3_;
	time_t _tmp4_;
	struct tm _tmp5_ = {0};
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
#line 1813 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self));
#line 1814 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->no_original_time;
#line 1814 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 1815 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 14405 "Dialogs.c"
	}
#line 1818 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = use_24_hr_format;
#line 1818 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_) {
#line 1818 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = _ ("%m/%d/%Y, %H:%M:%S");
#line 14413 "Dialogs.c"
	} else {
#line 1819 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = _ ("%m/%d/%Y, %I:%M:%S %p");
#line 14417 "Dialogs.c"
	}
#line 1817 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->priv->original_time_label;
#line 1817 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = self->priv->original_time;
#line 1817 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_time_local (_tmp4_, &_tmp5_);
#line 1817 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = g_time_format (&_tmp5_, _tmp1_);
#line 1817 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 1817 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = g_strconcat (_ ("Original: "), _tmp7_, NULL);
#line 1817 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 1817 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_text (_tmp3_, _tmp9_);
#line 1817 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp9_);
#line 1817 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp7_);
#line 14439 "Dialogs.c"
}


static time_t adjust_date_time_dialog_get_time (AdjustDateTimeDialog* self) {
	time_t result = 0;
	struct tm time = {0};
	GtkSpinButton* _tmp0_;
	gdouble _tmp1_;
	GtkSpinButton* _tmp2_;
	gdouble _tmp3_;
	gint hour = 0;
	GtkSpinButton* _tmp4_;
	gdouble _tmp5_;
	gint _tmp6_ = 0;
	gboolean _tmp7_ = FALSE;
	gint _tmp8_;
	gint _tmp12_ = 0;
	GtkComboBoxText* _tmp13_;
	gint _tmp14_;
	gint _tmp15_;
	guint year = 0U;
	guint month = 0U;
	guint day = 0U;
	GtkCalendar* _tmp16_;
	guint _tmp17_ = 0U;
	guint _tmp18_ = 0U;
	guint _tmp19_ = 0U;
	time_t _tmp20_;
#line 1822 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self), 0);
#line 1823 "/home/jens/Source/shotwell/src/Dialogs.vala"
	memset (&time, 0, sizeof (struct tm));
#line 1825 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->second;
#line 1825 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_spin_button_get_value (_tmp0_);
#line 1825 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_sec = (gint) _tmp1_;
#line 1826 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->minute;
#line 1826 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_spin_button_get_value (_tmp2_);
#line 1826 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_min = (gint) _tmp3_;
#line 1829 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = self->priv->hour;
#line 1829 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = gtk_spin_button_get_value (_tmp4_);
#line 1829 "/home/jens/Source/shotwell/src/Dialogs.vala"
	hour = (gint) _tmp5_;
#line 1830 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = hour;
#line 1830 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp8_ == 12) {
#line 14494 "Dialogs.c"
		GtkComboBoxText* _tmp9_;
		gint _tmp10_;
#line 1830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = self->priv->system;
#line 1830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_combo_box_get_type (), GtkComboBox));
#line 1830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp10_ != ((gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR);
#line 14503 "Dialogs.c"
	} else {
#line 1830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = FALSE;
#line 14507 "Dialogs.c"
	}
#line 1830 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp7_) {
#line 1830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = 0;
#line 14513 "Dialogs.c"
	} else {
		gint _tmp11_;
#line 1830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = hour;
#line 1830 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = _tmp11_;
#line 14520 "Dialogs.c"
	}
#line 1830 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_hour = _tmp6_;
#line 1831 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = self->priv->system;
#line 1831 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_combo_box_get_type (), GtkComboBox));
#line 1831 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp14_ == ((gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM)) {
#line 1831 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = 12;
#line 14532 "Dialogs.c"
	} else {
#line 1831 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = 0;
#line 14536 "Dialogs.c"
	}
#line 1831 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = time.tm_hour;
#line 1831 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_hour = _tmp15_ + _tmp12_;
#line 1834 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = self->priv->calendar;
#line 1834 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_calendar_get_date (_tmp16_, &_tmp17_, &_tmp18_, &_tmp19_);
#line 1834 "/home/jens/Source/shotwell/src/Dialogs.vala"
	year = _tmp17_;
#line 1834 "/home/jens/Source/shotwell/src/Dialogs.vala"
	month = _tmp18_;
#line 1834 "/home/jens/Source/shotwell/src/Dialogs.vala"
	day = _tmp19_;
#line 1835 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_year = ((gint) year) - ADJUST_DATE_TIME_DIALOG_YEAR_OFFSET;
#line 1836 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_mon = (gint) month;
#line 1837 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_mday = (gint) day;
#line 1839 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time.tm_isdst = -1;
#line 1841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = mktime (&time);
#line 1841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp20_;
#line 1841 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 14566 "Dialogs.c"
}


gboolean adjust_date_time_dialog_execute (AdjustDateTimeDialog* self, gint64* time_shift, gboolean* keep_relativity, gboolean* modify_originals) {
	gint64 _vala_time_shift = 0LL;
	gboolean _vala_keep_relativity = FALSE;
	gboolean _vala_modify_originals = FALSE;
	gboolean result = FALSE;
	gboolean response = FALSE;
	gint _tmp0_;
#line 1844 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self), FALSE);
#line 1846 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1848 "/home/jens/Source/shotwell/src/Dialogs.vala"
	response = FALSE;
#line 1850 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 1850 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == ((gint) GTK_RESPONSE_OK)) {
#line 14587 "Dialogs.c"
		gboolean _tmp1_;
		GtkRadioButton* _tmp5_;
		gboolean _tmp6_;
		GtkRadioButton* _tmp7_;
		gboolean _tmp8_;
		gboolean _tmp9_;
		GtkCheckButton* _tmp13_;
		gboolean _tmp14_;
		GtkCheckButton* _tmp15_;
		gboolean _tmp16_;
		gboolean _tmp17_;
#line 1851 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = self->priv->no_original_time;
#line 1851 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp1_) {
#line 14603 "Dialogs.c"
			time_t _tmp2_;
#line 1852 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = adjust_date_time_dialog_get_time (self);
#line 1852 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_vala_time_shift = (gint64) _tmp2_;
#line 14609 "Dialogs.c"
		} else {
			time_t _tmp3_;
			time_t _tmp4_;
#line 1854 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp3_ = adjust_date_time_dialog_get_time (self);
#line 1854 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp4_ = self->priv->original_time;
#line 1854 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_vala_time_shift = (gint64) (_tmp3_ - _tmp4_);
#line 14619 "Dialogs.c"
		}
#line 1856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = self->priv->relativity_radio_button;
#line 1856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1856 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_keep_relativity = _tmp6_;
#line 1858 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = self->priv->relativity_radio_button;
#line 1858 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget));
#line 1858 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = _tmp8_;
#line 1858 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp9_) {
#line 14635 "Dialogs.c"
			ConfigFacade* _tmp10_;
			ConfigFacade* _tmp11_;
			gboolean _tmp12_;
#line 1859 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp10_ = config_facade_get_instance ();
#line 1859 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = _tmp10_;
#line 1859 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = _vala_keep_relativity;
#line 1859 "/home/jens/Source/shotwell/src/Dialogs.vala"
			configuration_facade_set_keep_relativity (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp12_);
#line 1859 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_tmp11_);
#line 14649 "Dialogs.c"
		}
#line 1861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = self->priv->modify_originals_check_button;
#line 1861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1861 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_modify_originals = _tmp14_;
#line 1863 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = self->priv->modify_originals_check_button;
#line 1863 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_widget_get_type (), GtkWidget));
#line 1863 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = _tmp16_;
#line 1863 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp17_) {
#line 14665 "Dialogs.c"
			ConfigFacade* _tmp18_;
			ConfigFacade* _tmp19_;
			gboolean _tmp20_;
#line 1864 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = config_facade_get_instance ();
#line 1864 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp19_ = _tmp18_;
#line 1864 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = _vala_modify_originals;
#line 1864 "/home/jens/Source/shotwell/src/Dialogs.vala"
			configuration_facade_set_modify_originals (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp20_);
#line 1864 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_tmp19_);
#line 14679 "Dialogs.c"
		}
#line 1866 "/home/jens/Source/shotwell/src/Dialogs.vala"
		response = TRUE;
#line 14683 "Dialogs.c"
	} else {
#line 1868 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_time_shift = (gint64) 0;
#line 1869 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_keep_relativity = TRUE;
#line 1870 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_modify_originals = FALSE;
#line 14691 "Dialogs.c"
	}
#line 1873 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 1875 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = response;
#line 1875 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (time_shift) {
#line 1875 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*time_shift = _vala_time_shift;
#line 14701 "Dialogs.c"
	}
#line 1875 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (keep_relativity) {
#line 1875 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*keep_relativity = _vala_keep_relativity;
#line 14707 "Dialogs.c"
	}
#line 1875 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (modify_originals) {
#line 1875 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*modify_originals = _vala_modify_originals;
#line 14713 "Dialogs.c"
	}
#line 1875 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 14717 "Dialogs.c"
}


static gboolean adjust_date_time_dialog_on_spin_button_output (AdjustDateTimeDialog* self, GtkSpinButton* button) {
	gboolean result = FALSE;
	GtkSpinButton* _tmp0_;
	GtkSpinButton* _tmp1_;
	gdouble _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
#line 1878 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self), FALSE);
#line 1878 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_SPIN_BUTTON (button), FALSE);
#line 1879 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = button;
#line 1879 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = button;
#line 1879 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_spin_button_get_value (_tmp1_);
#line 1879 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup_printf ("%02d", (gint) _tmp2_);
#line 1879 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 1879 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_entry_set_text (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_entry_get_type (), GtkEntry), _tmp4_);
#line 1879 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp4_);
#line 1881 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed (self);
#line 1883 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 1883 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 14752 "Dialogs.c"
}


static void adjust_date_time_dialog_on_time_changed (AdjustDateTimeDialog* self) {
	gint64 time_shift = 0LL;
	time_t _tmp0_;
	time_t _tmp1_;
	GtkComboBoxText* _tmp2_;
	gint _tmp3_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	gint64 _tmp6_;
#line 1886 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self));
#line 1887 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = adjust_date_time_dialog_get_time (self);
#line 1887 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->original_time;
#line 1887 "/home/jens/Source/shotwell/src/Dialogs.vala"
	time_shift = ((gint64) _tmp0_) - ((gint64) _tmp1_);
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->system;
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_combo_box_get_type (), GtkComboBox));
#line 1889 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->previous_time_system = (AdjustDateTimeDialogTimeSystem) _tmp3_;
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = time_shift;
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp6_ == ((gint64) 0)) {
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = TRUE;
#line 14785 "Dialogs.c"
	} else {
		gboolean _tmp7_;
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = self->priv->no_original_time;
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = _tmp7_;
#line 14792 "Dialogs.c"
	}
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_) {
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = TRUE;
#line 14798 "Dialogs.c"
	} else {
		gboolean _tmp8_ = FALSE;
		GtkRadioButton* _tmp9_;
		gboolean _tmp10_;
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = self->priv->batch_radio_button;
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp10_) {
#line 14809 "Dialogs.c"
			GtkRadioButton* _tmp11_;
			gboolean _tmp12_;
			gboolean _tmp13_;
#line 1892 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = self->priv->batch_radio_button;
#line 1892 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = gtk_widget_get_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_widget_get_type (), GtkWidget));
#line 1892 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp13_ = _tmp12_;
#line 1892 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = _tmp13_;
#line 14821 "Dialogs.c"
		} else {
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = FALSE;
#line 14825 "Dialogs.c"
		}
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp8_;
#line 14829 "Dialogs.c"
	}
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_) {
#line 14833 "Dialogs.c"
		GtkLabel* _tmp14_;
#line 1893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = self->priv->notification;
#line 1893 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_widget_get_type (), GtkWidget));
#line 14839 "Dialogs.c"
	} else {
		gboolean forward = FALSE;
		gint64 _tmp15_;
		gint days = 0;
		gint hours = 0;
		gint minutes = 0;
		gint seconds = 0;
		gint64 _tmp16_;
		gint64 _tmp17_;
		gint64 _tmp18_;
		gint64 _tmp19_;
		gint64 _tmp20_;
		gint64 _tmp21_;
		gint64 _tmp22_;
		gint64 _tmp23_;
		const gchar* _tmp24_ = NULL;
		gboolean _tmp25_;
		gchar* shift_status = NULL;
		gchar* _tmp26_;
		GtkLabel* _tmp27_;
		const gchar* _tmp28_;
		gint _tmp29_;
		gint _tmp30_;
		gint _tmp31_;
		gint _tmp32_;
		gint _tmp33_;
		gint _tmp34_;
		gint _tmp35_;
		gint _tmp36_;
		gchar* _tmp37_;
		gchar* _tmp38_;
		GtkLabel* _tmp39_;
#line 1895 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = time_shift;
#line 1895 "/home/jens/Source/shotwell/src/Dialogs.vala"
		forward = _tmp15_ > ((gint64) 0);
#line 1898 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = time_shift;
#line 1898 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = llabs (_tmp16_);
#line 1898 "/home/jens/Source/shotwell/src/Dialogs.vala"
		time_shift = _tmp17_;
#line 1900 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = time_shift;
#line 1900 "/home/jens/Source/shotwell/src/Dialogs.vala"
		days = (gint) (_tmp18_ / ADJUST_DATE_TIME_DIALOG_SECONDS_IN_DAY);
#line 1901 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = time_shift;
#line 1901 "/home/jens/Source/shotwell/src/Dialogs.vala"
		time_shift = _tmp19_ % ADJUST_DATE_TIME_DIALOG_SECONDS_IN_DAY;
#line 1902 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = time_shift;
#line 1902 "/home/jens/Source/shotwell/src/Dialogs.vala"
		hours = (gint) (_tmp20_ / ADJUST_DATE_TIME_DIALOG_SECONDS_IN_HOUR);
#line 1903 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = time_shift;
#line 1903 "/home/jens/Source/shotwell/src/Dialogs.vala"
		time_shift = _tmp21_ % ADJUST_DATE_TIME_DIALOG_SECONDS_IN_HOUR;
#line 1904 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = time_shift;
#line 1904 "/home/jens/Source/shotwell/src/Dialogs.vala"
		minutes = (gint) (_tmp22_ / ADJUST_DATE_TIME_DIALOG_SECONDS_IN_MINUTE);
#line 1905 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = time_shift;
#line 1905 "/home/jens/Source/shotwell/src/Dialogs.vala"
		seconds = (gint) (_tmp23_ % ADJUST_DATE_TIME_DIALOG_SECONDS_IN_MINUTE);
#line 1907 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = forward;
#line 1907 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp25_) {
#line 1908 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = _ ("Exposure time will be shifted forward by\n" \
"%d %s, %d %s, %d %s, and %d %s.");
#line 14912 "Dialogs.c"
		} else {
#line 1909 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = _ ("Exposure time will be shifted backward by\n" \
"%d %s, %d %s, %d %s, and %d %s.");
#line 14916 "Dialogs.c"
		}
#line 1907 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = g_strdup (_tmp24_);
#line 1907 "/home/jens/Source/shotwell/src/Dialogs.vala"
		shift_status = _tmp26_;
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = self->priv->notification;
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = shift_status;
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = days;
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = days;
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp31_ = hours;
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = hours;
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = minutes;
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = minutes;
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp35_ = seconds;
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp36_ = seconds;
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp37_ = g_strdup_printf (_tmp28_, _tmp29_, ngettext ("day", "days", (gulong) _tmp30_), _tmp31_, ngettext ("hour", "hours", (gulong) _tmp32_), _tmp33_, ngettext ("minute", "minutes", (gulong) _tmp34_), _tmp35_, ngettext ("second", "seconds", (gulong) _tmp36_));
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp38_ = _tmp37_;
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_text (_tmp27_, _tmp38_);
#line 1911 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp38_);
#line 1916 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp39_ = self->priv->notification;
#line 1916 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_show (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, gtk_widget_get_type (), GtkWidget));
#line 1891 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (shift_status);
#line 14956 "Dialogs.c"
	}
}


static void adjust_date_time_dialog_on_time_system_changed (AdjustDateTimeDialog* self) {
	AdjustDateTimeDialogTimeSystem _tmp0_;
	GtkComboBoxText* _tmp1_;
	gint _tmp2_;
	ConfigFacade* _tmp3_;
	ConfigFacade* _tmp4_;
	GtkComboBoxText* _tmp5_;
	gint _tmp6_;
	GtkComboBoxText* _tmp7_;
	gint _tmp8_;
#line 1920 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_ADJUST_DATE_TIME_DIALOG (self));
#line 1921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->previous_time_system;
#line 1921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->system;
#line 1921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 1921 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == _tmp2_) {
#line 1922 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 14983 "Dialogs.c"
	}
#line 1924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = config_facade_get_instance ();
#line 1924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 1924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->system;
#line 1924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_combo_box_get_type (), GtkComboBox));
#line 1924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	configuration_facade_set_use_24_hour_time (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp6_ == ((gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR));
#line 1924 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp4_);
#line 1926 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = self->priv->system;
#line 1926 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_combo_box_get_type (), GtkComboBox));
#line 1926 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp8_ == ((gint) ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_24HR)) {
#line 15003 "Dialogs.c"
		gint _tmp9_ = 0;
		GtkSpinButton* _tmp10_;
		gdouble _tmp11_;
		gint time = 0;
		gint _tmp14_ = 0;
		AdjustDateTimeDialogTimeSystem _tmp15_;
		gint _tmp16_;
		GtkSpinButton* _tmp17_;
		GtkSpinButton* _tmp18_;
		gint _tmp19_;
#line 1927 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = self->priv->hour;
#line 1927 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = gtk_spin_button_get_value (_tmp10_);
#line 1927 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp11_ == 12.0) {
#line 1927 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = 0;
#line 15022 "Dialogs.c"
		} else {
			GtkSpinButton* _tmp12_;
			gdouble _tmp13_;
#line 1927 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = self->priv->hour;
#line 1927 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp13_ = gtk_spin_button_get_value (_tmp12_);
#line 1927 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = (gint) _tmp13_;
#line 15032 "Dialogs.c"
		}
#line 1927 "/home/jens/Source/shotwell/src/Dialogs.vala"
		time = _tmp9_;
#line 1928 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = self->priv->previous_time_system;
#line 1928 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp15_ == ADJUST_DATE_TIME_DIALOG_TIME_SYSTEM_PM) {
#line 1928 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp14_ = 12;
#line 15042 "Dialogs.c"
		} else {
#line 1928 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp14_ = 0;
#line 15046 "Dialogs.c"
		}
#line 1928 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = time;
#line 1928 "/home/jens/Source/shotwell/src/Dialogs.vala"
		time = _tmp16_ + _tmp14_;
#line 1930 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = self->priv->hour;
#line 1930 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_spin_button_set_range (_tmp17_, (gdouble) 0, (gdouble) 23);
#line 1931 "/home/jens/Source/shotwell/src/Dialogs.vala"
		adjust_date_time_dialog_set_original_time_label (self, TRUE);
#line 1933 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = self->priv->hour;
#line 1933 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = time;
#line 1933 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_spin_button_set_value (_tmp18_, (gdouble) _tmp19_);
#line 15064 "Dialogs.c"
	} else {
		gint AMPM_hour = 0;
		GtkSpinButton* _tmp20_;
		gdouble _tmp21_;
		GtkSpinButton* _tmp22_;
		gint _tmp23_ = 0;
		gint _tmp24_;
		GtkSpinButton* _tmp26_;
#line 1935 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = self->priv->hour;
#line 1935 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = gtk_spin_button_get_value (_tmp20_);
#line 1935 "/home/jens/Source/shotwell/src/Dialogs.vala"
		AMPM_hour = ((gint) _tmp21_) % 12;
#line 1937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = self->priv->hour;
#line 1937 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_spin_button_set_range (_tmp22_, (gdouble) 1, (gdouble) 12);
#line 1938 "/home/jens/Source/shotwell/src/Dialogs.vala"
		adjust_date_time_dialog_set_original_time_label (self, FALSE);
#line 1940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = AMPM_hour;
#line 1940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp24_ == 0) {
#line 1940 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = 12;
#line 15091 "Dialogs.c"
		} else {
			gint _tmp25_;
#line 1940 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = AMPM_hour;
#line 1940 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = _tmp25_;
#line 15098 "Dialogs.c"
		}
#line 1940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = self->priv->hour;
#line 1940 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_spin_button_set_value (_tmp26_, (gdouble) _tmp23_);
#line 15104 "Dialogs.c"
	}
#line 1943 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_on_time_changed (self);
#line 15108 "Dialogs.c"
}


static void adjust_date_time_dialog_class_init (AdjustDateTimeDialogClass * klass) {
#line 1626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	adjust_date_time_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (AdjustDateTimeDialogPrivate));
#line 1626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = adjust_date_time_dialog_finalize;
#line 15119 "Dialogs.c"
}


static void adjust_date_time_dialog_instance_init (AdjustDateTimeDialog * self) {
#line 1626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = ADJUST_DATE_TIME_DIALOG_GET_PRIVATE (self);
#line 1631 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->no_original_time = FALSE;
#line 15128 "Dialogs.c"
}


static void adjust_date_time_dialog_finalize (GObject * obj) {
	AdjustDateTimeDialog * self;
#line 1626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_ADJUST_DATE_TIME_DIALOG, AdjustDateTimeDialog);
#line 1636 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->original_time_label);
#line 1637 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->calendar);
#line 1638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->hour);
#line 1639 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->minute);
#line 1640 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->second);
#line 1641 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->system);
#line 1642 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->relativity_radio_button);
#line 1643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->batch_radio_button);
#line 1644 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->modify_originals_check_button);
#line 1645 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->notification);
#line 1626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (adjust_date_time_dialog_parent_class)->finalize (obj);
#line 15158 "Dialogs.c"
}


GType adjust_date_time_dialog_get_type (void) {
	static volatile gsize adjust_date_time_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&adjust_date_time_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AdjustDateTimeDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) adjust_date_time_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AdjustDateTimeDialog), 0, (GInstanceInitFunc) adjust_date_time_dialog_instance_init, NULL };
		GType adjust_date_time_dialog_type_id;
		adjust_date_time_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "AdjustDateTimeDialog", &g_define_type_info, 0);
		g_once_init_leave (&adjust_date_time_dialog_type_id__volatile, adjust_date_time_dialog_type_id);
	}
	return adjust_date_time_dialog_type_id__volatile;
}


void multiple_object_error_dialog (GeeArrayList* objects, const gchar* message, const gchar* title) {
	gchar* dialog_message = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gint remainder = 0;
	GeeArrayList* _tmp20_;
	gint _tmp21_;
	gint _tmp22_;
	gint _tmp23_;
	GtkMessageDialog* dialog = NULL;
	AppWindow* _tmp30_;
	AppWindow* _tmp31_;
	const gchar* _tmp32_;
	GtkMessageDialog* _tmp33_;
	GtkMessageDialog* _tmp34_;
	const gchar* _tmp35_;
#line 1948 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GEE_IS_ARRAY_LIST (objects));
#line 1948 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (message != NULL);
#line 1948 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (title != NULL);
#line 1950 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = message;
#line 1950 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strconcat (_tmp0_, "\n", NULL);
#line 1950 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog_message = _tmp1_;
#line 15202 "Dialogs.c"
	{
		gint i = 0;
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
		i = 0;
#line 15207 "Dialogs.c"
		{
			gboolean _tmp2_ = FALSE;
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp2_ = TRUE;
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 15214 "Dialogs.c"
				gboolean _tmp4_ = FALSE;
				gint _tmp5_;
				const gchar* _tmp10_;
				GeeArrayList* _tmp11_;
				gint _tmp12_;
				gpointer _tmp13_;
				DataObject* _tmp14_;
				gchar* _tmp15_;
				gchar* _tmp16_;
				gchar* _tmp17_;
				gchar* _tmp18_;
				gchar* _tmp19_;
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp2_) {
#line 15229 "Dialogs.c"
					gint _tmp3_;
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp3_ = i;
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
					i = _tmp3_ + 1;
#line 15235 "Dialogs.c"
				}
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp2_ = FALSE;
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp5_ = i;
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp5_ < MAX_OBJECTS_DISPLAYED) {
#line 15243 "Dialogs.c"
					GeeArrayList* _tmp6_;
					gint _tmp7_;
					gint _tmp8_;
					gint _tmp9_;
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp6_ = objects;
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp7_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp8_ = _tmp7_;
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp9_ = i;
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp4_ = _tmp8_ > _tmp9_;
#line 15258 "Dialogs.c"
				} else {
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp4_ = FALSE;
#line 15262 "Dialogs.c"
				}
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp4_) {
#line 1953 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 15268 "Dialogs.c"
				}
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = dialog_message;
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = objects;
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp12_ = i;
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp12_);
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp14_ = (DataObject*) _tmp13_;
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp15_ = data_object_to_string (_tmp14_);
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp16_ = _tmp15_;
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp17_ = g_strconcat ("\n", _tmp16_, NULL);
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp18_ = _tmp17_;
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp19_ = g_strconcat (_tmp10_, _tmp18_, NULL);
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (dialog_message);
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				dialog_message = _tmp19_;
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp18_);
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp16_);
#line 1954 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp14_);
#line 15300 "Dialogs.c"
			}
		}
	}
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = objects;
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = _tmp21_;
#line 1956 "/home/jens/Source/shotwell/src/Dialogs.vala"
	remainder = _tmp22_ - MAX_OBJECTS_DISPLAYED;
#line 1957 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = remainder;
#line 1957 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp23_ > 0) {
#line 15316 "Dialogs.c"
		const gchar* _tmp24_;
		gint _tmp25_;
		gint _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
#line 1958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = dialog_message;
#line 1958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = remainder;
#line 1958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = remainder;
#line 1958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = g_strdup_printf (ngettext ("\n\nAnd %d other.", "\n\nAnd %d others.", (gulong) _tmp25_), _tmp26_);
#line 1958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = _tmp27_;
#line 1958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = g_strconcat (_tmp24_, _tmp28_, NULL);
#line 1958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (dialog_message);
#line 1958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dialog_message = _tmp29_;
#line 1958 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp28_);
#line 15341 "Dialogs.c"
	}
#line 1962 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = app_window_get_instance ();
#line 1962 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = _tmp30_;
#line 1962 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = dialog_message;
#line 1962 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", _tmp32_);
#line 1962 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp33_);
#line 1962 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = _tmp33_;
#line 1962 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp31_);
#line 1962 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp34_;
#line 1965 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = title;
#line 1965 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_window_get_type (), GtkWindow), _tmp35_);
#line 1967 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 1968 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 1948 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 1948 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (dialog_message);
#line 15371 "Dialogs.c"
}


TagsDialog* tags_dialog_construct (GType object_type, const gchar* title, const gchar* label, const gchar* initial_text) {
	TagsDialog* self = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	HierarchicalTagIndex* _tmp3_;
	HierarchicalTagIndex* _tmp4_;
	GeeCollection* _tmp5_;
	GeeCollection* _tmp6_;
#line 1972 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (title != NULL, NULL);
#line 1972 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (label != NULL, NULL);
#line 1973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = title;
#line 1973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = label;
#line 1973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = initial_text;
#line 1973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = hierarchical_tag_index_get_global_index ();
#line 1973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 1973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = hierarchical_tag_index_get_all_tags (_tmp4_);
#line 1973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 1973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (TagsDialog*) text_entry_dialog_mediator_construct (object_type, _tmp0_, _tmp1_, _tmp2_, _tmp6_, ",");
#line 1973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp6_);
#line 1973 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_hierarchical_tag_index_unref0 (_tmp4_);
#line 1972 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 15410 "Dialogs.c"
}


static void tags_dialog_class_init (TagsDialogClass * klass) {
#line 1971 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tags_dialog_parent_class = g_type_class_peek_parent (klass);
#line 15417 "Dialogs.c"
}


static void tags_dialog_instance_init (TagsDialog * self) {
}


GType tags_dialog_get_type (void) {
	static volatile gsize tags_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&tags_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (TagsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tags_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TagsDialog), 0, (GInstanceInitFunc) tags_dialog_instance_init, NULL };
		GType tags_dialog_type_id;
		tags_dialog_type_id = g_type_register_static (TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, "TagsDialog", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_once_init_leave (&tags_dialog_type_id__volatile, tags_dialog_type_id);
	}
	return tags_dialog_type_id__volatile;
}


AddTagsDialog* add_tags_dialog_construct (GType object_type) {
	AddTagsDialog* self = NULL;
	gchar* title = NULL;
	gchar* _tmp0_;
#line 1980 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strdup (g_dpgettext2 (NULL, "Dialog Title", RESOURCES_ADD_TAGS_TITLE));
#line 1980 "/home/jens/Source/shotwell/src/Dialogs.vala"
	title = _tmp0_;
#line 1982 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (AddTagsDialog*) tags_dialog_construct (object_type, title, _ ("Tags (separated by commas):"), NULL);
#line 1979 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (title);
#line 1979 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 15451 "Dialogs.c"
}


AddTagsDialog* add_tags_dialog_new (void) {
#line 1979 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return add_tags_dialog_construct (TYPE_ADD_TAGS_DIALOG);
#line 15458 "Dialogs.c"
}


gchar** add_tags_dialog_execute (AddTagsDialog* self, int* result_length1) {
	gchar** result = NULL;
	gchar* text = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp3_;
	gchar** _tmp4_;
	gchar** _tmp5_;
	gchar** _tmp6_;
	gint _tmp6__length1;
	gint _tmp7_;
	gchar** _tmp8_;
	gchar** _tmp9_;
	gint _tmp9__length1;
	gchar** _tmp10_;
	gint _tmp10__length1;
#line 1985 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_ADD_TAGS_DIALOG (self), NULL);
#line 1986 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 1986 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = _tmp0_;
#line 1987 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text;
#line 1987 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == NULL) {
#line 15488 "Dialogs.c"
		gchar** _tmp2_;
		gint _tmp2__length1;
#line 1988 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = NULL;
#line 1988 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2__length1 = 0;
#line 1988 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (result_length1) {
#line 1988 "/home/jens/Source/shotwell/src/Dialogs.vala"
			*result_length1 = _tmp2__length1;
#line 15499 "Dialogs.c"
		}
#line 1988 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp2_;
#line 1988 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 1988 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 15507 "Dialogs.c"
	}
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = text;
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_ = g_strsplit (_tmp3_, ",", 0);
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_;
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6__length1 = _vala_array_length (_tmp4_);
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = tag_prep_tag_names (_tmp6_, _vala_array_length (_tmp4_), &_tmp7_);
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = _tmp8_;
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9__length1 = _tmp7_;
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = (_vala_array_free (_tmp6_, _tmp6__length1, (GDestroyNotify) g_free), NULL);
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10__length1 = _tmp9__length1;
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (result_length1) {
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*result_length1 = _tmp10__length1;
#line 15533 "Dialogs.c"
	}
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp10_;
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (text);
#line 1992 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 15541 "Dialogs.c"
}


static gboolean add_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text) {
	AddTagsDialog * self;
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gboolean _tmp1_;
	gchar** names = NULL;
	const gchar* _tmp2_;
	gchar** _tmp3_;
	gchar** _tmp4_;
	gchar** _tmp5_;
	gint _tmp5__length1;
	gint _tmp6_;
	gchar** _tmp7_;
	gchar** _tmp8_;
	gint _tmp8__length1;
	gint names_length1;
	gint _names_size_;
	gchar** _tmp9_;
	gint _tmp9__length1;
#line 1995 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_ADD_TAGS_DIALOG, AddTagsDialog);
#line 1995 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 1996 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = text;
#line 1996 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = string_contains (_tmp0_, TAG_PATH_SEPARATOR_STRING);
#line 1996 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_) {
#line 1997 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 1997 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 15578 "Dialogs.c"
	}
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = text;
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_ = g_strsplit (_tmp2_, ",", 0);
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5__length1 = _vala_array_length (_tmp3_);
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = tag_prep_tag_names (_tmp5_, _vala_array_length (_tmp3_), &_tmp6_);
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8__length1 = _tmp6_;
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = (_vala_array_free (_tmp5_, _tmp5__length1, (GDestroyNotify) g_free), NULL);
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	names = _tmp8_;
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	names_length1 = _tmp8__length1;
#line 2001 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_names_size_ = names_length1;
#line 2003 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = names;
#line 2003 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9__length1 = names_length1;
#line 2003 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp9__length1 > 0;
#line 2003 "/home/jens/Source/shotwell/src/Dialogs.vala"
	names = (_vala_array_free (names, names_length1, (GDestroyNotify) g_free), NULL);
#line 2003 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 15612 "Dialogs.c"
}


static void add_tags_dialog_class_init (AddTagsDialogClass * klass) {
#line 1978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	add_tags_dialog_parent_class = g_type_class_peek_parent (klass);
#line 1978 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (TextEntryDialogMediator *, const gchar*)) add_tags_dialog_real_on_modify_validate;
#line 15621 "Dialogs.c"
}


static void add_tags_dialog_instance_init (AddTagsDialog * self) {
}


GType add_tags_dialog_get_type (void) {
	static volatile gsize add_tags_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&add_tags_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (AddTagsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) add_tags_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (AddTagsDialog), 0, (GInstanceInitFunc) add_tags_dialog_instance_init, NULL };
		GType add_tags_dialog_type_id;
		add_tags_dialog_type_id = g_type_register_static (TYPE_TAGS_DIALOG, "AddTagsDialog", &g_define_type_info, 0);
		g_once_init_leave (&add_tags_dialog_type_id__volatile, add_tags_dialog_type_id);
	}
	return add_tags_dialog_type_id__volatile;
}


ModifyTagsDialog* modify_tags_dialog_construct (GType object_type, MediaSource* source) {
	ModifyTagsDialog* self = NULL;
	MediaSource* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
#line 2008 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MEDIA_SOURCE (source), NULL);
#line 2009 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = source;
#line 2009 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = modify_tags_dialog_get_initial_text (_tmp0_);
#line 2009 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 2009 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (ModifyTagsDialog*) tags_dialog_construct (object_type, RESOURCES_MODIFY_TAGS_LABEL, _ ("Tags (separated by commas):"), _tmp2_);
#line 2009 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp2_);
#line 2008 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 15660 "Dialogs.c"
}


ModifyTagsDialog* modify_tags_dialog_new (MediaSource* source) {
#line 2008 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return modify_tags_dialog_construct (TYPE_MODIFY_TAGS_DIALOG, source);
#line 15667 "Dialogs.c"
}


static gchar* modify_tags_dialog_get_initial_text (MediaSource* source) {
	gchar* result = NULL;
	GeeCollection* source_tags = NULL;
	TagSourceCollection* _tmp0_;
	MediaSource* _tmp1_;
	GeeList* _tmp2_;
	GeeCollection* _tmp3_;
	GeeCollection* terminal_tags = NULL;
	GeeCollection* _tmp4_;
	GeeCollection* _tmp5_;
	GeeSortedSet* tag_basenames = NULL;
	GeeTreeSet* _tmp6_;
	gchar* text = NULL;
#line 2013 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MEDIA_SOURCE (source), NULL);
#line 2014 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = tag_global;
#line 2014 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = source;
#line 2014 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = tag_source_collection_fetch_for_source (_tmp0_, _tmp1_);
#line 2014 "/home/jens/Source/shotwell/src/Dialogs.vala"
	source_tags = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection);
#line 2015 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = source_tags;
#line 2015 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ == NULL) {
#line 2016 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = NULL;
#line 2016 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (source_tags);
#line 2016 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 15704 "Dialogs.c"
	}
#line 2018 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = source_tags;
#line 2018 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = tag_get_terminal_tags (_tmp4_);
#line 2018 "/home/jens/Source/shotwell/src/Dialogs.vala"
	terminal_tags = _tmp5_;
#line 2020 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = gee_tree_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL);
#line 2020 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_basenames = G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_SORTED_SET, GeeSortedSet);
#line 15716 "Dialogs.c"
	{
		GeeIterator* _tag_it = NULL;
		GeeCollection* _tmp7_;
		GeeIterator* _tmp8_;
#line 2021 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = terminal_tags;
#line 2021 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_ITERABLE, GeeIterable));
#line 2021 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tag_it = _tmp8_;
#line 2021 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 15729 "Dialogs.c"
			GeeIterator* _tmp9_;
			gboolean _tmp10_;
			Tag* tag = NULL;
			GeeIterator* _tmp11_;
			gpointer _tmp12_;
			GeeSortedSet* _tmp13_;
			Tag* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
#line 2021 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = _tag_it;
#line 2021 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp10_ = gee_iterator_next (_tmp9_);
#line 2021 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp10_) {
#line 2021 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 15749 "Dialogs.c"
			}
#line 2021 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp11_ = _tag_it;
#line 2021 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = gee_iterator_get (_tmp11_);
#line 2021 "/home/jens/Source/shotwell/src/Dialogs.vala"
			tag = (Tag*) _tmp12_;
#line 2022 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp13_ = tag_basenames;
#line 2022 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp14_ = tag;
#line 2022 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp15_ = tag_get_path (_tmp14_);
#line 2022 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp16_ = _tmp15_;
#line 2022 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp17_ = hierarchical_tag_utilities_get_basename (_tmp16_);
#line 2022 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = _tmp17_;
#line 2022 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GEE_TYPE_COLLECTION, GeeCollection), _tmp18_);
#line 2022 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp18_);
#line 2022 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (_tmp16_);
#line 2021 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (tag);
#line 15777 "Dialogs.c"
		}
#line 2021 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tag_it);
#line 15781 "Dialogs.c"
	}
#line 2024 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = NULL;
#line 15785 "Dialogs.c"
	{
		GeeIterator* _name_it = NULL;
		GeeSortedSet* _tmp19_;
		GeeIterator* _tmp20_;
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = tag_basenames;
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_ITERABLE, GeeIterable));
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_name_it = _tmp20_;
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 15798 "Dialogs.c"
			GeeIterator* _tmp21_;
			gboolean _tmp22_;
			gchar* name = NULL;
			GeeIterator* _tmp23_;
			gpointer _tmp24_;
			const gchar* _tmp25_;
			const gchar* _tmp29_;
			const gchar* _tmp30_;
			gchar* _tmp31_;
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = _name_it;
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = gee_iterator_next (_tmp21_);
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp22_) {
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 15816 "Dialogs.c"
			}
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = _name_it;
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = gee_iterator_get (_tmp23_);
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
			name = (gchar*) _tmp24_;
#line 2026 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = text;
#line 2026 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp25_ == NULL) {
#line 15828 "Dialogs.c"
				gchar* _tmp26_;
#line 2027 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp26_ = g_strdup ("");
#line 2027 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (text);
#line 2027 "/home/jens/Source/shotwell/src/Dialogs.vala"
				text = _tmp26_;
#line 15836 "Dialogs.c"
			} else {
				const gchar* _tmp27_;
				gchar* _tmp28_;
#line 2029 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp27_ = text;
#line 2029 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp28_ = g_strconcat (_tmp27_, ", ", NULL);
#line 2029 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (text);
#line 2029 "/home/jens/Source/shotwell/src/Dialogs.vala"
				text = _tmp28_;
#line 15848 "Dialogs.c"
			}
#line 2031 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp29_ = text;
#line 2031 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp30_ = name;
#line 2031 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp31_ = g_strconcat (_tmp29_, _tmp30_, NULL);
#line 2031 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (text);
#line 2031 "/home/jens/Source/shotwell/src/Dialogs.vala"
			text = _tmp31_;
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (name);
#line 15862 "Dialogs.c"
		}
#line 2025 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_name_it);
#line 15866 "Dialogs.c"
	}
#line 2034 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = text;
#line 2034 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (tag_basenames);
#line 2034 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (terminal_tags);
#line 2034 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (source_tags);
#line 2034 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 15878 "Dialogs.c"
}


GeeArrayList* modify_tags_dialog_execute (ModifyTagsDialog* self) {
	GeeArrayList* result = NULL;
	gchar* text = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
	GeeArrayList* new_tags = NULL;
	GeeArrayList* _tmp2_;
	const gchar* _tmp3_;
	gboolean _tmp4_;
	gchar** tag_names = NULL;
	const gchar* _tmp5_;
	gchar** _tmp6_;
	gchar** _tmp7_;
	gchar** _tmp8_;
	gint _tmp8__length1;
	gint _tmp9_;
	gchar** _tmp10_;
	gchar** _tmp11_;
	gint _tmp11__length1;
	gint tag_names_length1;
	gint _tag_names_size_;
	HierarchicalTagIndex* _tmp12_;
	HierarchicalTagIndex* _tmp13_;
	gchar** _tmp14_;
	gint _tmp14__length1;
	gint _tmp15_;
	gchar** _tmp16_;
	gchar** _tmp17_;
	gint _tmp17__length1;
#line 2037 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_MODIFY_TAGS_DIALOG (self), NULL);
#line 2038 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = _text_entry_dialog_mediator_execute (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_TEXT_ENTRY_DIALOG_MEDIATOR, TextEntryDialogMediator));
#line 2038 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text = _tmp0_;
#line 2039 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = text;
#line 2039 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == NULL) {
#line 2040 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = NULL;
#line 2040 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 2040 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 15927 "Dialogs.c"
	}
#line 2042 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gee_array_list_new (TYPE_TAG, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 2042 "/home/jens/Source/shotwell/src/Dialogs.vala"
	new_tags = _tmp2_;
#line 2045 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = text;
#line 2045 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = is_string_empty (_tmp3_);
#line 2045 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp4_) {
#line 2046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = new_tags;
#line 2046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (text);
#line 2046 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 15945 "Dialogs.c"
	}
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = text;
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_ = g_strsplit (_tmp5_, ",", 0);
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8__length1 = _vala_array_length (_tmp6_);
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = tag_prep_tag_names (_tmp8_, _vala_array_length (_tmp6_), &_tmp9_);
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11__length1 = _tmp9_;
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = (_vala_array_free (_tmp8_, _tmp8__length1, (GDestroyNotify) g_free), NULL);
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = _tmp11_;
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names_length1 = _tmp11__length1;
#line 2049 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tag_names_size_ = tag_names_length1;
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = hierarchical_tag_index_get_global_index ();
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _tmp12_;
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = tag_names;
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14__length1 = tag_names_length1;
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = hierarchical_tag_index_get_paths_for_names_array (_tmp13_, _tmp14_, _tmp14__length1, &_tmp15_);
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = (_vala_array_free (tag_names, tag_names_length1, (GDestroyNotify) g_free), NULL);
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = _tmp16_;
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names_length1 = _tmp15_;
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tag_names_size_ = tag_names_length1;
#line 2051 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_hierarchical_tag_index_unref0 (_tmp13_);
#line 2053 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = tag_names;
#line 2053 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17__length1 = tag_names_length1;
#line 15993 "Dialogs.c"
	{
		gchar** name_collection = NULL;
		gint name_collection_length1 = 0;
		gint _name_collection_size_ = 0;
		gint name_it = 0;
#line 2053 "/home/jens/Source/shotwell/src/Dialogs.vala"
		name_collection = _tmp17_;
#line 2053 "/home/jens/Source/shotwell/src/Dialogs.vala"
		name_collection_length1 = _tmp17__length1;
#line 2053 "/home/jens/Source/shotwell/src/Dialogs.vala"
		for (name_it = 0; name_it < _tmp17__length1; name_it = name_it + 1) {
#line 16005 "Dialogs.c"
			gchar* _tmp18_;
			gchar* name = NULL;
#line 2053 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp18_ = g_strdup (name_collection[name_it]);
#line 2053 "/home/jens/Source/shotwell/src/Dialogs.vala"
			name = _tmp18_;
#line 16012 "Dialogs.c"
			{
				GeeArrayList* _tmp19_;
				const gchar* _tmp20_;
				Tag* _tmp21_;
				Tag* _tmp22_;
#line 2054 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp19_ = new_tags;
#line 2054 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp20_ = name;
#line 2054 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp21_ = tag_for_path (_tmp20_);
#line 2054 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp22_ = _tmp21_;
#line 2054 "/home/jens/Source/shotwell/src/Dialogs.vala"
				gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp22_);
#line 2054 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp22_);
#line 2053 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (name);
#line 16032 "Dialogs.c"
			}
		}
	}
#line 2056 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = new_tags;
#line 2056 "/home/jens/Source/shotwell/src/Dialogs.vala"
	tag_names = (_vala_array_free (tag_names, tag_names_length1, (GDestroyNotify) g_free), NULL);
#line 2056 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (text);
#line 2056 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 16044 "Dialogs.c"
}


static gboolean modify_tags_dialog_real_on_modify_validate (TextEntryDialogMediator* base, const gchar* text) {
	ModifyTagsDialog * self;
	gboolean result = FALSE;
	const gchar* _tmp0_;
	gboolean _tmp1_;
#line 2059 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_MODIFY_TAGS_DIALOG, ModifyTagsDialog);
#line 2059 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (text != NULL, FALSE);
#line 2060 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = text;
#line 2060 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = string_contains (_tmp0_, TAG_PATH_SEPARATOR_STRING);
#line 2060 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = !_tmp1_;
#line 2060 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 16065 "Dialogs.c"
}


static void modify_tags_dialog_class_init (ModifyTagsDialogClass * klass) {
#line 2007 "/home/jens/Source/shotwell/src/Dialogs.vala"
	modify_tags_dialog_parent_class = g_type_class_peek_parent (klass);
#line 2007 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((TextEntryDialogMediatorClass *) klass)->on_modify_validate = (gboolean (*) (TextEntryDialogMediator *, const gchar*)) modify_tags_dialog_real_on_modify_validate;
#line 16074 "Dialogs.c"
}


static void modify_tags_dialog_instance_init (ModifyTagsDialog * self) {
}


GType modify_tags_dialog_get_type (void) {
	static volatile gsize modify_tags_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&modify_tags_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ModifyTagsDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) modify_tags_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ModifyTagsDialog), 0, (GInstanceInitFunc) modify_tags_dialog_instance_init, NULL };
		GType modify_tags_dialog_type_id;
		modify_tags_dialog_type_id = g_type_register_static (TYPE_TAGS_DIALOG, "ModifyTagsDialog", &g_define_type_info, 0);
		g_once_init_leave (&modify_tags_dialog_type_id__volatile, modify_tags_dialog_type_id);
	}
	return modify_tags_dialog_type_id__volatile;
}


gchar* welcome_service_entry_get_service_name (WelcomeServiceEntry* self) {
#line 2066 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_WELCOME_SERVICE_ENTRY (self), NULL);
#line 2066 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return WELCOME_SERVICE_ENTRY_GET_INTERFACE (self)->get_service_name (self);
#line 16099 "Dialogs.c"
}


void welcome_service_entry_execute (WelcomeServiceEntry* self) {
#line 2068 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_WELCOME_SERVICE_ENTRY (self));
#line 2068 "/home/jens/Source/shotwell/src/Dialogs.vala"
	WELCOME_SERVICE_ENTRY_GET_INTERFACE (self)->execute (self);
#line 16108 "Dialogs.c"
}


static void welcome_service_entry_base_init (WelcomeServiceEntryIface * iface) {
#line 2065 "/home/jens/Source/shotwell/src/Dialogs.vala"
	static gboolean initialized = FALSE;
#line 2065 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!initialized) {
#line 2065 "/home/jens/Source/shotwell/src/Dialogs.vala"
		initialized = TRUE;
#line 16119 "Dialogs.c"
	}
}


GType welcome_service_entry_get_type (void) {
	static volatile gsize welcome_service_entry_type_id__volatile = 0;
	if (g_once_init_enter (&welcome_service_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (WelcomeServiceEntryIface), (GBaseInitFunc) welcome_service_entry_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType welcome_service_entry_type_id;
		welcome_service_entry_type_id = g_type_register_static (G_TYPE_INTERFACE, "WelcomeServiceEntry", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (welcome_service_entry_type_id, G_TYPE_OBJECT);
		g_once_init_leave (&welcome_service_entry_type_id__volatile, welcome_service_entry_type_id);
	}
	return welcome_service_entry_type_id__volatile;
}


WelcomeDialog* welcome_dialog_construct (GType object_type, GtkWindow* owner) {
	WelcomeDialog * self = NULL;
	SpitDataImportsWelcomeImportMetaHost* _tmp0_;
	gboolean show_system_pictures_import = FALSE;
	gboolean _tmp1_;
	GtkWidget* ok_button = NULL;
	GtkWidget* _tmp2_;
	GtkWidget* _tmp3_;
	GtkWindow* _tmp4_;
	GtkLabel* primary_text = NULL;
	GtkLabel* _tmp5_;
	GtkLabel* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	GtkLabel* _tmp9_;
	GtkLabel* _tmp10_;
	GtkLabel* _tmp11_;
	GtkLabel* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	GtkLabel* _tmp15_;
	GtkLabel* _tmp16_;
	GtkImage* image = NULL;
	GtkImage* _tmp17_;
	GtkBox* header_text = NULL;
	GtkBox* _tmp18_;
	GtkBox* _tmp19_;
	GtkLabel* _tmp20_;
	GtkBox* _tmp21_;
	GtkLabel* _tmp22_;
	GtkBox* header_content = NULL;
	GtkBox* _tmp23_;
	GtkBox* _tmp24_;
	GtkImage* _tmp25_;
	GtkBox* _tmp26_;
	GtkBox* _tmp27_;
	GtkLabel* instructions = NULL;
	GtkLabel* _tmp28_;
	gchar* indent_prefix = NULL;
	gchar* _tmp29_;
	const gchar* _tmp30_ = NULL;
	GtkTextDirection _tmp31_;
	gchar* arrow_glyph = NULL;
	gchar* _tmp32_;
	GtkLabel* _tmp33_;
	const gchar* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	const gchar* _tmp37_;
	gchar* _tmp38_;
	gchar* _tmp39_;
	gchar* _tmp40_;
	gchar* _tmp41_;
	const gchar* _tmp42_;
	gchar* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	const gchar* _tmp47_;
	gchar* _tmp48_;
	gchar* _tmp49_;
	gchar* _tmp50_;
	gchar* _tmp51_;
	GtkLabel* _tmp52_;
	GtkLabel* _tmp53_;
	GtkBox* _tmp54_;
	GtkBox* _tmp55_;
	GtkBox* _tmp56_;
	GtkBox* _tmp57_;
	gboolean _tmp58_;
	GtkLabel* _tmp69_;
	GtkLabel* _tmp70_;
	GtkLabel* _tmp71_;
	GtkLabel* _tmp72_;
	GtkBox* content = NULL;
	GtkBox* _tmp73_;
	GtkBox* _tmp74_;
	GtkBox* _tmp75_;
	GtkBox* _tmp76_;
	GtkLabel* _tmp77_;
	GtkCheckButton* _tmp78_;
	GtkCheckButton* _tmp79_;
	GtkCheckButton* _tmp80_;
	GtkBox* _tmp81_;
	GtkWidget* _tmp82_;
	SpitDataImportsWelcomeImportMetaHost* _tmp83_;
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (GTK_IS_WINDOW (owner), NULL);
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (WelcomeDialog*) g_object_new (object_type, NULL);
#line 2086 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = spit_data_imports_welcome_import_meta_host_new (self);
#line 2086 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->import_meta_host);
#line 2086 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->import_meta_host = _tmp0_;
#line 2087 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = welcome_dialog_is_system_pictures_import_possible ();
#line 2087 "/home/jens/Source/shotwell/src/Dialogs.vala"
	show_system_pictures_import = _tmp1_;
#line 2088 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), RESOURCES_OK_LABEL, (gint) GTK_RESPONSE_OK);
#line 2088 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 2088 "/home/jens/Source/shotwell/src/Dialogs.vala"
	ok_button = _tmp3_;
#line 2089 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _ ("Welcome!"));
#line 2090 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 2091 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_type_hint (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), GDK_WINDOW_TYPE_HINT_DIALOG);
#line 2092 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = owner;
#line 2092 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp4_);
#line 2094 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = (GtkLabel*) gtk_label_new ("");
#line 2094 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp5_);
#line 2094 "/home/jens/Source/shotwell/src/Dialogs.vala"
	primary_text = _tmp5_;
#line 2095 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = primary_text;
#line 2095 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = g_strdup_printf ("<span size=\"large\" weight=\"bold\">%s</span>", _ ("Welcome to Shotwell!"));
#line 2095 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 2095 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_markup (_tmp6_, _tmp8_);
#line 2095 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp8_);
#line 2097 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = primary_text;
#line 2097 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_xalign (_tmp9_, 0.0f);
#line 2098 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = primary_text;
#line 2098 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_yalign (_tmp10_, 0.5f);
#line 2099 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = (GtkLabel*) gtk_label_new ("");
#line 2099 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp11_);
#line 2099 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->secondary_text);
#line 2099 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->secondary_text = _tmp11_;
#line 2100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = self->priv->secondary_text;
#line 2100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = g_strdup_printf ("<span weight=\"normal\">%s</span>", _ ("To get started, import photos in any of these ways:"));
#line 2100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 2100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_markup (_tmp12_, _tmp14_);
#line 2100 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp14_);
#line 2102 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = self->priv->secondary_text;
#line 2102 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_xalign (_tmp15_, 0.0f);
#line 2103 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = self->priv->secondary_text;
#line 2103 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_yalign (_tmp16_, 0.5f);
#line 2104 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = (GtkImage*) gtk_image_new_from_icon_name ("shotwell", GTK_ICON_SIZE_DIALOG);
#line 2104 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp17_);
#line 2104 "/home/jens/Source/shotwell/src/Dialogs.vala"
	image = _tmp17_;
#line 2106 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 2106 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp18_);
#line 2106 "/home/jens/Source/shotwell/src/Dialogs.vala"
	header_text = _tmp18_;
#line 2107 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = header_text;
#line 2107 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = primary_text;
#line 2107 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp19_, G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 5);
#line 2108 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = header_text;
#line 2108 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = self->priv->secondary_text;
#line 2108 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp21_, G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 2110 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
#line 2110 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp23_);
#line 2110 "/home/jens/Source/shotwell/src/Dialogs.vala"
	header_content = _tmp23_;
#line 2111 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = header_content;
#line 2111 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = image;
#line 2111 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp24_, G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 2112 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = header_content;
#line 2112 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = header_text;
#line 2112 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (_tmp26_, G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 2114 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = (GtkLabel*) gtk_label_new ("");
#line 2114 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp28_);
#line 2114 "/home/jens/Source/shotwell/src/Dialogs.vala"
	instructions = _tmp28_;
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = g_strdup ("   ");
#line 2115 "/home/jens/Source/shotwell/src/Dialogs.vala"
	indent_prefix = _tmp29_;
#line 2117 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = gtk_widget_get_direction (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 2117 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp31_ == GTK_TEXT_DIR_RTL) {
#line 2117 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = "◂";
#line 16361 "Dialogs.c"
	} else {
#line 2117 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = "▸";
#line 16365 "Dialogs.c"
	}
#line 2117 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = g_strdup (_tmp30_);
#line 2117 "/home/jens/Source/shotwell/src/Dialogs.vala"
	arrow_glyph = _tmp32_;
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = instructions;
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = indent_prefix;
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = g_strconcat (_tmp34_, "&#8226; %s\n", NULL);
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = _tmp35_;
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = indent_prefix;
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = g_strconcat (_tmp37_, "&#8226; %s\n", NULL);
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = _tmp38_;
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = g_strconcat (_tmp36_, _tmp39_, NULL);
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = _tmp40_;
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = indent_prefix;
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = g_strconcat (_tmp42_, "&#8226; %s", NULL);
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = _tmp43_;
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp45_ = g_strconcat (_tmp41_, _tmp44_, NULL);
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp46_ = _tmp45_;
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp47_ = arrow_glyph;
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp48_ = g_strdup_printf (_ ("Choose <span weight=\"bold\">File %s Import From Folder</span>"), _tmp47_);
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp49_ = _tmp48_;
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp50_ = g_strdup_printf (_tmp46_, _tmp49_, _ ("Drag and drop photos onto the Shotwell window"), _ ("Connect a camera to your computer and import"));
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp51_ = _tmp50_;
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_markup (_tmp33_, _tmp51_);
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp51_);
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp49_);
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp46_);
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp44_);
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp41_);
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp39_);
#line 2119 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp36_);
#line 2124 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp52_ = instructions;
#line 2124 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_xalign (_tmp52_, 0.0f);
#line 2125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp53_ = instructions;
#line 2125 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_yalign (_tmp53_, 0.5f);
#line 2127 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp54_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
#line 2127 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp54_);
#line 2127 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->import_action_checkbox_packer);
#line 2127 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->import_action_checkbox_packer = _tmp54_;
#line 2129 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp55_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
#line 2129 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp55_);
#line 2129 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->external_import_action_checkbox_packer);
#line 2129 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_action_checkbox_packer = _tmp55_;
#line 2130 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp56_ = self->priv->import_action_checkbox_packer;
#line 2130 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp57_ = self->priv->external_import_action_checkbox_packer;
#line 2130 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp56_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp57_, gtk_widget_get_type (), GtkWidget));
#line 2132 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp58_ = show_system_pictures_import;
#line 2132 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp58_) {
#line 16459 "Dialogs.c"
		GFile* _tmp59_;
		GFile* _tmp60_;
		gchar* _tmp61_;
		gchar* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		GtkCheckButton* _tmp65_;
		GtkBox* _tmp66_;
		GtkCheckButton* _tmp67_;
		GtkCheckButton* _tmp68_;
#line 2133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp59_ = app_dirs_get_import_dir ();
#line 2133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp60_ = _tmp59_;
#line 2133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp61_ = get_display_pathname (_tmp60_);
#line 2133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp62_ = _tmp61_;
#line 2133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp63_ = g_strdup_printf (_ ("_Import photos from your %s folder"), _tmp62_);
#line 2133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp64_ = _tmp63_;
#line 2133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp65_ = (GtkCheckButton*) gtk_check_button_new_with_mnemonic (_tmp64_);
#line 2133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp65_);
#line 2133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (self->priv->system_pictures_import_check);
#line 2133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->system_pictures_import_check = _tmp65_;
#line 2133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp64_);
#line 2133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp62_);
#line 2133 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp60_);
#line 2136 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp66_ = self->priv->import_action_checkbox_packer;
#line 2136 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp67_ = self->priv->system_pictures_import_check;
#line 2136 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp66_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp67_, gtk_widget_get_type (), GtkWidget));
#line 2137 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp68_ = self->priv->system_pictures_import_check;
#line 2137 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 16506 "Dialogs.c"
	}
#line 2140 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp69_ = (GtkLabel*) gtk_label_new (_ ("You can also import photos in any of these ways:"));
#line 2140 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp69_);
#line 2140 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->instruction_header);
#line 2140 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->instruction_header = _tmp69_;
#line 2142 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp70_ = self->priv->instruction_header;
#line 2142 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_xalign (_tmp70_, 0.0f);
#line 2143 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp71_ = self->priv->instruction_header;
#line 2143 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_yalign (_tmp71_, 0.5f);
#line 2144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp72_ = self->priv->instruction_header;
#line 2144 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_margin_top (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, gtk_widget_get_type (), GtkWidget), 20);
#line 2146 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp73_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 16);
#line 2146 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp73_);
#line 2146 "/home/jens/Source/shotwell/src/Dialogs.vala"
	content = _tmp73_;
#line 2147 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp74_ = header_content;
#line 2147 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (content, G_TYPE_CHECK_INSTANCE_CAST (_tmp74_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 2148 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp75_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 2);
#line 2148 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp75_);
#line 2148 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->import_content);
#line 2148 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->import_content = _tmp75_;
#line 2149 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp76_ = self->priv->import_content;
#line 2149 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (content, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp76_, gtk_widget_get_type (), GtkWidget));
#line 2150 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp77_ = instructions;
#line 2150 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (content, G_TYPE_CHECK_INSTANCE_CAST (_tmp77_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 2152 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp78_ = (GtkCheckButton*) gtk_check_button_new_with_mnemonic (_ ("_Don’t show this message again"));
#line 2152 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp78_);
#line 2152 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->hide_button);
#line 2152 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->hide_button = _tmp78_;
#line 2153 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp79_ = self->priv->hide_button;
#line 2153 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp79_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 2154 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp80_ = self->priv->hide_button;
#line 2154 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (content, G_TYPE_CHECK_INSTANCE_CAST (_tmp80_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 6);
#line 2155 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (content, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_FILL);
#line 2156 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (content, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_FILL);
#line 2157 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_hexpand (G_TYPE_CHECK_INSTANCE_CAST (content, gtk_widget_get_type (), GtkWidget), FALSE);
#line 2158 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_vexpand (G_TYPE_CHECK_INSTANCE_CAST (content, gtk_widget_get_type (), GtkWidget), FALSE);
#line 2159 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_margin_top (G_TYPE_CHECK_INSTANCE_CAST (content, gtk_widget_get_type (), GtkWidget), 12);
#line 2160 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_margin_bottom (G_TYPE_CHECK_INSTANCE_CAST (content, gtk_widget_get_type (), GtkWidget), 0);
#line 2161 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_margin_start (G_TYPE_CHECK_INSTANCE_CAST (content, gtk_widget_get_type (), GtkWidget), 12);
#line 2162 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_margin_end (G_TYPE_CHECK_INSTANCE_CAST (content, gtk_widget_get_type (), GtkWidget), 12);
#line 2164 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp81_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 2164 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_box_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp81_, gtk_box_get_type (), GtkBox), G_TYPE_CHECK_INSTANCE_CAST (content, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 2166 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp82_ = ok_button;
#line 2166 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_grab_focus (_tmp82_);
#line 2168 "/home/jens/Source/shotwell/src/Dialogs.vala"
	welcome_dialog_install_import_content (self);
#line 2170 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp83_ = self->priv->import_meta_host;
#line 2170 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spit_data_imports_welcome_import_meta_host_start (_tmp83_);
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (content);
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (arrow_glyph);
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (indent_prefix);
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (instructions);
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (header_content);
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (header_text);
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (image);
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (primary_text);
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (ok_button);
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 16620 "Dialogs.c"
}


WelcomeDialog* welcome_dialog_new (GtkWindow* owner) {
#line 2085 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return welcome_dialog_construct (TYPE_WELCOME_DIALOG, owner);
#line 16627 "Dialogs.c"
}


static void welcome_dialog_install_import_content (WelcomeDialog* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GtkCheckButton** _tmp2_;
	gint _tmp2__length1;
#line 2173 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_WELCOME_DIALOG (self));
#line 2175 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->external_import_checks;
#line 2175 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2__length1 = self->priv->external_import_checks_length1;
#line 2175 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2__length1 > 0) {
#line 2175 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = TRUE;
#line 16646 "Dialogs.c"
	} else {
		GtkCheckButton* _tmp3_;
#line 2175 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = self->priv->system_pictures_import_check;
#line 2175 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = _tmp3_ != NULL;
#line 16653 "Dialogs.c"
	}
#line 2175 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_) {
#line 16657 "Dialogs.c"
		gboolean _tmp4_;
#line 2176 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = self->priv->import_content_already_installed;
#line 2176 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp4_ == FALSE;
#line 16663 "Dialogs.c"
	} else {
#line 2175 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = FALSE;
#line 16667 "Dialogs.c"
	}
#line 2174 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 16671 "Dialogs.c"
		GtkLabel* _tmp5_;
		GtkBox* _tmp6_;
		GtkBox* _tmp7_;
		GtkBox* _tmp8_;
		GtkLabel* _tmp9_;
#line 2178 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = self->priv->secondary_text;
#line 2178 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_markup (_tmp5_, "");
#line 2179 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = self->priv->import_content;
#line 2179 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = self->priv->import_action_checkbox_packer;
#line 2179 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_widget_get_type (), GtkWidget));
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = self->priv->import_content;
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = self->priv->instruction_header;
#line 2180 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_widget_get_type (), GtkWidget));
#line 2181 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->import_content_already_installed = TRUE;
#line 16695 "Dialogs.c"
	}
}


static void _vala_array_add109 (WelcomeServiceEntry** * array, int* length, int* size, WelcomeServiceEntry* value) {
#line 2187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if ((*length) == (*size)) {
#line 2187 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 2187 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*array = g_renew (WelcomeServiceEntry*, *array, (*size) + 1);
#line 16707 "Dialogs.c"
	}
#line 2187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(*array)[(*length)++] = value;
#line 2187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(*array)[*length] = NULL;
#line 16713 "Dialogs.c"
}


static void _vala_array_add110 (GtkCheckButton** * array, int* length, int* size, GtkCheckButton* value) {
#line 2190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if ((*length) == (*size)) {
#line 2190 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 2190 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*array = g_renew (GtkCheckButton*, *array, (*size) + 1);
#line 16724 "Dialogs.c"
	}
#line 2190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(*array)[(*length)++] = value;
#line 2190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(*array)[*length] = NULL;
#line 16730 "Dialogs.c"
}


void welcome_dialog_install_service_entry (WelcomeDialog* self, WelcomeServiceEntry* entry) {
	WelcomeServiceEntry* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	WelcomeServiceEntry** _tmp5_;
	gint _tmp5__length1;
	WelcomeServiceEntry* _tmp6_;
	WelcomeServiceEntry* _tmp7_;
	GtkCheckButton* entry_check = NULL;
	WelcomeServiceEntry* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	GtkCheckButton* _tmp13_;
	GtkCheckButton* _tmp14_;
	GtkCheckButton** _tmp15_;
	gint _tmp15__length1;
	GtkCheckButton* _tmp16_;
	GtkBox* _tmp17_;
#line 2185 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_WELCOME_DIALOG (self));
#line 2185 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_WELCOME_SERVICE_ENTRY (entry));
#line 2186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = entry;
#line 2186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = welcome_service_entry_get_service_name (_tmp0_);
#line 2186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 2186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup_printf ("WelcomeDialog: Installing service entry for %s", _tmp2_);
#line 2186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 2186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_debug ("Dialogs.vala:2186: %s", _tmp4_);
#line 2186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp4_);
#line 2186 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp2_);
#line 2187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = self->priv->external_import_entries;
#line 2187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5__length1 = self->priv->external_import_entries_length1;
#line 2187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = entry;
#line 2187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 2187 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_array_add109 (&self->priv->external_import_entries, &self->priv->external_import_entries_length1, &self->priv->_external_import_entries_size_, _tmp7_);
#line 2188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = entry;
#line 2188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = welcome_service_entry_get_service_name (_tmp8_);
#line 2188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 2188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = g_strdup_printf (_ ("Import photos from your %s library"), _tmp10_);
#line 2188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = _tmp11_;
#line 2188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = (GtkCheckButton*) gtk_check_button_new_with_label (_tmp12_);
#line 2188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp13_);
#line 2188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 2188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp12_);
#line 2188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp10_);
#line 2188 "/home/jens/Source/shotwell/src/Dialogs.vala"
	entry_check = _tmp14_;
#line 2190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = self->priv->external_import_checks;
#line 2190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15__length1 = self->priv->external_import_checks_length1;
#line 2190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = _g_object_ref0 (entry_check);
#line 2190 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_array_add110 (&self->priv->external_import_checks, &self->priv->external_import_checks_length1, &self->priv->_external_import_checks_size_, _tmp16_);
#line 2191 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (entry_check, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 2192 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = self->priv->external_import_action_checkbox_packer;
#line 2192 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (entry_check, gtk_widget_get_type (), GtkWidget));
#line 2193 "/home/jens/Source/shotwell/src/Dialogs.vala"
	welcome_dialog_install_import_content (self);
#line 2185 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (entry_check);
#line 16826 "Dialogs.c"
}


/**
     * Connected to the 'response' signal.  This is part of a workaround
     * for the fact that run()-ning this dialog can interfere with displaying
     * images from a camera; please see #4997 for details.
     */
static void welcome_dialog_on_dismiss (WelcomeDialog* self, gint resp) {
	gint _tmp0_;
#line 2201 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_WELCOME_DIALOG (self));
#line 2202 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = resp;
#line 2202 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == ((gint) GTK_RESPONSE_OK)) {
#line 2203 "/home/jens/Source/shotwell/src/Dialogs.vala"
		self->priv->ok_clicked = TRUE;
#line 16845 "Dialogs.c"
	}
#line 2205 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 2206 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_main_quit ();
#line 16851 "Dialogs.c"
}


static void _welcome_dialog_on_dismiss_gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 2212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	welcome_dialog_on_dismiss ((WelcomeDialog*) self, response_id);
#line 16858 "Dialogs.c"
}


static void _vala_array_add111 (WelcomeServiceEntry** * array, int* length, int* size, WelcomeServiceEntry* value) {
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if ((*length) == (*size)) {
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*array = g_renew (WelcomeServiceEntry*, *array, (*size) + 1);
#line 16869 "Dialogs.c"
	}
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(*array)[(*length)++] = value;
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(*array)[*length] = NULL;
#line 16875 "Dialogs.c"
}


static WelcomeServiceEntry** _vala_array_dup29 (WelcomeServiceEntry** self, int length) {
	WelcomeServiceEntry** result;
	int i;
#line 2237 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = g_new0 (WelcomeServiceEntry*, length + 1);
#line 2237 "/home/jens/Source/shotwell/src/Dialogs.vala"
	for (i = 0; i < length; i++) {
#line 16886 "Dialogs.c"
		WelcomeServiceEntry* _tmp0_;
#line 2237 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 2237 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result[i] = _tmp0_;
#line 16892 "Dialogs.c"
	}
#line 2237 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 16896 "Dialogs.c"
}


gboolean welcome_dialog_execute (WelcomeDialog* self, WelcomeServiceEntry*** selected_import_entries, int* selected_import_entries_length1, gboolean* do_system_pictures_import) {
	WelcomeServiceEntry** _vala_selected_import_entries = NULL;
	int _vala_selected_import_entries_length1 = 0;
	gboolean _vala_do_system_pictures_import = FALSE;
	gboolean result = FALSE;
	guint _tmp0_;
	gboolean ok = FALSE;
	gboolean _tmp1_;
	gboolean show_dialog = FALSE;
	gboolean _tmp2_;
	WelcomeServiceEntry** _result_ = NULL;
	WelcomeServiceEntry** _tmp5_;
	gint _result__length1;
	gint __result__size_;
	WelcomeServiceEntry** _tmp19_;
	gint _tmp19__length1;
	WelcomeServiceEntry** _tmp20_;
	gint _tmp20__length1;
	gboolean _tmp21_ = FALSE;
	GtkCheckButton* _tmp22_;
#line 2209 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_WELCOME_DIALOG (self), FALSE);
#line 2212 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), "response", (GCallback) _welcome_dialog_on_dismiss_gtk_dialog_response, self, 0);
#line 2213 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 2214 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 2219 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_main ();
#line 2223 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_parse_name ("response", gtk_dialog_get_type (), &_tmp0_, NULL, FALSE);
#line 2223 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp0_, 0, NULL, (GCallback) _welcome_dialog_on_dismiss_gtk_dialog_response, self);
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->ok_clicked;
#line 2225 "/home/jens/Source/shotwell/src/Dialogs.vala"
	ok = _tmp1_;
#line 2226 "/home/jens/Source/shotwell/src/Dialogs.vala"
	show_dialog = TRUE;
#line 2228 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = ok;
#line 2228 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_) {
#line 16944 "Dialogs.c"
		GtkCheckButton* _tmp3_;
		gboolean _tmp4_;
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = self->priv->hide_button;
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 2229 "/home/jens/Source/shotwell/src/Dialogs.vala"
		show_dialog = !_tmp4_;
#line 16953 "Dialogs.c"
	}
#line 2232 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = g_new0 (WelcomeServiceEntry*, 0 + 1);
#line 2232 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = _tmp5_;
#line 2232 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result__length1 = 0;
#line 2232 "/home/jens/Source/shotwell/src/Dialogs.vala"
	__result__size_ = _result__length1;
#line 16963 "Dialogs.c"
	{
		gint i = 0;
#line 2233 "/home/jens/Source/shotwell/src/Dialogs.vala"
		i = 0;
#line 16968 "Dialogs.c"
		{
			gboolean _tmp6_ = FALSE;
#line 2233 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = TRUE;
#line 2233 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 16975 "Dialogs.c"
				gint _tmp8_;
				WelcomeServiceEntry** _tmp9_;
				gint _tmp9__length1;
				GtkCheckButton** _tmp10_;
				gint _tmp10__length1;
				gint _tmp11_;
				GtkCheckButton* _tmp12_;
				gboolean _tmp13_;
#line 2233 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!_tmp6_) {
#line 16986 "Dialogs.c"
					gint _tmp7_;
#line 2233 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp7_ = i;
#line 2233 "/home/jens/Source/shotwell/src/Dialogs.vala"
					i = _tmp7_ + 1;
#line 16992 "Dialogs.c"
				}
#line 2233 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp6_ = FALSE;
#line 2233 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp8_ = i;
#line 2233 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9_ = self->priv->external_import_entries;
#line 2233 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp9__length1 = self->priv->external_import_entries_length1;
#line 2233 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp8_ < _tmp9__length1)) {
#line 2233 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 17006 "Dialogs.c"
				}
#line 2234 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = self->priv->external_import_checks;
#line 2234 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10__length1 = self->priv->external_import_checks_length1;
#line 2234 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = i;
#line 2234 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp12_ = _tmp10_[_tmp11_];
#line 2234 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 2234 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (_tmp13_ == TRUE) {
#line 17020 "Dialogs.c"
					WelcomeServiceEntry** _tmp14_;
					gint _tmp14__length1;
					WelcomeServiceEntry** _tmp15_;
					gint _tmp15__length1;
					gint _tmp16_;
					WelcomeServiceEntry* _tmp17_;
					WelcomeServiceEntry* _tmp18_;
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp14_ = _result_;
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp14__length1 = _result__length1;
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp15_ = self->priv->external_import_entries;
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp15__length1 = self->priv->external_import_entries_length1;
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp16_ = i;
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp17_ = _tmp15_[_tmp16_];
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp18_ = _g_object_ref0 (_tmp17_);
#line 2235 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_vala_array_add111 (&_result_, &_result__length1, &__result__size_, _tmp18_);
#line 17044 "Dialogs.c"
				}
			}
		}
	}
#line 2237 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = _result_;
#line 2237 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19__length1 = _result__length1;
#line 2237 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = (_tmp19_ != NULL) ? _vala_array_dup29 (_tmp19_, _tmp19__length1) : ((gpointer) _tmp19_);
#line 2237 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20__length1 = _tmp19__length1;
#line 2237 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_selected_import_entries = (_vala_array_free (_vala_selected_import_entries, _vala_selected_import_entries_length1, (GDestroyNotify) g_object_unref), NULL);
#line 2237 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_selected_import_entries = _tmp20_;
#line 2237 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_selected_import_entries_length1 = _tmp20__length1;
#line 2239 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = self->priv->system_pictures_import_check;
#line 2239 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp22_ != NULL) {
#line 17067 "Dialogs.c"
		GtkCheckButton* _tmp23_;
		gboolean _tmp24_;
#line 2239 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = self->priv->system_pictures_import_check;
#line 2239 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 2239 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = _tmp24_;
#line 17076 "Dialogs.c"
	} else {
#line 2239 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = FALSE;
#line 17080 "Dialogs.c"
	}
#line 2238 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_do_system_pictures_import = _tmp21_;
#line 2241 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 2243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = show_dialog;
#line 2243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (_vala_array_free (_result_, _result__length1, (GDestroyNotify) g_object_unref), NULL);
#line 2243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (selected_import_entries) {
#line 2243 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*selected_import_entries = _vala_selected_import_entries;
#line 17094 "Dialogs.c"
	} else {
#line 2243 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_vala_selected_import_entries = (_vala_array_free (_vala_selected_import_entries, _vala_selected_import_entries_length1, (GDestroyNotify) g_object_unref), NULL);
#line 17098 "Dialogs.c"
	}
#line 2243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (selected_import_entries_length1) {
#line 2243 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*selected_import_entries_length1 = _vala_selected_import_entries_length1;
#line 17104 "Dialogs.c"
	}
#line 2243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (do_system_pictures_import) {
#line 2243 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*do_system_pictures_import = _vala_do_system_pictures_import;
#line 17110 "Dialogs.c"
	}
#line 2243 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 17114 "Dialogs.c"
}


static gboolean welcome_dialog_is_system_pictures_import_possible (void) {
	gboolean result = FALSE;
	GFile* system_pictures = NULL;
	GFile* _tmp0_;
	GFile* _tmp1_;
	gboolean _tmp2_;
	GFile* _tmp3_;
	GFileType _tmp4_;
	gboolean _tmp10_ = FALSE;
	GError * _inner_error_ = NULL;
#line 2247 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_dirs_get_import_dir ();
#line 2247 "/home/jens/Source/shotwell/src/Dialogs.vala"
	system_pictures = _tmp0_;
#line 2248 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = system_pictures;
#line 2248 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = g_file_query_exists (_tmp1_, NULL);
#line 2248 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp2_) {
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (system_pictures);
#line 2249 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 17144 "Dialogs.c"
	}
#line 2251 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = system_pictures;
#line 2251 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = g_file_query_file_type (_tmp3_, G_FILE_QUERY_INFO_NONE, NULL);
#line 2251 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!(_tmp4_ == G_FILE_TYPE_DIRECTORY)) {
#line 2252 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 2252 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (system_pictures);
#line 2252 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 17158 "Dialogs.c"
	}
	{
		GFileEnumerator* syspics_child_enum = NULL;
		GFile* _tmp5_;
		GFileEnumerator* _tmp6_;
		GFileInfo* _tmp7_ = NULL;
		GFileEnumerator* _tmp8_;
		GFileInfo* _tmp9_;
#line 2255 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = system_pictures;
#line 2255 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = g_file_enumerate_children (_tmp5_, "standard::*", G_FILE_QUERY_INFO_NONE, NULL, &_inner_error_);
#line 2255 "/home/jens/Source/shotwell/src/Dialogs.vala"
		syspics_child_enum = _tmp6_;
#line 2255 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 17175 "Dialogs.c"
			goto __catch427_g_error;
		}
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = syspics_child_enum;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = g_file_enumerator_next_file (_tmp8_, NULL, &_inner_error_);
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp9_;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (syspics_child_enum);
#line 17188 "Dialogs.c"
			goto __catch427_g_error;
		}
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = _tmp7_ != NULL;
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp7_);
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (syspics_child_enum);
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (system_pictures);
#line 2257 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 17201 "Dialogs.c"
	}
	goto __finally427;
	__catch427_g_error:
	{
		GError* e = NULL;
#line 2254 "/home/jens/Source/shotwell/src/Dialogs.vala"
		e = _inner_error_;
#line 2254 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_inner_error_ = NULL;
#line 2259 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = FALSE;
#line 2259 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_error_free0 (e);
#line 2259 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (system_pictures);
#line 2259 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 17219 "Dialogs.c"
	}
	__finally427:
#line 2254 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (system_pictures);
#line 2254 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2254 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_clear_error (&_inner_error_);
#line 2254 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return _tmp10_;
#line 17230 "Dialogs.c"
}


static void welcome_dialog_class_init (WelcomeDialogClass * klass) {
#line 2071 "/home/jens/Source/shotwell/src/Dialogs.vala"
	welcome_dialog_parent_class = g_type_class_peek_parent (klass);
#line 2071 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (WelcomeDialogPrivate));
#line 2071 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (klass)->finalize = welcome_dialog_finalize;
#line 17241 "Dialogs.c"
}


static void welcome_dialog_instance_init (WelcomeDialog * self) {
	GtkCheckButton** _tmp0_;
	WelcomeServiceEntry** _tmp1_;
#line 2071 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = WELCOME_DIALOG_GET_PRIVATE (self);
#line 2073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->system_pictures_import_check = NULL;
#line 2074 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_new0 (GtkCheckButton*, 0 + 1);
#line 2074 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_checks = _tmp0_;
#line 2074 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_checks_length1 = 0;
#line 2074 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->_external_import_checks_size_ = self->priv->external_import_checks_length1;
#line 2075 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_new0 (WelcomeServiceEntry*, 0 + 1);
#line 2075 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_entries = _tmp1_;
#line 2075 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_entries_length1 = 0;
#line 2075 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->_external_import_entries_size_ = self->priv->external_import_entries_length1;
#line 2082 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->import_content_already_installed = FALSE;
#line 2083 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->ok_clicked = FALSE;
#line 17272 "Dialogs.c"
}


static void welcome_dialog_finalize (GObject * obj) {
	WelcomeDialog * self;
#line 2071 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_WELCOME_DIALOG, WelcomeDialog);
#line 2072 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->hide_button);
#line 2073 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->system_pictures_import_check);
#line 2074 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_checks = (_vala_array_free (self->priv->external_import_checks, self->priv->external_import_checks_length1, (GDestroyNotify) g_object_unref), NULL);
#line 2075 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_import_entries = (_vala_array_free (self->priv->external_import_entries, self->priv->external_import_entries_length1, (GDestroyNotify) g_object_unref), NULL);
#line 2076 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->secondary_text);
#line 2077 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->instruction_header);
#line 2078 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->import_content);
#line 2079 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->import_action_checkbox_packer);
#line 2080 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->external_import_action_checkbox_packer);
#line 2081 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->import_meta_host);
#line 2071 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_OBJECT_CLASS (welcome_dialog_parent_class)->finalize (obj);
#line 17302 "Dialogs.c"
}


GType welcome_dialog_get_type (void) {
	static volatile gsize welcome_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&welcome_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (WelcomeDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) welcome_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (WelcomeDialog), 0, (GInstanceInitFunc) welcome_dialog_instance_init, NULL };
		GType welcome_dialog_type_id;
		welcome_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "WelcomeDialog", &g_define_type_info, 0);
		g_once_init_leave (&welcome_dialog_type_id__volatile, welcome_dialog_type_id);
	}
	return welcome_dialog_type_id__volatile;
}


static gboolean _preferences_dialog_on_delete_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self) {
	gboolean result;
	result = preferences_dialog_on_delete ((PreferencesDialog*) self);
#line 2308 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 17323 "Dialogs.c"
}


static void _preferences_dialog_on_close_gtk_dialog_response (GtkDialog* _sender, gint response_id, gpointer self) {
#line 2309 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_close ((PreferencesDialog*) self);
#line 17330 "Dialogs.c"
}


static void _preferences_dialog_on_value_changed_gtk_adjustment_value_changed (GtkAdjustment* _sender, gpointer self) {
#line 2314 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_value_changed ((PreferencesDialog*) self);
#line 17337 "Dialogs.c"
}


static gboolean _preferences_dialog_on_bg_color_reset_gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = preferences_dialog_on_bg_color_reset ((PreferencesDialog*) self, event);
#line 2317 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 17346 "Dialogs.c"
}


static gboolean _preferences_dialog_on_local_pattern_help_gtk_label_activate_link (GtkLabel* _sender, const gchar* uri, gpointer self) {
	gboolean result;
	result = preferences_dialog_on_local_pattern_help ((PreferencesDialog*) self, uri);
#line 2340 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 17355 "Dialogs.c"
}


static void _preferences_dialog_on_dir_pattern_combo_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 2354 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_dir_pattern_combo_changed ((PreferencesDialog*) self);
#line 17362 "Dialogs.c"
}


static void _preferences_dialog_on_dir_pattern_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 2355 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_dir_pattern_entry_changed ((PreferencesDialog*) self);
#line 17369 "Dialogs.c"
}


static void _preferences_dialog_on_lowercase_toggled_gtk_toggle_button_toggled (GtkToggleButton* _sender, gpointer self) {
#line 2360 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_lowercase_toggled ((PreferencesDialog*) self);
#line 17376 "Dialogs.c"
}


static void _preferences_dialog_on_photo_editor_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 2367 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_photo_editor_changed ((PreferencesDialog*) self);
#line 17383 "Dialogs.c"
}


static void _preferences_dialog_on_raw_editor_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 2368 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_raw_editor_changed ((PreferencesDialog*) self);
#line 17390 "Dialogs.c"
}


static void _preferences_dialog_on_default_raw_developer_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 2380 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_default_raw_developer_changed ((PreferencesDialog*) self);
#line 17397 "Dialogs.c"
}


static gboolean _preferences_dialog_map_event_gtk_widget_map_event (GtkWidget* _sender, GdkEventAny* event, gpointer self) {
	gboolean result;
	result = preferences_dialog_map_event ((PreferencesDialog*) self);
#line 2382 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 17406 "Dialogs.c"
}


static PreferencesDialog* preferences_dialog_construct (GType object_type) {
	PreferencesDialog* self = NULL;
	GtkBuilder* _tmp0_;
	GtkBuilder* _tmp1_;
	GObject* _tmp2_;
	GtkDialog* _tmp3_;
	gboolean use_header = FALSE;
	GtkSettings* _tmp4_;
	gboolean _tmp5_;
	GtkDialog* _tmp8_;
	AppWindow* _tmp9_;
	AppWindow* _tmp10_;
	GdkWindow* _tmp11_;
	GtkDialog* _tmp12_;
	AppWindow* _tmp13_;
	AppWindow* _tmp14_;
	GtkDialog* _tmp15_;
	GtkDialog* _tmp16_;
	GtkBuilder* _tmp17_;
	GObject* _tmp18_;
	GtkAdjustment* _tmp19_;
	GtkAdjustment* _tmp20_;
	GtkAdjustment* _tmp21_;
	gdouble _tmp22_;
	ConfigFacade* _tmp23_;
	ConfigFacade* _tmp24_;
	GdkRGBA _tmp25_ = {0};
	gdouble _tmp26_;
	GtkAdjustment* _tmp27_;
	GtkBuilder* _tmp28_;
	GObject* _tmp29_;
	GtkScale* _tmp30_;
	GtkScale* _tmp31_;
	GtkBuilder* _tmp32_;
	GObject* _tmp33_;
	GtkFileChooserButton* _tmp34_;
	GtkBuilder* _tmp35_;
	GObject* _tmp36_;
	GtkComboBox* _tmp37_;
	GtkBuilder* _tmp38_;
	GObject* _tmp39_;
	GtkComboBox* _tmp40_;
	GtkLabel* pattern_help = NULL;
	GtkBuilder* _tmp41_;
	GObject* _tmp42_;
	GtkLabel* _tmp43_;
	gchar* help_path = NULL;
	gchar* _tmp44_;
	const gchar* _tmp45_;
	GtkBuilder* _tmp57_;
	GObject* _tmp58_;
	GtkComboBoxText* _tmp59_;
	GtkBuilder* _tmp60_;
	GObject* _tmp61_;
	GtkEntry* _tmp62_;
	GtkBuilder* _tmp63_;
	GObject* _tmp64_;
	GtkLabel* _tmp65_;
	gchar* _tmp66_;
	gchar* _tmp67_;
	gchar* _tmp68_;
	gchar* _tmp69_;
	gchar* _tmp70_;
	gchar* _tmp71_;
	GtkComboBoxText* _tmp72_;
	GtkEntry* _tmp73_;
	GtkBuilder* _tmp74_;
	GObject* _tmp75_;
	GtkComboBoxText* _tmp76_;
	GtkBuilder* _tmp77_;
	GObject* _tmp78_;
	GtkCheckButton* _tmp79_;
	GtkCheckButton* _tmp80_;
	GtkNotebook* notebook = NULL;
	GtkBuilder* _tmp81_;
	GObject* _tmp82_;
	GtkNotebook* _tmp83_;
	GtkWidget* _tmp84_;
	PluginsManifestWidgetMediator* _tmp85_;
	GtkWidget* _tmp86_;
	GtkWidget* _tmp87_;
	GtkComboBox* _tmp88_;
	GtkComboBox* _tmp89_;
	GtkCheckButton* auto_import_button = NULL;
	GtkBuilder* _tmp90_;
	GObject* _tmp91_;
	GtkCheckButton* _tmp92_;
	ConfigFacade* _tmp93_;
	ConfigFacade* _tmp94_;
	gboolean _tmp95_;
	GtkCheckButton* commit_metadata_button = NULL;
	GtkBuilder* _tmp96_;
	GObject* _tmp97_;
	GtkCheckButton* _tmp98_;
	ConfigFacade* _tmp99_;
	ConfigFacade* _tmp100_;
	gboolean _tmp101_;
	GtkBuilder* _tmp102_;
	GObject* _tmp103_;
	GtkComboBoxText* _tmp104_;
	GtkComboBoxText* _tmp105_;
	gchar* _tmp106_;
	gchar* _tmp107_;
	GtkComboBoxText* _tmp108_;
	gchar* _tmp109_;
	gchar* _tmp110_;
	ConfigFacade* _tmp111_;
	ConfigFacade* _tmp112_;
	RawDeveloper _tmp113_;
	GtkComboBoxText* _tmp114_;
	GtkDialog* _tmp115_;
#line 2296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (PreferencesDialog*) g_type_create_instance (object_type);
#line 2297 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = app_window_create_builder ("shotwell.ui", NULL);
#line 2297 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->builder);
#line 2297 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->builder = _tmp0_;
#line 2299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->builder;
#line 2299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_builder_get_object (_tmp1_, "preferences_dialog");
#line 2299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, gtk_dialog_get_type ()) ? ((GtkDialog*) _tmp2_) : NULL);
#line 2299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 2299 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dialog = _tmp3_;
#line 2301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gtk_settings_get_default ();
#line 2301 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 2302 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = use_header;
#line 2302 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp5_) {
#line 17547 "Dialogs.c"
		GtkWidget* null_titlebar = NULL;
		GtkDialog* _tmp6_;
		GtkWidget* _tmp7_;
#line 2303 "/home/jens/Source/shotwell/src/Dialogs.vala"
		null_titlebar = NULL;
#line 2304 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = self->priv->dialog;
#line 2304 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = null_titlebar;
#line 2304 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_window_set_titlebar (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_window_get_type (), GtkWindow), _tmp7_);
#line 2302 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (null_titlebar);
#line 17561 "Dialogs.c"
	}
#line 2306 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = self->priv->dialog;
#line 2306 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = app_window_get_instance ();
#line 2306 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 2306 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = gtk_widget_get_parent_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_widget_get_type (), GtkWidget));
#line 2306 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_set_parent_window (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_widget_get_type (), GtkWidget), _tmp11_);
#line 2306 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp10_);
#line 2307 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = self->priv->dialog;
#line 2307 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = app_window_get_instance ();
#line 2307 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 2307 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_window_get_type (), GtkWindow));
#line 2307 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp14_);
#line 2308 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = self->priv->dialog;
#line 2308 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_widget_get_type (), GtkWidget), "delete-event", (GCallback) _preferences_dialog_on_delete_gtk_widget_delete_event, self);
#line 2309 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = self->priv->dialog;
#line 2309 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (_tmp16_, "response", (GCallback) _preferences_dialog_on_close_gtk_dialog_response, self);
#line 2311 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = self->priv->builder;
#line 2311 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = gtk_builder_get_object (_tmp17_, "bg_color_adjustment");
#line 2311 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, gtk_adjustment_get_type ()) ? ((GtkAdjustment*) _tmp18_) : NULL);
#line 2311 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->bg_color_adjustment);
#line 2311 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->bg_color_adjustment = _tmp19_;
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = self->priv->bg_color_adjustment;
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = self->priv->bg_color_adjustment;
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = gtk_adjustment_get_upper (_tmp21_);
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = config_facade_get_instance ();
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = _tmp23_;
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	config_facade_get_bg_color (_tmp24_, &_tmp25_);
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = _tmp25_.red;
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_adjustment_set_value (_tmp20_, _tmp22_ - (_tmp26_ * 65535.0));
#line 2312 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp24_);
#line 2314 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = self->priv->bg_color_adjustment;
#line 2314 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (_tmp27_, "value-changed", (GCallback) _preferences_dialog_on_value_changed_gtk_adjustment_value_changed, self);
#line 2316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp28_ = self->priv->builder;
#line 2316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp29_ = gtk_builder_get_object (_tmp28_, "bg_color_slider");
#line 2316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp30_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, gtk_scale_get_type ()) ? ((GtkScale*) _tmp29_) : NULL);
#line 2316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->bg_color_slider);
#line 2316 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->bg_color_slider = _tmp30_;
#line 2317 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp31_ = self->priv->bg_color_slider;
#line 2317 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, gtk_widget_get_type (), GtkWidget), "button-press-event", (GCallback) _preferences_dialog_on_bg_color_reset_gtk_widget_button_press_event, self);
#line 2319 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = self->priv->builder;
#line 2319 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp33_ = gtk_builder_get_object (_tmp32_, "library_dir_button");
#line 2319 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp34_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp33_, gtk_file_chooser_button_get_type ()) ? ((GtkFileChooserButton*) _tmp33_) : NULL);
#line 2319 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->library_dir_button);
#line 2319 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->library_dir_button = _tmp34_;
#line 2321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp35_ = self->priv->builder;
#line 2321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp36_ = gtk_builder_get_object (_tmp35_, "external_photo_editor_combo");
#line 2321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp37_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, gtk_combo_box_get_type ()) ? ((GtkComboBox*) _tmp36_) : NULL);
#line 2321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->photo_editor_combo);
#line 2321 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->photo_editor_combo = _tmp37_;
#line 2322 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp38_ = self->priv->builder;
#line 2322 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = gtk_builder_get_object (_tmp38_, "external_raw_editor_combo");
#line 2322 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, gtk_combo_box_get_type ()) ? ((GtkComboBox*) _tmp39_) : NULL);
#line 2322 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->raw_editor_combo);
#line 2322 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->raw_editor_combo = _tmp40_;
#line 2324 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = self->priv->builder;
#line 2324 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = gtk_builder_get_object (_tmp41_, "pattern_help");
#line 2324 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp42_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp42_) : NULL);
#line 2324 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pattern_help = _tmp43_;
#line 2331 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = resources_get_help_path ();
#line 2331 "/home/jens/Source/shotwell/src/Dialogs.vala"
	help_path = _tmp44_;
#line 2333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp45_ = help_path;
#line 2333 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp45_ == NULL) {
#line 17685 "Dialogs.c"
		GtkLabel* _tmp46_;
		gchar* _tmp47_;
		gchar* _tmp48_;
		gchar* _tmp49_;
		gchar* _tmp50_;
#line 2335 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp46_ = pattern_help;
#line 2335 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp47_ = g_strconcat ("<a href=\"" RESOURCES_DIR_PATTERN_URI_SYSWIDE "\">", _ ("(Help)"), NULL);
#line 2335 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp48_ = _tmp47_;
#line 2335 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp49_ = g_strconcat (_tmp48_, "</a>", NULL);
#line 2335 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp50_ = _tmp49_;
#line 2335 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_markup (_tmp46_, _tmp50_);
#line 2335 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp50_);
#line 2335 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp48_);
#line 17707 "Dialogs.c"
	} else {
		GtkLabel* _tmp51_;
		gchar* _tmp52_;
		gchar* _tmp53_;
		gchar* _tmp54_;
		gchar* _tmp55_;
		GtkLabel* _tmp56_;
#line 2339 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp51_ = pattern_help;
#line 2339 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp52_ = g_strconcat ("<a href=\"dummy:\">", _ ("(Help)"), NULL);
#line 2339 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp53_ = _tmp52_;
#line 2339 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp54_ = g_strconcat (_tmp53_, "</a>", NULL);
#line 2339 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp55_ = _tmp54_;
#line 2339 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_markup (_tmp51_, _tmp55_);
#line 2339 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp55_);
#line 2339 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (_tmp53_);
#line 2340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp56_ = pattern_help;
#line 2340 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_signal_connect (_tmp56_, "activate-link", (GCallback) _preferences_dialog_on_local_pattern_help_gtk_label_activate_link, self);
#line 17735 "Dialogs.c"
	}
#line 2343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp57_ = self->priv->builder;
#line 2343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp58_ = gtk_builder_get_object (_tmp57_, "dir choser");
#line 2343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp59_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp58_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp58_) : NULL);
#line 2343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dir_pattern_combo);
#line 2343 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dir_pattern_combo = _tmp59_;
#line 2344 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp60_ = self->priv->builder;
#line 2344 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp61_ = gtk_builder_get_object (_tmp60_, "dir_pattern_entry");
#line 2344 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp62_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp61_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp61_) : NULL);
#line 2344 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dir_pattern_entry);
#line 2344 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dir_pattern_entry = _tmp62_;
#line 2345 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp63_ = self->priv->builder;
#line 2345 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp64_ = gtk_builder_get_object (_tmp63_, "dynamic example");
#line 2345 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp65_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp64_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp64_) : NULL);
#line 2345 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dir_pattern_example);
#line 2345 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->dir_pattern_example = _tmp65_;
#line 2346 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp66_ = g_strdup_printf (_ ("Year%sMonth%sDay"), G_DIR_SEPARATOR_S, G_DIR_SEPARATOR_S);
#line 2346 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp67_ = _tmp66_;
#line 2346 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_add_to_dir_formats (self, _tmp67_, "%Y" G_DIR_SEPARATOR_S "%m" G_DIR_SEPARATOR_S "%d");
#line 2346 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp67_);
#line 2348 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp68_ = g_strdup_printf (_ ("Year%sMonth"), G_DIR_SEPARATOR_S);
#line 2348 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp69_ = _tmp68_;
#line 2348 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_add_to_dir_formats (self, _tmp69_, "%Y" G_DIR_SEPARATOR_S "%m");
#line 2348 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp69_);
#line 2350 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp70_ = g_strdup_printf (_ ("Year%sMonth-Day"), G_DIR_SEPARATOR_S);
#line 2350 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp71_ = _tmp70_;
#line 2350 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_add_to_dir_formats (self, _tmp71_, "%Y" G_DIR_SEPARATOR_S "%m-%d");
#line 2350 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp71_);
#line 2352 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_add_to_dir_formats (self, _ ("Year-Month-Day"), "%Y-%m-%d");
#line 2353 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_add_to_dir_formats (self, _ ("Custom"), NULL);
#line 2354 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp72_ = self->priv->dir_pattern_combo;
#line 2354 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp72_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _preferences_dialog_on_dir_pattern_combo_changed_gtk_combo_box_changed, self);
#line 2355 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp73_ = self->priv->dir_pattern_entry;
#line 2355 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp73_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _preferences_dialog_on_dir_pattern_entry_changed_gtk_editable_changed, self);
#line 2357 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp74_ = self->priv->builder;
#line 2357 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp75_ = gtk_builder_get_object (_tmp74_, "dir_structure_label");
#line 2357 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp76_ = self->priv->dir_pattern_combo;
#line 2357 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_label_set_mnemonic_widget (G_TYPE_CHECK_INSTANCE_TYPE (_tmp75_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp75_) : NULL, G_TYPE_CHECK_INSTANCE_CAST (_tmp76_, gtk_widget_get_type (), GtkWidget));
#line 2359 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp77_ = self->priv->builder;
#line 2359 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp78_ = gtk_builder_get_object (_tmp77_, "lowercase");
#line 2359 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp79_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp78_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp78_) : NULL);
#line 2359 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->lowercase);
#line 2359 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->lowercase = _tmp79_;
#line 2360 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp80_ = self->priv->lowercase;
#line 2360 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp80_, gtk_toggle_button_get_type (), GtkToggleButton), "toggled", (GCallback) _preferences_dialog_on_lowercase_toggled_gtk_toggle_button_toggled, self);
#line 2362 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp81_ = self->priv->builder;
#line 2362 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp82_ = gtk_builder_get_object (_tmp81_, "preferences-notebook");
#line 2362 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp83_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp82_, gtk_notebook_get_type ()) ? ((GtkNotebook*) _tmp82_) : NULL);
#line 2362 "/home/jens/Source/shotwell/src/Dialogs.vala"
	notebook = _tmp83_;
#line 2363 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp84_ = gtk_notebook_get_nth_page (notebook, 2);
#line 2363 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp85_ = self->priv->plugins_mediator;
#line 2363 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp86_ = plugins_manifest_widget_mediator_get_widget (_tmp85_);
#line 2363 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp87_ = _tmp86_;
#line 2363 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_TYPE (_tmp84_, gtk_container_get_type ()) ? ((GtkContainer*) _tmp84_) : NULL, _tmp87_);
#line 2365 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_populate_preference_options (self);
#line 2367 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp88_ = self->priv->photo_editor_combo;
#line 2367 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (_tmp88_, "changed", (GCallback) _preferences_dialog_on_photo_editor_changed_gtk_combo_box_changed, self);
#line 2368 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp89_ = self->priv->raw_editor_combo;
#line 2368 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (_tmp89_, "changed", (GCallback) _preferences_dialog_on_raw_editor_changed_gtk_combo_box_changed, self);
#line 2370 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp90_ = self->priv->builder;
#line 2370 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp91_ = gtk_builder_get_object (_tmp90_, "autoimport");
#line 2370 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp92_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp91_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp91_) : NULL);
#line 2370 "/home/jens/Source/shotwell/src/Dialogs.vala"
	auto_import_button = _tmp92_;
#line 2371 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp93_ = config_facade_get_instance ();
#line 2371 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp94_ = _tmp93_;
#line 2371 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp95_ = configuration_facade_get_auto_import_from_library (G_TYPE_CHECK_INSTANCE_CAST (_tmp94_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2371 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (auto_import_button, gtk_toggle_button_get_type (), GtkToggleButton), _tmp95_);
#line 2371 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp94_);
#line 2373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp96_ = self->priv->builder;
#line 2373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp97_ = gtk_builder_get_object (_tmp96_, "write_metadata");
#line 2373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp98_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp97_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp97_) : NULL);
#line 2373 "/home/jens/Source/shotwell/src/Dialogs.vala"
	commit_metadata_button = _tmp98_;
#line 2374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp99_ = config_facade_get_instance ();
#line 2374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp100_ = _tmp99_;
#line 2374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp101_ = configuration_facade_get_commit_metadata_to_masters (G_TYPE_CHECK_INSTANCE_CAST (_tmp100_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (commit_metadata_button, gtk_toggle_button_get_type (), GtkToggleButton), _tmp101_);
#line 2374 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp100_);
#line 2376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp102_ = self->priv->builder;
#line 2376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp103_ = gtk_builder_get_object (_tmp102_, "default_raw_developer");
#line 2376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp104_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp103_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp103_) : NULL);
#line 2376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->default_raw_developer_combo);
#line 2376 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->default_raw_developer_combo = _tmp104_;
#line 2377 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp105_ = self->priv->default_raw_developer_combo;
#line 2377 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp106_ = raw_developer_get_label (RAW_DEVELOPER_CAMERA);
#line 2377 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp107_ = _tmp106_;
#line 2377 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp105_, _tmp107_);
#line 2377 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp107_);
#line 2378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp108_ = self->priv->default_raw_developer_combo;
#line 2378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp109_ = raw_developer_get_label (RAW_DEVELOPER_SHOTWELL);
#line 2378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp110_ = _tmp109_;
#line 2378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp108_, _tmp110_);
#line 2378 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp110_);
#line 2379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp111_ = config_facade_get_instance ();
#line 2379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp112_ = _tmp111_;
#line 2379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp113_ = configuration_facade_get_default_raw_developer (G_TYPE_CHECK_INSTANCE_CAST (_tmp112_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_set_raw_developer_combo (self, _tmp113_);
#line 2379 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp112_);
#line 2380 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp114_ = self->priv->default_raw_developer_combo;
#line 2380 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp114_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _preferences_dialog_on_default_raw_developer_changed_gtk_combo_box_changed, self);
#line 2382 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp115_ = self->priv->dialog;
#line 2382 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp115_, gtk_widget_get_type (), GtkWidget), "map-event", (GCallback) _preferences_dialog_map_event_gtk_widget_map_event, self);
#line 2296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (commit_metadata_button);
#line 2296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (auto_import_button);
#line 2296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (notebook);
#line 2296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (help_path);
#line 2296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (pattern_help);
#line 2296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 17949 "Dialogs.c"
}


static PreferencesDialog* preferences_dialog_new (void) {
#line 2296 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return preferences_dialog_construct (TYPE_PREFERENCES_DIALOG);
#line 17956 "Dialogs.c"
}


void preferences_dialog_populate_preference_options (PreferencesDialog* self) {
	GtkComboBox* _tmp0_;
	gint _tmp1_;
	gchar** _tmp2_;
	gchar** _tmp3_;
	gint _tmp3__length1;
	ConfigFacade* _tmp4_;
	ConfigFacade* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	SortedList* _tmp8_ = NULL;
	GtkComboBox* _tmp9_;
	gint _tmp10_;
	gchar** _tmp11_;
	gchar** _tmp12_;
	gint _tmp12__length1;
	ConfigFacade* _tmp13_;
	ConfigFacade* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	SortedList* _tmp17_ = NULL;
	GtkComboBoxText* _tmp18_;
	GtkEntry* _tmp19_;
	GtkCheckButton* _tmp20_;
	ConfigFacade* _tmp21_;
	ConfigFacade* _tmp22_;
	gboolean _tmp23_;
#line 2385 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->photo_editor_combo;
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = photo_file_format_get_editable_mime_types (&_tmp1_);
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3__length1 = _tmp1_;
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = config_facade_get_instance ();
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = configuration_facade_get_external_photo_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = _tmp6_;
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_populate_app_combo_box (self, _tmp0_, _tmp3_, _tmp1_, _tmp7_, &_tmp8_);
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->external_photo_apps);
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_photo_apps = _tmp8_;
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp7_);
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp5_);
#line 2386 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = (_vala_array_free (_tmp3_, _tmp3__length1, (GDestroyNotify) g_free), NULL);
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = self->priv->raw_editor_combo;
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = photo_file_format_get_mime_types (PHOTO_FILE_FORMAT_RAW, &_tmp10_);
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = _tmp11_;
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12__length1 = _tmp10_;
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = config_facade_get_instance ();
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = configuration_facade_get_external_raw_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = _tmp15_;
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_populate_app_combo_box (self, _tmp9_, _tmp12_, _tmp10_, _tmp16_, &_tmp17_);
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->external_raw_apps);
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->external_raw_apps = _tmp17_;
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp16_);
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp14_);
#line 2389 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = (_vala_array_free (_tmp12_, _tmp12__length1, (GDestroyNotify) g_free), NULL);
#line 2392 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = self->priv->dir_pattern_combo;
#line 2392 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp19_ = self->priv->dir_pattern_entry;
#line 2392 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_setup_dir_pattern (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_combo_box_get_type (), GtkComboBox), _tmp19_);
#line 2394 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = self->priv->lowercase;
#line 2394 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp21_ = config_facade_get_instance ();
#line 2394 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = _tmp21_;
#line 2394 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = configuration_facade_get_use_lowercase_filenames (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2394 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp23_);
#line 2394 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp22_);
#line 18063 "Dialogs.c"
}


static gboolean preferences_dialog_on_local_pattern_help (PreferencesDialog* self, const gchar* ignore) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 2399 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PREFERENCES_DIALOG (self), FALSE);
#line 2399 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (ignore != NULL, FALSE);
#line 18074 "Dialogs.c"
	{
		AppWindow* _tmp0_;
		AppWindow* _tmp1_;
		GdkScreen* _tmp2_;
#line 2401 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = app_window_get_instance ();
#line 2401 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = _tmp0_;
#line 2401 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = gtk_window_get_screen (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_window_get_type (), GtkWindow));
#line 2401 "/home/jens/Source/shotwell/src/Dialogs.vala"
		resources_launch_help (_tmp2_, "other-files.page", &_inner_error_);
#line 2401 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp1_);
#line 2401 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 18091 "Dialogs.c"
			goto __catch428_g_error;
		}
	}
	goto __finally428;
	__catch428_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
#line 2400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		e = _inner_error_;
#line 2400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_inner_error_ = NULL;
#line 2403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp3_ = e;
#line 2403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = _tmp3_->message;
#line 2403 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_message ("Dialogs.vala:2403: Unable to launch help: %s", _tmp4_);
#line 2400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_error_free0 (e);
#line 18113 "Dialogs.c"
	}
	__finally428:
#line 2400 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 18118 "Dialogs.c"
		gboolean _tmp5_ = FALSE;
#line 2400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_clear_error (&_inner_error_);
#line 2400 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return _tmp5_;
#line 18126 "Dialogs.c"
	}
#line 2405 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 2405 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 18132 "Dialogs.c"
}


static void preferences_dialog_populate_app_combo_box (PreferencesDialog* self, GtkComboBox* combo_box, gchar** mime_types, int mime_types_length1, const gchar* current_app_executable, SortedList* * external_apps) {
	SortedList* _vala_external_apps = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gchar** _tmp1_;
	gint _tmp1__length1;
	SortedList* _tmp2_;
	SortedList* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	GtkCellRendererPixbuf* pixbuf_renderer = NULL;
	GtkCellRendererPixbuf* _tmp6_;
	GtkCellRendererText* text_renderer = NULL;
	GtkCellRendererText* _tmp7_;
	GtkComboBox* _tmp8_;
	GtkComboBox* _tmp9_;
	GtkCellRendererPixbuf* _tmp10_;
	GtkComboBox* _tmp11_;
	GtkCellRendererText* _tmp12_;
	GtkComboBox* _tmp13_;
	GtkCellRendererPixbuf* _tmp14_;
	GtkComboBox* _tmp15_;
	GtkCellRendererText* _tmp16_;
	GtkListStore* combo_store = NULL;
	GtkListStore* _tmp17_;
	GtkTreeIter iter = {0};
	gint current_app = 0;
	GtkComboBox* _tmp67_;
	GtkListStore* _tmp68_;
	gint _tmp69_;
	GError * _inner_error_ = NULL;
#line 2408 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2408 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GTK_IS_COMBO_BOX (combo_box));
#line 2408 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (current_app_executable != NULL);
#line 2411 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = mime_types;
#line 2411 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0__length1 = mime_types_length1;
#line 2411 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_assert (_tmp0__length1 != 0, "mime_types.length != 0");
#line 2412 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = mime_types;
#line 2412 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1__length1 = mime_types_length1;
#line 2412 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = desktop_integration_get_apps_for_mime_types (_tmp1_, _tmp1__length1);
#line 2412 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_vala_external_apps);
#line 2412 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_vala_external_apps = _tmp2_;
#line 2414 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _vala_external_apps;
#line 2414 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2414 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 2414 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_ == 0) {
#line 2415 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (external_apps) {
#line 2415 "/home/jens/Source/shotwell/src/Dialogs.vala"
			*external_apps = _vala_external_apps;
#line 18201 "Dialogs.c"
		} else {
#line 2415 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_vala_external_apps);
#line 18205 "Dialogs.c"
		}
#line 2415 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 18209 "Dialogs.c"
	}
#line 2418 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = (GtkCellRendererPixbuf*) gtk_cell_renderer_pixbuf_new ();
#line 2418 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp6_);
#line 2418 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pixbuf_renderer = _tmp6_;
#line 2419 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
#line 2419 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp7_);
#line 2419 "/home/jens/Source/shotwell/src/Dialogs.vala"
	text_renderer = _tmp7_;
#line 2420 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = combo_box;
#line 2420 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_cell_layout_clear (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout));
#line 2421 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = combo_box;
#line 2421 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = pixbuf_renderer;
#line 2421 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_cell_renderer_get_type (), GtkCellRenderer), FALSE);
#line 2422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = combo_box;
#line 2422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = text_renderer;
#line 2422 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_cell_renderer_get_type (), GtkCellRenderer), FALSE);
#line 2423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = combo_box;
#line 2423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = pixbuf_renderer;
#line 2423 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_cell_renderer_get_type (), GtkCellRenderer), "pixbuf", 0);
#line 2424 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = combo_box;
#line 2424 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = text_renderer;
#line 2424 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_cell_renderer_get_type (), GtkCellRenderer), "text", 1);
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = gtk_list_store_new (2, gdk_pixbuf_get_type (), G_TYPE_STRING, -1);
#line 2427 "/home/jens/Source/shotwell/src/Dialogs.vala"
	combo_store = _tmp17_;
#line 2430 "/home/jens/Source/shotwell/src/Dialogs.vala"
	current_app = -1;
#line 18257 "Dialogs.c"
	{
		GeeIterator* _app_it = NULL;
		SortedList* _tmp18_;
		GeeIterator* _tmp19_;
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = _vala_external_apps;
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, GEE_TYPE_ITERABLE, GeeIterable));
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_app_it = _tmp19_;
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		while (TRUE) {
#line 18270 "Dialogs.c"
			GeeIterator* _tmp20_;
			gboolean _tmp21_;
			GAppInfo* app = NULL;
			GeeIterator* _tmp22_;
			gpointer _tmp23_;
			GtkListStore* _tmp24_;
			GtkTreeIter _tmp25_ = {0};
			GIcon* app_icon = NULL;
			GAppInfo* _tmp26_;
			GIcon* _tmp27_;
			GIcon* _tmp28_;
			GtkListStore* _tmp56_;
			GtkTreeIter _tmp57_;
			GAppInfo* _tmp58_;
			const gchar* _tmp59_;
			GValue _tmp60_ = {0};
			GAppInfo* _tmp61_;
			const gchar* _tmp62_;
			const gchar* _tmp63_;
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp20_ = _app_it;
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp21_ = gee_iterator_next (_tmp20_);
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (!_tmp21_) {
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
				break;
#line 18298 "Dialogs.c"
			}
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp22_ = _app_it;
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp23_ = gee_iterator_get (_tmp22_);
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
			app = (GAppInfo*) _tmp23_;
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp24_ = combo_store;
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_list_store_append (_tmp24_, &_tmp25_);
#line 2433 "/home/jens/Source/shotwell/src/Dialogs.vala"
			iter = _tmp25_;
#line 2435 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp26_ = app;
#line 2435 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = g_app_info_get_icon (_tmp26_);
#line 2435 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp28_ = _g_object_ref0 (_tmp27_);
#line 2435 "/home/jens/Source/shotwell/src/Dialogs.vala"
			app_icon = _tmp28_;
#line 18320 "Dialogs.c"
			{
				GIcon* _tmp29_;
#line 2437 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp29_ = app_icon;
#line 2437 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, g_file_icon_get_type ())) {
#line 18327 "Dialogs.c"
					GdkPixbuf* _tmp30_ = NULL;
					GIcon* _tmp31_;
					GFile* _tmp32_;
					gchar* _tmp33_;
					gchar* _tmp34_;
					GdkPixbuf* _tmp35_;
					GdkPixbuf* _tmp36_;
					GtkListStore* _tmp37_;
					GtkTreeIter _tmp38_;
					GdkPixbuf* _tmp39_;
					GValue _tmp40_ = {0};
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp31_ = app_icon;
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp32_ = g_file_icon_get_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, g_file_icon_get_type (), GFileIcon));
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp33_ = g_file_get_path (_tmp32_);
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp34_ = _tmp33_;
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp35_ = gdk_pixbuf_new_from_file (_tmp34_, &_inner_error_);
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp36_ = _tmp35_;
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_g_free0 (_tmp34_);
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp30_ = _tmp36_;
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 18357 "Dialogs.c"
						goto __catch429_g_error;
					}
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp37_ = combo_store;
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp38_ = iter;
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp39_ = scale_pixbuf (_tmp30_, RESOURCES_DEFAULT_ICON_SCALE, GDK_INTERP_BILINEAR, FALSE);
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					g_value_init (&_tmp40_, gdk_pixbuf_get_type ());
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					g_value_take_object (&_tmp40_, _tmp39_);
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					gtk_list_store_set_value (_tmp37_, &_tmp38_, 0, &_tmp40_);
#line 2438 "/home/jens/Source/shotwell/src/Dialogs.vala"
					G_IS_VALUE (&_tmp40_) ? (g_value_unset (&_tmp40_), NULL) : NULL;
#line 2437 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_g_object_unref0 (_tmp30_);
#line 18376 "Dialogs.c"
				} else {
					GIcon* _tmp41_;
#line 2441 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp41_ = app_icon;
#line 2441 "/home/jens/Source/shotwell/src/Dialogs.vala"
					if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp41_, g_themed_icon_get_type ())) {
#line 18383 "Dialogs.c"
						GdkPixbuf* icon_pixbuf = NULL;
						GtkIconTheme* _tmp42_;
						GIcon* _tmp43_;
						gchar** _tmp44_;
						gchar** _tmp45_;
						const gchar* _tmp46_;
						GdkPixbuf* _tmp47_;
						GtkListStore* _tmp48_;
						GtkTreeIter _tmp49_;
						GdkPixbuf* _tmp50_;
						GValue _tmp51_ = {0};
#line 2442 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp42_ = gtk_icon_theme_get_default ();
#line 2442 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp43_ = app_icon;
#line 2442 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp45_ = _tmp44_ = g_themed_icon_get_names (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, g_themed_icon_get_type (), GThemedIcon));
#line 2442 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp46_ = _tmp45_[0];
#line 2442 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp47_ = gtk_icon_theme_load_icon (_tmp42_, _tmp46_, RESOURCES_DEFAULT_ICON_SCALE, GTK_ICON_LOOKUP_FORCE_SIZE, &_inner_error_);
#line 2442 "/home/jens/Source/shotwell/src/Dialogs.vala"
						icon_pixbuf = _tmp47_;
#line 2442 "/home/jens/Source/shotwell/src/Dialogs.vala"
						if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 18409 "Dialogs.c"
							goto __catch429_g_error;
						}
#line 2446 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp48_ = combo_store;
#line 2446 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp49_ = iter;
#line 2446 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_tmp50_ = icon_pixbuf;
#line 2446 "/home/jens/Source/shotwell/src/Dialogs.vala"
						g_value_init (&_tmp51_, gdk_pixbuf_get_type ());
#line 2446 "/home/jens/Source/shotwell/src/Dialogs.vala"
						g_value_set_object (&_tmp51_, _tmp50_);
#line 2446 "/home/jens/Source/shotwell/src/Dialogs.vala"
						gtk_list_store_set_value (_tmp48_, &_tmp49_, 0, &_tmp51_);
#line 2446 "/home/jens/Source/shotwell/src/Dialogs.vala"
						G_IS_VALUE (&_tmp51_) ? (g_value_unset (&_tmp51_), NULL) : NULL;
#line 2441 "/home/jens/Source/shotwell/src/Dialogs.vala"
						_g_object_unref0 (icon_pixbuf);
#line 18428 "Dialogs.c"
					}
				}
			}
			goto __finally429;
			__catch429_g_error:
			{
				GError* _error_ = NULL;
				GError* _tmp52_;
				const gchar* _tmp53_;
				gchar* _tmp54_;
				gchar* _tmp55_;
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_error_ = _inner_error_;
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_inner_error_ = NULL;
#line 2449 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp52_ = _error_;
#line 2449 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp53_ = _tmp52_->message;
#line 2449 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp54_ = g_strconcat ("Error loading icon pixbuf: ", _tmp53_, NULL);
#line 2449 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp55_ = _tmp54_;
#line 2449 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_warning ("Dialogs.vala:2449: %s", _tmp55_);
#line 2449 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (_tmp55_);
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_error_free0 (_error_);
#line 18458 "Dialogs.c"
			}
			__finally429:
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (app_icon);
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (app);
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_app_it);
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (combo_store);
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (text_renderer);
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (pixbuf_renderer);
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				g_clear_error (&_inner_error_);
#line 2436 "/home/jens/Source/shotwell/src/Dialogs.vala"
				return;
#line 18481 "Dialogs.c"
			}
#line 2452 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp56_ = combo_store;
#line 2452 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp57_ = iter;
#line 2452 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp58_ = app;
#line 2452 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp59_ = g_app_info_get_name (_tmp58_);
#line 2452 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_value_init (&_tmp60_, G_TYPE_STRING);
#line 2452 "/home/jens/Source/shotwell/src/Dialogs.vala"
			g_value_set_string (&_tmp60_, _tmp59_);
#line 2452 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_list_store_set_value (_tmp56_, &_tmp57_, 1, &_tmp60_);
#line 2452 "/home/jens/Source/shotwell/src/Dialogs.vala"
			G_IS_VALUE (&_tmp60_) ? (g_value_unset (&_tmp60_), NULL) : NULL;
#line 2454 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp61_ = app;
#line 2454 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp62_ = g_app_info_get_commandline (_tmp61_);
#line 2454 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp63_ = current_app_executable;
#line 2454 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (g_strcmp0 (_tmp62_, _tmp63_) == 0) {
#line 18507 "Dialogs.c"
				SortedList* _tmp64_;
				GAppInfo* _tmp65_;
				gint _tmp66_;
#line 2455 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp64_ = _vala_external_apps;
#line 2455 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp65_ = app;
#line 2455 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp66_ = sorted_list_index_of (_tmp64_, _tmp65_);
#line 2455 "/home/jens/Source/shotwell/src/Dialogs.vala"
				current_app = _tmp66_;
#line 18519 "Dialogs.c"
			}
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (app_icon);
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (app);
#line 18525 "Dialogs.c"
		}
#line 2432 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_app_it);
#line 18529 "Dialogs.c"
	}
#line 2460 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp67_ = combo_box;
#line 2460 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp68_ = combo_store;
#line 2460 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_set_model (_tmp67_, G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, GTK_TYPE_TREE_MODEL, GtkTreeModel));
#line 2462 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp69_ = current_app;
#line 2462 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp69_ != -1) {
#line 18541 "Dialogs.c"
		GtkComboBox* _tmp70_;
		gint _tmp71_;
#line 2463 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp70_ = combo_box;
#line 2463 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp71_ = current_app;
#line 2463 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (_tmp70_, _tmp71_);
#line 18550 "Dialogs.c"
	}
#line 2408 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (combo_store);
#line 2408 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (text_renderer);
#line 2408 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (pixbuf_renderer);
#line 2408 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (external_apps) {
#line 2408 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*external_apps = _vala_external_apps;
#line 18562 "Dialogs.c"
	} else {
#line 2408 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_vala_external_apps);
#line 18566 "Dialogs.c"
	}
}


static void preferences_dialog_setup_dir_pattern (PreferencesDialog* self, GtkComboBox* combo_box, GtkEntry* entry) {
	gchar* pattern = NULL;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gboolean found = FALSE;
	const gchar* _tmp4_;
	gboolean _tmp32_;
#line 2466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GTK_IS_COMBO_BOX (combo_box));
#line 2466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GTK_IS_ENTRY (entry));
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = config_facade_get_instance ();
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = configuration_facade_get_directory_pattern (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 2467 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pattern = _tmp3_;
#line 2468 "/home/jens/Source/shotwell/src/Dialogs.vala"
	found = FALSE;
#line 2469 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = pattern;
#line 2469 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (NULL != _tmp4_) {
#line 18604 "Dialogs.c"
		gint i = 0;
#line 2471 "/home/jens/Source/shotwell/src/Dialogs.vala"
		i = 0;
#line 18608 "Dialogs.c"
		{
			GeeArrayList* _pf_list = NULL;
			GeeArrayList* _tmp5_;
			GeeArrayList* _tmp6_;
			gint _pf_size = 0;
			GeeArrayList* _tmp7_;
			gint _tmp8_;
			gint _tmp9_;
			gint _pf_index = 0;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp5_ = self->priv->path_formats;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp6_ = _g_object_ref0 (_tmp5_);
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_pf_list = _tmp6_;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp7_ = _pf_list;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp8_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp9_ = _tmp8_;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_pf_size = _tmp9_;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_pf_index = -1;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
			while (TRUE) {
#line 18636 "Dialogs.c"
				gint _tmp10_;
				gint _tmp11_;
				gint _tmp12_;
				PreferencesDialogPathFormat* pf = NULL;
				GeeArrayList* _tmp13_;
				gint _tmp14_;
				gpointer _tmp15_;
				PreferencesDialogPathFormat* _tmp16_;
				const gchar* _tmp17_;
				const gchar* _tmp18_;
				gint _tmp21_;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp10_ = _pf_index;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_pf_index = _tmp10_ + 1;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp11_ = _pf_index;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp12_ = _pf_size;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (!(_tmp11_ < _tmp12_)) {
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 18660 "Dialogs.c"
				}
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp13_ = _pf_list;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp14_ = _pf_index;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp15_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp14_);
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				pf = (PreferencesDialogPathFormat*) _tmp15_;
#line 2473 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp16_ = pf;
#line 2473 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp17_ = _tmp16_->pattern;
#line 2473 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp18_ = pattern;
#line 2473 "/home/jens/Source/shotwell/src/Dialogs.vala"
				if (g_strcmp0 (_tmp17_, _tmp18_) == 0) {
#line 18678 "Dialogs.c"
					GtkComboBox* _tmp19_;
					gint _tmp20_;
#line 2474 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp19_ = combo_box;
#line 2474 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_tmp20_ = i;
#line 2474 "/home/jens/Source/shotwell/src/Dialogs.vala"
					gtk_combo_box_set_active (_tmp19_, _tmp20_);
#line 2475 "/home/jens/Source/shotwell/src/Dialogs.vala"
					found = TRUE;
#line 2476 "/home/jens/Source/shotwell/src/Dialogs.vala"
					_preferences_dialog_path_format_unref0 (pf);
#line 2476 "/home/jens/Source/shotwell/src/Dialogs.vala"
					break;
#line 18693 "Dialogs.c"
				}
#line 2478 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp21_ = i;
#line 2478 "/home/jens/Source/shotwell/src/Dialogs.vala"
				i = _tmp21_ + 1;
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_preferences_dialog_path_format_unref0 (pf);
#line 18701 "Dialogs.c"
			}
#line 2472 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (_pf_list);
#line 18705 "Dialogs.c"
		}
	} else {
		gchar* s = NULL;
		ConfigFacade* _tmp22_;
		ConfigFacade* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		const gchar* _tmp26_;
		gboolean _tmp27_;
#line 2482 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = config_facade_get_instance ();
#line 2482 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = _tmp22_;
#line 2482 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = configuration_facade_get_directory_pattern_custom (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2482 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp25_ = _tmp24_;
#line 2482 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp23_);
#line 2482 "/home/jens/Source/shotwell/src/Dialogs.vala"
		s = _tmp25_;
#line 2483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp26_ = s;
#line 2483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp27_ = is_string_empty (_tmp26_);
#line 2483 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (!_tmp27_) {
#line 18733 "Dialogs.c"
			GtkComboBox* _tmp28_;
			GeeArrayList* _tmp29_;
			gint _tmp30_;
			gint _tmp31_;
#line 2484 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp28_ = combo_box;
#line 2484 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp29_ = self->priv->path_formats;
#line 2484 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp30_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 2484 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp31_ = _tmp30_;
#line 2484 "/home/jens/Source/shotwell/src/Dialogs.vala"
			gtk_combo_box_set_active (_tmp28_, _tmp31_ - 1);
#line 2485 "/home/jens/Source/shotwell/src/Dialogs.vala"
			found = TRUE;
#line 18750 "Dialogs.c"
		}
#line 2469 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (s);
#line 18754 "Dialogs.c"
	}
#line 2489 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp32_ = found;
#line 2489 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp32_) {
#line 18760 "Dialogs.c"
		GtkComboBox* _tmp33_;
#line 2490 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = combo_box;
#line 2490 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (_tmp33_, 0);
#line 18766 "Dialogs.c"
	}
#line 2493 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_dir_pattern_combo_changed (self);
#line 2466 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (pattern);
#line 18772 "Dialogs.c"
}


void preferences_dialog_show (void) {
	PreferencesDialog* _tmp0_;
	PreferencesDialog* _tmp2_;
	PreferencesDialog* _tmp3_;
	GtkDialog* _tmp4_;
	PreferencesDialog* _tmp5_;
	GtkFileChooserButton* _tmp6_;
	GFile* _tmp7_;
	GFile* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	PreferencesDialog* _tmp11_;
	GtkDialog* _tmp12_;
#line 2497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = preferences_dialog_preferences_dialog;
#line 2497 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == NULL) {
#line 18793 "Dialogs.c"
		PreferencesDialog* _tmp1_;
#line 2498 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = preferences_dialog_new ();
#line 2498 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_preferences_dialog_unref0 (preferences_dialog_preferences_dialog);
#line 2498 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_preferences_dialog = _tmp1_;
#line 18801 "Dialogs.c"
	}
#line 2500 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = preferences_dialog_preferences_dialog;
#line 2500 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_populate_preference_options (_tmp2_);
#line 2501 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = preferences_dialog_preferences_dialog;
#line 2501 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_->priv->dialog;
#line 2501 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget));
#line 2502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = preferences_dialog_preferences_dialog;
#line 2502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = _tmp5_->priv->library_dir_button;
#line 2502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = app_dirs_get_import_dir ();
#line 2502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp8_ = _tmp7_;
#line 2502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = g_file_get_path (_tmp8_);
#line 2502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = _tmp9_;
#line 2502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_file_chooser_set_current_folder (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), _tmp10_);
#line 2502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp10_);
#line 2502 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp8_);
#line 2506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = preferences_dialog_preferences_dialog;
#line 2506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = _tmp11_->priv->dialog;
#line 2506 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_present (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, gtk_window_get_type (), GtkWindow));
#line 18837 "Dialogs.c"
}


static void preferences_dialog_commit_on_close (PreferencesDialog* self) {
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	GtkCheckButton* autoimport = NULL;
	GtkBuilder* _tmp2_;
	GObject* _tmp3_;
	GtkCheckButton* _tmp4_;
	GtkCheckButton* _tmp5_;
	GtkCheckButton* commit_metadata = NULL;
	GtkBuilder* _tmp11_;
	GObject* _tmp12_;
	GtkCheckButton* _tmp13_;
	GtkCheckButton* _tmp14_;
	const gchar* _tmp20_;
	PreferencesDialogPathFormat* pf = NULL;
	GeeArrayList* _tmp22_;
	GtkComboBoxText* _tmp23_;
	gint _tmp24_;
	gpointer _tmp25_;
	PreferencesDialogPathFormat* _tmp26_;
	const gchar* _tmp27_;
#line 2511 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2512 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = config_facade_get_instance ();
#line 2512 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 2512 "/home/jens/Source/shotwell/src/Dialogs.vala"
	config_facade_commit_bg_color (_tmp1_);
#line 2512 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 2514 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->builder;
#line 2514 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_builder_get_object (_tmp2_, "autoimport");
#line 2514 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp3_) : NULL);
#line 2514 "/home/jens/Source/shotwell/src/Dialogs.vala"
	autoimport = _tmp4_;
#line 2515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = autoimport;
#line 2515 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_ != NULL) {
#line 18884 "Dialogs.c"
		ConfigFacade* _tmp6_;
		ConfigFacade* _tmp7_;
		GtkCheckButton* _tmp8_;
		gboolean _tmp9_;
		gboolean _tmp10_;
#line 2516 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = config_facade_get_instance ();
#line 2516 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp6_;
#line 2516 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = autoimport;
#line 2516 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 2516 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp9_;
#line 2516 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_auto_import_from_library (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp10_);
#line 2516 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp7_);
#line 18904 "Dialogs.c"
	}
#line 2518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = self->priv->builder;
#line 2518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = gtk_builder_get_object (_tmp11_, "write_metadata");
#line 2518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp12_) : NULL);
#line 2518 "/home/jens/Source/shotwell/src/Dialogs.vala"
	commit_metadata = _tmp13_;
#line 2519 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = commit_metadata;
#line 2519 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp14_ != NULL) {
#line 18918 "Dialogs.c"
		ConfigFacade* _tmp15_;
		ConfigFacade* _tmp16_;
		GtkCheckButton* _tmp17_;
		gboolean _tmp18_;
		gboolean _tmp19_;
#line 2520 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = config_facade_get_instance ();
#line 2520 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = _tmp15_;
#line 2520 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = commit_metadata;
#line 2520 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 2520 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = _tmp18_;
#line 2520 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_commit_metadata_to_masters (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp19_);
#line 2520 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp16_);
#line 18938 "Dialogs.c"
	}
#line 2522 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp20_ = self->priv->lib_dir;
#line 2522 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp20_ != NULL) {
#line 18944 "Dialogs.c"
		const gchar* _tmp21_;
#line 2523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = self->priv->lib_dir;
#line 2523 "/home/jens/Source/shotwell/src/Dialogs.vala"
		app_dirs_set_import_dir (_tmp21_);
#line 18950 "Dialogs.c"
	}
#line 2525 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp22_ = self->priv->path_formats;
#line 2525 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp23_ = self->priv->dir_pattern_combo;
#line 2525 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp24_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, gtk_combo_box_get_type (), GtkComboBox));
#line 2525 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp25_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp24_);
#line 2525 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pf = (PreferencesDialogPathFormat*) _tmp25_;
#line 2526 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp26_ = pf;
#line 2526 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp27_ = _tmp26_->pattern;
#line 2526 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (NULL == _tmp27_) {
#line 18968 "Dialogs.c"
		ConfigFacade* _tmp28_;
		ConfigFacade* _tmp29_;
		GtkEntry* _tmp30_;
		const gchar* _tmp31_;
		const gchar* _tmp32_;
		ConfigFacade* _tmp33_;
		ConfigFacade* _tmp34_;
#line 2527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp28_ = config_facade_get_instance ();
#line 2527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp29_ = _tmp28_;
#line 2527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp30_ = self->priv->dir_pattern_entry;
#line 2527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp31_ = gtk_entry_get_text (_tmp30_);
#line 2527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp32_ = _tmp31_;
#line 2527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_directory_pattern_custom (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp32_);
#line 2527 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp29_);
#line 2528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp33_ = config_facade_get_instance ();
#line 2528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp34_ = _tmp33_;
#line 2528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_directory_pattern (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), NULL);
#line 2528 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp34_);
#line 18998 "Dialogs.c"
	} else {
		ConfigFacade* _tmp35_;
		ConfigFacade* _tmp36_;
		PreferencesDialogPathFormat* _tmp37_;
		const gchar* _tmp38_;
#line 2530 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp35_ = config_facade_get_instance ();
#line 2530 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp36_ = _tmp35_;
#line 2530 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp37_ = pf;
#line 2530 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp38_ = _tmp37_->pattern;
#line 2530 "/home/jens/Source/shotwell/src/Dialogs.vala"
		configuration_facade_set_directory_pattern (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp38_);
#line 2530 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp36_);
#line 19016 "Dialogs.c"
	}
#line 2511 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_preferences_dialog_path_format_unref0 (pf);
#line 2511 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (commit_metadata);
#line 2511 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (autoimport);
#line 19024 "Dialogs.c"
}


static gboolean preferences_dialog_on_delete (PreferencesDialog* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
	GtkDialog* _tmp1_;
	gboolean _tmp2_;
#line 2534 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PREFERENCES_DIALOG (self), FALSE);
#line 2535 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = preferences_dialog_get_allow_closing (self);
#line 2535 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp0_) {
#line 2536 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = TRUE;
#line 2536 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 19043 "Dialogs.c"
	}
#line 2538 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_commit_on_close (self);
#line 2539 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->dialog;
#line 2539 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_widget_hide_on_delete (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 2539 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp2_;
#line 2539 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 19055 "Dialogs.c"
}


static void preferences_dialog_on_close (PreferencesDialog* self) {
	gboolean _tmp0_;
	GtkDialog* _tmp1_;
#line 2542 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = preferences_dialog_get_allow_closing (self);
#line 2543 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp0_) {
#line 2544 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 19070 "Dialogs.c"
	}
#line 2546 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->dialog;
#line 2546 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 2547 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_commit_on_close (self);
#line 19078 "Dialogs.c"
}


static void preferences_dialog_on_value_changed (PreferencesDialog* self) {
	GtkAdjustment* _tmp0_;
	gdouble _tmp1_;
	GtkAdjustment* _tmp2_;
	gdouble _tmp3_;
#line 2550 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->bg_color_adjustment;
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_adjustment_get_upper (_tmp0_);
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->bg_color_adjustment;
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_adjustment_get_value (_tmp2_);
#line 2551 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_set_background_color (self, ((gdouble) (_tmp1_ - _tmp3_)) / 65535.0);
#line 19099 "Dialogs.c"
}


static gboolean preferences_dialog_on_bg_color_reset (PreferencesDialog* self, GdkEventButton* event) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GdkEventButton* _tmp2_;
	guint _tmp3_;
#line 2555 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PREFERENCES_DIALOG (self), FALSE);
#line 2555 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 2556 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = event;
#line 2556 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_->button;
#line 2556 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ == ((guint) 1)) {
#line 19119 "Dialogs.c"
		GdkEventButton* _tmp4_;
		GdkEventType _tmp5_;
#line 2556 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp4_ = event;
#line 2556 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = _tmp4_->type;
#line 2556 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = _tmp5_ == GDK_BUTTON_PRESS;
#line 19128 "Dialogs.c"
	} else {
#line 2556 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = FALSE;
#line 19132 "Dialogs.c"
	}
#line 2556 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_) {
#line 19136 "Dialogs.c"
		GdkEventButton* _tmp6_;
		GdkModifierType _tmp7_;
		gboolean _tmp8_;
#line 2557 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = event;
#line 2557 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp6_->state;
#line 2557 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = has_only_key_modifier (_tmp7_, GDK_CONTROL_MASK);
#line 2557 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp8_;
#line 19148 "Dialogs.c"
	} else {
#line 2556 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = FALSE;
#line 19152 "Dialogs.c"
	}
#line 2556 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_) {
#line 19156 "Dialogs.c"
		GtkScale* _tmp9_;
		GtkAdjustment* _tmp10_;
		gdouble _tmp11_;
		GdkRGBA _tmp12_ = {0};
		gdouble _tmp13_;
#line 2559 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = self->priv->bg_color_slider;
#line 2559 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = self->priv->bg_color_adjustment;
#line 2559 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = gtk_adjustment_get_upper (_tmp10_);
#line 2559 "/home/jens/Source/shotwell/src/Dialogs.vala"
		parse_color (CONFIG_FACADE_DEFAULT_BG_COLOR, &_tmp12_);
#line 2559 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = _tmp12_.red;
#line 2559 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_range_set_value (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_range_get_type (), GtkRange), _tmp11_ - (_tmp13_ * 65536.0f));
#line 2561 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_on_value_changed (self);
#line 2563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = TRUE;
#line 2563 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 19180 "Dialogs.c"
	}
#line 2566 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = FALSE;
#line 2566 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 19186 "Dialogs.c"
}


static void preferences_dialog_on_dir_pattern_combo_changed (PreferencesDialog* self) {
	PreferencesDialogPathFormat* pf = NULL;
	GeeArrayList* _tmp0_;
	GtkComboBoxText* _tmp1_;
	gint _tmp2_;
	gpointer _tmp3_;
	PreferencesDialogPathFormat* _tmp4_;
	const gchar* _tmp5_;
#line 2569 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2570 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->path_formats;
#line 2570 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->dir_pattern_combo;
#line 2570 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox));
#line 2570 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), _tmp2_);
#line 2570 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pf = (PreferencesDialogPathFormat*) _tmp3_;
#line 2571 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = pf;
#line 2571 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_->pattern;
#line 2571 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (NULL == _tmp5_) {
#line 19216 "Dialogs.c"
		gchar* dir_pattern = NULL;
		ConfigFacade* _tmp6_;
		ConfigFacade* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		const gchar* _tmp10_;
		gboolean _tmp11_;
		GtkEntry* _tmp13_;
		const gchar* _tmp14_;
		GtkEntry* _tmp15_;
		GtkEntry* _tmp16_;
#line 2573 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = config_facade_get_instance ();
#line 2573 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = _tmp6_;
#line 2573 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = configuration_facade_get_directory_pattern_custom (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 2573 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = _tmp8_;
#line 2573 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp7_);
#line 2573 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dir_pattern = _tmp9_;
#line 2574 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = dir_pattern;
#line 2574 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = is_string_empty (_tmp10_);
#line 2574 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (_tmp11_) {
#line 19246 "Dialogs.c"
			gchar* _tmp12_;
#line 2575 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp12_ = g_strdup ("");
#line 2575 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (dir_pattern);
#line 2575 "/home/jens/Source/shotwell/src/Dialogs.vala"
			dir_pattern = _tmp12_;
#line 19254 "Dialogs.c"
		}
#line 2576 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = self->priv->dir_pattern_entry;
#line 2576 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = dir_pattern;
#line 2576 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_entry_set_text (_tmp13_, _tmp14_);
#line 2577 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = self->priv->dir_pattern_entry;
#line 2577 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_set (_tmp15_, "editable", TRUE, NULL);
#line 2578 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = self->priv->dir_pattern_entry;
#line 2578 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 2571 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (dir_pattern);
#line 19272 "Dialogs.c"
	} else {
		GtkEntry* _tmp17_;
		PreferencesDialogPathFormat* _tmp18_;
		const gchar* _tmp19_;
		GtkEntry* _tmp20_;
		GtkEntry* _tmp21_;
#line 2580 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = self->priv->dir_pattern_entry;
#line 2580 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = pf;
#line 2580 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = _tmp18_->pattern;
#line 2580 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_entry_set_text (_tmp17_, _tmp19_);
#line 2581 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = self->priv->dir_pattern_entry;
#line 2581 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_set (_tmp20_, "editable", FALSE, NULL);
#line 2582 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = self->priv->dir_pattern_entry;
#line 2582 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 19295 "Dialogs.c"
	}
#line 2569 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_preferences_dialog_path_format_unref0 (pf);
#line 19299 "Dialogs.c"
}


static void preferences_dialog_on_dir_pattern_entry_changed (PreferencesDialog* self) {
	gchar* example = NULL;
	GDateTime* _tmp0_;
	GtkEntry* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gboolean _tmp5_ = FALSE;
	const gchar* _tmp6_;
	gboolean _tmp7_;
#line 2586 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2587 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->example_date;
#line 2587 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->dir_pattern_entry;
#line 2587 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_entry_get_text (_tmp1_);
#line 2587 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 2587 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = g_date_time_format (_tmp0_, _tmp3_);
#line 2587 "/home/jens/Source/shotwell/src/Dialogs.vala"
	example = _tmp4_;
#line 2588 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = example;
#line 2588 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = is_string_empty (_tmp6_);
#line 2588 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp7_) {
#line 19333 "Dialogs.c"
		GtkEntry* _tmp8_;
		const gchar* _tmp9_;
		const gchar* _tmp10_;
		gboolean _tmp11_;
#line 2588 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = self->priv->dir_pattern_entry;
#line 2588 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = gtk_entry_get_text (_tmp8_);
#line 2588 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp9_;
#line 2588 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp11_ = is_string_empty (_tmp10_);
#line 2588 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = !_tmp11_;
#line 19348 "Dialogs.c"
	} else {
#line 2588 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp5_ = FALSE;
#line 19352 "Dialogs.c"
	}
#line 2588 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp5_) {
#line 19356 "Dialogs.c"
		GtkLabel* _tmp12_;
		GtkEntry* _tmp13_;
		GtkEntry* _tmp14_;
#line 2590 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = self->priv->dir_pattern_example;
#line 2590 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_text (_tmp12_, _ ("Invalid pattern"));
#line 2591 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = self->priv->dir_pattern_entry;
#line 2591 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_entry_set_icon_from_icon_name (_tmp13_, GTK_ENTRY_ICON_SECONDARY, "dialog-error");
#line 2592 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = self->priv->dir_pattern_entry;
#line 2592 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_entry_set_icon_activatable (_tmp14_, GTK_ENTRY_ICON_SECONDARY, FALSE);
#line 2593 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_set_allow_closing (self, FALSE);
#line 19374 "Dialogs.c"
	} else {
		GtkLabel* _tmp15_;
		const gchar* _tmp16_;
		GtkEntry* _tmp17_;
#line 2596 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = self->priv->dir_pattern_example;
#line 2596 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = example;
#line 2596 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_label_set_text (_tmp15_, _tmp16_);
#line 2597 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = self->priv->dir_pattern_entry;
#line 2597 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_entry_set_icon_from_icon_name (_tmp17_, GTK_ENTRY_ICON_SECONDARY, NULL);
#line 2598 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_set_allow_closing (self, TRUE);
#line 19391 "Dialogs.c"
	}
#line 2586 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (example);
#line 19395 "Dialogs.c"
}


static void preferences_dialog_set_allow_closing (PreferencesDialog* self, gboolean allow) {
	GtkDialog* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 2602 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->dialog;
#line 2603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = allow;
#line 2603 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_deletable (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_window_get_type (), GtkWindow), _tmp1_);
#line 2604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = allow;
#line 2604 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->allow_closing = _tmp2_;
#line 19415 "Dialogs.c"
}


static gboolean preferences_dialog_get_allow_closing (PreferencesDialog* self) {
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 2607 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PREFERENCES_DIALOG (self), FALSE);
#line 2608 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->allow_closing;
#line 2608 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _tmp0_;
#line 2608 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 19430 "Dialogs.c"
}


static void preferences_dialog_set_background_color (PreferencesDialog* self, gdouble bg_color_value) {
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	gdouble _tmp2_;
	GdkRGBA _tmp3_ = {0};
#line 2611 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = config_facade_get_instance ();
#line 2612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 2612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = bg_color_value;
#line 2612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_to_grayscale (self, _tmp2_, &_tmp3_);
#line 2612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	config_facade_set_bg_color (_tmp1_, &_tmp3_);
#line 2612 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 19453 "Dialogs.c"
}


static void preferences_dialog_to_grayscale (PreferencesDialog* self, gdouble color_value, GdkRGBA* result) {
	GdkRGBA color = {0};
	gdouble _tmp0_;
	gdouble _tmp1_;
	gdouble _tmp2_;
#line 2615 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2616 "/home/jens/Source/shotwell/src/Dialogs.vala"
	memset (&color, 0, sizeof (GdkRGBA));
#line 2618 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = color_value;
#line 2618 "/home/jens/Source/shotwell/src/Dialogs.vala"
	color.red = _tmp0_;
#line 2619 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = color_value;
#line 2619 "/home/jens/Source/shotwell/src/Dialogs.vala"
	color.green = _tmp1_;
#line 2620 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = color_value;
#line 2620 "/home/jens/Source/shotwell/src/Dialogs.vala"
	color.blue = _tmp2_;
#line 2621 "/home/jens/Source/shotwell/src/Dialogs.vala"
	color.alpha = 1.0;
#line 2623 "/home/jens/Source/shotwell/src/Dialogs.vala"
	*result = color;
#line 2623 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return;
#line 19484 "Dialogs.c"
}


static void preferences_dialog_on_photo_editor_changed (PreferencesDialog* self) {
	gint _tmp0_ = 0;
	GtkComboBox* _tmp1_;
	gint _tmp2_;
	SortedList* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	gint photo_app_choice_index = 0;
	GAppInfo* app = NULL;
	SortedList* _tmp11_;
	gpointer _tmp12_;
	ConfigFacade* _tmp13_;
	ConfigFacade* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
#line 2626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->photo_editor_combo;
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_combo_box_get_active (_tmp1_);
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->priv->external_photo_apps;
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ < _tmp5_) {
#line 19519 "Dialogs.c"
		GtkComboBox* _tmp6_;
		gint _tmp7_;
#line 2628 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = self->priv->photo_editor_combo;
#line 2628 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = gtk_combo_box_get_active (_tmp6_);
#line 2628 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp7_;
#line 19528 "Dialogs.c"
	} else {
		SortedList* _tmp8_;
		gint _tmp9_;
		gint _tmp10_;
#line 2628 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = self->priv->external_photo_apps;
#line 2628 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2628 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp9_;
#line 2628 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp10_;
#line 19541 "Dialogs.c"
	}
#line 2627 "/home/jens/Source/shotwell/src/Dialogs.vala"
	photo_app_choice_index = _tmp0_;
#line 2630 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = self->priv->external_photo_apps;
#line 2630 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = sorted_list_get_at (_tmp11_, photo_app_choice_index);
#line 2630 "/home/jens/Source/shotwell/src/Dialogs.vala"
	app = (GAppInfo*) _tmp12_;
#line 2632 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = config_facade_get_instance ();
#line 2632 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 2632 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = desktop_integration_get_app_open_command (app);
#line 2632 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = _tmp15_;
#line 2632 "/home/jens/Source/shotwell/src/Dialogs.vala"
	configuration_facade_set_external_photo_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp16_);
#line 2632 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp16_);
#line 2632 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp14_);
#line 2634 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp17_ = desktop_integration_get_app_open_command (app);
#line 2634 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp18_ = _tmp17_;
#line 2634 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_debug ("Dialogs.vala:2634: setting external photo editor to: %s", _tmp18_);
#line 2634 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (_tmp18_);
#line 2626 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (app);
#line 19575 "Dialogs.c"
}


static void preferences_dialog_on_raw_editor_changed (PreferencesDialog* self) {
	gint _tmp0_ = 0;
	GtkComboBox* _tmp1_;
	gint _tmp2_;
	SortedList* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	gint raw_app_choice_index = 0;
	GAppInfo* app = NULL;
	SortedList* _tmp11_;
	gpointer _tmp12_;
	ConfigFacade* _tmp13_;
	ConfigFacade* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
#line 2637 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = self->priv->raw_editor_combo;
#line 2638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gtk_combo_box_get_active (_tmp1_);
#line 2638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->priv->external_raw_apps;
#line 2638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = _tmp4_;
#line 2638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ < _tmp5_) {
#line 19608 "Dialogs.c"
		GtkComboBox* _tmp6_;
		gint _tmp7_;
#line 2639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp6_ = self->priv->raw_editor_combo;
#line 2639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp7_ = gtk_combo_box_get_active (_tmp6_);
#line 2639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp7_;
#line 19617 "Dialogs.c"
	} else {
		SortedList* _tmp8_;
		gint _tmp9_;
		gint _tmp10_;
#line 2639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = self->priv->external_raw_apps;
#line 2639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp9_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp10_ = _tmp9_;
#line 2639 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _tmp10_;
#line 19630 "Dialogs.c"
	}
#line 2638 "/home/jens/Source/shotwell/src/Dialogs.vala"
	raw_app_choice_index = _tmp0_;
#line 2641 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = self->priv->external_raw_apps;
#line 2641 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp12_ = sorted_list_get_at (_tmp11_, raw_app_choice_index);
#line 2641 "/home/jens/Source/shotwell/src/Dialogs.vala"
	app = (GAppInfo*) _tmp12_;
#line 2643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp13_ = config_facade_get_instance ();
#line 2643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp14_ = _tmp13_;
#line 2643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp15_ = g_app_info_get_commandline (app);
#line 2643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	configuration_facade_set_external_raw_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp15_);
#line 2643 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp14_);
#line 2645 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp16_ = g_app_info_get_commandline (app);
#line 2645 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_debug ("Dialogs.vala:2645: setting external raw editor to: %s", _tmp16_);
#line 2637 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (app);
#line 19656 "Dialogs.c"
}


static RawDeveloper preferences_dialog_raw_developer_from_combo (PreferencesDialog* self) {
	RawDeveloper result = 0;
	GtkComboBoxText* _tmp0_;
	gint _tmp1_;
#line 2648 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PREFERENCES_DIALOG (self), 0);
#line 2649 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->default_raw_developer_combo;
#line 2649 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_combo_box_get_type (), GtkComboBox));
#line 2649 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp1_ == 0) {
#line 2650 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result = RAW_DEVELOPER_CAMERA;
#line 2650 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return result;
#line 19676 "Dialogs.c"
	}
#line 2651 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = RAW_DEVELOPER_SHOTWELL;
#line 2651 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 19682 "Dialogs.c"
}


static void preferences_dialog_set_raw_developer_combo (PreferencesDialog* self, RawDeveloper d) {
	RawDeveloper _tmp0_;
#line 2654 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = d;
#line 2655 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp0_ == RAW_DEVELOPER_CAMERA) {
#line 19694 "Dialogs.c"
		GtkComboBoxText* _tmp1_;
#line 2656 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp1_ = self->priv->default_raw_developer_combo;
#line 2656 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 19700 "Dialogs.c"
	} else {
		GtkComboBoxText* _tmp2_;
#line 2658 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp2_ = self->priv->default_raw_developer_combo;
#line 2658 "/home/jens/Source/shotwell/src/Dialogs.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_combo_box_get_type (), GtkComboBox), 1);
#line 19707 "Dialogs.c"
	}
}


static void preferences_dialog_on_default_raw_developer_changed (PreferencesDialog* self) {
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	RawDeveloper _tmp2_;
#line 2661 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2662 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = config_facade_get_instance ();
#line 2662 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 2662 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = preferences_dialog_raw_developer_from_combo (self);
#line 2662 "/home/jens/Source/shotwell/src/Dialogs.vala"
	configuration_facade_set_default_raw_developer (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp2_);
#line 2662 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 19728 "Dialogs.c"
}


static void preferences_dialog_on_current_folder_changed (PreferencesDialog* self) {
	GtkFileChooserButton* _tmp0_;
	gchar* _tmp1_;
#line 2665 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->library_dir_button;
#line 2666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gtk_file_chooser_get_filename (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser));
#line 2666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->priv->lib_dir);
#line 2666 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->lib_dir = _tmp1_;
#line 19745 "Dialogs.c"
}


static void _preferences_dialog_on_current_folder_changed_gtk_file_chooser_current_folder_changed (GtkFileChooser* _sender, gpointer self) {
#line 2674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_on_current_folder_changed ((PreferencesDialog*) self);
#line 19752 "Dialogs.c"
}


static gboolean preferences_dialog_map_event (PreferencesDialog* self) {
	gboolean result = FALSE;
	GtkFileChooserButton* _tmp0_;
#line 2669 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (IS_PREFERENCES_DIALOG (self), FALSE);
#line 2674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = self->priv->library_dir_button;
#line 2674 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_connect (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GTK_TYPE_FILE_CHOOSER, GtkFileChooser), "current-folder-changed", (GCallback) _preferences_dialog_on_current_folder_changed_gtk_file_chooser_current_folder_changed, self);
#line 2675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = TRUE;
#line 2675 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 19769 "Dialogs.c"
}


static void preferences_dialog_add_to_dir_formats (PreferencesDialog* self, const gchar* name, const gchar* pattern) {
	PreferencesDialogPathFormat* pf = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	PreferencesDialogPathFormat* _tmp2_;
	GeeArrayList* _tmp3_;
	GtkComboBoxText* _tmp4_;
	const gchar* _tmp5_;
#line 2678 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2678 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (name != NULL);
#line 2679 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = name;
#line 2679 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = pattern;
#line 2679 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = preferences_dialog_path_format_new (_tmp0_, _tmp1_);
#line 2679 "/home/jens/Source/shotwell/src/Dialogs.vala"
	pf = _tmp2_;
#line 2680 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = self->priv->path_formats;
#line 2680 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), pf);
#line 2681 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = self->priv->dir_pattern_combo;
#line 2681 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = name;
#line 2681 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_combo_box_text_append_text (_tmp4_, _tmp5_);
#line 2678 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_preferences_dialog_path_format_unref0 (pf);
#line 19805 "Dialogs.c"
}


static void preferences_dialog_on_lowercase_toggled (PreferencesDialog* self) {
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	GtkCheckButton* _tmp2_;
	gboolean _tmp3_;
#line 2684 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (IS_PREFERENCES_DIALOG (self));
#line 2685 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = config_facade_get_instance ();
#line 2685 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = _tmp0_;
#line 2685 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = self->priv->lowercase;
#line 2685 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 2685 "/home/jens/Source/shotwell/src/Dialogs.vala"
	configuration_facade_set_use_lowercase_filenames (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp3_);
#line 2685 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp1_);
#line 19828 "Dialogs.c"
}


static PreferencesDialogPathFormat* preferences_dialog_path_format_construct (GType object_type, const gchar* name, const gchar* pattern) {
	PreferencesDialogPathFormat* self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
#line 2266 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 2266 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = (PreferencesDialogPathFormat*) g_type_create_instance (object_type);
#line 2267 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = name;
#line 2267 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 2267 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->name);
#line 2267 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->name = _tmp1_;
#line 2268 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = pattern;
#line 2268 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 2268 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->pattern);
#line 2268 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->pattern = _tmp3_;
#line 2266 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return self;
#line 19860 "Dialogs.c"
}


static PreferencesDialogPathFormat* preferences_dialog_path_format_new (const gchar* name, const gchar* pattern) {
#line 2266 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return preferences_dialog_path_format_construct (PREFERENCES_DIALOG_TYPE_PATH_FORMAT, name, pattern);
#line 19867 "Dialogs.c"
}


static void preferences_dialog_value_path_format_init (GValue* value) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 19874 "Dialogs.c"
}


static void preferences_dialog_value_path_format_free_value (GValue* value) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_path_format_unref (value->data[0].v_pointer);
#line 19883 "Dialogs.c"
	}
}


static void preferences_dialog_value_path_format_copy_value (const GValue* src_value, GValue* dest_value) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = preferences_dialog_path_format_ref (src_value->data[0].v_pointer);
#line 19893 "Dialogs.c"
	} else {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 19897 "Dialogs.c"
	}
}


static gpointer preferences_dialog_value_path_format_peek_pointer (const GValue* value) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 19905 "Dialogs.c"
}


static gchar* preferences_dialog_value_path_format_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 19912 "Dialogs.c"
		PreferencesDialogPathFormat * object;
		object = collect_values[0].v_pointer;
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 19919 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 19923 "Dialogs.c"
		}
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = preferences_dialog_path_format_ref (object);
#line 19927 "Dialogs.c"
	} else {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 19931 "Dialogs.c"
	}
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 19935 "Dialogs.c"
}


static gchar* preferences_dialog_value_path_format_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PreferencesDialogPathFormat ** object_p;
	object_p = collect_values[0].v_pointer;
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 19946 "Dialogs.c"
	}
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 19952 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 19956 "Dialogs.c"
	} else {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = preferences_dialog_path_format_ref (value->data[0].v_pointer);
#line 19960 "Dialogs.c"
	}
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 19964 "Dialogs.c"
}


static GParamSpec* preferences_dialog_param_spec_path_format (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PreferencesDialogParamSpecPathFormat* spec;
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PREFERENCES_DIALOG_TYPE_PATH_FORMAT), NULL);
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 19978 "Dialogs.c"
}


static gpointer preferences_dialog_value_get_path_format (const GValue* value) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PREFERENCES_DIALOG_TYPE_PATH_FORMAT), NULL);
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 19987 "Dialogs.c"
}


static void preferences_dialog_value_set_path_format (GValue* value, gpointer v_object) {
	PreferencesDialogPathFormat * old;
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PREFERENCES_DIALOG_TYPE_PATH_FORMAT));
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PREFERENCES_DIALOG_TYPE_PATH_FORMAT));
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_path_format_ref (value->data[0].v_pointer);
#line 20007 "Dialogs.c"
	} else {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 20011 "Dialogs.c"
	}
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_path_format_unref (old);
#line 20017 "Dialogs.c"
	}
}


static void preferences_dialog_value_take_path_format (GValue* value, gpointer v_object) {
	PreferencesDialogPathFormat * old;
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PREFERENCES_DIALOG_TYPE_PATH_FORMAT));
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PREFERENCES_DIALOG_TYPE_PATH_FORMAT));
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 20036 "Dialogs.c"
	} else {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 20040 "Dialogs.c"
	}
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_path_format_unref (old);
#line 20046 "Dialogs.c"
	}
}


static void preferences_dialog_path_format_class_init (PreferencesDialogPathFormatClass * klass) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_path_format_parent_class = g_type_class_peek_parent (klass);
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((PreferencesDialogPathFormatClass *) klass)->finalize = preferences_dialog_path_format_finalize;
#line 20056 "Dialogs.c"
}


static void preferences_dialog_path_format_instance_init (PreferencesDialogPathFormat * self) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 20063 "Dialogs.c"
}


static void preferences_dialog_path_format_finalize (PreferencesDialogPathFormat * obj) {
	PreferencesDialogPathFormat * self;
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PREFERENCES_DIALOG_TYPE_PATH_FORMAT, PreferencesDialogPathFormat);
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 2270 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->name);
#line 2271 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->pattern);
#line 20077 "Dialogs.c"
}


static GType preferences_dialog_path_format_get_type (void) {
	static volatile gsize preferences_dialog_path_format_type_id__volatile = 0;
	if (g_once_init_enter (&preferences_dialog_path_format_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { preferences_dialog_value_path_format_init, preferences_dialog_value_path_format_free_value, preferences_dialog_value_path_format_copy_value, preferences_dialog_value_path_format_peek_pointer, "p", preferences_dialog_value_path_format_collect_value, "p", preferences_dialog_value_path_format_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PreferencesDialogPathFormatClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) preferences_dialog_path_format_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PreferencesDialogPathFormat), 0, (GInstanceInitFunc) preferences_dialog_path_format_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType preferences_dialog_path_format_type_id;
		preferences_dialog_path_format_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PreferencesDialogPathFormat", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&preferences_dialog_path_format_type_id__volatile, preferences_dialog_path_format_type_id);
	}
	return preferences_dialog_path_format_type_id__volatile;
}


static gpointer preferences_dialog_path_format_ref (gpointer instance) {
	PreferencesDialogPathFormat * self;
	self = instance;
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 20102 "Dialogs.c"
}


static void preferences_dialog_path_format_unref (gpointer instance) {
	PreferencesDialogPathFormat * self;
	self = instance;
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		PREFERENCES_DIALOG_PATH_FORMAT_GET_CLASS (self)->finalize (self);
#line 2265 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 20115 "Dialogs.c"
	}
}


static void value_preferences_dialog_init (GValue* value) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	value->data[0].v_pointer = NULL;
#line 20123 "Dialogs.c"
}


static void value_preferences_dialog_free_value (GValue* value) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (value->data[0].v_pointer) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_unref (value->data[0].v_pointer);
#line 20132 "Dialogs.c"
	}
}


static void value_preferences_dialog_copy_value (const GValue* src_value, GValue* dest_value) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (src_value->data[0].v_pointer) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = preferences_dialog_ref (src_value->data[0].v_pointer);
#line 20142 "Dialogs.c"
	} else {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		dest_value->data[0].v_pointer = NULL;
#line 20146 "Dialogs.c"
	}
}


static gpointer value_preferences_dialog_peek_pointer (const GValue* value) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 20154 "Dialogs.c"
}


static gchar* value_preferences_dialog_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (collect_values[0].v_pointer) {
#line 20161 "Dialogs.c"
		PreferencesDialog * object;
		object = collect_values[0].v_pointer;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (object->parent_instance.g_class == NULL) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 20168 "Dialogs.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 20172 "Dialogs.c"
		}
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = preferences_dialog_ref (object);
#line 20176 "Dialogs.c"
	} else {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 20180 "Dialogs.c"
	}
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 20184 "Dialogs.c"
}


static gchar* value_preferences_dialog_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PreferencesDialog ** object_p;
	object_p = collect_values[0].v_pointer;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!object_p) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 20195 "Dialogs.c"
	}
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!value->data[0].v_pointer) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = NULL;
#line 20201 "Dialogs.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = value->data[0].v_pointer;
#line 20205 "Dialogs.c"
	} else {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		*object_p = preferences_dialog_ref (value->data[0].v_pointer);
#line 20209 "Dialogs.c"
	}
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return NULL;
#line 20213 "Dialogs.c"
}


GParamSpec* param_spec_preferences_dialog (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	ParamSpecPreferencesDialog* spec;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_PREFERENCES_DIALOG), NULL);
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return G_PARAM_SPEC (spec);
#line 20227 "Dialogs.c"
}


gpointer value_get_preferences_dialog (const GValue* value) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_PREFERENCES_DIALOG), NULL);
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return value->data[0].v_pointer;
#line 20236 "Dialogs.c"
}


void value_set_preferences_dialog (GValue* value, gpointer v_object) {
	PreferencesDialog * old;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_PREFERENCES_DIALOG));
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_PREFERENCES_DIALOG));
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_ref (value->data[0].v_pointer);
#line 20256 "Dialogs.c"
	} else {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 20260 "Dialogs.c"
	}
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_unref (old);
#line 20266 "Dialogs.c"
	}
}


void value_take_preferences_dialog (GValue* value, gpointer v_object) {
	PreferencesDialog * old;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_PREFERENCES_DIALOG));
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	old = value->data[0].v_pointer;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (v_object) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_PREFERENCES_DIALOG));
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = v_object;
#line 20285 "Dialogs.c"
	} else {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		value->data[0].v_pointer = NULL;
#line 20289 "Dialogs.c"
	}
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (old) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		preferences_dialog_unref (old);
#line 20295 "Dialogs.c"
	}
}


static void preferences_dialog_class_init (PreferencesDialogClass * klass) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	preferences_dialog_parent_class = g_type_class_peek_parent (klass);
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	((PreferencesDialogClass *) klass)->finalize = preferences_dialog_finalize;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_type_class_add_private (klass, sizeof (PreferencesDialogPrivate));
#line 20307 "Dialogs.c"
}


static void preferences_dialog_instance_init (PreferencesDialog * self) {
	GeeArrayList* _tmp0_;
	GDateTime* _tmp1_;
	PluginsManifestWidgetMediator* _tmp2_;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv = PREFERENCES_DIALOG_GET_PRIVATE (self);
#line 2288 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->allow_closing = FALSE;
#line 2289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->lib_dir = NULL;
#line 2290 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = gee_array_list_new (PREFERENCES_DIALOG_TYPE_PATH_FORMAT, (GBoxedCopyFunc) preferences_dialog_path_format_ref, (GDestroyNotify) preferences_dialog_path_format_unref, NULL, NULL, NULL);
#line 2290 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->path_formats = _tmp0_;
#line 2291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = g_date_time_new_local (2009, 3, 10, 18, 16, (gdouble) 11);
#line 2291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->example_date = _tmp1_;
#line 2293 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = plugins_manifest_widget_mediator_new ();
#line 2293 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->priv->plugins_mediator = _tmp2_;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self->ref_count = 1;
#line 20335 "Dialogs.c"
}


static void preferences_dialog_finalize (PreferencesDialog * obj) {
	PreferencesDialog * self;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PREFERENCES_DIALOG, PreferencesDialog);
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_signal_handlers_destroy (self);
#line 2276 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dialog);
#line 2277 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->builder);
#line 2278 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->bg_color_adjustment);
#line 2279 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->bg_color_slider);
#line 2280 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->photo_editor_combo);
#line 2281 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->raw_editor_combo);
#line 2282 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->external_raw_apps);
#line 2283 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->external_photo_apps);
#line 2284 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->library_dir_button);
#line 2285 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dir_pattern_combo);
#line 2286 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dir_pattern_entry);
#line 2287 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->dir_pattern_example);
#line 2289 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (self->priv->lib_dir);
#line 2290 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->path_formats);
#line 2291 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_date_time_unref0 (self->priv->example_date);
#line 2292 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->lowercase);
#line 2293 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_plugins_manifest_widget_mediator_unref0 (self->priv->plugins_mediator);
#line 2294 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (self->priv->default_raw_developer_combo);
#line 20381 "Dialogs.c"
}


GType preferences_dialog_get_type (void) {
	static volatile gsize preferences_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&preferences_dialog_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { value_preferences_dialog_init, value_preferences_dialog_free_value, value_preferences_dialog_copy_value, value_preferences_dialog_peek_pointer, "p", value_preferences_dialog_collect_value, "p", value_preferences_dialog_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PreferencesDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) preferences_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PreferencesDialog), 0, (GInstanceInitFunc) preferences_dialog_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType preferences_dialog_type_id;
		preferences_dialog_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PreferencesDialog", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&preferences_dialog_type_id__volatile, preferences_dialog_type_id);
	}
	return preferences_dialog_type_id__volatile;
}


gpointer preferences_dialog_ref (gpointer instance) {
	PreferencesDialog * self;
	self = instance;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_atomic_int_inc (&self->ref_count);
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return instance;
#line 20406 "Dialogs.c"
}


void preferences_dialog_unref (gpointer instance) {
	PreferencesDialog * self;
	self = instance;
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		PREFERENCES_DIALOG_GET_CLASS (self)->finalize (self);
#line 2264 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 20419 "Dialogs.c"
	}
}


GtkResponseType copy_files_dialog (void) {
	GtkResponseType result = 0;
	gchar* msg = NULL;
	gchar* _tmp0_;
	GtkMessageDialog* dialog = NULL;
	AppWindow* _tmp1_;
	AppWindow* _tmp2_;
	GtkMessageDialog* _tmp3_;
	GtkMessageDialog* _tmp4_;
	GtkResponseType _result_ = 0;
	gint _tmp5_;
#line 2692 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = g_strdup (_ ("Shotwell can copy the photos into your library folder or it can import" \
" them without copying."));
#line 2692 "/home/jens/Source/shotwell/src/Dialogs.vala"
	msg = _tmp0_;
#line 2694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = app_window_get_instance ();
#line 2694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 2694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = (GtkMessageDialog*) gtk_message_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_window_get_type (), GtkWindow), GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_CANCEL, "%s", msg);
#line 2694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_object_ref_sink (_tmp3_);
#line 2694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = _tmp3_;
#line 2694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp2_);
#line 2694 "/home/jens/Source/shotwell/src/Dialogs.vala"
	dialog = _tmp4_;
#line 2697 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("Co_py Photos"), (gint) GTK_RESPONSE_ACCEPT);
#line 2698 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog), _ ("_Import in Place"), (gint) GTK_RESPONSE_REJECT);
#line 2699 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_window_get_type (), GtkWindow), _ ("Import to Library"));
#line 2701 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_dialog_get_type (), GtkDialog));
#line 2701 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = (GtkResponseType) _tmp5_;
#line 2703 "/home/jens/Source/shotwell/src/Dialogs.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 2705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	result = _result_;
#line 2705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (dialog);
#line 2705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (msg);
#line 2705 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 20473 "Dialogs.c"
}


void remove_photos_from_library (GeeCollection* photos) {
	const gchar* _tmp0_ = NULL;
	GeeCollection* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	GeeCollection* _tmp4_;
#line 2708 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GEE_IS_COLLECTION (photos));
#line 2710 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = photos;
#line 2710 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = gee_collection_get_size (_tmp1_);
#line 2710 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = _tmp2_;
#line 2710 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp3_ == 1) {
#line 2710 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _ ("Removing Photo From Library");
#line 20495 "Dialogs.c"
	} else {
#line 2710 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp0_ = _ ("Removing Photos From Library");
#line 20499 "Dialogs.c"
	}
#line 2709 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = photos;
#line 2709 "/home/jens/Source/shotwell/src/Dialogs.vala"
	remove_from_app (_tmp4_, _ ("Remove From Library"), _tmp0_);
#line 20505 "Dialogs.c"
}


static gboolean _progress_dialog_monitor_progress_monitor (guint64 current, guint64 total, gboolean do_event_loop, gpointer self) {
	gboolean result;
	result = progress_dialog_monitor ((ProgressDialog*) self, current, total, do_event_loop);
#line 2750 "/home/jens/Source/shotwell/src/Dialogs.vala"
	return result;
#line 20514 "Dialogs.c"
}


void remove_from_app (GeeCollection* sources, const gchar* dialog_title, const gchar* progress_dialog_text) {
	GeeCollection* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	GeeArrayList* photos = NULL;
	GeeArrayList* _tmp3_;
	GeeArrayList* videos = NULL;
	GeeArrayList* _tmp4_;
	GeeCollection* _tmp5_;
	GeeArrayList* _tmp6_;
	GeeArrayList* _tmp7_;
	gchar* user_message = NULL;
	gboolean _tmp8_ = FALSE;
	GeeArrayList* _tmp9_;
	gboolean _tmp10_;
	gboolean _tmp11_;
	GtkResponseType _result_ = 0;
	AppWindow* _tmp39_;
	AppWindow* _tmp40_;
	const gchar* _tmp41_;
	const gchar* _tmp42_;
	GeeCollection* _tmp43_;
	gint _tmp44_;
	gint _tmp45_;
	GtkResponseType _tmp46_;
	GtkResponseType _tmp47_;
	gboolean _tmp48_ = FALSE;
	GtkResponseType _tmp49_;
	gboolean delete_backing = FALSE;
	GtkResponseType _tmp51_;
	AppWindow* _tmp52_;
	AppWindow* _tmp53_;
	ProgressDialog* progress = NULL;
	ProgressMonitor monitor = NULL;
	void* monitor_target;
	GDestroyNotify monitor_target_destroy_notify;
	GeeCollection* _tmp54_;
	gint _tmp55_;
	gint _tmp56_;
	GeeArrayList* not_removed_photos = NULL;
	GeeArrayList* _tmp62_;
	GeeArrayList* not_removed_videos = NULL;
	GeeArrayList* _tmp63_;
	LibraryPhotoSourceCollection* _tmp64_;
	GeeArrayList* _tmp65_;
	gboolean _tmp66_;
	ProgressMonitor _tmp67_;
	void* _tmp67__target;
	GeeArrayList* _tmp68_;
	VideoSourceCollection* _tmp69_;
	GeeArrayList* _tmp70_;
	gboolean _tmp71_;
	ProgressMonitor _tmp72_;
	void* _tmp72__target;
	GeeArrayList* _tmp73_;
	gint num_not_removed = 0;
	GeeArrayList* _tmp74_;
	gint _tmp75_;
	gint _tmp76_;
	GeeArrayList* _tmp77_;
	gint _tmp78_;
	gint _tmp79_;
	gboolean _tmp80_ = FALSE;
	gboolean _tmp81_;
	ProgressDialog* _tmp117_;
	AppWindow* _tmp119_;
	AppWindow* _tmp120_;
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (GEE_IS_COLLECTION (sources));
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (dialog_title != NULL);
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	g_return_if_fail (progress_dialog_text != NULL);
#line 2715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp0_ = sources;
#line 2715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp1_ = gee_collection_get_size (_tmp0_);
#line 2715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp2_ = _tmp1_;
#line 2715 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp2_ == 0) {
#line 2716 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 20601 "Dialogs.c"
	}
#line 2718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp3_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 2718 "/home/jens/Source/shotwell/src/Dialogs.vala"
	photos = _tmp3_;
#line 2719 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp4_ = gee_array_list_new (TYPE_VIDEO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 2719 "/home/jens/Source/shotwell/src/Dialogs.vala"
	videos = _tmp4_;
#line 2720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp5_ = sources;
#line 2720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp6_ = photos;
#line 2720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp7_ = videos;
#line 2720 "/home/jens/Source/shotwell/src/Dialogs.vala"
	media_source_collection_filter_media (_tmp5_, G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_COLLECTION, GeeCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2722 "/home/jens/Source/shotwell/src/Dialogs.vala"
	user_message = NULL;
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp9_ = photos;
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp10_ = gee_collection_get_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp11_ = _tmp10_;
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (!_tmp11_) {
#line 20629 "Dialogs.c"
		GeeArrayList* _tmp12_;
		gboolean _tmp13_;
		gboolean _tmp14_;
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp12_ = videos;
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp13_ = gee_collection_get_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp14_ = _tmp13_;
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = !_tmp14_;
#line 20641 "Dialogs.c"
	} else {
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp8_ = FALSE;
#line 20645 "Dialogs.c"
	}
#line 2723 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp8_) {
#line 20649 "Dialogs.c"
		GeeCollection* _tmp15_;
		gint _tmp16_;
		gint _tmp17_;
		GeeCollection* _tmp18_;
		gint _tmp19_;
		gint _tmp20_;
		gchar* _tmp21_;
#line 2724 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp15_ = sources;
#line 2724 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp16_ = gee_collection_get_size (_tmp15_);
#line 2724 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp17_ = _tmp16_;
#line 2724 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp18_ = sources;
#line 2724 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp19_ = gee_collection_get_size (_tmp18_);
#line 2724 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp20_ = _tmp19_;
#line 2724 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp21_ = g_strdup_printf (ngettext ("This will remove the photo/video from your Shotwell library. Would you" \
" also like to move the file to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", "This will remove %d photos/videos from your Shotwell library. Would yo" \
"u also like to move the files to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", (gulong) _tmp17_), _tmp20_);
#line 2724 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (user_message);
#line 2724 "/home/jens/Source/shotwell/src/Dialogs.vala"
		user_message = _tmp21_;
#line 20675 "Dialogs.c"
	} else {
		GeeArrayList* _tmp22_;
		gboolean _tmp23_;
		gboolean _tmp24_;
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp22_ = videos;
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp23_ = gee_collection_get_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GEE_TYPE_COLLECTION, GeeCollection));
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp24_ = _tmp23_;
#line 2727 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (!_tmp24_) {
#line 20688 "Dialogs.c"
			GeeCollection* _tmp25_;
			gint _tmp26_;
			gint _tmp27_;
			GeeCollection* _tmp28_;
			gint _tmp29_;
			gint _tmp30_;
			gchar* _tmp31_;
#line 2728 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp25_ = sources;
#line 2728 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp26_ = gee_collection_get_size (_tmp25_);
#line 2728 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp27_ = _tmp26_;
#line 2728 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp28_ = sources;
#line 2728 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp29_ = gee_collection_get_size (_tmp28_);
#line 2728 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp30_ = _tmp29_;
#line 2728 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp31_ = g_strdup_printf (ngettext ("This will remove the video from your Shotwell library. Would you also " \
"like to move the file to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", "This will remove %d videos from your Shotwell library. Would you also " \
"like to move the files to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", (gulong) _tmp27_), _tmp30_);
#line 2728 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (user_message);
#line 2728 "/home/jens/Source/shotwell/src/Dialogs.vala"
			user_message = _tmp31_;
#line 20714 "Dialogs.c"
		} else {
			GeeCollection* _tmp32_;
			gint _tmp33_;
			gint _tmp34_;
			GeeCollection* _tmp35_;
			gint _tmp36_;
			gint _tmp37_;
			gchar* _tmp38_;
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp32_ = sources;
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp33_ = gee_collection_get_size (_tmp32_);
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp34_ = _tmp33_;
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp35_ = sources;
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp36_ = gee_collection_get_size (_tmp35_);
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp37_ = _tmp36_;
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp38_ = g_strdup_printf (ngettext ("This will remove the photo from your Shotwell library. Would you also " \
"like to move the file to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", "This will remove %d photos from your Shotwell library. Would you also " \
"like to move the files to your desktop trash?\n" \
"\n" \
"This action cannot be undone.", (gulong) _tmp34_), _tmp37_);
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_free0 (user_message);
#line 2732 "/home/jens/Source/shotwell/src/Dialogs.vala"
			user_message = _tmp38_;
#line 20741 "Dialogs.c"
		}
	}
#line 2737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp39_ = app_window_get_instance ();
#line 2737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp40_ = _tmp39_;
#line 2737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp41_ = dialog_title;
#line 2737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp42_ = user_message;
#line 2737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp43_ = sources;
#line 2737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp44_ = gee_collection_get_size (_tmp43_);
#line 2737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp45_ = _tmp44_;
#line 2737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp46_ = remove_from_library_dialog (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, gtk_window_get_type (), GtkWindow), _tmp41_, _tmp42_, _tmp45_);
#line 2737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp47_ = _tmp46_;
#line 2737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp40_);
#line 2737 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_result_ = _tmp47_;
#line 2739 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp49_ = _result_;
#line 2739 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp49_ != GTK_RESPONSE_YES) {
#line 20770 "Dialogs.c"
		GtkResponseType _tmp50_;
#line 2739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp50_ = _result_;
#line 2739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp48_ = _tmp50_ != GTK_RESPONSE_NO;
#line 20776 "Dialogs.c"
	} else {
#line 2739 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp48_ = FALSE;
#line 20780 "Dialogs.c"
	}
#line 2739 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp48_) {
#line 2740 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (user_message);
#line 2740 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (videos);
#line 2740 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (photos);
#line 2740 "/home/jens/Source/shotwell/src/Dialogs.vala"
		return;
#line 20792 "Dialogs.c"
	}
#line 2742 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp51_ = _result_;
#line 2742 "/home/jens/Source/shotwell/src/Dialogs.vala"
	delete_backing = _tmp51_ == GTK_RESPONSE_YES;
#line 2744 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp52_ = app_window_get_instance ();
#line 2744 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp53_ = _tmp52_;
#line 2744 "/home/jens/Source/shotwell/src/Dialogs.vala"
	page_window_set_busy_cursor (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, TYPE_PAGE_WINDOW, PageWindow));
#line 2744 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp53_);
#line 2746 "/home/jens/Source/shotwell/src/Dialogs.vala"
	progress = NULL;
#line 2747 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor = NULL;
#line 2747 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target = NULL;
#line 2747 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target_destroy_notify = NULL;
#line 2748 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp54_ = sources;
#line 2748 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp55_ = gee_collection_get_size (_tmp54_);
#line 2748 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp56_ = _tmp55_;
#line 2748 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp56_ >= 20) {
#line 20822 "Dialogs.c"
		AppWindow* _tmp57_;
		AppWindow* _tmp58_;
		const gchar* _tmp59_;
		ProgressDialog* _tmp60_;
		ProgressDialog* _tmp61_;
#line 2749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp57_ = app_window_get_instance ();
#line 2749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp58_ = _tmp57_;
#line 2749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp59_ = progress_dialog_text;
#line 2749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp60_ = progress_dialog_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, gtk_window_get_type (), GtkWindow), _tmp59_, NULL);
#line 2749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		g_object_ref_sink (_tmp60_);
#line 2749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (progress);
#line 2749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		progress = _tmp60_;
#line 2749 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp58_);
#line 2750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp61_ = progress;
#line 2750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		(monitor_target_destroy_notify == NULL) ? NULL : (monitor_target_destroy_notify (monitor_target), NULL);
#line 2750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor = NULL;
#line 2750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target = NULL;
#line 2750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target_destroy_notify = NULL;
#line 2750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor = _progress_dialog_monitor_progress_monitor;
#line 2750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target = g_object_ref (_tmp61_);
#line 2750 "/home/jens/Source/shotwell/src/Dialogs.vala"
		monitor_target_destroy_notify = g_object_unref;
#line 20860 "Dialogs.c"
	}
#line 2753 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp62_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 2753 "/home/jens/Source/shotwell/src/Dialogs.vala"
	not_removed_photos = _tmp62_;
#line 2754 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp63_ = gee_array_list_new (TYPE_VIDEO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 2754 "/home/jens/Source/shotwell/src/Dialogs.vala"
	not_removed_videos = _tmp63_;
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp64_ = library_photo_global;
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp65_ = photos;
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp66_ = delete_backing;
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp67_ = monitor;
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp67__target = monitor_target;
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp68_ = not_removed_photos;
#line 2757 "/home/jens/Source/shotwell/src/Dialogs.vala"
	media_source_collection_remove_from_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp64_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp65_, GEE_TYPE_COLLECTION, GeeCollection), _tmp66_, _tmp67_, _tmp67__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, GEE_TYPE_LIST, GeeList));
#line 2758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp69_ = video_global;
#line 2758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp70_ = videos;
#line 2758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp71_ = delete_backing;
#line 2758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp72_ = monitor;
#line 2758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp72__target = monitor_target;
#line 2758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp73_ = not_removed_videos;
#line 2758 "/home/jens/Source/shotwell/src/Dialogs.vala"
	media_source_collection_remove_from_app (G_TYPE_CHECK_INSTANCE_CAST (_tmp69_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp70_, GEE_TYPE_COLLECTION, GeeCollection), _tmp71_, _tmp72_, _tmp72__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp73_, GEE_TYPE_LIST, GeeList));
#line 2761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp74_ = not_removed_photos;
#line 2761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp75_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp74_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 2761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp76_ = _tmp75_;
#line 2761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp77_ = not_removed_videos;
#line 2761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp78_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp77_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 2761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp79_ = _tmp78_;
#line 2761 "/home/jens/Source/shotwell/src/Dialogs.vala"
	num_not_removed = _tmp76_ + _tmp79_;
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp81_ = delete_backing;
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp81_) {
#line 20916 "Dialogs.c"
		gint _tmp82_;
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp82_ = num_not_removed;
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp80_ = _tmp82_ > 0;
#line 20922 "Dialogs.c"
	} else {
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp80_ = FALSE;
#line 20926 "Dialogs.c"
	}
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp80_) {
#line 20930 "Dialogs.c"
		gchar* not_deleted_message = NULL;
		gint _tmp83_;
		gint _tmp84_;
		gchar* _tmp85_;
		GtkResponseType result_delete = 0;
		AppWindow* _tmp86_;
		AppWindow* _tmp87_;
		const gchar* _tmp88_;
		const gchar* _tmp89_;
		GtkResponseType _tmp90_;
		GtkResponseType _tmp91_;
		GtkResponseType _tmp92_;
#line 2763 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp83_ = num_not_removed;
#line 2763 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp84_ = num_not_removed;
#line 2763 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp85_ = g_strdup_printf (ngettext ("The photo or video cannot be moved to your desktop trash. Delete this " \
"file?", "%d photos/videos cannot be moved to your desktop trash. Delete these f" \
"iles?", (gulong) _tmp83_), _tmp84_);
#line 2763 "/home/jens/Source/shotwell/src/Dialogs.vala"
		not_deleted_message = _tmp85_;
#line 2767 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp86_ = app_window_get_instance ();
#line 2767 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp87_ = _tmp86_;
#line 2767 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp88_ = dialog_title;
#line 2767 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp89_ = not_deleted_message;
#line 2767 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp90_ = remove_from_filesystem_dialog (G_TYPE_CHECK_INSTANCE_CAST (_tmp87_, gtk_window_get_type (), GtkWindow), _tmp88_, _tmp89_);
#line 2767 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp91_ = _tmp90_;
#line 2767 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_object_unref0 (_tmp87_);
#line 2767 "/home/jens/Source/shotwell/src/Dialogs.vala"
		result_delete = _tmp91_;
#line 2770 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp92_ = result_delete;
#line 2770 "/home/jens/Source/shotwell/src/Dialogs.vala"
		if (GTK_RESPONSE_YES == _tmp92_) {
#line 20971 "Dialogs.c"
			GeeArrayList* not_deleted_photos = NULL;
			GeeArrayList* _tmp93_;
			GeeArrayList* not_deleted_videos = NULL;
			GeeArrayList* _tmp94_;
			LibraryPhotoSourceCollection* _tmp95_;
			GeeArrayList* _tmp96_;
			ProgressMonitor _tmp97_;
			void* _tmp97__target;
			GeeArrayList* _tmp98_;
			VideoSourceCollection* _tmp99_;
			GeeArrayList* _tmp100_;
			ProgressMonitor _tmp101_;
			void* _tmp101__target;
			GeeArrayList* _tmp102_;
			gint num_not_deleted = 0;
			GeeArrayList* _tmp103_;
			gint _tmp104_;
			gint _tmp105_;
			GeeArrayList* _tmp106_;
			gint _tmp107_;
			gint _tmp108_;
			gint _tmp109_;
#line 2772 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp93_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 2772 "/home/jens/Source/shotwell/src/Dialogs.vala"
			not_deleted_photos = _tmp93_;
#line 2773 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp94_ = gee_array_list_new (TYPE_VIDEO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 2773 "/home/jens/Source/shotwell/src/Dialogs.vala"
			not_deleted_videos = _tmp94_;
#line 2774 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp95_ = library_photo_global;
#line 2774 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp96_ = not_removed_photos;
#line 2774 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp97_ = monitor;
#line 2774 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp97__target = monitor_target;
#line 2774 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp98_ = not_deleted_photos;
#line 2774 "/home/jens/Source/shotwell/src/Dialogs.vala"
			media_source_collection_delete_backing_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp95_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp96_, GEE_TYPE_COLLECTION, GeeCollection), _tmp97_, _tmp97__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp98_, GEE_TYPE_LIST, GeeList));
#line 2775 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp99_ = video_global;
#line 2775 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp100_ = not_removed_videos;
#line 2775 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp101_ = monitor;
#line 2775 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp101__target = monitor_target;
#line 2775 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp102_ = not_deleted_videos;
#line 2775 "/home/jens/Source/shotwell/src/Dialogs.vala"
			media_source_collection_delete_backing_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp99_, TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp100_, GEE_TYPE_COLLECTION, GeeCollection), _tmp101_, _tmp101__target, G_TYPE_CHECK_INSTANCE_CAST (_tmp102_, GEE_TYPE_LIST, GeeList));
#line 2777 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp103_ = not_deleted_photos;
#line 2777 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp104_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp103_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 2777 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp105_ = _tmp104_;
#line 2777 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp106_ = not_deleted_videos;
#line 2777 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp107_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp106_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 2777 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp108_ = _tmp107_;
#line 2777 "/home/jens/Source/shotwell/src/Dialogs.vala"
			num_not_deleted = _tmp105_ + _tmp108_;
#line 2778 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_tmp109_ = num_not_deleted;
#line 2778 "/home/jens/Source/shotwell/src/Dialogs.vala"
			if (_tmp109_ > 0) {
#line 21044 "Dialogs.c"
				gchar* delete_failed_message = NULL;
				gint _tmp110_;
				gint _tmp111_;
				gchar* _tmp112_;
				const gchar* _tmp113_;
				const gchar* _tmp114_;
				AppWindow* _tmp115_;
				AppWindow* _tmp116_;
#line 2780 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp110_ = num_not_deleted;
#line 2780 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp111_ = num_not_deleted;
#line 2780 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp112_ = g_strdup_printf (ngettext ("The photo or video cannot be deleted.", "%d photos/videos cannot be deleted.", (gulong) _tmp110_), _tmp111_);
#line 2780 "/home/jens/Source/shotwell/src/Dialogs.vala"
				delete_failed_message = _tmp112_;
#line 2784 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp113_ = dialog_title;
#line 2784 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp114_ = delete_failed_message;
#line 2784 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp115_ = app_window_get_instance ();
#line 2784 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_tmp116_ = _tmp115_;
#line 2784 "/home/jens/Source/shotwell/src/Dialogs.vala"
				app_window_error_message_with_title (_tmp113_, _tmp114_, G_TYPE_CHECK_INSTANCE_CAST (_tmp116_, gtk_window_get_type (), GtkWindow), TRUE);
#line 2784 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_object_unref0 (_tmp116_);
#line 2778 "/home/jens/Source/shotwell/src/Dialogs.vala"
				_g_free0 (delete_failed_message);
#line 21075 "Dialogs.c"
			}
#line 2770 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (not_deleted_videos);
#line 2770 "/home/jens/Source/shotwell/src/Dialogs.vala"
			_g_object_unref0 (not_deleted_photos);
#line 21081 "Dialogs.c"
		}
#line 2762 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_g_free0 (not_deleted_message);
#line 21085 "Dialogs.c"
	}
#line 2789 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp117_ = progress;
#line 2789 "/home/jens/Source/shotwell/src/Dialogs.vala"
	if (_tmp117_ != NULL) {
#line 21091 "Dialogs.c"
		ProgressDialog* _tmp118_;
#line 2790 "/home/jens/Source/shotwell/src/Dialogs.vala"
		_tmp118_ = progress;
#line 2790 "/home/jens/Source/shotwell/src/Dialogs.vala"
		progress_dialog_close (_tmp118_);
#line 21097 "Dialogs.c"
	}
#line 2792 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp119_ = app_window_get_instance ();
#line 2792 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_tmp120_ = _tmp119_;
#line 2792 "/home/jens/Source/shotwell/src/Dialogs.vala"
	page_window_set_normal_cursor (G_TYPE_CHECK_INSTANCE_CAST (_tmp120_, TYPE_PAGE_WINDOW, PageWindow));
#line 2792 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (_tmp120_);
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (not_removed_videos);
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (not_removed_photos);
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	(monitor_target_destroy_notify == NULL) ? NULL : (monitor_target_destroy_notify (monitor_target), NULL);
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor = NULL;
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target = NULL;
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	monitor_target_destroy_notify = NULL;
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (progress);
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_free0 (user_message);
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (videos);
#line 2713 "/home/jens/Source/shotwell/src/Dialogs.vala"
	_g_object_unref0 (photos);
#line 21127 "Dialogs.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



