/* PiwigoPublishing.c generated by valac 0.36.6, the Vala compiler
 * generated from PiwigoPublishing.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include <shotwell-plugin-dev-1.0.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include "shotwell-plugin-common.h"
#include <glib/gi18n-lib.h>
#include <libsoup/soup.h>
#include <libxml/tree.h>
#include <gee.h>
#include <float.h>
#include <math.h>
#include <gtk/gtk.h>
#include <gcr/gcr-base.h>
#include <ui/gcr-ui.h>
#include <gobject/gvaluecollector.h>


#define TYPE_PIWIGO_SERVICE (piwigo_service_get_type ())
#define PIWIGO_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PIWIGO_SERVICE, PiwigoService))
#define PIWIGO_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PIWIGO_SERVICE, PiwigoServiceClass))
#define IS_PIWIGO_SERVICE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PIWIGO_SERVICE))
#define IS_PIWIGO_SERVICE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PIWIGO_SERVICE))
#define PIWIGO_SERVICE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PIWIGO_SERVICE, PiwigoServiceClass))

typedef struct _PiwigoService PiwigoService;
typedef struct _PiwigoServiceClass PiwigoServiceClass;
typedef struct _PiwigoServicePrivate PiwigoServicePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER (publishing_piwigo_piwigo_publisher_get_type ())
#define PUBLISHING_PIWIGO_PIWIGO_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisher))
#define PUBLISHING_PIWIGO_PIWIGO_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisherClass))
#define PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER))
#define PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER))
#define PUBLISHING_PIWIGO_PIWIGO_PUBLISHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisherClass))

typedef struct _PublishingPiwigoPiwigoPublisher PublishingPiwigoPiwigoPublisher;
typedef struct _PublishingPiwigoPiwigoPublisherClass PublishingPiwigoPiwigoPublisherClass;

#define PUBLISHING_PIWIGO_TYPE_CATEGORY (publishing_piwigo_category_get_type ())
#define PUBLISHING_PIWIGO_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORY, PublishingPiwigoCategory))
#define PUBLISHING_PIWIGO_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_CATEGORY, PublishingPiwigoCategoryClass))
#define PUBLISHING_PIWIGO_IS_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORY))
#define PUBLISHING_PIWIGO_IS_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_CATEGORY))
#define PUBLISHING_PIWIGO_CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORY, PublishingPiwigoCategoryClass))

typedef struct _PublishingPiwigoCategory PublishingPiwigoCategory;
typedef struct _PublishingPiwigoCategoryClass PublishingPiwigoCategoryClass;
typedef struct _PublishingPiwigoCategoryPrivate PublishingPiwigoCategoryPrivate;
typedef struct _PublishingPiwigoParamSpecCategory PublishingPiwigoParamSpecCategory;

#define PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL (publishing_piwigo_permission_level_get_type ())
#define PUBLISHING_PIWIGO_PERMISSION_LEVEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL, PublishingPiwigoPermissionLevel))
#define PUBLISHING_PIWIGO_PERMISSION_LEVEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL, PublishingPiwigoPermissionLevelClass))
#define PUBLISHING_PIWIGO_IS_PERMISSION_LEVEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL))
#define PUBLISHING_PIWIGO_IS_PERMISSION_LEVEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL))
#define PUBLISHING_PIWIGO_PERMISSION_LEVEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL, PublishingPiwigoPermissionLevelClass))

typedef struct _PublishingPiwigoPermissionLevel PublishingPiwigoPermissionLevel;
typedef struct _PublishingPiwigoPermissionLevelClass PublishingPiwigoPermissionLevelClass;
typedef struct _PublishingPiwigoPermissionLevelPrivate PublishingPiwigoPermissionLevelPrivate;
typedef struct _PublishingPiwigoParamSpecPermissionLevel PublishingPiwigoParamSpecPermissionLevel;

#define PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY (publishing_piwigo_size_entry_get_type ())
#define PUBLISHING_PIWIGO_SIZE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY, PublishingPiwigoSizeEntry))
#define PUBLISHING_PIWIGO_SIZE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY, PublishingPiwigoSizeEntryClass))
#define PUBLISHING_PIWIGO_IS_SIZE_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY))
#define PUBLISHING_PIWIGO_IS_SIZE_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY))
#define PUBLISHING_PIWIGO_SIZE_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY, PublishingPiwigoSizeEntryClass))

typedef struct _PublishingPiwigoSizeEntry PublishingPiwigoSizeEntry;
typedef struct _PublishingPiwigoSizeEntryClass PublishingPiwigoSizeEntryClass;
typedef struct _PublishingPiwigoSizeEntryPrivate PublishingPiwigoSizeEntryPrivate;
typedef struct _PublishingPiwigoParamSpecSizeEntry PublishingPiwigoParamSpecSizeEntry;

#define PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS (publishing_piwigo_publishing_parameters_get_type ())
#define PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS, PublishingPiwigoPublishingParameters))
#define PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS, PublishingPiwigoPublishingParametersClass))
#define PUBLISHING_PIWIGO_IS_PUBLISHING_PARAMETERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_PIWIGO_IS_PUBLISHING_PARAMETERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS))
#define PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS, PublishingPiwigoPublishingParametersClass))

typedef struct _PublishingPiwigoPublishingParameters PublishingPiwigoPublishingParameters;
typedef struct _PublishingPiwigoPublishingParametersClass PublishingPiwigoPublishingParametersClass;
typedef struct _PublishingPiwigoPublishingParametersPrivate PublishingPiwigoPublishingParametersPrivate;
#define _publishing_piwigo_category_unref0(var) ((var == NULL) ? NULL : (var = (publishing_piwigo_category_unref (var), NULL)))
#define _publishing_piwigo_permission_level_unref0(var) ((var == NULL) ? NULL : (var = (publishing_piwigo_permission_level_unref (var), NULL)))
#define _publishing_piwigo_size_entry_unref0(var) ((var == NULL) ? NULL : (var = (publishing_piwigo_size_entry_unref (var), NULL)))
typedef struct _PublishingPiwigoParamSpecPublishingParameters PublishingPiwigoParamSpecPublishingParameters;
typedef struct _PublishingPiwigoPiwigoPublisherPrivate PublishingPiwigoPiwigoPublisherPrivate;

#define PUBLISHING_PIWIGO_TYPE_SESSION (publishing_piwigo_session_get_type ())
#define PUBLISHING_PIWIGO_SESSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSession))
#define PUBLISHING_PIWIGO_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSessionClass))
#define PUBLISHING_PIWIGO_IS_SESSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_SESSION))
#define PUBLISHING_PIWIGO_IS_SESSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_SESSION))
#define PUBLISHING_PIWIGO_SESSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSessionClass))

typedef struct _PublishingPiwigoSession PublishingPiwigoSession;
typedef struct _PublishingPiwigoSessionClass PublishingPiwigoSessionClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _publishing_rest_support_session_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_session_unref (var), NULL)))
#define _publishing_piwigo_publishing_parameters_unref0(var) ((var == NULL) ? NULL : (var = (publishing_piwigo_publishing_parameters_unref (var), NULL)))

#define PUBLISHING_PIWIGO_AUTHENTICATION_PANE_TYPE_MODE (publishing_piwigo_authentication_pane_mode_get_type ())

#define PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE (publishing_piwigo_authentication_pane_get_type ())
#define PUBLISHING_PIWIGO_AUTHENTICATION_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPane))
#define PUBLISHING_PIWIGO_AUTHENTICATION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPaneClass))
#define PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE))
#define PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE))
#define PUBLISHING_PIWIGO_AUTHENTICATION_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPaneClass))

typedef struct _PublishingPiwigoAuthenticationPane PublishingPiwigoAuthenticationPane;
typedef struct _PublishingPiwigoAuthenticationPaneClass PublishingPiwigoAuthenticationPaneClass;

#define PUBLISHING_PIWIGO_TYPE_TRANSACTION (publishing_piwigo_transaction_get_type ())
#define PUBLISHING_PIWIGO_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_TRANSACTION, PublishingPiwigoTransaction))
#define PUBLISHING_PIWIGO_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_TRANSACTION, PublishingPiwigoTransactionClass))
#define PUBLISHING_PIWIGO_IS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_TRANSACTION))
#define PUBLISHING_PIWIGO_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_TRANSACTION, PublishingPiwigoTransactionClass))

typedef struct _PublishingPiwigoTransaction PublishingPiwigoTransaction;
typedef struct _PublishingPiwigoTransactionClass PublishingPiwigoTransactionClass;

#define PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION (publishing_piwigo_session_login_transaction_get_type ())
#define PUBLISHING_PIWIGO_SESSION_LOGIN_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION, PublishingPiwigoSessionLoginTransaction))
#define PUBLISHING_PIWIGO_SESSION_LOGIN_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION, PublishingPiwigoSessionLoginTransactionClass))
#define PUBLISHING_PIWIGO_IS_SESSION_LOGIN_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_SESSION_LOGIN_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION))
#define PUBLISHING_PIWIGO_SESSION_LOGIN_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION, PublishingPiwigoSessionLoginTransactionClass))

typedef struct _PublishingPiwigoSessionLoginTransaction PublishingPiwigoSessionLoginTransaction;
typedef struct _PublishingPiwigoSessionLoginTransactionClass PublishingPiwigoSessionLoginTransactionClass;

#define PUBLISHING_PIWIGO_TYPE_SSL_ERROR_PANE (publishing_piwigo_ssl_error_pane_get_type ())
#define PUBLISHING_PIWIGO_SSL_ERROR_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_SSL_ERROR_PANE, PublishingPiwigoSSLErrorPane))
#define PUBLISHING_PIWIGO_SSL_ERROR_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_SSL_ERROR_PANE, PublishingPiwigoSSLErrorPaneClass))
#define PUBLISHING_PIWIGO_IS_SSL_ERROR_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_SSL_ERROR_PANE))
#define PUBLISHING_PIWIGO_IS_SSL_ERROR_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_SSL_ERROR_PANE))
#define PUBLISHING_PIWIGO_SSL_ERROR_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_SSL_ERROR_PANE, PublishingPiwigoSSLErrorPaneClass))

typedef struct _PublishingPiwigoSSLErrorPane PublishingPiwigoSSLErrorPane;
typedef struct _PublishingPiwigoSSLErrorPaneClass PublishingPiwigoSSLErrorPaneClass;
#define __vala_SoupURI_free0(var) ((var == NULL) ? NULL : (var = (_vala_SoupURI_free (var), NULL)))
#define _publishing_rest_support_transaction_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_transaction_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _publishing_rest_support_xml_document_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_xml_document_unref (var), NULL)))

#define PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION (publishing_piwigo_session_get_status_transaction_get_type ())
#define PUBLISHING_PIWIGO_SESSION_GET_STATUS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION, PublishingPiwigoSessionGetStatusTransaction))
#define PUBLISHING_PIWIGO_SESSION_GET_STATUS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION, PublishingPiwigoSessionGetStatusTransactionClass))
#define PUBLISHING_PIWIGO_IS_SESSION_GET_STATUS_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_SESSION_GET_STATUS_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION))
#define PUBLISHING_PIWIGO_SESSION_GET_STATUS_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION, PublishingPiwigoSessionGetStatusTransactionClass))

typedef struct _PublishingPiwigoSessionGetStatusTransaction PublishingPiwigoSessionGetStatusTransaction;
typedef struct _PublishingPiwigoSessionGetStatusTransactionClass PublishingPiwigoSessionGetStatusTransactionClass;

#define PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION (publishing_piwigo_categories_get_list_transaction_get_type ())
#define PUBLISHING_PIWIGO_CATEGORIES_GET_LIST_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION, PublishingPiwigoCategoriesGetListTransaction))
#define PUBLISHING_PIWIGO_CATEGORIES_GET_LIST_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION, PublishingPiwigoCategoriesGetListTransactionClass))
#define PUBLISHING_PIWIGO_IS_CATEGORIES_GET_LIST_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_CATEGORIES_GET_LIST_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION))
#define PUBLISHING_PIWIGO_CATEGORIES_GET_LIST_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION, PublishingPiwigoCategoriesGetListTransactionClass))

typedef struct _PublishingPiwigoCategoriesGetListTransaction PublishingPiwigoCategoriesGetListTransaction;
typedef struct _PublishingPiwigoCategoriesGetListTransactionClass PublishingPiwigoCategoriesGetListTransactionClass;
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))

#define PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE (publishing_piwigo_publishing_options_pane_get_type ())
#define PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPane))
#define PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPaneClass))
#define PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE))
#define PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPaneClass))

typedef struct _PublishingPiwigoPublishingOptionsPane PublishingPiwigoPublishingOptionsPane;
typedef struct _PublishingPiwigoPublishingOptionsPaneClass PublishingPiwigoPublishingOptionsPaneClass;

#define PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION (publishing_piwigo_session_logout_transaction_get_type ())
#define PUBLISHING_PIWIGO_SESSION_LOGOUT_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION, PublishingPiwigoSessionLogoutTransaction))
#define PUBLISHING_PIWIGO_SESSION_LOGOUT_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION, PublishingPiwigoSessionLogoutTransactionClass))
#define PUBLISHING_PIWIGO_IS_SESSION_LOGOUT_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_SESSION_LOGOUT_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION))
#define PUBLISHING_PIWIGO_SESSION_LOGOUT_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION, PublishingPiwigoSessionLogoutTransactionClass))

typedef struct _PublishingPiwigoSessionLogoutTransaction PublishingPiwigoSessionLogoutTransaction;
typedef struct _PublishingPiwigoSessionLogoutTransactionClass PublishingPiwigoSessionLogoutTransactionClass;

#define PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION (publishing_piwigo_categories_add_transaction_get_type ())
#define PUBLISHING_PIWIGO_CATEGORIES_ADD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION, PublishingPiwigoCategoriesAddTransaction))
#define PUBLISHING_PIWIGO_CATEGORIES_ADD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION, PublishingPiwigoCategoriesAddTransactionClass))
#define PUBLISHING_PIWIGO_IS_CATEGORIES_ADD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_CATEGORIES_ADD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION))
#define PUBLISHING_PIWIGO_CATEGORIES_ADD_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION, PublishingPiwigoCategoriesAddTransactionClass))

typedef struct _PublishingPiwigoCategoriesAddTransaction PublishingPiwigoCategoriesAddTransaction;
typedef struct _PublishingPiwigoCategoriesAddTransactionClass PublishingPiwigoCategoriesAddTransactionClass;

#define PUBLISHING_PIWIGO_TYPE_UPLOADER (publishing_piwigo_uploader_get_type ())
#define PUBLISHING_PIWIGO_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_UPLOADER, PublishingPiwigoUploader))
#define PUBLISHING_PIWIGO_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_UPLOADER, PublishingPiwigoUploaderClass))
#define PUBLISHING_PIWIGO_IS_UPLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_UPLOADER))
#define PUBLISHING_PIWIGO_IS_UPLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_UPLOADER))
#define PUBLISHING_PIWIGO_UPLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_UPLOADER, PublishingPiwigoUploaderClass))

typedef struct _PublishingPiwigoUploader PublishingPiwigoUploader;
typedef struct _PublishingPiwigoUploaderClass PublishingPiwigoUploaderClass;
#define _publishing_rest_support_batch_uploader_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_batch_uploader_unref (var), NULL)))
#define __vala_SoupCookie_free0(var) ((var == NULL) ? NULL : (var = (_vala_SoupCookie_free (var), NULL)))
#define __g_slist_free___vala_SoupCookie_free0_0(var) ((var == NULL) ? NULL : (var = (_g_slist_free___vala_SoupCookie_free0_ (var), NULL)))
typedef struct _PublishingPiwigoUploaderPrivate PublishingPiwigoUploaderPrivate;

#define PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION (publishing_piwigo_images_add_transaction_get_type ())
#define PUBLISHING_PIWIGO_IMAGES_ADD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION, PublishingPiwigoImagesAddTransaction))
#define PUBLISHING_PIWIGO_IMAGES_ADD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION, PublishingPiwigoImagesAddTransactionClass))
#define PUBLISHING_PIWIGO_IS_IMAGES_ADD_TRANSACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION))
#define PUBLISHING_PIWIGO_IS_IMAGES_ADD_TRANSACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION))
#define PUBLISHING_PIWIGO_IMAGES_ADD_TRANSACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION, PublishingPiwigoImagesAddTransactionClass))

typedef struct _PublishingPiwigoImagesAddTransaction PublishingPiwigoImagesAddTransaction;
typedef struct _PublishingPiwigoImagesAddTransactionClass PublishingPiwigoImagesAddTransactionClass;
typedef struct _PublishingPiwigoSSLErrorPanePrivate PublishingPiwigoSSLErrorPanePrivate;
#define _g_byte_array_unref0(var) ((var == NULL) ? NULL : (var = (g_byte_array_unref (var), NULL)))
enum  {
	PUBLISHING_PIWIGO_SSL_ERROR_PANE_PROCEED_SIGNAL,
	PUBLISHING_PIWIGO_SSL_ERROR_PANE_LAST_SIGNAL
};
static guint publishing_piwigo_ssl_error_pane_signals[PUBLISHING_PIWIGO_SSL_ERROR_PANE_LAST_SIGNAL] = {0};
typedef struct _PublishingPiwigoAuthenticationPanePrivate PublishingPiwigoAuthenticationPanePrivate;
enum  {
	PUBLISHING_PIWIGO_AUTHENTICATION_PANE_LOGIN_SIGNAL,
	PUBLISHING_PIWIGO_AUTHENTICATION_PANE_LAST_SIGNAL
};
static guint publishing_piwigo_authentication_pane_signals[PUBLISHING_PIWIGO_AUTHENTICATION_PANE_LAST_SIGNAL] = {0};
typedef struct _PublishingPiwigoPublishingOptionsPanePrivate PublishingPiwigoPublishingOptionsPanePrivate;
enum  {
	PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL,
	PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL,
	PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_SIGNAL
};
static guint publishing_piwigo_publishing_options_pane_signals[PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_SIGNAL] = {0};
typedef struct _PublishingPiwigoSessionPrivate PublishingPiwigoSessionPrivate;
typedef struct _PublishingPiwigoTransactionPrivate PublishingPiwigoTransactionPrivate;
typedef struct _PublishingPiwigoSessionLoginTransactionPrivate PublishingPiwigoSessionLoginTransactionPrivate;
#define _publishing_rest_support_argument_unref0(var) ((var == NULL) ? NULL : (var = (publishing_rest_support_argument_unref (var), NULL)))
typedef struct _PublishingPiwigoSessionGetStatusTransactionPrivate PublishingPiwigoSessionGetStatusTransactionPrivate;
typedef struct _PublishingPiwigoCategoriesGetListTransactionPrivate PublishingPiwigoCategoriesGetListTransactionPrivate;
typedef struct _PublishingPiwigoSessionLogoutTransactionPrivate PublishingPiwigoSessionLogoutTransactionPrivate;
typedef struct _PublishingPiwigoCategoriesAddTransactionPrivate PublishingPiwigoCategoriesAddTransactionPrivate;
typedef struct _PublishingPiwigoImagesAddTransactionPrivate PublishingPiwigoImagesAddTransactionPrivate;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PiwigoService {
	GObject parent_instance;
	PiwigoServicePrivate * priv;
};

struct _PiwigoServiceClass {
	GObjectClass parent_class;
};

struct _PublishingPiwigoCategory {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingPiwigoCategoryPrivate * priv;
	gint id;
	gchar* name;
	gchar* comment;
	gchar* display_name;
	gchar* uppercats;
};

struct _PublishingPiwigoCategoryClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingPiwigoCategory *self);
};

struct _PublishingPiwigoParamSpecCategory {
	GParamSpec parent_instance;
};

struct _PublishingPiwigoPermissionLevel {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingPiwigoPermissionLevelPrivate * priv;
	gint id;
	gchar* name;
};

struct _PublishingPiwigoPermissionLevelClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingPiwigoPermissionLevel *self);
};

struct _PublishingPiwigoParamSpecPermissionLevel {
	GParamSpec parent_instance;
};

struct _PublishingPiwigoSizeEntry {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingPiwigoSizeEntryPrivate * priv;
	gint id;
	gchar* name;
};

struct _PublishingPiwigoSizeEntryClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingPiwigoSizeEntry *self);
};

struct _PublishingPiwigoParamSpecSizeEntry {
	GParamSpec parent_instance;
};

struct _PublishingPiwigoPublishingParameters {
	GTypeInstance parent_instance;
	volatile int ref_count;
	PublishingPiwigoPublishingParametersPrivate * priv;
	PublishingPiwigoCategory* category;
	PublishingPiwigoPermissionLevel* perm_level;
	PublishingPiwigoSizeEntry* photo_size;
	gboolean title_as_comment;
	gboolean no_upload_tags;
};

struct _PublishingPiwigoPublishingParametersClass {
	GTypeClass parent_class;
	void (*finalize) (PublishingPiwigoPublishingParameters *self);
};

struct _PublishingPiwigoParamSpecPublishingParameters {
	GParamSpec parent_instance;
};

struct _PublishingPiwigoPiwigoPublisher {
	GObject parent_instance;
	PublishingPiwigoPiwigoPublisherPrivate * priv;
};

struct _PublishingPiwigoPiwigoPublisherClass {
	GObjectClass parent_class;
};

struct _PublishingPiwigoPiwigoPublisherPrivate {
	SpitPublishingService* service;
	SpitPublishingPluginHost* host;
	gboolean running;
	gboolean strip_metadata;
	PublishingPiwigoSession* session;
	PublishingPiwigoCategory** categories;
	gint categories_length1;
	gint _categories_size_;
	PublishingPiwigoPublishingParameters* parameters;
	SpitPublishingProgressCallback progress_reporter;
	gpointer progress_reporter_target;
	GDestroyNotify progress_reporter_target_destroy_notify;
};

typedef enum  {
	PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_INTRO,
	PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_URL,
	PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER
} PublishingPiwigoAuthenticationPaneMode;

struct _PublishingPiwigoUploader {
	PublishingRESTSupportBatchUploader parent_instance;
	PublishingPiwigoUploaderPrivate * priv;
};

struct _PublishingPiwigoUploaderClass {
	PublishingRESTSupportBatchUploaderClass parent_class;
};

struct _PublishingPiwigoUploaderPrivate {
	PublishingPiwigoPublishingParameters* parameters;
};

struct _PublishingPiwigoSSLErrorPane {
	ShotwellPluginsCommonBuilderPane parent_instance;
	PublishingPiwigoSSLErrorPanePrivate * priv;
};

struct _PublishingPiwigoSSLErrorPaneClass {
	ShotwellPluginsCommonBuilderPaneClass parent_class;
};

struct _PublishingPiwigoSSLErrorPanePrivate {
	gchar* _host;
	GTlsCertificate* _cert;
	gchar* _error_text;
};

struct _PublishingPiwigoAuthenticationPane {
	ShotwellPluginsCommonBuilderPane parent_instance;
	PublishingPiwigoAuthenticationPanePrivate * priv;
};

struct _PublishingPiwigoAuthenticationPaneClass {
	ShotwellPluginsCommonBuilderPaneClass parent_class;
};

struct _PublishingPiwigoAuthenticationPanePrivate {
	PublishingPiwigoAuthenticationPaneMode _mode;
	PublishingPiwigoPiwigoPublisher* _publisher;
	GtkEntry* url_entry;
	GtkEntry* username_entry;
	GtkEntry* password_entry;
	GtkSwitch* remember_password_checkbutton;
	GtkButton* login_button;
};

struct _PublishingPiwigoPublishingOptionsPane {
	ShotwellPluginsCommonBuilderPane parent_instance;
	PublishingPiwigoPublishingOptionsPanePrivate * priv;
};

struct _PublishingPiwigoPublishingOptionsPaneClass {
	ShotwellPluginsCommonBuilderPaneClass parent_class;
};

struct _PublishingPiwigoPublishingOptionsPanePrivate {
	GtkRadioButton* use_existing_radio;
	GtkRadioButton* create_new_radio;
	GtkComboBoxText* existing_categories_combo;
	GtkEntry* new_category_entry;
	GtkLabel* within_existing_label;
	GtkComboBoxText* within_existing_combo;
	GtkComboBoxText* perms_combo;
	GtkComboBoxText* size_combo;
	GtkCheckButton* strip_metadata_check;
	GtkCheckButton* title_as_comment_check;
	GtkCheckButton* no_upload_tags_check;
	GtkButton* logout_button;
	GtkButton* publish_button;
	GtkTextView* album_comment;
	GtkLabel* album_comment_label;
	PublishingPiwigoPermissionLevel** perm_levels;
	gint perm_levels_length1;
	gint _perm_levels_size_;
	PublishingPiwigoSizeEntry** photo_sizes;
	gint photo_sizes_length1;
	gint _photo_sizes_size_;
	gint _last_category;
	gint _last_permission_level;
	gint _last_photo_size;
	gboolean _last_title_as_comment;
	gboolean _last_no_upload_tags;
	gboolean _strip_metadata_enabled;
	GeeList* _existing_categories;
	gchar* _default_comment;
};

struct _PublishingPiwigoSession {
	PublishingRESTSupportSession parent_instance;
	PublishingPiwigoSessionPrivate * priv;
};

struct _PublishingPiwigoSessionClass {
	PublishingRESTSupportSessionClass parent_class;
};

struct _PublishingPiwigoSessionPrivate {
	gchar* pwg_url;
	gchar* pwg_id;
	gchar* username;
};

struct _PublishingPiwigoTransaction {
	PublishingRESTSupportTransaction parent_instance;
	PublishingPiwigoTransactionPrivate * priv;
};

struct _PublishingPiwigoTransactionClass {
	PublishingRESTSupportTransactionClass parent_class;
};

struct _PublishingPiwigoSessionLoginTransaction {
	PublishingPiwigoTransaction parent_instance;
	PublishingPiwigoSessionLoginTransactionPrivate * priv;
};

struct _PublishingPiwigoSessionLoginTransactionClass {
	PublishingPiwigoTransactionClass parent_class;
};

struct _PublishingPiwigoSessionGetStatusTransaction {
	PublishingPiwigoTransaction parent_instance;
	PublishingPiwigoSessionGetStatusTransactionPrivate * priv;
};

struct _PublishingPiwigoSessionGetStatusTransactionClass {
	PublishingPiwigoTransactionClass parent_class;
};

struct _PublishingPiwigoCategoriesGetListTransaction {
	PublishingPiwigoTransaction parent_instance;
	PublishingPiwigoCategoriesGetListTransactionPrivate * priv;
};

struct _PublishingPiwigoCategoriesGetListTransactionClass {
	PublishingPiwigoTransactionClass parent_class;
};

struct _PublishingPiwigoSessionLogoutTransaction {
	PublishingPiwigoTransaction parent_instance;
	PublishingPiwigoSessionLogoutTransactionPrivate * priv;
};

struct _PublishingPiwigoSessionLogoutTransactionClass {
	PublishingPiwigoTransactionClass parent_class;
};

struct _PublishingPiwigoCategoriesAddTransaction {
	PublishingPiwigoTransaction parent_instance;
	PublishingPiwigoCategoriesAddTransactionPrivate * priv;
};

struct _PublishingPiwigoCategoriesAddTransactionClass {
	PublishingPiwigoTransactionClass parent_class;
};

struct _PublishingPiwigoImagesAddTransaction {
	PublishingRESTSupportUploadTransaction parent_instance;
	PublishingPiwigoImagesAddTransactionPrivate * priv;
};

struct _PublishingPiwigoImagesAddTransactionClass {
	PublishingRESTSupportUploadTransactionClass parent_class;
};

struct _PublishingPiwigoImagesAddTransactionPrivate {
	PublishingPiwigoPublishingParameters* parameters;
};


static gpointer piwigo_service_parent_class = NULL;
static GdkPixbuf** piwigo_service_icon_pixbuf_set;
static gint piwigo_service_icon_pixbuf_set_length1;
static GdkPixbuf** piwigo_service_icon_pixbuf_set = NULL;
static gint piwigo_service_icon_pixbuf_set_length1 = 0;
static gint _piwigo_service_icon_pixbuf_set_size_ = 0;
static SpitPluggableIface * piwigo_service_spit_pluggable_parent_iface = NULL;
static SpitPublishingServiceIface * piwigo_service_spit_publishing_service_parent_iface = NULL;
static gpointer publishing_piwigo_category_parent_class = NULL;
static gpointer publishing_piwigo_permission_level_parent_class = NULL;
static gpointer publishing_piwigo_size_entry_parent_class = NULL;
static gpointer publishing_piwigo_publishing_parameters_parent_class = NULL;
static gpointer publishing_piwigo_piwigo_publisher_parent_class = NULL;
static SpitPublishingPublisherIface * publishing_piwigo_piwigo_publisher_spit_publishing_publisher_parent_iface = NULL;
static gpointer publishing_piwigo_uploader_parent_class = NULL;
static gpointer publishing_piwigo_ssl_error_pane_parent_class = NULL;
static gpointer publishing_piwigo_authentication_pane_parent_class = NULL;
static gchar* publishing_piwigo_authentication_pane_INTRO_MESSAGE;
static gchar* publishing_piwigo_authentication_pane_INTRO_MESSAGE = NULL;
static gchar* publishing_piwigo_authentication_pane_FAILED_RETRY_URL_MESSAGE;
static gchar* publishing_piwigo_authentication_pane_FAILED_RETRY_URL_MESSAGE = NULL;
static gchar* publishing_piwigo_authentication_pane_FAILED_RETRY_USER_MESSAGE;
static gchar* publishing_piwigo_authentication_pane_FAILED_RETRY_USER_MESSAGE = NULL;
static gpointer publishing_piwigo_publishing_options_pane_parent_class = NULL;
static gchar* publishing_piwigo_publishing_options_pane_DEFAULT_CATEGORY_NAME;
static gchar* publishing_piwigo_publishing_options_pane_DEFAULT_CATEGORY_NAME = NULL;
static gpointer publishing_piwigo_session_parent_class = NULL;
static gpointer publishing_piwigo_transaction_parent_class = NULL;
static gpointer publishing_piwigo_session_login_transaction_parent_class = NULL;
static gpointer publishing_piwigo_session_get_status_transaction_parent_class = NULL;
static gpointer publishing_piwigo_categories_get_list_transaction_parent_class = NULL;
static gpointer publishing_piwigo_session_logout_transaction_parent_class = NULL;
static gpointer publishing_piwigo_categories_add_transaction_parent_class = NULL;
static gpointer publishing_piwigo_images_add_transaction_parent_class = NULL;

GType piwigo_service_get_type (void) G_GNUC_CONST;
enum  {
	PIWIGO_SERVICE_DUMMY_PROPERTY
};
#define PIWIGO_SERVICE_ICON_FILENAME "piwigo.png"
PiwigoService* piwigo_service_new (GFile* resource_directory);
PiwigoService* piwigo_service_construct (GType object_type, GFile* resource_directory);
static gint piwigo_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface);
static const gchar* piwigo_service_real_get_id (SpitPluggable* base);
static const gchar* piwigo_service_real_get_pluggable_name (SpitPluggable* base);
static void piwigo_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info);
static GdkPixbuf** _vala_array_dup10 (GdkPixbuf** self, int length);
static void piwigo_service_real_activation (SpitPluggable* base, gboolean enabled);
static SpitPublishingPublisher* piwigo_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host);
PublishingPiwigoPiwigoPublisher* publishing_piwigo_piwigo_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host);
PublishingPiwigoPiwigoPublisher* publishing_piwigo_piwigo_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host);
GType publishing_piwigo_piwigo_publisher_get_type (void) G_GNUC_CONST;
static SpitPublishingPublisherMediaType piwigo_service_real_get_supported_media (SpitPublishingService* base);
static void piwigo_service_finalize (GObject * obj);
#define PUBLISHING_PIWIGO_SERVICE_NAME "Piwigo"
#define PUBLISHING_PIWIGO_PIWIGO_WS "ws.php"
#define PUBLISHING_PIWIGO_ORIGINAL_SIZE -1
gpointer publishing_piwigo_category_ref (gpointer instance);
void publishing_piwigo_category_unref (gpointer instance);
GParamSpec* publishing_piwigo_param_spec_category (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_piwigo_value_set_category (GValue* value, gpointer v_object);
void publishing_piwigo_value_take_category (GValue* value, gpointer v_object);
gpointer publishing_piwigo_value_get_category (const GValue* value);
GType publishing_piwigo_category_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_PIWIGO_CATEGORY_DUMMY_PROPERTY
};
#define PUBLISHING_PIWIGO_CATEGORY_NO_ID -1
PublishingPiwigoCategory* publishing_piwigo_category_new (gint id, const gchar* name, const gchar* uppercats, const gchar* comment);
PublishingPiwigoCategory* publishing_piwigo_category_construct (GType object_type, gint id, const gchar* name, const gchar* uppercats, const gchar* comment);
PublishingPiwigoCategory* publishing_piwigo_category_new_local (const gchar* name, gint parent_id, const gchar* comment);
PublishingPiwigoCategory* publishing_piwigo_category_construct_local (GType object_type, const gchar* name, gint parent_id, const gchar* comment);
gboolean publishing_piwigo_category_is_local (PublishingPiwigoCategory* self);
gboolean publishing_piwigo_category_equal (PublishingPiwigoCategory* _self_, PublishingPiwigoCategory* other);
static void publishing_piwigo_category_finalize (PublishingPiwigoCategory * obj);
gpointer publishing_piwigo_permission_level_ref (gpointer instance);
void publishing_piwigo_permission_level_unref (gpointer instance);
GParamSpec* publishing_piwigo_param_spec_permission_level (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_piwigo_value_set_permission_level (GValue* value, gpointer v_object);
void publishing_piwigo_value_take_permission_level (GValue* value, gpointer v_object);
gpointer publishing_piwigo_value_get_permission_level (const GValue* value);
GType publishing_piwigo_permission_level_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_PIWIGO_PERMISSION_LEVEL_DUMMY_PROPERTY
};
PublishingPiwigoPermissionLevel* publishing_piwigo_permission_level_new (gint id, const gchar* name);
PublishingPiwigoPermissionLevel* publishing_piwigo_permission_level_construct (GType object_type, gint id, const gchar* name);
static void publishing_piwigo_permission_level_finalize (PublishingPiwigoPermissionLevel * obj);
gpointer publishing_piwigo_size_entry_ref (gpointer instance);
void publishing_piwigo_size_entry_unref (gpointer instance);
GParamSpec* publishing_piwigo_param_spec_size_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_piwigo_value_set_size_entry (GValue* value, gpointer v_object);
void publishing_piwigo_value_take_size_entry (GValue* value, gpointer v_object);
gpointer publishing_piwigo_value_get_size_entry (const GValue* value);
GType publishing_piwigo_size_entry_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_PIWIGO_SIZE_ENTRY_DUMMY_PROPERTY
};
PublishingPiwigoSizeEntry* publishing_piwigo_size_entry_new (gint id, const gchar* name);
PublishingPiwigoSizeEntry* publishing_piwigo_size_entry_construct (GType object_type, gint id, const gchar* name);
static void publishing_piwigo_size_entry_finalize (PublishingPiwigoSizeEntry * obj);
gpointer publishing_piwigo_publishing_parameters_ref (gpointer instance);
void publishing_piwigo_publishing_parameters_unref (gpointer instance);
GParamSpec* publishing_piwigo_param_spec_publishing_parameters (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void publishing_piwigo_value_set_publishing_parameters (GValue* value, gpointer v_object);
void publishing_piwigo_value_take_publishing_parameters (GValue* value, gpointer v_object);
gpointer publishing_piwigo_value_get_publishing_parameters (const GValue* value);
GType publishing_piwigo_publishing_parameters_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_DUMMY_PROPERTY
};
PublishingPiwigoPublishingParameters* publishing_piwigo_publishing_parameters_new (void);
PublishingPiwigoPublishingParameters* publishing_piwigo_publishing_parameters_construct (GType object_type);
static void publishing_piwigo_publishing_parameters_finalize (PublishingPiwigoPublishingParameters * obj);
GType publishing_piwigo_session_get_type (void) G_GNUC_CONST;
#define PUBLISHING_PIWIGO_PIWIGO_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisherPrivate))
enum  {
	PUBLISHING_PIWIGO_PIWIGO_PUBLISHER_DUMMY_PROPERTY
};
PublishingPiwigoSession* publishing_piwigo_session_new (void);
PublishingPiwigoSession* publishing_piwigo_session_construct (GType object_type);
static SpitPublishingService* publishing_piwigo_piwigo_publisher_real_get_service (SpitPublishingPublisher* base);
SpitPublishingPluginHost* publishing_piwigo_piwigo_publisher_get_host (PublishingPiwigoPiwigoPublisher* self);
static gboolean publishing_piwigo_piwigo_publisher_real_is_running (SpitPublishingPublisher* base);
static void publishing_piwigo_piwigo_publisher_real_start (SpitPublishingPublisher* base);
static void publishing_piwigo_piwigo_publisher_do_fetch_categories (PublishingPiwigoPiwigoPublisher* self);
gchar* publishing_piwigo_piwigo_publisher_get_persistent_url (PublishingPiwigoPiwigoPublisher* self);
gchar* publishing_piwigo_piwigo_publisher_get_persistent_username (PublishingPiwigoPiwigoPublisher* self);
gchar* publishing_piwigo_piwigo_publisher_get_persistent_password (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_do_network_login (PublishingPiwigoPiwigoPublisher* self, const gchar* url, const gchar* username, const gchar* password, gboolean remember_password);
gboolean publishing_piwigo_piwigo_publisher_get_remember_password (PublishingPiwigoPiwigoPublisher* self);
GType publishing_piwigo_authentication_pane_mode_get_type (void) G_GNUC_CONST;
static void publishing_piwigo_piwigo_publisher_do_show_authentication_pane (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoAuthenticationPaneMode mode);
static void publishing_piwigo_piwigo_publisher_real_stop (SpitPublishingPublisher* base);
static void publishing_piwigo_piwigo_publisher_set_persistent_url (PublishingPiwigoPiwigoPublisher* self, const gchar* url);
static void publishing_piwigo_piwigo_publisher_set_persistent_username (PublishingPiwigoPiwigoPublisher* self, const gchar* username);
static void publishing_piwigo_piwigo_publisher_set_persistent_password (PublishingPiwigoPiwigoPublisher* self, const gchar* password);
static void publishing_piwigo_piwigo_publisher_set_remember_password (PublishingPiwigoPiwigoPublisher* self, gboolean remember_password);
gint publishing_piwigo_piwigo_publisher_get_last_category (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_set_last_category (PublishingPiwigoPiwigoPublisher* self, gint last_category);
gint publishing_piwigo_piwigo_publisher_get_last_permission_level (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_set_last_permission_level (PublishingPiwigoPiwigoPublisher* self, gint last_permission_level);
gint publishing_piwigo_piwigo_publisher_get_last_photo_size (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_set_last_photo_size (PublishingPiwigoPiwigoPublisher* self, gint last_photo_size);
static gboolean publishing_piwigo_piwigo_publisher_get_last_title_as_comment (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_set_last_title_as_comment (PublishingPiwigoPiwigoPublisher* self, gboolean title_as_comment);
static gboolean publishing_piwigo_piwigo_publisher_get_last_no_upload_tags (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_set_last_no_upload_tags (PublishingPiwigoPiwigoPublisher* self, gboolean no_upload_tags);
static gboolean publishing_piwigo_piwigo_publisher_get_metadata_removal_choice (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_set_metadata_removal_choice (PublishingPiwigoPiwigoPublisher* self, gboolean strip_metadata);
GType publishing_piwigo_authentication_pane_get_type (void) G_GNUC_CONST;
PublishingPiwigoAuthenticationPane* publishing_piwigo_authentication_pane_new (PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoAuthenticationPaneMode mode);
PublishingPiwigoAuthenticationPane* publishing_piwigo_authentication_pane_construct (GType object_type, PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoAuthenticationPaneMode mode);
static void publishing_piwigo_piwigo_publisher_on_authentication_pane_login_clicked (PublishingPiwigoPiwigoPublisher* self, const gchar* url, const gchar* username, const gchar* password, gboolean remember_password);
static void _publishing_piwigo_piwigo_publisher_on_authentication_pane_login_clicked_publishing_piwigo_authentication_pane_login (PublishingPiwigoAuthenticationPane* _sender, const gchar* url, const gchar* user, const gchar* password, gboolean remember_password, gpointer self);
GType publishing_piwigo_transaction_get_type (void) G_GNUC_CONST;
GType publishing_piwigo_session_login_transaction_get_type (void) G_GNUC_CONST;
static void publishing_piwigo_piwigo_publisher_do_show_ssl_downgrade_pane (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoSessionLoginTransaction* trans, const gchar* url);
GType publishing_piwigo_ssl_error_pane_get_type (void) G_GNUC_CONST;
PublishingPiwigoSSLErrorPane* publishing_piwigo_ssl_error_pane_new (PublishingPiwigoSessionLoginTransaction* transaction, const gchar* host);
PublishingPiwigoSSLErrorPane* publishing_piwigo_ssl_error_pane_construct (GType object_type, PublishingPiwigoSessionLoginTransaction* transaction, const gchar* host);
static void __lambda7_ (PublishingPiwigoPiwigoPublisher* self);
static void ___lambda7__publishing_piwigo_ssl_error_pane_proceed (PublishingPiwigoSSLErrorPane* _sender, gpointer self);
static void _vala_SoupURI_free (SoupURI* self);
gchar* publishing_piwigo_piwigo_publisher_normalise_url (const gchar* url);
PublishingPiwigoSessionLoginTransaction* publishing_piwigo_session_login_transaction_new (PublishingPiwigoSession* session, const gchar* url, const gchar* username, const gchar* password);
PublishingPiwigoSessionLoginTransaction* publishing_piwigo_session_login_transaction_construct (GType object_type, PublishingPiwigoSession* session, const gchar* url, const gchar* username, const gchar* password);
static void publishing_piwigo_piwigo_publisher_on_login_network_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_piwigo_piwigo_publisher_on_login_network_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_login_network_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_piwigo_piwigo_publisher_on_login_network_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void publishing_piwigo_piwigo_publisher_do_show_error (PublishingPiwigoPiwigoPublisher* self, GError* e);
gchar* publishing_piwigo_transaction_validate_xml (PublishingRESTSupportXmlDocument* doc);
static gchar* _publishing_piwigo_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc, gpointer self);
gchar* publishing_piwigo_transaction_get_error_code (PublishingRESTSupportXmlDocument* doc);
static gchar* _publishing_piwigo_transaction_get_error_code_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc, gpointer self);
static gchar* publishing_piwigo_piwigo_publisher_get_pwg_id_from_transaction (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn);
void publishing_piwigo_session_set_pwg_id (PublishingPiwigoSession* self, const gchar* id);
static void publishing_piwigo_piwigo_publisher_do_fetch_session_status (PublishingPiwigoPiwigoPublisher* self, const gchar* url, const gchar* pwg_id);
GType publishing_piwigo_session_get_status_transaction_get_type (void) G_GNUC_CONST;
PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_new_unauthenticated (PublishingPiwigoSession* session, const gchar* url, const gchar* pwg_id);
PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_construct_unauthenticated (GType object_type, PublishingPiwigoSession* session, const gchar* url, const gchar* pwg_id);
static void publishing_piwigo_piwigo_publisher_on_session_get_status_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_piwigo_piwigo_publisher_on_session_get_status_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_session_get_status_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_piwigo_piwigo_publisher_on_session_get_status_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_new (PublishingPiwigoSession* session);
PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_construct (GType object_type, PublishingPiwigoSession* session);
gchar* publishing_piwigo_session_get_pwg_id (PublishingPiwigoSession* self);
void publishing_piwigo_session_authenticate (PublishingPiwigoSession* self, const gchar* url, const gchar* username, const gchar* id);
gchar* publishing_piwigo_session_get_pwg_url (PublishingPiwigoSession* self);
gchar* publishing_piwigo_session_get_username (PublishingPiwigoSession* self);
static void publishing_piwigo_piwigo_publisher_on_network_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
GType publishing_piwigo_categories_get_list_transaction_get_type (void) G_GNUC_CONST;
PublishingPiwigoCategoriesGetListTransaction* publishing_piwigo_categories_get_list_transaction_new (PublishingPiwigoSession* session);
PublishingPiwigoCategoriesGetListTransaction* publishing_piwigo_categories_get_list_transaction_construct (GType object_type, PublishingPiwigoSession* session);
static void publishing_piwigo_piwigo_publisher_on_category_fetch_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_piwigo_piwigo_publisher_on_category_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_category_fetch_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_piwigo_piwigo_publisher_on_category_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
static void _vala_array_add35 (PublishingPiwigoCategory** * array, int* length, int* size, PublishingPiwigoCategory* value);
static void publishing_piwigo_piwigo_publisher_do_show_publishing_options_pane (PublishingPiwigoPiwigoPublisher* self);
GType publishing_piwigo_publishing_options_pane_get_type (void) G_GNUC_CONST;
PublishingPiwigoPublishingOptionsPane* publishing_piwigo_publishing_options_pane_new (PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoCategory** categories, int categories_length1, gint last_category, gint last_permission_level, gint last_photo_size, gboolean last_title_as_comment, gboolean last_no_upload_tags, gboolean strip_metadata_enabled);
PublishingPiwigoPublishingOptionsPane* publishing_piwigo_publishing_options_pane_construct (GType object_type, PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoCategory** categories, int categories_length1, gint last_category, gint last_permission_level, gint last_photo_size, gboolean last_title_as_comment, gboolean last_no_upload_tags, gboolean strip_metadata_enabled);
static void publishing_piwigo_piwigo_publisher_on_publishing_options_pane_logout_clicked (PublishingPiwigoPiwigoPublisher* self);
static void _publishing_piwigo_piwigo_publisher_on_publishing_options_pane_logout_clicked_publishing_piwigo_publishing_options_pane_logout (PublishingPiwigoPublishingOptionsPane* _sender, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_publishing_options_pane_publish_clicked (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoPublishingParameters* parameters, gboolean strip_metadata);
static void _publishing_piwigo_piwigo_publisher_on_publishing_options_pane_publish_clicked_publishing_piwigo_publishing_options_pane_publish (PublishingPiwigoPublishingOptionsPane* _sender, PublishingPiwigoPublishingParameters* parameters, gboolean strip_metadata, gpointer self);
GType publishing_piwigo_session_logout_transaction_get_type (void) G_GNUC_CONST;
PublishingPiwigoSessionLogoutTransaction* publishing_piwigo_session_logout_transaction_new (PublishingPiwigoSession* session);
PublishingPiwigoSessionLogoutTransaction* publishing_piwigo_session_logout_transaction_construct (GType object_type, PublishingPiwigoSession* session);
static void publishing_piwigo_piwigo_publisher_on_logout_network_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_piwigo_piwigo_publisher_on_logout_network_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_logout_network_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_piwigo_piwigo_publisher_on_logout_network_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
void publishing_piwigo_session_deauthenticate (PublishingPiwigoSession* self);
static void publishing_piwigo_piwigo_publisher_do_create_category (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoCategory* category);
static void publishing_piwigo_piwigo_publisher_do_upload (PublishingPiwigoPiwigoPublisher* self, gboolean strip_metadata);
GType publishing_piwigo_categories_add_transaction_get_type (void) G_GNUC_CONST;
PublishingPiwigoCategoriesAddTransaction* publishing_piwigo_categories_add_transaction_new (PublishingPiwigoSession* session, const gchar* category, gint parent_id, const gchar* comment);
PublishingPiwigoCategoriesAddTransaction* publishing_piwigo_categories_add_transaction_construct (GType object_type, PublishingPiwigoSession* session, const gchar* category, gint parent_id, const gchar* comment);
static void publishing_piwigo_piwigo_publisher_on_category_add_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err);
static void _publishing_piwigo_piwigo_publisher_on_category_add_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_category_add_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn);
static void _publishing_piwigo_piwigo_publisher_on_category_add_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self);
GType publishing_piwigo_uploader_get_type (void) G_GNUC_CONST;
PublishingPiwigoUploader* publishing_piwigo_uploader_new (PublishingPiwigoSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingPiwigoPublishingParameters* parameters);
PublishingPiwigoUploader* publishing_piwigo_uploader_construct (GType object_type, PublishingPiwigoSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingPiwigoPublishingParameters* parameters);
static void publishing_piwigo_piwigo_publisher_on_upload_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportBatchUploader* uploader, gint num_published);
static void _publishing_piwigo_piwigo_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender, gint num_photos_published, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_upload_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportBatchUploader* uploader, GError* err);
static void _publishing_piwigo_piwigo_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender, GError* err, gpointer self);
static void publishing_piwigo_piwigo_publisher_on_upload_status_updated (PublishingPiwigoPiwigoPublisher* self, gint file_number, gdouble completed_fraction);
static void _publishing_piwigo_piwigo_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self);
static void publishing_piwigo_piwigo_publisher_do_show_success_pane (PublishingPiwigoPiwigoPublisher* self);
static void publishing_piwigo_piwigo_publisher_do_show_error_message (PublishingPiwigoPiwigoPublisher* self, const gchar* message);
static SoupCookie* _vala_SoupCookie_copy (SoupCookie* self);
static void _vala_SoupCookie_free (SoupCookie* self);
static void __vala_SoupCookie_free0_ (gpointer var);
static void _g_slist_free___vala_SoupCookie_free0_ (GSList* self);
static void publishing_piwigo_piwigo_publisher_finalize (GObject * obj);
#define PUBLISHING_PIWIGO_UPLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PIWIGO_TYPE_UPLOADER, PublishingPiwigoUploaderPrivate))
enum  {
	PUBLISHING_PIWIGO_UPLOADER_DUMMY_PROPERTY
};
static PublishingRESTSupportTransaction* publishing_piwigo_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base, SpitPublishingPublishable* publishable);
PublishingPiwigoImagesAddTransaction* publishing_piwigo_images_add_transaction_new (PublishingPiwigoSession* session, PublishingPiwigoPublishingParameters* parameters, SpitPublishingPublishable* publishable);
PublishingPiwigoImagesAddTransaction* publishing_piwigo_images_add_transaction_construct (GType object_type, PublishingPiwigoSession* session, PublishingPiwigoPublishingParameters* parameters, SpitPublishingPublishable* publishable);
GType publishing_piwigo_images_add_transaction_get_type (void) G_GNUC_CONST;
static void publishing_piwigo_uploader_finalize (PublishingRESTSupportBatchUploader * obj);
#define PUBLISHING_PIWIGO_SSL_ERROR_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PIWIGO_TYPE_SSL_ERROR_PANE, PublishingPiwigoSSLErrorPanePrivate))
enum  {
	PUBLISHING_PIWIGO_SSL_ERROR_PANE_DUMMY_PROPERTY,
	PUBLISHING_PIWIGO_SSL_ERROR_PANE_HOST_PROPERTY,
	PUBLISHING_PIWIGO_SSL_ERROR_PANE_CERT_PROPERTY,
	PUBLISHING_PIWIGO_SSL_ERROR_PANE_ERROR_TEXT_PROPERTY
};
static void publishing_piwigo_ssl_error_pane_real_constructed (GObject* base);
gchar* publishing_piwigo_ssl_error_pane_get_host (PublishingPiwigoSSLErrorPane* self);
gchar* publishing_piwigo_ssl_error_pane_get_error_text (PublishingPiwigoSSLErrorPane* self);
static void __lambda5_ (PublishingPiwigoSSLErrorPane* self);
static GTlsCertificate* publishing_piwigo_ssl_error_pane_get_cert (PublishingPiwigoSSLErrorPane* self);
static void ___lambda5__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda6_ (PublishingPiwigoSSLErrorPane* self);
static void ___lambda6__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_piwigo_ssl_error_pane_set_host (PublishingPiwigoSSLErrorPane* self, const gchar* value);
static void publishing_piwigo_ssl_error_pane_set_cert (PublishingPiwigoSSLErrorPane* self, GTlsCertificate* value);
static void publishing_piwigo_ssl_error_pane_set_error_text (PublishingPiwigoSSLErrorPane* self, const gchar* value);
static void publishing_piwigo_ssl_error_pane_finalize (GObject * obj);
static void _vala_publishing_piwigo_ssl_error_pane_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_publishing_piwigo_ssl_error_pane_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define PUBLISHING_PIWIGO_AUTHENTICATION_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPanePrivate))
enum  {
	PUBLISHING_PIWIGO_AUTHENTICATION_PANE_DUMMY_PROPERTY,
	PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_PROPERTY,
	PUBLISHING_PIWIGO_AUTHENTICATION_PANE_PUBLISHER_PROPERTY
};
static void publishing_piwigo_authentication_pane_real_constructed (GObject* base);
PublishingPiwigoAuthenticationPaneMode publishing_piwigo_authentication_pane_get_mode (PublishingPiwigoAuthenticationPane* self);
PublishingPiwigoPiwigoPublisher* publishing_piwigo_authentication_pane_get_publisher (PublishingPiwigoAuthenticationPane* self);
static void publishing_piwigo_authentication_pane_on_user_changed (PublishingPiwigoAuthenticationPane* self);
static void _publishing_piwigo_authentication_pane_on_user_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_piwigo_authentication_pane_on_url_changed (PublishingPiwigoAuthenticationPane* self);
static void _publishing_piwigo_authentication_pane_on_url_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_piwigo_authentication_pane_on_password_changed (PublishingPiwigoAuthenticationPane* self);
static void _publishing_piwigo_authentication_pane_on_password_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_piwigo_authentication_pane_on_login_button_clicked (PublishingPiwigoAuthenticationPane* self);
static void _publishing_piwigo_authentication_pane_on_login_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_piwigo_authentication_pane_update_login_button_sensitivity (PublishingPiwigoAuthenticationPane* self);
static void publishing_piwigo_authentication_pane_real_on_pane_installed (ShotwellPluginsCommonBuilderPane* base);
static void publishing_piwigo_authentication_pane_set_mode (PublishingPiwigoAuthenticationPane* self, PublishingPiwigoAuthenticationPaneMode value);
static void publishing_piwigo_authentication_pane_set_publisher (PublishingPiwigoAuthenticationPane* self, PublishingPiwigoPiwigoPublisher* value);
static void g_cclosure_user_marshal_VOID__STRING_STRING_STRING_BOOLEAN (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void publishing_piwigo_authentication_pane_finalize (GObject * obj);
static void _vala_publishing_piwigo_authentication_pane_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_publishing_piwigo_authentication_pane_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPanePrivate))
enum  {
	PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_DUMMY_PROPERTY,
	PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_CATEGORY_PROPERTY,
	PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_PERMISSION_LEVEL_PROPERTY,
	PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_PHOTO_SIZE_PROPERTY,
	PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_TITLE_AS_COMMENT_PROPERTY,
	PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_NO_UPLOAD_TAGS_PROPERTY,
	PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_STRIP_METADATA_ENABLED_PROPERTY,
	PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_EXISTING_CATEGORIES_PROPERTY,
	PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_DEFAULT_COMMENT_PROPERTY
};
static PublishingPiwigoCategory** _vala_array_dup11 (PublishingPiwigoCategory** self, int length);
static gboolean _publishing_piwigo_category_equal_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static gchar* publishing_piwigo_publishing_options_pane_get_common_comment_if_possible (PublishingPiwigoPiwigoPublisher* publisher);
static void publishing_piwigo_publishing_options_pane_real_constructed (GObject* base);
static gboolean publishing_piwigo_publishing_options_pane_get_strip_metadata_enabled (PublishingPiwigoPublishingOptionsPane* self);
static gboolean publishing_piwigo_publishing_options_pane_get_last_title_as_comment (PublishingPiwigoPublishingOptionsPane* self);
static gboolean publishing_piwigo_publishing_options_pane_get_last_no_upload_tags (PublishingPiwigoPublishingOptionsPane* self);
static void publishing_piwigo_publishing_options_pane_on_logout_button_clicked (PublishingPiwigoPublishingOptionsPane* self);
static void _publishing_piwigo_publishing_options_pane_on_logout_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_piwigo_publishing_options_pane_on_publish_button_clicked (PublishingPiwigoPublishingOptionsPane* self);
static void _publishing_piwigo_publishing_options_pane_on_publish_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_piwigo_publishing_options_pane_on_use_existing_radio_clicked (PublishingPiwigoPublishingOptionsPane* self);
static void _publishing_piwigo_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_piwigo_publishing_options_pane_on_create_new_radio_clicked (PublishingPiwigoPublishingOptionsPane* self);
static void _publishing_piwigo_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_piwigo_publishing_options_pane_on_new_category_entry_changed (PublishingPiwigoPublishingOptionsPane* self);
static void _publishing_piwigo_publishing_options_pane_on_new_category_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self);
static void publishing_piwigo_publishing_options_pane_on_existing_combo_changed (PublishingPiwigoPublishingOptionsPane* self);
static void _publishing_piwigo_publishing_options_pane_on_existing_combo_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static PublishingPiwigoPermissionLevel** publishing_piwigo_publishing_options_pane_create_perm_levels (PublishingPiwigoPublishingOptionsPane* self, int* result_length1);
static PublishingPiwigoSizeEntry** publishing_piwigo_publishing_options_pane_create_sizes (PublishingPiwigoPublishingOptionsPane* self, int* result_length1);
static const gchar* publishing_piwigo_publishing_options_pane_get_default_comment (PublishingPiwigoPublishingOptionsPane* self);
static void _vala_array_add36 (PublishingPiwigoPermissionLevel** * array, int* length, int* size, PublishingPiwigoPermissionLevel* value);
static void _vala_array_add37 (PublishingPiwigoPermissionLevel** * array, int* length, int* size, PublishingPiwigoPermissionLevel* value);
static void _vala_array_add38 (PublishingPiwigoPermissionLevel** * array, int* length, int* size, PublishingPiwigoPermissionLevel* value);
static void _vala_array_add39 (PublishingPiwigoPermissionLevel** * array, int* length, int* size, PublishingPiwigoPermissionLevel* value);
static void _vala_array_add40 (PublishingPiwigoPermissionLevel** * array, int* length, int* size, PublishingPiwigoPermissionLevel* value);
static void _vala_array_add41 (PublishingPiwigoSizeEntry** * array, int* length, int* size, PublishingPiwigoSizeEntry* value);
static void _vala_array_add42 (PublishingPiwigoSizeEntry** * array, int* length, int* size, PublishingPiwigoSizeEntry* value);
static void _vala_array_add43 (PublishingPiwigoSizeEntry** * array, int* length, int* size, PublishingPiwigoSizeEntry* value);
static void _vala_array_add44 (PublishingPiwigoSizeEntry** * array, int* length, int* size, PublishingPiwigoSizeEntry* value);
static void _vala_array_add45 (PublishingPiwigoSizeEntry** * array, int* length, int* size, PublishingPiwigoSizeEntry* value);
static GeeList* publishing_piwigo_publishing_options_pane_get_existing_categories (PublishingPiwigoPublishingOptionsPane* self);
static void publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (PublishingPiwigoPublishingOptionsPane* self);
static gboolean publishing_piwigo_publishing_options_pane_category_already_exists (PublishingPiwigoPublishingOptionsPane* self, const gchar* category_name);
static void publishing_piwigo_publishing_options_pane_real_on_pane_installed (ShotwellPluginsCommonBuilderPane* base);
static void publishing_piwigo_publishing_options_pane_create_categories_combo (PublishingPiwigoPublishingOptionsPane* self);
static void publishing_piwigo_publishing_options_pane_create_within_categories_combo (PublishingPiwigoPublishingOptionsPane* self);
static void publishing_piwigo_publishing_options_pane_create_permissions_combo (PublishingPiwigoPublishingOptionsPane* self);
static void publishing_piwigo_publishing_options_pane_create_size_combo (PublishingPiwigoPublishingOptionsPane* self);
static gint publishing_piwigo_publishing_options_pane_find_category_index (PublishingPiwigoPublishingOptionsPane* self, gint category_id);
static gint publishing_piwigo_publishing_options_pane_get_last_category (PublishingPiwigoPublishingOptionsPane* self);
static gint publishing_piwigo_publishing_options_pane_find_permission_level_index (PublishingPiwigoPublishingOptionsPane* self, gint permission_level_id);
static gint publishing_piwigo_publishing_options_pane_get_last_permission_level (PublishingPiwigoPublishingOptionsPane* self);
static gint publishing_piwigo_publishing_options_pane_find_size_index (PublishingPiwigoPublishingOptionsPane* self, gint size_id);
static gint publishing_piwigo_publishing_options_pane_get_last_photo_size (PublishingPiwigoPublishingOptionsPane* self);
static void publishing_piwigo_publishing_options_pane_set_last_category (PublishingPiwigoPublishingOptionsPane* self, gint value);
static void publishing_piwigo_publishing_options_pane_set_last_permission_level (PublishingPiwigoPublishingOptionsPane* self, gint value);
static void publishing_piwigo_publishing_options_pane_set_last_photo_size (PublishingPiwigoPublishingOptionsPane* self, gint value);
static void publishing_piwigo_publishing_options_pane_set_last_title_as_comment (PublishingPiwigoPublishingOptionsPane* self, gboolean value);
static void publishing_piwigo_publishing_options_pane_set_last_no_upload_tags (PublishingPiwigoPublishingOptionsPane* self, gboolean value);
static void publishing_piwigo_publishing_options_pane_set_strip_metadata_enabled (PublishingPiwigoPublishingOptionsPane* self, gboolean value);
static void publishing_piwigo_publishing_options_pane_set_existing_categories (PublishingPiwigoPublishingOptionsPane* self, GeeList* value);
static void publishing_piwigo_publishing_options_pane_set_default_comment (PublishingPiwigoPublishingOptionsPane* self, const gchar* value);
static void g_cclosure_user_marshal_VOID__PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_BOOLEAN (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void publishing_piwigo_publishing_options_pane_finalize (GObject * obj);
static void _vala_publishing_piwigo_publishing_options_pane_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_publishing_piwigo_publishing_options_pane_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define PUBLISHING_PIWIGO_SESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSessionPrivate))
enum  {
	PUBLISHING_PIWIGO_SESSION_DUMMY_PROPERTY
};
static gboolean publishing_piwigo_session_real_is_authenticated (PublishingRESTSupportSession* base);
static void publishing_piwigo_session_finalize (PublishingRESTSupportSession * obj);
enum  {
	PUBLISHING_PIWIGO_TRANSACTION_DUMMY_PROPERTY
};
PublishingPiwigoTransaction* publishing_piwigo_transaction_new (PublishingPiwigoSession* session);
PublishingPiwigoTransaction* publishing_piwigo_transaction_construct (GType object_type, PublishingPiwigoSession* session);
PublishingPiwigoTransaction* publishing_piwigo_transaction_new_authenticated (PublishingPiwigoSession* session);
PublishingPiwigoTransaction* publishing_piwigo_transaction_construct_authenticated (GType object_type, PublishingPiwigoSession* session);
enum  {
	PUBLISHING_PIWIGO_SESSION_LOGIN_TRANSACTION_DUMMY_PROPERTY
};
PublishingPiwigoSessionLoginTransaction* publishing_piwigo_session_login_transaction_new_from_other (PublishingPiwigoSession* session, PublishingPiwigoTransaction* other);
PublishingPiwigoSessionLoginTransaction* publishing_piwigo_session_login_transaction_construct_from_other (GType object_type, PublishingPiwigoSession* session, PublishingPiwigoTransaction* other);
enum  {
	PUBLISHING_PIWIGO_SESSION_GET_STATUS_TRANSACTION_DUMMY_PROPERTY
};
enum  {
	PUBLISHING_PIWIGO_CATEGORIES_GET_LIST_TRANSACTION_DUMMY_PROPERTY
};
enum  {
	PUBLISHING_PIWIGO_SESSION_LOGOUT_TRANSACTION_DUMMY_PROPERTY
};
enum  {
	PUBLISHING_PIWIGO_CATEGORIES_ADD_TRANSACTION_DUMMY_PROPERTY
};
#define PUBLISHING_PIWIGO_IMAGES_ADD_TRANSACTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION, PublishingPiwigoImagesAddTransactionPrivate))
enum  {
	PUBLISHING_PIWIGO_IMAGES_ADD_TRANSACTION_DUMMY_PROPERTY
};
static void _g_free0_ (gpointer var);
static void publishing_piwigo_images_add_transaction_finalize (PublishingRESTSupportTransaction * obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


PiwigoService* piwigo_service_construct (GType object_type, GFile* resource_directory) {
	PiwigoService * self = NULL;
	GdkPixbuf** _tmp0_;
	gint _tmp0__length1;
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (G_IS_FILE (resource_directory), NULL);
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PiwigoService*) g_object_new (object_type, NULL);
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = piwigo_service_icon_pixbuf_set;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0__length1 = piwigo_service_icon_pixbuf_set_length1;
#line 13 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp0_ == NULL) {
#line 979 "PiwigoPublishing.c"
		gint _tmp1_;
		GdkPixbuf** _tmp2_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp2_ = resources_load_from_resource (PLUGIN_RESOURCE_PATH "/" PIWIGO_SERVICE_ICON_FILENAME, &_tmp1_);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		piwigo_service_icon_pixbuf_set = (_vala_array_free (piwigo_service_icon_pixbuf_set, piwigo_service_icon_pixbuf_set_length1, (GDestroyNotify) g_object_unref), NULL);
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		piwigo_service_icon_pixbuf_set = _tmp2_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		piwigo_service_icon_pixbuf_set_length1 = _tmp1_;
#line 14 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_piwigo_service_icon_pixbuf_set_size_ = piwigo_service_icon_pixbuf_set_length1;
#line 992 "PiwigoPublishing.c"
	}
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 996 "PiwigoPublishing.c"
}


PiwigoService* piwigo_service_new (GFile* resource_directory) {
#line 12 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return piwigo_service_construct (TYPE_PIWIGO_SERVICE, resource_directory);
#line 1003 "PiwigoPublishing.c"
}


static gint piwigo_service_real_get_pluggable_interface (SpitPluggable* base, gint min_host_interface, gint max_host_interface) {
	PiwigoService * self;
	gint result = 0;
	gint _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
#line 18 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = min_host_interface;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = max_host_interface;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = spit_negotiate_interfaces (_tmp0_, _tmp1_, SPIT_PUBLISHING_CURRENT_INTERFACE);
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp2_;
#line 19 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 1025 "PiwigoPublishing.c"
}


static const gchar* piwigo_service_real_get_id (SpitPluggable* base) {
	PiwigoService * self;
	const gchar* result = NULL;
#line 23 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = "org.yorba.shotwell.publishing.piwigo";
#line 24 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 1038 "PiwigoPublishing.c"
}


static const gchar* piwigo_service_real_get_pluggable_name (SpitPluggable* base) {
	PiwigoService * self;
	const gchar* result = NULL;
#line 27 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = "Piwigo";
#line 28 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 1051 "PiwigoPublishing.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self ? g_object_ref (self) : NULL;
#line 1058 "PiwigoPublishing.c"
}


static GdkPixbuf** _vala_array_dup10 (GdkPixbuf** self, int length) {
	GdkPixbuf** result;
	int i;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = g_new0 (GdkPixbuf*, length + 1);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	for (i = 0; i < length; i++) {
#line 1069 "PiwigoPublishing.c"
		GdkPixbuf* _tmp0_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = _g_object_ref0 (self[i]);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		result[i] = _tmp0_;
#line 1075 "PiwigoPublishing.c"
	}
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 1079 "PiwigoPublishing.c"
}


static void piwigo_service_real_get_info (SpitPluggable* base, SpitPluggableInfo* info) {
	PiwigoService * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	GdkPixbuf** _tmp7_;
	gint _tmp7__length1;
	GdkPixbuf** _tmp8_;
	gint _tmp8__length1;
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 31 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (info != NULL);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = g_strdup ("Bruno Girin");
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).authors);
#line 32 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).authors = _tmp0_;
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_ ("Copyright 2016 Software Freedom Conservancy Inc."));
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).copyright);
#line 33 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).copyright = _tmp1_;
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = g_strdup (RESOURCES_TRANSLATORS);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).translators);
#line 34 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).translators = _tmp2_;
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = g_strdup (_VERSION);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).version);
#line 35 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).version = _tmp3_;
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = g_strdup (RESOURCES_WEBSITE_NAME);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).website_name);
#line 36 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).website_name = _tmp4_;
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = g_strdup (RESOURCES_WEBSITE_URL);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).website_url);
#line 37 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).website_url = _tmp5_;
#line 38 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).is_license_wordwrapped = FALSE;
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = g_strdup (RESOURCES_LICENSE);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 ((*info).license);
#line 39 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).license = _tmp6_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = piwigo_service_icon_pixbuf_set;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7__length1 = piwigo_service_icon_pixbuf_set_length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = (_tmp7_ != NULL) ? _vala_array_dup10 (_tmp7_, _tmp7__length1) : ((gpointer) _tmp7_);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8__length1 = _tmp7__length1;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).icons = (_vala_array_free ((*info).icons, (*info).icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).icons = _tmp8_;
#line 40 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*info).icons_length1 = _tmp8__length1;
#line 1158 "PiwigoPublishing.c"
}


static void piwigo_service_real_activation (SpitPluggable* base, gboolean enabled) {
	PiwigoService * self;
#line 43 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 1166 "PiwigoPublishing.c"
}


static SpitPublishingPublisher* piwigo_service_real_create_publisher (SpitPublishingService* base, SpitPublishingPluginHost* host) {
	PiwigoService * self;
	SpitPublishingPublisher* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	PublishingPiwigoPiwigoPublisher* _tmp1_;
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 46 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = host;
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishing_piwigo_piwigo_publisher_new (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_SERVICE, SpitPublishingService), _tmp0_);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher);
#line 47 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 1187 "PiwigoPublishing.c"
}


static SpitPublishingPublisherMediaType piwigo_service_real_get_supported_media (SpitPublishingService* base) {
	PiwigoService * self;
	SpitPublishingPublisherMediaType result = 0;
#line 50 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO;
#line 51 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 1200 "PiwigoPublishing.c"
}


static void piwigo_service_class_init (PiwigoServiceClass * klass) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	piwigo_service_parent_class = g_type_class_peek_parent (klass);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = piwigo_service_finalize;
#line 1209 "PiwigoPublishing.c"
}


static void piwigo_service_spit_pluggable_interface_init (SpitPluggableIface * iface) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	piwigo_service_spit_pluggable_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_pluggable_interface = (gint (*) (SpitPluggable *, gint, gint)) piwigo_service_real_get_pluggable_interface;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_id = (const gchar* (*) (SpitPluggable *)) piwigo_service_real_get_id;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_pluggable_name = (const gchar* (*) (SpitPluggable *)) piwigo_service_real_get_pluggable_name;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_info = (void (*) (SpitPluggable *, SpitPluggableInfo*)) piwigo_service_real_get_info;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->activation = (void (*) (SpitPluggable *, gboolean)) piwigo_service_real_activation;
#line 1226 "PiwigoPublishing.c"
}


static void piwigo_service_spit_publishing_service_interface_init (SpitPublishingServiceIface * iface) {
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	piwigo_service_spit_publishing_service_parent_iface = g_type_interface_peek_parent (iface);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->create_publisher = (SpitPublishingPublisher* (*) (SpitPublishingService *, SpitPublishingPluginHost*)) piwigo_service_real_create_publisher;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_supported_media = (SpitPublishingPublisherMediaType (*) (SpitPublishingService *)) piwigo_service_real_get_supported_media;
#line 1237 "PiwigoPublishing.c"
}


static void piwigo_service_instance_init (PiwigoService * self) {
}


static void piwigo_service_finalize (GObject * obj) {
	PiwigoService * self;
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_PIWIGO_SERVICE, PiwigoService);
#line 7 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (piwigo_service_parent_class)->finalize (obj);
#line 1251 "PiwigoPublishing.c"
}


GType piwigo_service_get_type (void) {
	static volatile gsize piwigo_service_type_id__volatile = 0;
	if (g_once_init_enter (&piwigo_service_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PiwigoServiceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) piwigo_service_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PiwigoService), 0, (GInstanceInitFunc) piwigo_service_instance_init, NULL };
		static const GInterfaceInfo spit_pluggable_info = { (GInterfaceInitFunc) piwigo_service_spit_pluggable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo spit_publishing_service_info = { (GInterfaceInitFunc) piwigo_service_spit_publishing_service_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType piwigo_service_type_id;
		piwigo_service_type_id = g_type_register_static (G_TYPE_OBJECT, "PiwigoService", &g_define_type_info, 0);
		g_type_add_interface_static (piwigo_service_type_id, SPIT_TYPE_PLUGGABLE, &spit_pluggable_info);
		g_type_add_interface_static (piwigo_service_type_id, SPIT_PUBLISHING_TYPE_SERVICE, &spit_publishing_service_info);
		g_once_init_leave (&piwigo_service_type_id__volatile, piwigo_service_type_id);
	}
	return piwigo_service_type_id__volatile;
}


PublishingPiwigoCategory* publishing_piwigo_category_construct (GType object_type, gint id, const gchar* name, const gchar* uppercats, const gchar* comment) {
	PublishingPiwigoCategory* self = NULL;
	gint _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (uppercats != NULL, NULL);
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoCategory*) g_type_create_instance (object_type);
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = id;
#line 70 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->id = _tmp0_;
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = name;
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 71 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->name = _tmp2_;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = uppercats;
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->uppercats);
#line 72 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->uppercats = _tmp4_;
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = comment;
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->comment);
#line 73 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->comment = _tmp6_;
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 1316 "PiwigoPublishing.c"
}


PublishingPiwigoCategory* publishing_piwigo_category_new (gint id, const gchar* name, const gchar* uppercats, const gchar* comment) {
#line 69 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_category_construct (PUBLISHING_PIWIGO_TYPE_CATEGORY, id, name, uppercats, comment);
#line 1323 "PiwigoPublishing.c"
}


PublishingPiwigoCategory* publishing_piwigo_category_construct_local (GType object_type, const gchar* name, gint parent_id, const gchar* comment) {
	PublishingPiwigoCategory* self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gint _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoCategory*) g_type_create_instance (object_type);
#line 77 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->id = PUBLISHING_PIWIGO_CATEGORY_NO_ID;
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = name;
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 78 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->name = _tmp1_;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = parent_id;
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = g_strdup_printf ("%i", _tmp2_);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->uppercats);
#line 81 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->uppercats = _tmp3_;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = comment;
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->comment);
#line 82 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->comment = _tmp5_;
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 1367 "PiwigoPublishing.c"
}


PublishingPiwigoCategory* publishing_piwigo_category_new_local (const gchar* name, gint parent_id, const gchar* comment) {
#line 76 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_category_construct_local (PUBLISHING_PIWIGO_TYPE_CATEGORY, name, parent_id, comment);
#line 1374 "PiwigoPublishing.c"
}


gboolean publishing_piwigo_category_is_local (PublishingPiwigoCategory* self) {
	gboolean result = FALSE;
	gint _tmp0_;
#line 85 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_CATEGORY (self), FALSE);
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->id;
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_ == PUBLISHING_PIWIGO_CATEGORY_NO_ID;
#line 86 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 1389 "PiwigoPublishing.c"
}


gboolean publishing_piwigo_category_equal (PublishingPiwigoCategory* _self_, PublishingPiwigoCategory* other) {
	gboolean result = FALSE;
	PublishingPiwigoCategory* _tmp0_;
	gint _tmp1_;
	PublishingPiwigoCategory* _tmp2_;
	gint _tmp3_;
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_CATEGORY (_self_), FALSE);
#line 89 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_CATEGORY (other), FALSE);
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = _self_;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _tmp0_->id;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = other;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _tmp2_->id;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_ == _tmp3_;
#line 90 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 1415 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_category_init (GValue* value) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1422 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_category_free_value (GValue* value) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (value->data[0].v_pointer) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_category_unref (value->data[0].v_pointer);
#line 1431 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_value_category_copy_value (const GValue* src_value, GValue* dest_value) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = publishing_piwigo_category_ref (src_value->data[0].v_pointer);
#line 1441 "PiwigoPublishing.c"
	} else {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1445 "PiwigoPublishing.c"
	}
}


static gpointer publishing_piwigo_value_category_peek_pointer (const GValue* value) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 1453 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_category_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1460 "PiwigoPublishing.c"
		PublishingPiwigoCategory * object;
		object = collect_values[0].v_pointer;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1467 "PiwigoPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1471 "PiwigoPublishing.c"
		}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = publishing_piwigo_category_ref (object);
#line 1475 "PiwigoPublishing.c"
	} else {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1479 "PiwigoPublishing.c"
	}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 1483 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_category_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingPiwigoCategory ** object_p;
	object_p = collect_values[0].v_pointer;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!object_p) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1494 "PiwigoPublishing.c"
	}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = NULL;
#line 1500 "PiwigoPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 1504 "PiwigoPublishing.c"
	} else {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = publishing_piwigo_category_ref (value->data[0].v_pointer);
#line 1508 "PiwigoPublishing.c"
	}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 1512 "PiwigoPublishing.c"
}


GParamSpec* publishing_piwigo_param_spec_category (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingPiwigoParamSpecCategory* spec;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_PIWIGO_TYPE_CATEGORY), NULL);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 1526 "PiwigoPublishing.c"
}


gpointer publishing_piwigo_value_get_category (const GValue* value) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_CATEGORY), NULL);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 1535 "PiwigoPublishing.c"
}


void publishing_piwigo_value_set_category (GValue* value, gpointer v_object) {
	PublishingPiwigoCategory * old;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_CATEGORY));
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_CATEGORY));
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_category_ref (value->data[0].v_pointer);
#line 1555 "PiwigoPublishing.c"
	} else {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1559 "PiwigoPublishing.c"
	}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_category_unref (old);
#line 1565 "PiwigoPublishing.c"
	}
}


void publishing_piwigo_value_take_category (GValue* value, gpointer v_object) {
	PublishingPiwigoCategory * old;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_CATEGORY));
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_CATEGORY));
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1584 "PiwigoPublishing.c"
	} else {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1588 "PiwigoPublishing.c"
	}
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_category_unref (old);
#line 1594 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_category_class_init (PublishingPiwigoCategoryClass * klass) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_category_parent_class = g_type_class_peek_parent (klass);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingPiwigoCategoryClass *) klass)->finalize = publishing_piwigo_category_finalize;
#line 1604 "PiwigoPublishing.c"
}


static void publishing_piwigo_category_instance_init (PublishingPiwigoCategory * self) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->ref_count = 1;
#line 1611 "PiwigoPublishing.c"
}


static void publishing_piwigo_category_finalize (PublishingPiwigoCategory * obj) {
	PublishingPiwigoCategory * self;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_CATEGORY, PublishingPiwigoCategory);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_destroy (self);
#line 63 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 64 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->comment);
#line 65 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->display_name);
#line 66 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->uppercats);
#line 1629 "PiwigoPublishing.c"
}


GType publishing_piwigo_category_get_type (void) {
	static volatile gsize publishing_piwigo_category_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_category_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_piwigo_value_category_init, publishing_piwigo_value_category_free_value, publishing_piwigo_value_category_copy_value, publishing_piwigo_value_category_peek_pointer, "p", publishing_piwigo_value_category_collect_value, "p", publishing_piwigo_value_category_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoCategoryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_category_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoCategory), 0, (GInstanceInitFunc) publishing_piwigo_category_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_piwigo_category_type_id;
		publishing_piwigo_category_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingPiwigoCategory", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_piwigo_category_type_id__volatile, publishing_piwigo_category_type_id);
	}
	return publishing_piwigo_category_type_id__volatile;
}


gpointer publishing_piwigo_category_ref (gpointer instance) {
	PublishingPiwigoCategory * self;
	self = instance;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return instance;
#line 1654 "PiwigoPublishing.c"
}


void publishing_piwigo_category_unref (gpointer instance) {
	PublishingPiwigoCategory * self;
	self = instance;
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		PUBLISHING_PIWIGO_CATEGORY_GET_CLASS (self)->finalize (self);
#line 61 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1667 "PiwigoPublishing.c"
	}
}


PublishingPiwigoPermissionLevel* publishing_piwigo_permission_level_construct (GType object_type, gint id, const gchar* name) {
	PublishingPiwigoPermissionLevel* self = NULL;
	gint _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoPermissionLevel*) g_type_create_instance (object_type);
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = id;
#line 99 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->id = _tmp0_;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = name;
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->name = _tmp2_;
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 1695 "PiwigoPublishing.c"
}


PublishingPiwigoPermissionLevel* publishing_piwigo_permission_level_new (gint id, const gchar* name) {
#line 98 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_permission_level_construct (PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL, id, name);
#line 1702 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_permission_level_init (GValue* value) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1709 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_permission_level_free_value (GValue* value) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (value->data[0].v_pointer) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_permission_level_unref (value->data[0].v_pointer);
#line 1718 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_value_permission_level_copy_value (const GValue* src_value, GValue* dest_value) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = publishing_piwigo_permission_level_ref (src_value->data[0].v_pointer);
#line 1728 "PiwigoPublishing.c"
	} else {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1732 "PiwigoPublishing.c"
	}
}


static gpointer publishing_piwigo_value_permission_level_peek_pointer (const GValue* value) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 1740 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_permission_level_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 1747 "PiwigoPublishing.c"
		PublishingPiwigoPermissionLevel * object;
		object = collect_values[0].v_pointer;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1754 "PiwigoPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1758 "PiwigoPublishing.c"
		}
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = publishing_piwigo_permission_level_ref (object);
#line 1762 "PiwigoPublishing.c"
	} else {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1766 "PiwigoPublishing.c"
	}
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 1770 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_permission_level_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingPiwigoPermissionLevel ** object_p;
	object_p = collect_values[0].v_pointer;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!object_p) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1781 "PiwigoPublishing.c"
	}
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = NULL;
#line 1787 "PiwigoPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 1791 "PiwigoPublishing.c"
	} else {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = publishing_piwigo_permission_level_ref (value->data[0].v_pointer);
#line 1795 "PiwigoPublishing.c"
	}
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 1799 "PiwigoPublishing.c"
}


GParamSpec* publishing_piwigo_param_spec_permission_level (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingPiwigoParamSpecPermissionLevel* spec;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL), NULL);
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 1813 "PiwigoPublishing.c"
}


gpointer publishing_piwigo_value_get_permission_level (const GValue* value) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL), NULL);
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 1822 "PiwigoPublishing.c"
}


void publishing_piwigo_value_set_permission_level (GValue* value, gpointer v_object) {
	PublishingPiwigoPermissionLevel * old;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL));
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL));
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_permission_level_ref (value->data[0].v_pointer);
#line 1842 "PiwigoPublishing.c"
	} else {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1846 "PiwigoPublishing.c"
	}
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_permission_level_unref (old);
#line 1852 "PiwigoPublishing.c"
	}
}


void publishing_piwigo_value_take_permission_level (GValue* value, gpointer v_object) {
	PublishingPiwigoPermissionLevel * old;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL));
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL));
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 1871 "PiwigoPublishing.c"
	} else {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 1875 "PiwigoPublishing.c"
	}
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_permission_level_unref (old);
#line 1881 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_permission_level_class_init (PublishingPiwigoPermissionLevelClass * klass) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_permission_level_parent_class = g_type_class_peek_parent (klass);
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingPiwigoPermissionLevelClass *) klass)->finalize = publishing_piwigo_permission_level_finalize;
#line 1891 "PiwigoPublishing.c"
}


static void publishing_piwigo_permission_level_instance_init (PublishingPiwigoPermissionLevel * self) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->ref_count = 1;
#line 1898 "PiwigoPublishing.c"
}


static void publishing_piwigo_permission_level_finalize (PublishingPiwigoPermissionLevel * obj) {
	PublishingPiwigoPermissionLevel * self;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_PERMISSION_LEVEL, PublishingPiwigoPermissionLevel);
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_destroy (self);
#line 96 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 1910 "PiwigoPublishing.c"
}


GType publishing_piwigo_permission_level_get_type (void) {
	static volatile gsize publishing_piwigo_permission_level_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_permission_level_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_piwigo_value_permission_level_init, publishing_piwigo_value_permission_level_free_value, publishing_piwigo_value_permission_level_copy_value, publishing_piwigo_value_permission_level_peek_pointer, "p", publishing_piwigo_value_permission_level_collect_value, "p", publishing_piwigo_value_permission_level_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoPermissionLevelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_permission_level_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoPermissionLevel), 0, (GInstanceInitFunc) publishing_piwigo_permission_level_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_piwigo_permission_level_type_id;
		publishing_piwigo_permission_level_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingPiwigoPermissionLevel", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_piwigo_permission_level_type_id__volatile, publishing_piwigo_permission_level_type_id);
	}
	return publishing_piwigo_permission_level_type_id__volatile;
}


gpointer publishing_piwigo_permission_level_ref (gpointer instance) {
	PublishingPiwigoPermissionLevel * self;
	self = instance;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return instance;
#line 1935 "PiwigoPublishing.c"
}


void publishing_piwigo_permission_level_unref (gpointer instance) {
	PublishingPiwigoPermissionLevel * self;
	self = instance;
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		PUBLISHING_PIWIGO_PERMISSION_LEVEL_GET_CLASS (self)->finalize (self);
#line 94 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1948 "PiwigoPublishing.c"
	}
}


PublishingPiwigoSizeEntry* publishing_piwigo_size_entry_construct (GType object_type, gint id, const gchar* name) {
	PublishingPiwigoSizeEntry* self = NULL;
	gint _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSizeEntry*) g_type_create_instance (object_type);
#line 109 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = id;
#line 109 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->id = _tmp0_;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = name;
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 110 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->name = _tmp2_;
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 1976 "PiwigoPublishing.c"
}


PublishingPiwigoSizeEntry* publishing_piwigo_size_entry_new (gint id, const gchar* name) {
#line 108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_size_entry_construct (PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY, id, name);
#line 1983 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_size_entry_init (GValue* value) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 1990 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_size_entry_free_value (GValue* value) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (value->data[0].v_pointer) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_size_entry_unref (value->data[0].v_pointer);
#line 1999 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_value_size_entry_copy_value (const GValue* src_value, GValue* dest_value) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = publishing_piwigo_size_entry_ref (src_value->data[0].v_pointer);
#line 2009 "PiwigoPublishing.c"
	} else {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 2013 "PiwigoPublishing.c"
	}
}


static gpointer publishing_piwigo_value_size_entry_peek_pointer (const GValue* value) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 2021 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_size_entry_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 2028 "PiwigoPublishing.c"
		PublishingPiwigoSizeEntry * object;
		object = collect_values[0].v_pointer;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2035 "PiwigoPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2039 "PiwigoPublishing.c"
		}
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = publishing_piwigo_size_entry_ref (object);
#line 2043 "PiwigoPublishing.c"
	} else {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2047 "PiwigoPublishing.c"
	}
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 2051 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_size_entry_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingPiwigoSizeEntry ** object_p;
	object_p = collect_values[0].v_pointer;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!object_p) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 2062 "PiwigoPublishing.c"
	}
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = NULL;
#line 2068 "PiwigoPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 2072 "PiwigoPublishing.c"
	} else {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = publishing_piwigo_size_entry_ref (value->data[0].v_pointer);
#line 2076 "PiwigoPublishing.c"
	}
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 2080 "PiwigoPublishing.c"
}


GParamSpec* publishing_piwigo_param_spec_size_entry (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingPiwigoParamSpecSizeEntry* spec;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY), NULL);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 2094 "PiwigoPublishing.c"
}


gpointer publishing_piwigo_value_get_size_entry (const GValue* value) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY), NULL);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 2103 "PiwigoPublishing.c"
}


void publishing_piwigo_value_set_size_entry (GValue* value, gpointer v_object) {
	PublishingPiwigoSizeEntry * old;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY));
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY));
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_size_entry_ref (value->data[0].v_pointer);
#line 2123 "PiwigoPublishing.c"
	} else {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2127 "PiwigoPublishing.c"
	}
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_size_entry_unref (old);
#line 2133 "PiwigoPublishing.c"
	}
}


void publishing_piwigo_value_take_size_entry (GValue* value, gpointer v_object) {
	PublishingPiwigoSizeEntry * old;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY));
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY));
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 2152 "PiwigoPublishing.c"
	} else {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2156 "PiwigoPublishing.c"
	}
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_size_entry_unref (old);
#line 2162 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_size_entry_class_init (PublishingPiwigoSizeEntryClass * klass) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_size_entry_parent_class = g_type_class_peek_parent (klass);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingPiwigoSizeEntryClass *) klass)->finalize = publishing_piwigo_size_entry_finalize;
#line 2172 "PiwigoPublishing.c"
}


static void publishing_piwigo_size_entry_instance_init (PublishingPiwigoSizeEntry * self) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->ref_count = 1;
#line 2179 "PiwigoPublishing.c"
}


static void publishing_piwigo_size_entry_finalize (PublishingPiwigoSizeEntry * obj) {
	PublishingPiwigoSizeEntry * self;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_SIZE_ENTRY, PublishingPiwigoSizeEntry);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_destroy (self);
#line 106 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->name);
#line 2191 "PiwigoPublishing.c"
}


GType publishing_piwigo_size_entry_get_type (void) {
	static volatile gsize publishing_piwigo_size_entry_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_size_entry_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_piwigo_value_size_entry_init, publishing_piwigo_value_size_entry_free_value, publishing_piwigo_value_size_entry_copy_value, publishing_piwigo_value_size_entry_peek_pointer, "p", publishing_piwigo_value_size_entry_collect_value, "p", publishing_piwigo_value_size_entry_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoSizeEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_size_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoSizeEntry), 0, (GInstanceInitFunc) publishing_piwigo_size_entry_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_piwigo_size_entry_type_id;
		publishing_piwigo_size_entry_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingPiwigoSizeEntry", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_piwigo_size_entry_type_id__volatile, publishing_piwigo_size_entry_type_id);
	}
	return publishing_piwigo_size_entry_type_id__volatile;
}


gpointer publishing_piwigo_size_entry_ref (gpointer instance) {
	PublishingPiwigoSizeEntry * self;
	self = instance;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return instance;
#line 2216 "PiwigoPublishing.c"
}


void publishing_piwigo_size_entry_unref (gpointer instance) {
	PublishingPiwigoSizeEntry * self;
	self = instance;
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		PUBLISHING_PIWIGO_SIZE_ENTRY_GET_CLASS (self)->finalize (self);
#line 104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2229 "PiwigoPublishing.c"
	}
}


PublishingPiwigoPublishingParameters* publishing_piwigo_publishing_parameters_construct (GType object_type) {
	PublishingPiwigoPublishingParameters* self = NULL;
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoPublishingParameters*) g_type_create_instance (object_type);
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 2240 "PiwigoPublishing.c"
}


PublishingPiwigoPublishingParameters* publishing_piwigo_publishing_parameters_new (void) {
#line 121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_publishing_parameters_construct (PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS);
#line 2247 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_publishing_parameters_init (GValue* value) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	value->data[0].v_pointer = NULL;
#line 2254 "PiwigoPublishing.c"
}


static void publishing_piwigo_value_publishing_parameters_free_value (GValue* value) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (value->data[0].v_pointer) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_parameters_unref (value->data[0].v_pointer);
#line 2263 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_value_publishing_parameters_copy_value (const GValue* src_value, GValue* dest_value) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (src_value->data[0].v_pointer) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = publishing_piwigo_publishing_parameters_ref (src_value->data[0].v_pointer);
#line 2273 "PiwigoPublishing.c"
	} else {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		dest_value->data[0].v_pointer = NULL;
#line 2277 "PiwigoPublishing.c"
	}
}


static gpointer publishing_piwigo_value_publishing_parameters_peek_pointer (const GValue* value) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 2285 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_publishing_parameters_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (collect_values[0].v_pointer) {
#line 2292 "PiwigoPublishing.c"
		PublishingPiwigoPublishingParameters * object;
		object = collect_values[0].v_pointer;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (object->parent_instance.g_class == NULL) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2299 "PiwigoPublishing.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 2303 "PiwigoPublishing.c"
		}
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = publishing_piwigo_publishing_parameters_ref (object);
#line 2307 "PiwigoPublishing.c"
	} else {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2311 "PiwigoPublishing.c"
	}
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 2315 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_value_publishing_parameters_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	PublishingPiwigoPublishingParameters ** object_p;
	object_p = collect_values[0].v_pointer;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!object_p) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 2326 "PiwigoPublishing.c"
	}
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!value->data[0].v_pointer) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = NULL;
#line 2332 "PiwigoPublishing.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = value->data[0].v_pointer;
#line 2336 "PiwigoPublishing.c"
	} else {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*object_p = publishing_piwigo_publishing_parameters_ref (value->data[0].v_pointer);
#line 2340 "PiwigoPublishing.c"
	}
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return NULL;
#line 2344 "PiwigoPublishing.c"
}


GParamSpec* publishing_piwigo_param_spec_publishing_parameters (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	PublishingPiwigoParamSpecPublishingParameters* spec;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (g_type_is_a (object_type, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return G_PARAM_SPEC (spec);
#line 2358 "PiwigoPublishing.c"
}


gpointer publishing_piwigo_value_get_publishing_parameters (const GValue* value) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS), NULL);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return value->data[0].v_pointer;
#line 2367 "PiwigoPublishing.c"
}


void publishing_piwigo_value_set_publishing_parameters (GValue* value, gpointer v_object) {
	PublishingPiwigoPublishingParameters * old;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS));
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS));
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_parameters_ref (value->data[0].v_pointer);
#line 2387 "PiwigoPublishing.c"
	} else {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2391 "PiwigoPublishing.c"
	}
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_parameters_unref (old);
#line 2397 "PiwigoPublishing.c"
	}
}


void publishing_piwigo_value_take_publishing_parameters (GValue* value, gpointer v_object) {
	PublishingPiwigoPublishingParameters * old;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS));
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	old = value->data[0].v_pointer;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (v_object) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS));
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = v_object;
#line 2416 "PiwigoPublishing.c"
	} else {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		value->data[0].v_pointer = NULL;
#line 2420 "PiwigoPublishing.c"
	}
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (old) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_parameters_unref (old);
#line 2426 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_publishing_parameters_class_init (PublishingPiwigoPublishingParametersClass * klass) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_parameters_parent_class = g_type_class_peek_parent (klass);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingPiwigoPublishingParametersClass *) klass)->finalize = publishing_piwigo_publishing_parameters_finalize;
#line 2436 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_parameters_instance_init (PublishingPiwigoPublishingParameters * self) {
#line 115 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->category = NULL;
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->perm_level = NULL;
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->photo_size = NULL;
#line 118 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->title_as_comment = FALSE;
#line 119 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->no_upload_tags = FALSE;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->ref_count = 1;
#line 2453 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_parameters_finalize (PublishingPiwigoPublishingParameters * obj) {
	PublishingPiwigoPublishingParameters * self;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS, PublishingPiwigoPublishingParameters);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_destroy (self);
#line 115 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_category_unref0 (self->category);
#line 116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_permission_level_unref0 (self->perm_level);
#line 117 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_size_entry_unref0 (self->photo_size);
#line 2469 "PiwigoPublishing.c"
}


GType publishing_piwigo_publishing_parameters_get_type (void) {
	static volatile gsize publishing_piwigo_publishing_parameters_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_publishing_parameters_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { publishing_piwigo_value_publishing_parameters_init, publishing_piwigo_value_publishing_parameters_free_value, publishing_piwigo_value_publishing_parameters_copy_value, publishing_piwigo_value_publishing_parameters_peek_pointer, "p", publishing_piwigo_value_publishing_parameters_collect_value, "p", publishing_piwigo_value_publishing_parameters_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoPublishingParametersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_publishing_parameters_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoPublishingParameters), 0, (GInstanceInitFunc) publishing_piwigo_publishing_parameters_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType publishing_piwigo_publishing_parameters_type_id;
		publishing_piwigo_publishing_parameters_type_id = g_type_register_fundamental (g_type_fundamental_next (), "PublishingPiwigoPublishingParameters", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&publishing_piwigo_publishing_parameters_type_id__volatile, publishing_piwigo_publishing_parameters_type_id);
	}
	return publishing_piwigo_publishing_parameters_type_id__volatile;
}


gpointer publishing_piwigo_publishing_parameters_ref (gpointer instance) {
	PublishingPiwigoPublishingParameters * self;
	self = instance;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_atomic_int_inc (&self->ref_count);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return instance;
#line 2494 "PiwigoPublishing.c"
}


void publishing_piwigo_publishing_parameters_unref (gpointer instance) {
	PublishingPiwigoPublishingParameters * self;
	self = instance;
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_GET_CLASS (self)->finalize (self);
#line 114 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2507 "PiwigoPublishing.c"
	}
}


PublishingPiwigoPiwigoPublisher* publishing_piwigo_piwigo_publisher_construct (GType object_type, SpitPublishingService* service, SpitPublishingPluginHost* host) {
	PublishingPiwigoPiwigoPublisher * self = NULL;
	SpitPublishingService* _tmp0_;
	SpitPublishingService* _tmp1_;
	SpitPublishingPluginHost* _tmp2_;
	SpitPublishingPluginHost* _tmp3_;
	PublishingPiwigoSession* _tmp4_;
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_SERVICE (service), NULL);
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PLUGIN_HOST (host), NULL);
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoPiwigoPublisher*) g_object_new (object_type, NULL);
#line 137 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:137: PiwigoPublisher instantiated.");
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = service;
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->service);
#line 138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->service = _tmp1_;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = host;
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->host);
#line 139 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->host = _tmp3_;
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = publishing_piwigo_session_new ();
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->session = _tmp4_;
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 2551 "PiwigoPublishing.c"
}


PublishingPiwigoPiwigoPublisher* publishing_piwigo_piwigo_publisher_new (SpitPublishingService* service, SpitPublishingPluginHost* host) {
#line 135 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_piwigo_publisher_construct (PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, service, host);
#line 2558 "PiwigoPublishing.c"
}


static SpitPublishingService* publishing_piwigo_piwigo_publisher_real_get_service (SpitPublishingPublisher* base) {
	PublishingPiwigoPiwigoPublisher * self;
	SpitPublishingService* result = NULL;
	SpitPublishingService* _tmp0_;
	SpitPublishingService* _tmp1_;
#line 145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisher);
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->service;
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 146 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2577 "PiwigoPublishing.c"
}


SpitPublishingPluginHost* publishing_piwigo_piwigo_publisher_get_host (PublishingPiwigoPiwigoPublisher* self) {
	SpitPublishingPluginHost* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
#line 149 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), NULL);
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2595 "PiwigoPublishing.c"
}


static gboolean publishing_piwigo_piwigo_publisher_real_is_running (SpitPublishingPublisher* base) {
	PublishingPiwigoPiwigoPublisher * self;
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 153 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisher);
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->running;
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 154 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2611 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_real_start (SpitPublishingPublisher* base) {
	PublishingPiwigoPiwigoPublisher * self;
	gboolean _tmp0_;
	PublishingPiwigoSession* _tmp1_;
	gboolean _tmp2_;
#line 157 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisher);
#line 158 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 158 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp0_) {
#line 159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 2628 "PiwigoPublishing.c"
	}
#line 161 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:161: PiwigoPublisher: starting interaction.");
#line 163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->running = TRUE;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->session;
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp2_) {
#line 166 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:166: PiwigoPublisher: session is authenticated.");
#line 167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_fetch_categories (self);
#line 2644 "PiwigoPublishing.c"
	} else {
		gchar* persistent_url = NULL;
		gchar* _tmp3_;
		gchar* persistent_username = NULL;
		gchar* _tmp4_;
		gchar* persistent_password = NULL;
		gchar* _tmp5_;
		gboolean _tmp6_ = FALSE;
		gboolean _tmp7_ = FALSE;
		const gchar* _tmp8_;
#line 169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:169: PiwigoPublisher: session is not authenticat" \
"ed.");
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = publishing_piwigo_piwigo_publisher_get_persistent_url (self);
#line 170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		persistent_url = _tmp3_;
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = publishing_piwigo_piwigo_publisher_get_persistent_username (self);
#line 171 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		persistent_username = _tmp4_;
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = publishing_piwigo_piwigo_publisher_get_persistent_password (self);
#line 172 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		persistent_password = _tmp5_;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = persistent_url;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp8_ != NULL) {
#line 2673 "PiwigoPublishing.c"
			const gchar* _tmp9_;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp9_ = persistent_username;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp7_ = _tmp9_ != NULL;
#line 2679 "PiwigoPublishing.c"
		} else {
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp7_ = FALSE;
#line 2683 "PiwigoPublishing.c"
		}
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp7_) {
#line 2687 "PiwigoPublishing.c"
			const gchar* _tmp10_;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp10_ = persistent_password;
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp6_ = _tmp10_ != NULL;
#line 2693 "PiwigoPublishing.c"
		} else {
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp6_ = FALSE;
#line 2697 "PiwigoPublishing.c"
		}
#line 173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp6_) {
#line 2701 "PiwigoPublishing.c"
			const gchar* _tmp11_;
			const gchar* _tmp12_;
			const gchar* _tmp13_;
			gboolean _tmp14_;
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp11_ = persistent_url;
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp12_ = persistent_username;
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp13_ = persistent_password;
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp14_ = publishing_piwigo_piwigo_publisher_get_remember_password (self);
#line 174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_piwigo_piwigo_publisher_do_network_login (self, _tmp11_, _tmp12_, _tmp13_, _tmp14_);
#line 2716 "PiwigoPublishing.c"
		} else {
#line 177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_piwigo_piwigo_publisher_do_show_authentication_pane (self, PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_INTRO);
#line 2720 "PiwigoPublishing.c"
		}
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (persistent_password);
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (persistent_username);
#line 165 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (persistent_url);
#line 2728 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_piwigo_publisher_real_stop (SpitPublishingPublisher* base) {
	PublishingPiwigoPiwigoPublisher * self;
#line 181 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisher);
#line 182 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->running = FALSE;
#line 2739 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_piwigo_publisher_get_persistent_url (PublishingPiwigoPiwigoPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	gchar* _tmp1_;
#line 187 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), NULL);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "url", NULL);
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2757 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_persistent_url (PublishingPiwigoPiwigoPublisher* self, const gchar* url) {
	SpitPublishingPluginHost* _tmp0_;
	const gchar* _tmp1_;
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (url != NULL);
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = url;
#line 192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "url", _tmp1_);
#line 2774 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_piwigo_publisher_get_persistent_username (PublishingPiwigoPiwigoPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	gchar* _tmp1_;
#line 195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), NULL);
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "username", NULL);
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2792 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_persistent_username (PublishingPiwigoPiwigoPublisher* self, const gchar* username) {
	SpitPublishingPluginHost* _tmp0_;
	const gchar* _tmp1_;
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 199 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (username != NULL);
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = username;
#line 200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "username", _tmp1_);
#line 2809 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_piwigo_publisher_get_persistent_password (PublishingPiwigoPiwigoPublisher* self) {
	gchar* result = NULL;
	SpitPublishingPluginHost* _tmp0_;
	gchar* _tmp1_;
#line 203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), NULL);
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "password", NULL);
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2827 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_persistent_password (PublishingPiwigoPiwigoPublisher* self, const gchar* password) {
	SpitPublishingPluginHost* _tmp0_;
	const gchar* _tmp1_;
#line 207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = password;
#line 208 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "password", _tmp1_);
#line 2842 "PiwigoPublishing.c"
}


gboolean publishing_piwigo_piwigo_publisher_get_remember_password (PublishingPiwigoPiwigoPublisher* self) {
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_;
	gboolean _tmp1_;
#line 211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), FALSE);
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "remember-password", FALSE);
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2860 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_remember_password (PublishingPiwigoPiwigoPublisher* self, gboolean remember_password) {
	SpitPublishingPluginHost* _tmp0_;
	gboolean _tmp1_;
#line 215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = remember_password;
#line 216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "remember-password", _tmp1_);
#line 2875 "PiwigoPublishing.c"
}


gint publishing_piwigo_piwigo_publisher_get_last_category (PublishingPiwigoPiwigoPublisher* self) {
	gint result = 0;
	SpitPublishingPluginHost* _tmp0_;
	gint _tmp1_;
#line 219 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), 0);
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-category", -1);
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 220 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2893 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_last_category (PublishingPiwigoPiwigoPublisher* self, gint last_category) {
	SpitPublishingPluginHost* _tmp0_;
	gint _tmp1_;
#line 223 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = last_category;
#line 224 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-category", _tmp1_);
#line 2908 "PiwigoPublishing.c"
}


gint publishing_piwigo_piwigo_publisher_get_last_permission_level (PublishingPiwigoPiwigoPublisher* self) {
	gint result = 0;
	SpitPublishingPluginHost* _tmp0_;
	gint _tmp1_;
#line 227 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), 0);
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-permission-level", -1);
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 228 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2926 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_last_permission_level (PublishingPiwigoPiwigoPublisher* self, gint last_permission_level) {
	SpitPublishingPluginHost* _tmp0_;
	gint _tmp1_;
#line 231 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = last_permission_level;
#line 232 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-permission-level", _tmp1_);
#line 2941 "PiwigoPublishing.c"
}


gint publishing_piwigo_piwigo_publisher_get_last_photo_size (PublishingPiwigoPiwigoPublisher* self) {
	gint result = 0;
	SpitPublishingPluginHost* _tmp0_;
	gint _tmp1_;
#line 235 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), 0);
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-photo-size", -1);
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 236 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2959 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_last_photo_size (PublishingPiwigoPiwigoPublisher* self, gint last_photo_size) {
	SpitPublishingPluginHost* _tmp0_;
	gint _tmp1_;
#line 239 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = last_photo_size;
#line 240 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_int (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-photo-size", _tmp1_);
#line 2974 "PiwigoPublishing.c"
}


static gboolean publishing_piwigo_piwigo_publisher_get_last_title_as_comment (PublishingPiwigoPiwigoPublisher* self) {
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_;
	gboolean _tmp1_;
#line 243 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), FALSE);
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-title-as-comment", FALSE);
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 2992 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_last_title_as_comment (PublishingPiwigoPiwigoPublisher* self, gboolean title_as_comment) {
	SpitPublishingPluginHost* _tmp0_;
	gboolean _tmp1_;
#line 247 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = title_as_comment;
#line 248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-title-as-comment", _tmp1_);
#line 3007 "PiwigoPublishing.c"
}


static gboolean publishing_piwigo_piwigo_publisher_get_last_no_upload_tags (PublishingPiwigoPiwigoPublisher* self) {
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_;
	gboolean _tmp1_;
#line 251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), FALSE);
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-no-upload-tags", FALSE);
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 3025 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_last_no_upload_tags (PublishingPiwigoPiwigoPublisher* self, gboolean no_upload_tags) {
	SpitPublishingPluginHost* _tmp0_;
	gboolean _tmp1_;
#line 255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = no_upload_tags;
#line 256 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "last-no-upload-tags", _tmp1_);
#line 3040 "PiwigoPublishing.c"
}


static gboolean publishing_piwigo_piwigo_publisher_get_metadata_removal_choice (PublishingPiwigoPiwigoPublisher* self) {
	gboolean result = FALSE;
	SpitPublishingPluginHost* _tmp0_;
	gboolean _tmp1_;
#line 259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), FALSE);
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = spit_host_interface_get_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip_metadata", FALSE);
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 3058 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_set_metadata_removal_choice (PublishingPiwigoPiwigoPublisher* self, gboolean strip_metadata) {
	SpitPublishingPluginHost* _tmp0_;
	gboolean _tmp1_;
#line 263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = strip_metadata;
#line 264 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_host_interface_set_config_bool (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_TYPE_HOST_INTERFACE, SpitHostInterface), "strip_metadata", _tmp1_);
#line 3073 "PiwigoPublishing.c"
}


/**
     * Action that shows the authentication pane.
     *
     * This action method shows the authentication pane. It is shown at the
     * very beginning of the interaction when no persistent parameters are found
     * or after a failed login attempt using persisted parameters. It can be
     * given a mode flag to specify whether it should be displayed in initial
     * mode or in any of the error modes that it supports.
     *
     * @param mode the mode for the authentication pane
     */
static void _publishing_piwigo_piwigo_publisher_on_authentication_pane_login_clicked_publishing_piwigo_authentication_pane_login (PublishingPiwigoAuthenticationPane* _sender, const gchar* url, const gchar* user, const gchar* password, gboolean remember_password, gpointer self) {
#line 286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_authentication_pane_login_clicked ((PublishingPiwigoPiwigoPublisher*) self, url, user, password, remember_password);
#line 3091 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_show_authentication_pane (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoAuthenticationPaneMode mode) {
	SpitPublishingPluginHost* _tmp0_;
	PublishingPiwigoAuthenticationPane* authentication_pane = NULL;
	PublishingPiwigoAuthenticationPaneMode _tmp1_;
	PublishingPiwigoAuthenticationPane* _tmp2_;
	SpitPublishingPluginHost* _tmp3_;
	SpitPublishingPluginHost* _tmp4_;
	GtkWidget* _tmp5_;
	GtkWidget* _tmp6_;
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 281 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:281: ACTION: installing authentication pane");
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = mode;
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_piwigo_authentication_pane_new (self, _tmp1_);
#line 284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	authentication_pane = _tmp2_;
#line 286 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (authentication_pane, "login", (GCallback) _publishing_piwigo_piwigo_publisher_on_authentication_pane_login_clicked_publishing_piwigo_authentication_pane_login, self, 0);
#line 287 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = self->priv->host;
#line 287 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp3_, G_TYPE_CHECK_INSTANCE_CAST (authentication_pane, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->host;
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = shotwell_plugins_common_builder_pane_get_default_widget (G_TYPE_CHECK_INSTANCE_CAST (authentication_pane, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane));
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _tmp5_;
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_dialog_default_widget (_tmp4_, _tmp6_);
#line 288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp6_);
#line 280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (authentication_pane);
#line 3136 "PiwigoPublishing.c"
}


static void __lambda7_ (PublishingPiwigoPiwigoPublisher* self) {
	PublishingPiwigoSession* _tmp0_;
	PublishingPiwigoSession* _tmp1_;
	gchar* persistent_url = NULL;
	gchar* _tmp2_;
	gchar* persistent_username = NULL;
	gchar* _tmp3_;
	gchar* persistent_password = NULL;
	gchar* _tmp4_;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	const gchar* _tmp7_;
#line 297 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:297: SSL: User wants us to retry with broken cer" \
"tificate");
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = publishing_piwigo_session_new ();
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 298 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->session = _tmp0_;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->session;
#line 299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_session_set_insecure (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_piwigo_piwigo_publisher_get_persistent_url (self);
#line 301 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	persistent_url = _tmp2_;
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishing_piwigo_piwigo_publisher_get_persistent_username (self);
#line 302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	persistent_username = _tmp3_;
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = publishing_piwigo_piwigo_publisher_get_persistent_password (self);
#line 303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	persistent_password = _tmp4_;
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = persistent_url;
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp7_ != NULL) {
#line 3180 "PiwigoPublishing.c"
		const gchar* _tmp8_;
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = persistent_username;
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = _tmp8_ != NULL;
#line 3186 "PiwigoPublishing.c"
	} else {
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = FALSE;
#line 3190 "PiwigoPublishing.c"
	}
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp6_) {
#line 3194 "PiwigoPublishing.c"
		const gchar* _tmp9_;
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = persistent_password;
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = _tmp9_ != NULL;
#line 3200 "PiwigoPublishing.c"
	} else {
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = FALSE;
#line 3204 "PiwigoPublishing.c"
	}
#line 304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp5_) {
#line 3208 "PiwigoPublishing.c"
		const gchar* _tmp10_;
		const gchar* _tmp11_;
		const gchar* _tmp12_;
		gboolean _tmp13_;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = persistent_url;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = persistent_username;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp12_ = persistent_password;
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = publishing_piwigo_piwigo_publisher_get_remember_password (self);
#line 305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_network_login (self, _tmp10_, _tmp11_, _tmp12_, _tmp13_);
#line 3223 "PiwigoPublishing.c"
	} else {
#line 308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_authentication_pane (self, PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_INTRO);
#line 3227 "PiwigoPublishing.c"
	}
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (persistent_password);
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (persistent_username);
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (persistent_url);
#line 3235 "PiwigoPublishing.c"
}


static void ___lambda7__publishing_piwigo_ssl_error_pane_proceed (PublishingPiwigoSSLErrorPane* _sender, gpointer self) {
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	__lambda7_ ((PublishingPiwigoPiwigoPublisher*) self);
#line 3242 "PiwigoPublishing.c"
}


static void _vala_SoupURI_free (SoupURI* self) {
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_boxed_free (soup_uri_get_type (), self);
#line 3249 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_show_ssl_downgrade_pane (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoSessionLoginTransaction* trans, const gchar* url) {
	SoupURI* uri = NULL;
	const gchar* _tmp0_;
	SoupURI* _tmp1_;
	SpitPublishingPluginHost* _tmp2_;
	PublishingPiwigoSSLErrorPane* ssl_pane = NULL;
	PublishingPiwigoSessionLoginTransaction* _tmp3_;
	const gchar* _tmp4_;
	PublishingPiwigoSSLErrorPane* _tmp5_;
	SpitPublishingPluginHost* _tmp6_;
	SpitPublishingPluginHost* _tmp7_;
	GtkWidget* _tmp8_;
	GtkWidget* _tmp9_;
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_SESSION_LOGIN_TRANSACTION (trans));
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (url != NULL);
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = url;
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = soup_uri_new (_tmp0_);
#line 293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	uri = _tmp1_;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->host;
#line 294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp2_, FALSE);
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = trans;
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = soup_uri_get_host (uri);
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_piwigo_ssl_error_pane_new (_tmp3_, _tmp4_);
#line 295 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	ssl_pane = _tmp5_;
#line 296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (ssl_pane, "proceed", (GCallback) ___lambda7__publishing_piwigo_ssl_error_pane_proceed, self, 0);
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = self->priv->host;
#line 310 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp6_, G_TYPE_CHECK_INSTANCE_CAST (ssl_pane, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = self->priv->host;
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = shotwell_plugins_common_builder_pane_get_default_widget (G_TYPE_CHECK_INSTANCE_CAST (ssl_pane, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane));
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = _tmp8_;
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_dialog_default_widget (_tmp7_, _tmp9_);
#line 312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp9_);
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (ssl_pane);
#line 291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	__vala_SoupURI_free0 (uri);
#line 3310 "PiwigoPublishing.c"
}


/**
     * Event triggered when the login button in the authentication panel is
     * clicked.
     *
     * This event is triggered when the login button in the authentication
     * panel is clicked. It then triggers a network login interaction.
     *
     * @param url the URL of the Piwigo service as entered in the dialog
     * @param username the name of the Piwigo user as entered in the dialog
     * @param password the password of the Piwigo as entered in the dialog
     */
static void publishing_piwigo_piwigo_publisher_on_authentication_pane_login_clicked (PublishingPiwigoPiwigoPublisher* self, const gchar* url, const gchar* username, const gchar* password, gboolean remember_password) {
	gboolean _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gboolean _tmp4_;
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (url != NULL);
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (username != NULL);
#line 326 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (password != NULL);
#line 329 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:329: EVENT: on_authentication_pane_login_clicked");
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->running;
#line 330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp0_) {
#line 331 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 3347 "PiwigoPublishing.c"
	}
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = url;
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = username;
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = password;
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = remember_password;
#line 333 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_network_login (self, _tmp1_, _tmp2_, _tmp3_, _tmp4_);
#line 3359 "PiwigoPublishing.c"
}


/**
     * Action to perform a network login to a Piwigo service.
     *
     * This action performs a network login a Piwigo service specified by a
     * URL and using the given user name and password as credentials.
     *
     * @param url the URL of the Piwigo service; this URL will be normalised
     *     before being used
     * @param username the name of the Piwigo user used to login
     * @param password the password of the Piwigo user used to login
     */
static void _publishing_piwigo_piwigo_publisher_on_login_network_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 360 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_login_network_error ((PublishingPiwigoPiwigoPublisher*) self, _sender, err);
#line 3377 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_login_network_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_login_network_complete ((PublishingPiwigoPiwigoPublisher*) self, _sender);
#line 3384 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_network_login (PublishingPiwigoPiwigoPublisher* self, const gchar* url, const gchar* username, const gchar* password, gboolean remember_password) {
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	PublishingPiwigoSessionLoginTransaction* login_trans = NULL;
	PublishingPiwigoSession* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	PublishingPiwigoSessionLoginTransaction* _tmp11_;
	PublishingPiwigoSessionLoginTransaction* _tmp12_;
	GError * _inner_error_ = NULL;
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (url != NULL);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (username != NULL);
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (password != NULL);
#line 348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:348: ACTION: logging in");
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 349 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->host;
#line 350 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_login_wait_pane (_tmp1_);
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = remember_password;
#line 352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_remember_password (self, _tmp2_);
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = remember_password;
#line 353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp3_) {
#line 3429 "PiwigoPublishing.c"
		const gchar* _tmp4_;
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = password;
#line 354 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_set_persistent_password (self, _tmp4_);
#line 3435 "PiwigoPublishing.c"
	} else {
#line 356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_set_persistent_password (self, NULL);
#line 3439 "PiwigoPublishing.c"
	}
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = self->priv->session;
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = url;
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = publishing_piwigo_piwigo_publisher_normalise_url (_tmp6_);
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = _tmp7_;
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = username;
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = password;
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = publishing_piwigo_session_login_transaction_new (_tmp5_, _tmp8_, _tmp9_, _tmp10_);
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = _tmp11_;
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp8_);
#line 358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	login_trans = _tmp12_;
#line 360 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (login_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_login_network_error_publishing_rest_support_transaction_network_error, self, 0);
#line 361 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (login_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_piwigo_piwigo_publisher_on_login_network_complete_publishing_rest_support_transaction_completed, self, 0);
#line 3465 "PiwigoPublishing.c"
	{
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (login_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3473 "PiwigoPublishing.c"
				goto __catch23_spit_publishing_publishing_error;
			}
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_transaction_unref0 (login_trans);
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 364 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 3484 "PiwigoPublishing.c"
		}
	}
	goto __finally23;
	__catch23_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp13_;
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 366 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = err;
#line 366 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (g_error_matches (_tmp13_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_SSL_FAILED)) {
#line 3500 "PiwigoPublishing.c"
			const gchar* _tmp14_;
#line 367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_debug ("PiwigoPublishing.vala:367: ERROR: SSL connection problems");
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp14_ = url;
#line 368 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_piwigo_piwigo_publisher_do_show_ssl_downgrade_pane (self, login_trans, _tmp14_);
#line 3508 "PiwigoPublishing.c"
		} else {
			GError* _tmp15_;
#line 370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_debug ("PiwigoPublishing.vala:370: ERROR: do_network_login");
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp15_ = err;
#line 371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp15_);
#line 3517 "PiwigoPublishing.c"
		}
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 3521 "PiwigoPublishing.c"
	}
	__finally23:
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_transaction_unref0 (login_trans);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 3534 "PiwigoPublishing.c"
	}
#line 347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_transaction_unref0 (login_trans);
#line 3538 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_piwigo_publisher_normalise_url (const gchar* url) {
	gchar* result = NULL;
	gchar* norm_url = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp10_ = FALSE;
	const gchar* _tmp11_;
	gboolean _tmp12_;
#line 376 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = url;
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	norm_url = _tmp1_;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = norm_url;
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = g_str_has_suffix (_tmp2_, ".php");
#line 379 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp3_) {
#line 3566 "PiwigoPublishing.c"
		const gchar* _tmp4_;
		gboolean _tmp5_;
		const gchar* _tmp8_;
		gchar* _tmp9_;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = norm_url;
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = g_str_has_suffix (_tmp4_, "/");
#line 380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (!_tmp5_) {
#line 3577 "PiwigoPublishing.c"
			const gchar* _tmp6_;
			gchar* _tmp7_;
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp6_ = norm_url;
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp7_ = g_strconcat (_tmp6_, "/", NULL);
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (norm_url);
#line 381 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			norm_url = _tmp7_;
#line 3588 "PiwigoPublishing.c"
		}
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = norm_url;
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = g_strconcat (_tmp8_, PUBLISHING_PIWIGO_PIWIGO_WS, NULL);
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (norm_url);
#line 383 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		norm_url = _tmp9_;
#line 3598 "PiwigoPublishing.c"
	}
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = norm_url;
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = g_str_has_prefix (_tmp11_, "http://");
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp12_) {
#line 3606 "PiwigoPublishing.c"
		const gchar* _tmp13_;
		gboolean _tmp14_;
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = norm_url;
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp14_ = g_str_has_prefix (_tmp13_, "https://");
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = !_tmp14_;
#line 3615 "PiwigoPublishing.c"
	} else {
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = FALSE;
#line 3619 "PiwigoPublishing.c"
	}
#line 386 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp10_) {
#line 3623 "PiwigoPublishing.c"
		const gchar* _tmp15_;
		gchar* _tmp16_;
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp15_ = norm_url;
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp16_ = g_strconcat ("http://", _tmp15_, NULL);
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (norm_url);
#line 387 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		norm_url = _tmp16_;
#line 3634 "PiwigoPublishing.c"
	}
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = norm_url;
#line 390 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 3640 "PiwigoPublishing.c"
}


/**
     * Event triggered when the network login action is complete and successful.
     *
     * This event is triggered on successful completion of a network login.
     * Calling this event implies that the URL, user name and password provided
     * in the authentication pane are valid and that the transaction should
     * contain a Set-Cookie header that includes the value pwg_id for that
     * user. As a result, this event will also authenticate the session and
     * persist all values so that they can be re-used during the next publishing
     * interaction.
     *
     * @param txn the received REST transaction
     */
static gchar* _publishing_piwigo_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc, gpointer self) {
	gchar* result;
	result = publishing_piwigo_transaction_validate_xml (doc);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 3662 "PiwigoPublishing.c"
}


static gchar* _publishing_piwigo_transaction_get_error_code_publishing_rest_support_xml_document_check_for_error_response (PublishingRESTSupportXmlDocument* doc, gpointer self) {
	gchar* result;
	result = publishing_piwigo_transaction_get_error_code (doc);
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 3671 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_on_login_network_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportTransaction* _tmp2_;
	guint _tmp3_;
	gchar* endpoint_url = NULL;
	PublishingRESTSupportTransaction* _tmp19_;
	gchar* _tmp20_;
	const gchar* _tmp21_;
	gchar* pwg_id = NULL;
	PublishingRESTSupportTransaction* _tmp22_;
	gchar* _tmp23_;
	const gchar* _tmp24_;
	PublishingPiwigoSession* _tmp25_;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	const gchar* _tmp28_;
	GError * _inner_error_ = NULL;
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:407: EVENT: on_login_network_complete");
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = txn;
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 408 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_login_network_complete_publishing_rest_support_transaction_completed, self);
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = txn;
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_login_network_error_publishing_rest_support_transaction_network_error, self);
#line 3711 "PiwigoPublishing.c"
	{
		PublishingRESTSupportTransaction* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		PublishingRESTSupportXmlDocument* _tmp7_;
		PublishingRESTSupportXmlDocument* _tmp8_;
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = txn;
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = publishing_rest_support_transaction_get_response (_tmp4_);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = _tmp5_;
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = publishing_rest_support_xml_document_parse_string (_tmp6_, _publishing_piwigo_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = _tmp7_;
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (_tmp8_);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp6_);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3736 "PiwigoPublishing.c"
				goto __catch24_spit_publishing_publishing_error;
			}
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 412 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 3745 "PiwigoPublishing.c"
		}
	}
	goto __finally24;
	__catch24_spit_publishing_publishing_error:
	{
		GError* err = NULL;
#line 411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 3756 "PiwigoPublishing.c"
		{
			PublishingRESTSupportTransaction* _tmp9_;
			gchar* _tmp10_;
			gchar* _tmp11_;
			PublishingRESTSupportXmlDocument* _tmp12_;
			PublishingRESTSupportXmlDocument* _tmp13_;
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp9_ = txn;
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp10_ = publishing_rest_support_transaction_get_response (_tmp9_);
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp11_ = _tmp10_;
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp12_ = publishing_rest_support_xml_document_parse_string (_tmp11_, _publishing_piwigo_transaction_get_error_code_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp13_ = _tmp12_;
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (_tmp13_);
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (_tmp11_);
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 3781 "PiwigoPublishing.c"
					goto __catch25_spit_publishing_publishing_error;
				}
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_error_free0 (err);
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_clear_error (&_inner_error_);
#line 417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				return;
#line 3792 "PiwigoPublishing.c"
			}
		}
		goto __finally25;
		__catch25_spit_publishing_publishing_error:
		{
			GError* code = NULL;
			gint code_int = 0;
			GError* _tmp14_;
			const gchar* _tmp15_;
			gint _tmp16_;
			gint _tmp17_;
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			code = _inner_error_;
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_inner_error_ = NULL;
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp14_ = code;
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp15_ = _tmp14_->message;
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp16_ = atoi (_tmp15_);
#line 420 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			code_int = _tmp16_;
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp17_ = code_int;
#line 421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_tmp17_ == 999) {
#line 422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_debug ("PiwigoPublishing.vala:422: ERROR: on_login_network_complete, code 999");
#line 423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_piwigo_publisher_do_show_authentication_pane (self, PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER);
#line 3824 "PiwigoPublishing.c"
			} else {
				GError* _tmp18_;
#line 425 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_debug ("PiwigoPublishing.vala:425: ERROR: on_login_network_complete");
#line 426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp18_ = err;
#line 426 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp18_);
#line 3833 "PiwigoPublishing.c"
			}
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_error_free0 (code);
#line 3837 "PiwigoPublishing.c"
		}
		__finally25:
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_error_free0 (err);
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_error_free0 (err);
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 416 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 3852 "PiwigoPublishing.c"
		}
#line 429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 3858 "PiwigoPublishing.c"
	}
	__finally24:
#line 411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 3869 "PiwigoPublishing.c"
	}
#line 432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = txn;
#line 432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = publishing_rest_support_transaction_get_endpoint_url (_tmp19_);
#line 432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	endpoint_url = _tmp20_;
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp21_ = endpoint_url;
#line 433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:433: Setting endpoint URL to %s", _tmp21_);
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp22_ = txn;
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp23_ = publishing_piwigo_piwigo_publisher_get_pwg_id_from_transaction (self, _tmp22_);
#line 434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	pwg_id = _tmp23_;
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp24_ = pwg_id;
#line 435 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:435: Setting session pwg_id to %s", _tmp24_);
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp25_ = self->priv->session;
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp26_ = pwg_id;
#line 436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_session_set_pwg_id (_tmp25_, _tmp26_);
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp27_ = endpoint_url;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp28_ = pwg_id;
#line 438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_fetch_session_status (self, _tmp27_, _tmp28_);
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (pwg_id);
#line 406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (endpoint_url);
#line 3907 "PiwigoPublishing.c"
}


/**
     * Event triggered when a network login action fails due to a network error.
     *
     * This event triggered as a result of a network error during the login
     * transaction. As a result, it assumes that the service URL entered in the
     * authentication dialog is incorrect and re-presents the authentication
     * dialog with FAILED_RETRY_URL mode.
     *
     * @param bad_txn the received REST transaction
     * @param err the received error
     */
static void publishing_piwigo_piwigo_publisher_on_login_network_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportTransaction* _tmp2_;
	guint _tmp3_;
	PublishingPiwigoSession* _tmp4_;
	gboolean _tmp5_;
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 456 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:456: EVENT: on_login_network_error");
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = bad_txn;
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 457 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_login_network_complete_publishing_rest_support_transaction_completed, self);
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = bad_txn;
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_login_network_error_publishing_rest_support_transaction_network_error, self);
#line 460 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->session;
#line 460 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 460 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp5_) {
#line 461 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 3955 "PiwigoPublishing.c"
	}
#line 463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_authentication_pane (self, PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_URL);
#line 3959 "PiwigoPublishing.c"
}


/**
     * Action to fetch the session status for a known Piwigo user.
     *
     * This action fetches the session status for a Piwigo user for whom the
     * pwg_id is known. If triggered after a network login, it should just
     * confirm that the session is OK. It can also be triggered as the first
     * action of the interaction for users for who the pwg_id was previously
     * persisted. In this case, it will log the user in and confirm the
     * identity.
     */
static void _publishing_piwigo_piwigo_publisher_on_session_get_status_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_session_get_status_error ((PublishingPiwigoPiwigoPublisher*) self, _sender, err);
#line 3976 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_session_get_status_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_session_get_status_complete ((PublishingPiwigoPiwigoPublisher*) self, _sender);
#line 3983 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_fetch_session_status (PublishingPiwigoPiwigoPublisher* self, const gchar* url, const gchar* pwg_id) {
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	PublishingPiwigoSession* _tmp2_;
	gboolean _tmp3_;
	GError * _inner_error_ = NULL;
#line 476 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 476 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (url != NULL);
#line 476 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (pwg_id != NULL);
#line 477 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:477: ACTION: fetching session status");
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 478 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->host;
#line 479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp1_);
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->session;
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp3_) {
#line 4015 "PiwigoPublishing.c"
		PublishingPiwigoSessionGetStatusTransaction* status_txn = NULL;
		PublishingPiwigoSession* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		PublishingPiwigoSessionGetStatusTransaction* _tmp7_;
		PublishingPiwigoSessionGetStatusTransaction* _tmp8_;
		PublishingPiwigoSessionGetStatusTransaction* _tmp9_;
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = self->priv->session;
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = url;
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = pwg_id;
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = publishing_piwigo_session_get_status_transaction_new_unauthenticated (_tmp4_, _tmp5_, _tmp6_);
#line 482 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		status_txn = _tmp7_;
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = status_txn;
#line 483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_error_publishing_rest_support_transaction_network_error, self, 0);
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = status_txn;
#line 484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_complete_publishing_rest_support_transaction_completed, self, 0);
#line 4041 "PiwigoPublishing.c"
		{
			PublishingPiwigoSessionGetStatusTransaction* _tmp10_;
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp10_ = status_txn;
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4052 "PiwigoPublishing.c"
					goto __catch26_spit_publishing_publishing_error;
				}
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_rest_support_transaction_unref0 (status_txn);
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_clear_error (&_inner_error_);
#line 487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				return;
#line 4063 "PiwigoPublishing.c"
			}
		}
		goto __finally26;
		__catch26_spit_publishing_publishing_error:
		{
			GError* err = NULL;
			GError* _tmp11_;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			err = _inner_error_;
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_inner_error_ = NULL;
#line 489 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_debug ("PiwigoPublishing.vala:489: ERROR: do_fetch_session_status, not authent" \
"icated");
#line 490 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp11_ = err;
#line 490 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp11_);
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_error_free0 (err);
#line 4083 "PiwigoPublishing.c"
		}
		__finally26:
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_transaction_unref0 (status_txn);
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 486 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 4096 "PiwigoPublishing.c"
		}
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_transaction_unref0 (status_txn);
#line 4100 "PiwigoPublishing.c"
	} else {
		PublishingPiwigoSessionGetStatusTransaction* status_txn = NULL;
		PublishingPiwigoSession* _tmp12_;
		PublishingPiwigoSessionGetStatusTransaction* _tmp13_;
		PublishingPiwigoSessionGetStatusTransaction* _tmp14_;
		PublishingPiwigoSessionGetStatusTransaction* _tmp15_;
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp12_ = self->priv->session;
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = publishing_piwigo_session_get_status_transaction_new (_tmp12_);
#line 493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		status_txn = _tmp13_;
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp14_ = status_txn;
#line 494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_error_publishing_rest_support_transaction_network_error, self, 0);
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp15_ = status_txn;
#line 495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_complete_publishing_rest_support_transaction_completed, self, 0);
#line 4121 "PiwigoPublishing.c"
		{
			PublishingPiwigoSessionGetStatusTransaction* _tmp16_;
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp16_ = status_txn;
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4132 "PiwigoPublishing.c"
					goto __catch27_spit_publishing_publishing_error;
				}
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_rest_support_transaction_unref0 (status_txn);
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_clear_error (&_inner_error_);
#line 498 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				return;
#line 4143 "PiwigoPublishing.c"
			}
		}
		goto __finally27;
		__catch27_spit_publishing_publishing_error:
		{
			GError* err = NULL;
			GError* _tmp17_;
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			err = _inner_error_;
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_inner_error_ = NULL;
#line 500 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_debug ("PiwigoPublishing.vala:500: ERROR: do_fetch_session_status, authenticat" \
"ed");
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp17_ = err;
#line 501 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp17_);
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_error_free0 (err);
#line 4163 "PiwigoPublishing.c"
		}
		__finally27:
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_transaction_unref0 (status_txn);
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 497 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 4176 "PiwigoPublishing.c"
		}
#line 481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_transaction_unref0 (status_txn);
#line 4180 "PiwigoPublishing.c"
	}
}


/**
     * Event triggered when the get session status action completes successfully.
     *
     * This event being triggered confirms that the session is valid and can becyclonic enema
     * used. If the session is not fully authenticated yet, this event finalises
     * session authentication. It then triggers the fetch categories action.
     */
static void publishing_piwigo_piwigo_publisher_on_session_get_status_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportTransaction* _tmp2_;
	guint _tmp3_;
	PublishingPiwigoSession* _tmp4_;
	gboolean _tmp5_;
	GError * _inner_error_ = NULL;
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 514 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:514: EVENT: on_session_get_status_complete");
#line 515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = txn;
#line 515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_complete_publishing_rest_support_transaction_completed, self);
#line 516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = txn;
#line 516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_error_publishing_rest_support_transaction_network_error, self);
#line 518 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->session;
#line 518 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 518 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp5_) {
#line 4224 "PiwigoPublishing.c"
		gchar* endpoint_url = NULL;
		PublishingRESTSupportTransaction* _tmp6_;
		gchar* _tmp7_;
		gchar* pwg_id = NULL;
		PublishingPiwigoSession* _tmp8_;
		gchar* _tmp9_;
		const gchar* _tmp10_;
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = txn;
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = publishing_rest_support_transaction_get_endpoint_url (_tmp6_);
#line 519 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		endpoint_url = _tmp7_;
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = self->priv->session;
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = publishing_piwigo_session_get_pwg_id (_tmp8_);
#line 520 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		pwg_id = _tmp9_;
#line 521 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = pwg_id;
#line 521 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:521: Fetching session status for pwg_id %s", _tmp10_);
#line 4248 "PiwigoPublishing.c"
		{
			PublishingRESTSupportXmlDocument* doc = NULL;
			PublishingRESTSupportTransaction* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
			PublishingRESTSupportXmlDocument* _tmp14_;
			PublishingRESTSupportXmlDocument* _tmp15_;
			xmlNode* root = NULL;
			PublishingRESTSupportXmlDocument* _tmp16_;
			xmlNode* _tmp17_;
			xmlNode* username_node = NULL;
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp11_ = txn;
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp12_ = publishing_rest_support_transaction_get_response (_tmp11_);
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp13_ = _tmp12_;
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp14_ = publishing_rest_support_xml_document_parse_string (_tmp13_, _publishing_piwigo_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp15_ = _tmp14_;
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (_tmp13_);
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			doc = _tmp15_;
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4278 "PiwigoPublishing.c"
					goto __catch28_spit_publishing_publishing_error;
				}
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (pwg_id);
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (endpoint_url);
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_clear_error (&_inner_error_);
#line 524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				return;
#line 4291 "PiwigoPublishing.c"
			}
#line 527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp16_ = doc;
#line 527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp17_ = publishing_rest_support_xml_document_get_root_node (_tmp16_);
#line 527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			root = _tmp17_;
#line 4299 "PiwigoPublishing.c"
			{
				xmlNode* _tmp18_ = NULL;
				PublishingRESTSupportXmlDocument* _tmp19_;
				xmlNode* _tmp20_;
				xmlNode* _tmp21_;
				gchar* username = NULL;
				xmlNode* _tmp22_;
				gchar* _tmp23_;
				const gchar* _tmp24_;
				PublishingPiwigoSession* _tmp25_;
				const gchar* _tmp26_;
				const gchar* _tmp27_;
				const gchar* _tmp28_;
				PublishingPiwigoSession* _tmp29_;
				gchar* _tmp30_;
				gchar* _tmp31_;
				PublishingPiwigoSession* _tmp32_;
				gchar* _tmp33_;
				gchar* _tmp34_;
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp19_ = doc;
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp20_ = root;
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp21_ = publishing_rest_support_xml_document_get_named_child (_tmp19_, _tmp20_, "username", &_inner_error_);
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp18_ = _tmp21_;
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4331 "PiwigoPublishing.c"
						goto __catch29_spit_publishing_publishing_error;
					}
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_publishing_rest_support_xml_document_unref0 (doc);
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (pwg_id);
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (endpoint_url);
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_clear_error (&_inner_error_);
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					return;
#line 4346 "PiwigoPublishing.c"
				}
#line 530 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				username_node = _tmp18_;
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp22_ = username_node;
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp23_ = (gchar*) xmlNodeGetContent (_tmp22_);
#line 531 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				username = _tmp23_;
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp24_ = username;
#line 532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_debug ("PiwigoPublishing.vala:532: Returned username is %s", _tmp24_);
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp25_ = self->priv->session;
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp26_ = endpoint_url;
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp27_ = username;
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp28_ = pwg_id;
#line 533 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_session_authenticate (_tmp25_, _tmp26_, _tmp27_, _tmp28_);
#line 534 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp29_ = self->priv->session;
#line 534 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp30_ = publishing_piwigo_session_get_pwg_url (_tmp29_);
#line 534 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp31_ = _tmp30_;
#line 534 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_piwigo_publisher_set_persistent_url (self, _tmp31_);
#line 534 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (_tmp31_);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp32_ = self->priv->session;
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp33_ = publishing_piwigo_session_get_username (_tmp32_);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp34_ = _tmp33_;
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_piwigo_publisher_set_persistent_username (self, _tmp34_);
#line 535 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (_tmp34_);
#line 536 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_piwigo_publisher_do_fetch_categories (self);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (username);
#line 4394 "PiwigoPublishing.c"
			}
			goto __finally29;
			__catch29_spit_publishing_publishing_error:
			{
				GError* err2 = NULL;
				GError* _tmp35_;
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				err2 = _inner_error_;
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_inner_error_ = NULL;
#line 538 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_debug ("PiwigoPublishing.vala:538: ERROR: on_session_get_status_complete, inne" \
"r");
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp35_ = err2;
#line 539 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp35_);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_error_free0 (err2);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_rest_support_xml_document_unref0 (doc);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (pwg_id);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (endpoint_url);
#line 540 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				return;
#line 4421 "PiwigoPublishing.c"
			}
			__finally29:
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_rest_support_xml_document_unref0 (doc);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4430 "PiwigoPublishing.c"
					goto __catch28_spit_publishing_publishing_error;
				}
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_rest_support_xml_document_unref0 (doc);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (pwg_id);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (endpoint_url);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				g_clear_error (&_inner_error_);
#line 529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				return;
#line 4445 "PiwigoPublishing.c"
			}
#line 523 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 4449 "PiwigoPublishing.c"
		}
		goto __finally28;
		__catch28_spit_publishing_publishing_error:
		{
			GError* err = NULL;
			GError* _tmp36_;
#line 523 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			err = _inner_error_;
#line 523 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_inner_error_ = NULL;
#line 543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_debug ("PiwigoPublishing.vala:543: ERROR: on_session_get_status_complete, oute" \
"r");
#line 544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp36_ = err;
#line 544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp36_);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_error_free0 (err);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (pwg_id);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (endpoint_url);
#line 545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 4474 "PiwigoPublishing.c"
		}
		__finally28:
#line 523 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 523 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (pwg_id);
#line 523 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (endpoint_url);
#line 523 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 523 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 523 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 4489 "PiwigoPublishing.c"
		}
#line 518 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (pwg_id);
#line 518 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (endpoint_url);
#line 4495 "PiwigoPublishing.c"
	} else {
#line 551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_fetch_categories (self);
#line 4499 "PiwigoPublishing.c"
	}
}


/**
     * Event triggered when the get session status fails due to a network error.
     */
static void publishing_piwigo_piwigo_publisher_on_session_get_status_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportTransaction* _tmp2_;
	guint _tmp3_;
	PublishingRESTSupportTransaction* _tmp4_;
	GError* _tmp5_;
#line 558 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 558 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 562 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:562: EVENT: on_session_get_status_error");
#line 563 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = bad_txn;
#line 563 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 563 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_complete_publishing_rest_support_transaction_completed, self);
#line 564 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = bad_txn;
#line 564 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 564 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_session_get_status_error_publishing_rest_support_transaction_network_error, self);
#line 565 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = bad_txn;
#line 565 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = err;
#line 565 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_network_error (self, _tmp4_, _tmp5_);
#line 4538 "PiwigoPublishing.c"
}


/**
     * Action that fetches all available categories from the Piwigo service.
     *
     * This action fetches all categories from the Piwigo service in order
     * to populate the publishing pane presented to the user.
     */
static void _publishing_piwigo_piwigo_publisher_on_category_fetch_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 580 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_category_fetch_error ((PublishingPiwigoPiwigoPublisher*) self, _sender, err);
#line 4551 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_category_fetch_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_category_fetch_complete ((PublishingPiwigoPiwigoPublisher*) self, _sender);
#line 4558 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_fetch_categories (PublishingPiwigoPiwigoPublisher* self) {
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	PublishingPiwigoCategoriesGetListTransaction* cat_trans = NULL;
	PublishingPiwigoSession* _tmp2_;
	PublishingPiwigoCategoriesGetListTransaction* _tmp3_;
	GError * _inner_error_ = NULL;
#line 574 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 575 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:575: ACTION: fetching categories");
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, TRUE);
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->host;
#line 577 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_account_fetch_wait_pane (_tmp1_);
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->session;
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishing_piwigo_categories_get_list_transaction_new (_tmp2_);
#line 579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	cat_trans = _tmp3_;
#line 580 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (cat_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_category_fetch_error_publishing_rest_support_transaction_network_error, self, 0);
#line 581 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (cat_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_piwigo_piwigo_publisher_on_category_fetch_complete_publishing_rest_support_transaction_completed, self, 0);
#line 4591 "PiwigoPublishing.c"
	{
#line 584 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (cat_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 584 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 584 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4599 "PiwigoPublishing.c"
				goto __catch30_spit_publishing_publishing_error;
			}
#line 584 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_transaction_unref0 (cat_trans);
#line 584 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 584 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 584 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 4610 "PiwigoPublishing.c"
		}
	}
	goto __finally30;
	__catch30_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp4_;
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 586 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:586: ERROR: do_fetch_categories");
#line 587 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = err;
#line 587 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp4_);
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 4630 "PiwigoPublishing.c"
	}
	__finally30:
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_transaction_unref0 (cat_trans);
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 583 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 4643 "PiwigoPublishing.c"
	}
#line 574 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_transaction_unref0 (cat_trans);
#line 4647 "PiwigoPublishing.c"
}


/**
     * Event triggered when the fetch categories action completes successfully.
     *
     * This event retrieves all categories from the received transaction and
     * populates the categories list. It then triggers the display of the
     * publishing options pane.
     */
static void _vala_array_add35 (PublishingPiwigoCategory** * array, int* length, int* size, PublishingPiwigoCategory* value) {
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoCategory*, *array, (*size) + 1);
#line 4665 "PiwigoPublishing.c"
	}
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 4671 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_on_category_fetch_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportTransaction* _tmp2_;
	guint _tmp3_;
	PublishingRESTSupportTransaction* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	PublishingPiwigoCategory** _tmp7_;
	gint _tmp7__length1;
	GError * _inner_error_ = NULL;
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 598 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 599 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:599: EVENT: on_category_fetch_complete");
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = txn;
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = txn;
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = txn;
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_rest_support_transaction_get_response (_tmp4_);
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _tmp5_;
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:602: PiwigoConnector: list of categories: %s", _tmp6_);
#line 602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp6_);
#line 604 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = self->priv->categories;
#line 604 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7__length1 = self->priv->categories_length1;
#line 604 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp7_ != NULL) {
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->categories = (_vala_array_free (self->priv->categories, self->priv->categories_length1, (GDestroyNotify) publishing_piwigo_category_unref), NULL);
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->categories = NULL;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->categories_length1 = 0;
#line 605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_categories_size_ = self->priv->categories_length1;
#line 4728 "PiwigoPublishing.c"
	}
	{
		PublishingRESTSupportXmlDocument* doc = NULL;
		PublishingRESTSupportTransaction* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		PublishingRESTSupportXmlDocument* _tmp11_;
		PublishingRESTSupportXmlDocument* _tmp12_;
		xmlNode* root = NULL;
		PublishingRESTSupportXmlDocument* _tmp13_;
		xmlNode* _tmp14_;
		xmlNode* categories_node = NULL;
		xmlNode* _tmp15_;
		xmlNode* _tmp16_;
		xmlNode* category_node_iter = NULL;
		xmlNode* _tmp17_;
		xmlNode* _tmp18_;
		xmlNode* name_node = NULL;
		xmlNode* uppercats_node = NULL;
		gchar* name = NULL;
		gchar* _tmp19_;
		gchar* id_string = NULL;
		gchar* _tmp20_;
		gchar* uppercats = NULL;
		gchar* _tmp21_;
		GeeHashMap* id_map = NULL;
		GeeHashMap* _tmp22_;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = txn;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = publishing_rest_support_transaction_get_response (_tmp8_);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = _tmp9_;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = publishing_rest_support_xml_document_parse_string (_tmp10_, _publishing_piwigo_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp12_ = _tmp11_;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp10_);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		doc = _tmp12_;
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4774 "PiwigoPublishing.c"
				goto __catch31_spit_publishing_publishing_error;
			}
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 609 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 4783 "PiwigoPublishing.c"
		}
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = doc;
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp14_ = publishing_rest_support_xml_document_get_root_node (_tmp13_);
#line 612 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		root = _tmp14_;
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp15_ = root;
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp16_ = xmlFirstElementChild (_tmp15_);
#line 613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		categories_node = _tmp16_;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp17_ = categories_node;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp18_ = _tmp17_->children;
#line 614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		category_node_iter = _tmp18_;
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp19_ = g_strdup ("");
#line 617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		name = _tmp19_;
#line 618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp20_ = g_strdup ("");
#line 618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		id_string = _tmp20_;
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp21_ = g_strdup ("");
#line 619 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		uppercats = _tmp21_;
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp22_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 620 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		id_map = _tmp22_;
#line 4819 "PiwigoPublishing.c"
		{
			gboolean _tmp23_ = FALSE;
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp23_ = TRUE;
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			while (TRUE) {
#line 4826 "PiwigoPublishing.c"
				xmlNode* _tmp26_;
				xmlNode* _tmp27_ = NULL;
				PublishingRESTSupportXmlDocument* _tmp28_;
				xmlNode* _tmp29_;
				xmlNode* _tmp30_;
				xmlNode* _tmp31_;
				gchar* _tmp32_;
				xmlNode* _tmp33_ = NULL;
				PublishingRESTSupportXmlDocument* _tmp34_;
				xmlNode* _tmp35_;
				xmlNode* _tmp36_;
				xmlNode* _tmp37_;
				gchar* _tmp38_;
				xmlNode* _tmp39_;
				gchar* _tmp40_;
				GeeHashMap* _tmp41_;
				const gchar* _tmp42_;
				const gchar* _tmp43_;
				PublishingPiwigoCategory** _tmp44_;
				gint _tmp44__length1;
				PublishingPiwigoCategory** _tmp46_;
				gint _tmp46__length1;
				const gchar* _tmp47_;
				gint _tmp48_;
				const gchar* _tmp49_;
				const gchar* _tmp50_;
				PublishingPiwigoCategory* _tmp51_;
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!_tmp23_) {
#line 4856 "PiwigoPublishing.c"
					xmlNode* _tmp24_;
					xmlNode* _tmp25_;
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp24_ = category_node_iter;
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp25_ = _tmp24_->next;
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					category_node_iter = _tmp25_;
#line 4865 "PiwigoPublishing.c"
				}
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp23_ = FALSE;
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp26_ = category_node_iter;
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!(_tmp26_ != NULL)) {
#line 622 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 4875 "PiwigoPublishing.c"
				}
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp28_ = doc;
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp29_ = category_node_iter;
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp30_ = publishing_rest_support_xml_document_get_named_child (_tmp28_, _tmp29_, "name", &_inner_error_);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp27_ = _tmp30_;
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_object_unref0 (id_map);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (uppercats);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (id_string);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (name);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_publishing_rest_support_xml_document_unref0 (doc);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4899 "PiwigoPublishing.c"
						goto __catch31_spit_publishing_publishing_error;
					}
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_object_unref0 (id_map);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (uppercats);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (id_string);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (name);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_publishing_rest_support_xml_document_unref0 (doc);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_clear_error (&_inner_error_);
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					return;
#line 4918 "PiwigoPublishing.c"
				}
#line 623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				name_node = _tmp27_;
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp31_ = name_node;
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp32_ = (gchar*) xmlNodeGetContent (_tmp31_);
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (name);
#line 624 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				name = _tmp32_;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp34_ = doc;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp35_ = category_node_iter;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp36_ = publishing_rest_support_xml_document_get_named_child (_tmp34_, _tmp35_, "uppercats", &_inner_error_);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp33_ = _tmp36_;
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_object_unref0 (id_map);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (uppercats);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (id_string);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (name);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_publishing_rest_support_xml_document_unref0 (doc);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 4952 "PiwigoPublishing.c"
						goto __catch31_spit_publishing_publishing_error;
					}
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_object_unref0 (id_map);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (uppercats);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (id_string);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (name);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_publishing_rest_support_xml_document_unref0 (doc);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_clear_error (&_inner_error_);
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					return;
#line 4971 "PiwigoPublishing.c"
				}
#line 625 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				uppercats_node = _tmp33_;
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp37_ = uppercats_node;
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp38_ = (gchar*) xmlNodeGetContent (_tmp37_);
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (uppercats);
#line 626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				uppercats = (gchar*) _tmp38_;
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp39_ = category_node_iter;
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp40_ = (gchar*) xmlGetProp (_tmp39_, (xmlChar*) "id");
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (id_string);
#line 627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				id_string = _tmp40_;
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp41_ = id_map;
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp42_ = id_string;
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp43_ = name;
#line 628 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp42_, _tmp43_);
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp44_ = self->priv->categories;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp44__length1 = self->priv->categories_length1;
#line 630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_tmp44_ == NULL) {
#line 5005 "PiwigoPublishing.c"
					PublishingPiwigoCategory** _tmp45_;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp45_ = g_new0 (PublishingPiwigoCategory*, 0 + 1);
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					self->priv->categories = (_vala_array_free (self->priv->categories, self->priv->categories_length1, (GDestroyNotify) publishing_piwigo_category_unref), NULL);
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					self->priv->categories = _tmp45_;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					self->priv->categories_length1 = 0;
#line 631 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					self->priv->_categories_size_ = self->priv->categories_length1;
#line 5017 "PiwigoPublishing.c"
				}
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp46_ = self->priv->categories;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp46__length1 = self->priv->categories_length1;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp47_ = id_string;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp48_ = atoi (_tmp47_);
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp49_ = name;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp50_ = uppercats;
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp51_ = publishing_piwigo_category_new (_tmp48_, _tmp49_, _tmp50_, "");
#line 633 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_vala_array_add35 (&self->priv->categories, &self->priv->categories_length1, &self->priv->_categories_size_, _tmp51_);
#line 5035 "PiwigoPublishing.c"
			}
		}
		{
			gint i = 0;
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			i = 0;
#line 5042 "PiwigoPublishing.c"
			{
				gboolean _tmp52_ = FALSE;
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp52_ = TRUE;
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				while (TRUE) {
#line 5049 "PiwigoPublishing.c"
					gint _tmp54_;
					PublishingPiwigoCategory** _tmp55_;
					gint _tmp55__length1;
					gchar** upcatids = NULL;
					PublishingPiwigoCategory** _tmp56_;
					gint _tmp56__length1;
					gint _tmp57_;
					PublishingPiwigoCategory* _tmp58_;
					const gchar* _tmp59_;
					gchar** _tmp60_;
					gchar** _tmp61_;
					gint upcatids_length1;
					gint _upcatids_size_;
					GString* builder = NULL;
					GString* _tmp62_;
					PublishingPiwigoCategory** _tmp76_;
					gint _tmp76__length1;
					gint _tmp77_;
					PublishingPiwigoCategory* _tmp78_;
					GString* _tmp79_;
					const gchar* _tmp80_;
					gchar* _tmp81_;
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (!_tmp52_) {
#line 5074 "PiwigoPublishing.c"
						gint _tmp53_;
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp53_ = i;
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						i = _tmp53_ + 1;
#line 5080 "PiwigoPublishing.c"
					}
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp52_ = FALSE;
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp54_ = i;
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp55_ = self->priv->categories;
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp55__length1 = self->priv->categories_length1;
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (!(_tmp54_ < _tmp55__length1)) {
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						break;
#line 5094 "PiwigoPublishing.c"
					}
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp56_ = self->priv->categories;
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp56__length1 = self->priv->categories_length1;
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp57_ = i;
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp58_ = _tmp56_[_tmp57_];
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp59_ = _tmp58_->uppercats;
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp61_ = _tmp60_ = g_strsplit (_tmp59_, ",", 0);
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					upcatids = _tmp61_;
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					upcatids_length1 = _vala_array_length (_tmp60_);
#line 638 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_upcatids_size_ = upcatids_length1;
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp62_ = g_string_new ("");
#line 639 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					builder = _tmp62_;
#line 5118 "PiwigoPublishing.c"
					{
						gint j = 0;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						j = 0;
#line 5123 "PiwigoPublishing.c"
						{
							gboolean _tmp63_ = FALSE;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_tmp63_ = TRUE;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							while (TRUE) {
#line 5130 "PiwigoPublishing.c"
								gint _tmp65_;
								gchar** _tmp66_;
								gint _tmp66__length1;
								GString* _tmp67_;
								GString* _tmp68_;
								GeeHashMap* _tmp69_;
								gchar** _tmp70_;
								gint _tmp70__length1;
								gint _tmp71_;
								const gchar* _tmp72_;
								gpointer _tmp73_;
								gchar* _tmp74_;
								GString* _tmp75_;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								if (!_tmp63_) {
#line 5146 "PiwigoPublishing.c"
									gint _tmp64_;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
									_tmp64_ = j;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
									j = _tmp64_ + 1;
#line 5152 "PiwigoPublishing.c"
								}
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp63_ = FALSE;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp65_ = j;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp66_ = upcatids;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp66__length1 = upcatids_length1;
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								if (!(_tmp65_ < _tmp66__length1)) {
#line 640 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
									break;
#line 5166 "PiwigoPublishing.c"
								}
#line 641 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp67_ = builder;
#line 641 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								g_string_append (_tmp67_, "/ ");
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp68_ = builder;
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp69_ = id_map;
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp70_ = upcatids;
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp70__length1 = upcatids_length1;
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp71_ = j;
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp72_ = _tmp70_[_tmp71_];
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp73_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp69_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp72_);
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp74_ = (gchar*) _tmp73_;
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								g_string_append (_tmp68_, _tmp74_);
#line 642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_g_free0 (_tmp74_);
#line 643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp75_ = builder;
#line 643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								g_string_append (_tmp75_, " ");
#line 5196 "PiwigoPublishing.c"
							}
						}
					}
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp76_ = self->priv->categories;
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp76__length1 = self->priv->categories_length1;
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp77_ = i;
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp78_ = _tmp76_[_tmp77_];
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp79_ = builder;
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp80_ = _tmp79_->str;
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp81_ = g_strdup (_tmp80_);
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (_tmp78_->display_name);
#line 645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp78_->display_name = _tmp81_;
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_string_free0 (builder);
#line 637 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					upcatids = (_vala_array_free (upcatids, upcatids_length1, (GDestroyNotify) g_free), NULL);
#line 5222 "PiwigoPublishing.c"
				}
			}
		}
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (id_map);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (uppercats);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (id_string);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (name);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (doc);
#line 5236 "PiwigoPublishing.c"
	}
	goto __finally31;
	__catch31_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp82_;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 648 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:648: ERROR: on_category_fetch_complete");
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp82_ = err;
#line 649 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp82_);
#line 650 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 650 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 5257 "PiwigoPublishing.c"
	}
	__finally31:
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 608 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 5268 "PiwigoPublishing.c"
	}
#line 653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_publishing_options_pane (self);
#line 5272 "PiwigoPublishing.c"
}


/**
     * Event triggered when the fetch categories transaction fails due to a
     * network error.
     */
static void publishing_piwigo_piwigo_publisher_on_category_fetch_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportTransaction* _tmp2_;
	guint _tmp3_;
	PublishingRESTSupportTransaction* _tmp4_;
	GError* _tmp5_;
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 660 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:664: EVENT: on_category_fetch_error");
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = bad_txn;
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_fetch_complete_publishing_rest_support_transaction_completed, self);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = bad_txn;
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 666 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_fetch_error_publishing_rest_support_transaction_network_error, self);
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = bad_txn;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = err;
#line 667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_network_error (self, _tmp4_, _tmp5_);
#line 5311 "PiwigoPublishing.c"
}


/**
     * Action that shows the publishing options pane.
     *
     * This action method shows the publishing options pane.
     */
static void _publishing_piwigo_piwigo_publisher_on_publishing_options_pane_logout_clicked_publishing_piwigo_publishing_options_pane_logout (PublishingPiwigoPublishingOptionsPane* _sender, gpointer self) {
#line 682 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_publishing_options_pane_logout_clicked ((PublishingPiwigoPiwigoPublisher*) self);
#line 5323 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_publishing_options_pane_publish_clicked_publishing_piwigo_publishing_options_pane_publish (PublishingPiwigoPublishingOptionsPane* _sender, PublishingPiwigoPublishingParameters* parameters, gboolean strip_metadata, gpointer self) {
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_publishing_options_pane_publish_clicked ((PublishingPiwigoPiwigoPublisher*) self, parameters, strip_metadata);
#line 5330 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_show_publishing_options_pane (PublishingPiwigoPiwigoPublisher* self) {
	SpitPublishingPluginHost* _tmp0_;
	PublishingPiwigoPublishingOptionsPane* opts_pane = NULL;
	PublishingPiwigoCategory** _tmp1_;
	gint _tmp1__length1;
	gint _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
	gboolean _tmp7_;
	PublishingPiwigoPublishingOptionsPane* _tmp8_;
	SpitPublishingPluginHost* _tmp9_;
	SpitPublishingPluginHost* _tmp10_;
	GtkWidget* _tmp11_;
	GtkWidget* _tmp12_;
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 676 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:676: ACTION: installing publishing options pane");
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 678 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->categories;
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1__length1 = self->priv->categories_length1;
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_piwigo_piwigo_publisher_get_last_category (self);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishing_piwigo_piwigo_publisher_get_last_permission_level (self);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = publishing_piwigo_piwigo_publisher_get_last_photo_size (self);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_piwigo_piwigo_publisher_get_last_title_as_comment (self);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_piwigo_piwigo_publisher_get_last_no_upload_tags (self);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = publishing_piwigo_piwigo_publisher_get_metadata_removal_choice (self);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = publishing_piwigo_publishing_options_pane_new (self, _tmp1_, _tmp1__length1, _tmp2_, _tmp3_, _tmp4_, _tmp5_, _tmp6_, _tmp7_);
#line 679 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	opts_pane = _tmp8_;
#line 682 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (opts_pane, "logout", (GCallback) _publishing_piwigo_piwigo_publisher_on_publishing_options_pane_logout_clicked_publishing_piwigo_publishing_options_pane_logout, self, 0);
#line 683 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (opts_pane, "publish", (GCallback) _publishing_piwigo_piwigo_publisher_on_publishing_options_pane_publish_clicked_publishing_piwigo_publishing_options_pane_publish, self, 0);
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = self->priv->host;
#line 684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_dialog_pane (_tmp9_, G_TYPE_CHECK_INSTANCE_CAST (opts_pane, SPIT_PUBLISHING_TYPE_DIALOG_PANE, SpitPublishingDialogPane), SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = self->priv->host;
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = shotwell_plugins_common_builder_pane_get_default_widget (G_TYPE_CHECK_INSTANCE_CAST (opts_pane, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane));
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = _tmp11_;
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_dialog_default_widget (_tmp10_, _tmp12_);
#line 685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp12_);
#line 675 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (opts_pane);
#line 5398 "PiwigoPublishing.c"
}


/**
     * Event triggered when the user clicks logout in the publishing options pane.
     */
static void _publishing_piwigo_piwigo_publisher_on_logout_network_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 694 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_logout_network_error ((PublishingPiwigoPiwigoPublisher*) self, _sender, err);
#line 5408 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_logout_network_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 695 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_logout_network_complete ((PublishingPiwigoPiwigoPublisher*) self, _sender);
#line 5415 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_on_publishing_options_pane_logout_clicked (PublishingPiwigoPiwigoPublisher* self) {
	PublishingPiwigoSessionLogoutTransaction* logout_trans = NULL;
	PublishingPiwigoSession* _tmp0_;
	PublishingPiwigoSessionLogoutTransaction* _tmp1_;
	GError * _inner_error_ = NULL;
#line 691 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 692 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:692: EVENT: on_publishing_options_pane_logout_cl" \
"icked");
#line 693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->session;
#line 693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishing_piwigo_session_logout_transaction_new (_tmp0_);
#line 693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	logout_trans = _tmp1_;
#line 694 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (logout_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_logout_network_error_publishing_rest_support_transaction_network_error, self, 0);
#line 695 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (logout_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_piwigo_piwigo_publisher_on_logout_network_complete_publishing_rest_support_transaction_completed, self, 0);
#line 5438 "PiwigoPublishing.c"
	{
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (logout_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5446 "PiwigoPublishing.c"
				goto __catch32_spit_publishing_publishing_error;
			}
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_transaction_unref0 (logout_trans);
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 5457 "PiwigoPublishing.c"
		}
	}
	goto __finally32;
	__catch32_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp2_;
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 700 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:700: ERROR: on_publishing_options_pane_logout_cl" \
"icked");
#line 701 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp2_ = err;
#line 701 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp2_);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 5477 "PiwigoPublishing.c"
	}
	__finally32:
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_transaction_unref0 (logout_trans);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 5490 "PiwigoPublishing.c"
	}
#line 691 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_transaction_unref0 (logout_trans);
#line 5494 "PiwigoPublishing.c"
}


/**
     * Event triggered when the logout action completes successfully.
     *
     * This event de-authenticates the session and shows the authentication
     * pane again.
     */
static void publishing_piwigo_piwigo_publisher_on_logout_network_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportTransaction* _tmp2_;
	guint _tmp3_;
	PublishingPiwigoSession* _tmp4_;
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 711 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 712 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:712: EVENT: on_logout_network_complete");
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = txn;
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 713 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_logout_network_complete_publishing_rest_support_transaction_completed, self);
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = txn;
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_logout_network_error_publishing_rest_support_transaction_network_error, self);
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->session;
#line 716 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_session_deauthenticate (_tmp4_);
#line 718 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_authentication_pane (self, PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_INTRO);
#line 5534 "PiwigoPublishing.c"
}


/**
     * Event triggered when the logout action fails due to a network error.
     */
static void publishing_piwigo_piwigo_publisher_on_logout_network_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportTransaction* _tmp2_;
	guint _tmp3_;
	PublishingRESTSupportTransaction* _tmp4_;
	GError* _tmp5_;
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 728 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:728: EVENT: on_logout_network_error");
#line 729 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = bad_txn;
#line 729 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 729 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_logout_network_complete_publishing_rest_support_transaction_completed, self);
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = bad_txn;
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_logout_network_error_publishing_rest_support_transaction_network_error, self);
#line 731 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = bad_txn;
#line 731 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = err;
#line 731 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_network_error (self, _tmp4_, _tmp5_);
#line 5572 "PiwigoPublishing.c"
}


/**
     * Event triggered when the user clicks publish in the publishing options pane.
     *
     * This event first saves the parameters so that they can re-used later.
     * If the publishing parameters indicate that the user wants to create a new
     * category, the create category action is called. Otherwise, the upload
     * action is called.
     *
     * @param parameters the publishing parameters
     */
static gpointer _publishing_piwigo_publishing_parameters_ref0 (gpointer self) {
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self ? publishing_piwigo_publishing_parameters_ref (self) : NULL;
#line 5589 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_on_publishing_options_pane_publish_clicked (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoPublishingParameters* parameters, gboolean strip_metadata) {
	PublishingPiwigoPublishingParameters* _tmp0_;
	PublishingPiwigoPublishingParameters* _tmp1_;
	gboolean _tmp2_;
	PublishingPiwigoPublishingParameters* _tmp3_;
	PublishingPiwigoCategory* _tmp4_;
	gboolean _tmp5_;
#line 744 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 744 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_PARAMETERS (parameters));
#line 746 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:746: EVENT: on_publishing_options_pane_publish_c" \
"licked");
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = parameters;
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _publishing_piwigo_publishing_parameters_ref0 (_tmp0_);
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (self->priv->parameters);
#line 747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->parameters = _tmp1_;
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = strip_metadata;
#line 748 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->strip_metadata = _tmp2_;
#line 750 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = parameters;
#line 750 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_->category;
#line 750 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_piwigo_category_is_local (_tmp4_);
#line 750 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp5_) {
#line 5626 "PiwigoPublishing.c"
		PublishingPiwigoPublishingParameters* _tmp6_;
		PublishingPiwigoCategory* _tmp7_;
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = parameters;
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = _tmp6_->category;
#line 751 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_create_category (self, _tmp7_);
#line 5635 "PiwigoPublishing.c"
	} else {
		gboolean _tmp8_;
#line 753 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = self->priv->strip_metadata;
#line 753 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_upload (self, _tmp8_);
#line 5642 "PiwigoPublishing.c"
	}
}


/**
     * Action that creates a new category in the Piwigo library.
     *
     * This actions runs a REST transaction to create a new category in the
     * Piwigo library. It displays a wait pane with an information message
     * while the transaction is running. This action should only be called with
     * a local cateogory, i.e. one that does not exist on the server and does
     * not yet have an ID.
     *
     * @param category the new category to create on the server
     */
static gchar* string_strip (const gchar* self) {
	gchar* result = NULL;
	gchar* _result_ = NULL;
	gchar* _tmp0_;
	const gchar* _tmp1_;
#line 1234 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1235 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = g_strdup (self);
#line 1235 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_result_ = _tmp0_;
#line 1236 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp1_ = _result_;
#line 1236 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	g_strstrip (_tmp1_);
#line 1237 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	result = _result_;
#line 1237 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	return result;
#line 5677 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_category_add_error_publishing_rest_support_transaction_network_error (PublishingRESTSupportTransaction* _sender, GError* err, gpointer self) {
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_category_add_error ((PublishingPiwigoPiwigoPublisher*) self, _sender, err);
#line 5684 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_category_add_complete_publishing_rest_support_transaction_completed (PublishingRESTSupportTransaction* _sender, gpointer self) {
#line 778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_category_add_complete ((PublishingPiwigoPiwigoPublisher*) self, _sender);
#line 5691 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_create_category (PublishingPiwigoPiwigoPublisher* self, PublishingPiwigoCategory* category) {
	PublishingPiwigoCategory* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	PublishingPiwigoCategory* _tmp4_;
	gboolean _tmp5_;
	SpitPublishingPluginHost* _tmp6_;
	SpitPublishingPluginHost* _tmp7_;
	PublishingPiwigoCategory* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	PublishingPiwigoCategoriesAddTransaction* creation_trans = NULL;
	PublishingPiwigoSession* _tmp12_;
	PublishingPiwigoCategory* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	PublishingPiwigoCategory* _tmp17_;
	const gchar* _tmp18_;
	gint _tmp19_;
	PublishingPiwigoCategory* _tmp20_;
	const gchar* _tmp21_;
	PublishingPiwigoCategoriesAddTransaction* _tmp22_;
	PublishingPiwigoCategoriesAddTransaction* _tmp23_;
	GError * _inner_error_ = NULL;
#line 768 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 768 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_CATEGORY (category));
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = category;
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _tmp0_->name;
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = g_strdup_printf ("ACTION: creating a new category: %s", _tmp1_);
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _tmp2_;
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:769: %s", _tmp3_);
#line 769 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp3_);
#line 770 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = category;
#line 770 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_piwigo_category_is_local (_tmp4_);
#line 770 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_assert (_tmp5_, "category.is_local()");
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = self->priv->host;
#line 772 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp6_, TRUE);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = self->priv->host;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = category;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = _tmp8_->name;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = g_strdup_printf (_ ("Creating album %s…"), _tmp9_);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = _tmp10_;
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_static_message_pane (_tmp7_, _tmp11_, SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CANCEL);
#line 773 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp11_);
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = self->priv->session;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = category;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = _tmp13_->name;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = string_strip (_tmp14_);
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = _tmp15_;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = category;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = _tmp17_->uppercats;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = atoi (_tmp18_);
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = category;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp21_ = _tmp20_->comment;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp22_ = publishing_piwigo_categories_add_transaction_new (_tmp12_, _tmp16_, _tmp19_, _tmp21_);
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp23_ = _tmp22_;
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp16_);
#line 775 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	creation_trans = _tmp23_;
#line 777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (creation_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "network-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_category_add_error_publishing_rest_support_transaction_network_error, self, 0);
#line 778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (creation_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "completed", (GCallback) _publishing_piwigo_piwigo_publisher_on_category_add_complete_publishing_rest_support_transaction_completed, self, 0);
#line 5794 "PiwigoPublishing.c"
	{
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_execute (G_TYPE_CHECK_INSTANCE_CAST (creation_trans, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_inner_error_);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5802 "PiwigoPublishing.c"
				goto __catch33_spit_publishing_publishing_error;
			}
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_transaction_unref0 (creation_trans);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 5813 "PiwigoPublishing.c"
		}
	}
	goto __finally33;
	__catch33_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp24_;
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 783 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:783: ERROR: do_create_category");
#line 784 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp24_ = err;
#line 784 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp24_);
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 5833 "PiwigoPublishing.c"
	}
	__finally33:
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_transaction_unref0 (creation_trans);
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 780 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 5846 "PiwigoPublishing.c"
	}
#line 768 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_transaction_unref0 (creation_trans);
#line 5850 "PiwigoPublishing.c"
}


/**
     * Event triggered when the add category action completes successfully.
     *
     * This event parses the ID assigned to new category out of the received
     * transaction and assigns that ID to the category currently held in
     * the publishing parameters. It then calls the upload action.
     */
static void publishing_piwigo_piwigo_publisher_on_category_add_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn) {
	PublishingRESTSupportTransaction* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportTransaction* _tmp2_;
	guint _tmp3_;
	GError * _inner_error_ = NULL;
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 795 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn));
#line 796 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:796: EVENT: on_category_add_complete");
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = txn;
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 797 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_add_complete_publishing_rest_support_transaction_completed, self);
#line 798 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = txn;
#line 798 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 798 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_add_error_publishing_rest_support_transaction_network_error, self);
#line 5885 "PiwigoPublishing.c"
	{
		PublishingRESTSupportXmlDocument* doc = NULL;
		PublishingRESTSupportTransaction* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		PublishingRESTSupportXmlDocument* _tmp7_;
		PublishingRESTSupportXmlDocument* _tmp8_;
		xmlNode* rsp = NULL;
		PublishingRESTSupportXmlDocument* _tmp9_;
		xmlNode* _tmp10_;
		xmlNode* id_node = NULL;
		xmlNode* _tmp11_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp12_;
		xmlNode* _tmp13_;
		xmlNode* _tmp14_;
		gchar* id_string = NULL;
		xmlNode* _tmp15_;
		gchar* _tmp16_;
		gint id = 0;
		const gchar* _tmp17_;
		gint _tmp18_;
		PublishingPiwigoPublishingParameters* _tmp19_;
		PublishingPiwigoCategory* _tmp20_;
		gint _tmp21_;
		gboolean _tmp22_;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = txn;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = publishing_rest_support_transaction_get_response (_tmp4_);
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = _tmp5_;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = publishing_rest_support_xml_document_parse_string (_tmp6_, _publishing_piwigo_transaction_validate_xml_publishing_rest_support_xml_document_check_for_error_response, NULL, &_inner_error_);
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = _tmp7_;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp6_);
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		doc = _tmp8_;
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5929 "PiwigoPublishing.c"
				goto __catch34_spit_publishing_publishing_error;
			}
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 802 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 5938 "PiwigoPublishing.c"
		}
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = doc;
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = publishing_rest_support_xml_document_get_root_node (_tmp9_);
#line 805 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		rsp = _tmp10_;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp12_ = doc;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = rsp;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp14_ = publishing_rest_support_xml_document_get_named_child (_tmp12_, _tmp13_, "id", &_inner_error_);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = _tmp14_;
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 5960 "PiwigoPublishing.c"
				goto __catch34_spit_publishing_publishing_error;
			}
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_rest_support_xml_document_unref0 (doc);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return;
#line 5971 "PiwigoPublishing.c"
		}
#line 807 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		id_node = _tmp11_;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp15_ = id_node;
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp16_ = (gchar*) xmlNodeGetContent (_tmp15_);
#line 808 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		id_string = _tmp16_;
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp17_ = id_string;
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp18_ = atoi (_tmp17_);
#line 809 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		id = _tmp18_;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp19_ = self->priv->parameters;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp20_ = _tmp19_->category;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp21_ = id;
#line 810 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp20_->id = _tmp21_;
#line 811 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp22_ = self->priv->strip_metadata;
#line 811 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_upload (self, _tmp22_);
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (id_string);
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_rest_support_xml_document_unref0 (doc);
#line 6003 "PiwigoPublishing.c"
	}
	goto __finally34;
	__catch34_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		GError* _tmp23_;
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 813 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_debug ("PiwigoPublishing.vala:813: ERROR: on_category_add_complete");
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp23_ = err;
#line 814 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp23_);
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 6022 "PiwigoPublishing.c"
	}
	__finally34:
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 801 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 6033 "PiwigoPublishing.c"
	}
}


/**
     * Event triggered when the add category action fails due to a network error.
     */
static void publishing_piwigo_piwigo_publisher_on_category_add_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	PublishingRESTSupportTransaction* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportTransaction* _tmp2_;
	guint _tmp3_;
	PublishingRESTSupportTransaction* _tmp4_;
	GError* _tmp5_;
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 821 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 825 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:825: EVENT: on_category_add_error");
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = bad_txn;
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("completed", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp1_, NULL, FALSE);
#line 826 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_add_complete_publishing_rest_support_transaction_completed, self);
#line 827 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = bad_txn;
#line 827 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("network-error", PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, &_tmp3_, NULL, FALSE);
#line 827 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_category_add_error_publishing_rest_support_transaction_network_error, self);
#line 828 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = bad_txn;
#line 828 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = err;
#line 828 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_network_error (self, _tmp4_, _tmp5_);
#line 6072 "PiwigoPublishing.c"
}


/**
     * Upload action: the big one, the one we've been waiting for!
     */
static void _publishing_piwigo_piwigo_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete (PublishingRESTSupportBatchUploader* _sender, gint num_photos_published, gpointer self) {
#line 851 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_upload_complete ((PublishingPiwigoPiwigoPublisher*) self, _sender, num_photos_published);
#line 6082 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error (PublishingRESTSupportBatchUploader* _sender, GError* err, gpointer self) {
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_upload_error ((PublishingPiwigoPiwigoPublisher*) self, _sender, err);
#line 6089 "PiwigoPublishing.c"
}


static void _publishing_piwigo_piwigo_publisher_on_upload_status_updated_spit_publishing_progress_callback (gint file_number, gdouble fraction_complete, gpointer self) {
#line 853 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_on_upload_status_updated ((PublishingPiwigoPiwigoPublisher*) self, file_number, fraction_complete);
#line 6096 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_do_upload (PublishingPiwigoPiwigoPublisher* self, gboolean strip_metadata) {
	gboolean _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	PublishingPiwigoPublishingParameters* _tmp2_;
	PublishingPiwigoCategory* _tmp3_;
	gint _tmp4_;
	PublishingPiwigoPublishingParameters* _tmp5_;
	PublishingPiwigoPermissionLevel* _tmp6_;
	gint _tmp7_;
	PublishingPiwigoPublishingParameters* _tmp8_;
	PublishingPiwigoSizeEntry* _tmp9_;
	gint _tmp10_;
	PublishingPiwigoPublishingParameters* _tmp11_;
	gboolean _tmp12_;
	PublishingPiwigoPublishingParameters* _tmp13_;
	gboolean _tmp14_;
	gboolean _tmp15_;
	SpitPublishingPluginHost* _tmp16_;
	PublishingPiwigoPublishingParameters* _tmp17_;
	PublishingPiwigoSizeEntry* _tmp18_;
	gint _tmp19_;
	gboolean _tmp20_;
	void* _tmp21_;
	GDestroyNotify _tmp22_;
	SpitPublishingProgressCallback _tmp23_;
	SpitPublishingPublishable** publishables = NULL;
	SpitPublishingPluginHost* _tmp24_;
	gint _tmp25_;
	SpitPublishingPublishable** _tmp26_;
	gint publishables_length1;
	gint _publishables_size_;
	PublishingPiwigoUploader* uploader = NULL;
	PublishingPiwigoSession* _tmp27_;
	PublishingPiwigoPublishingParameters* _tmp28_;
	PublishingPiwigoUploader* _tmp29_;
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 835 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = strip_metadata;
#line 835 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->strip_metadata = _tmp0_;
#line 836 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:836: ACTION: uploading pictures");
#line 838 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->host;
#line 838 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp1_, TRUE);
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->parameters;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _tmp2_->category;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_->id;
#line 840 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_last_category (self, _tmp4_);
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = self->priv->parameters;
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _tmp5_->perm_level;
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = _tmp6_->id;
#line 841 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_last_permission_level (self, _tmp7_);
#line 842 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = self->priv->parameters;
#line 842 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = _tmp8_->photo_size;
#line 842 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = _tmp9_->id;
#line 842 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_last_photo_size (self, _tmp10_);
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = self->priv->parameters;
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = _tmp11_->title_as_comment;
#line 843 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_last_title_as_comment (self, _tmp12_);
#line 844 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = self->priv->parameters;
#line 844 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = _tmp13_->no_upload_tags;
#line 844 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_last_no_upload_tags (self, _tmp14_);
#line 845 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = strip_metadata;
#line 845 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_set_metadata_removal_choice (self, _tmp15_);
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = self->priv->host;
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = self->priv->parameters;
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = _tmp17_->photo_size;
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = _tmp18_->id;
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = self->priv->strip_metadata;
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp23_ = spit_publishing_plugin_host_serialize_publishables (_tmp16_, _tmp19_, _tmp20_, &_tmp21_, &_tmp22_);
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter = _tmp23_;
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target = _tmp21_;
#line 847 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = _tmp22_;
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp24_ = self->priv->host;
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp26_ = spit_publishing_plugin_host_get_publishables (_tmp24_, &_tmp25_);
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishables = _tmp26_;
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishables_length1 = _tmp25_;
#line 848 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishables_size_ = publishables_length1;
#line 850 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp27_ = self->priv->session;
#line 850 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp28_ = self->priv->parameters;
#line 850 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp29_ = publishing_piwigo_uploader_new (_tmp27_, publishables, publishables_length1, _tmp28_);
#line 850 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	uploader = _tmp29_;
#line 851 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (uploader, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-complete", (GCallback) _publishing_piwigo_piwigo_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self, 0);
#line 852 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (uploader, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), "upload-error", (GCallback) _publishing_piwigo_piwigo_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self, 0);
#line 853 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_batch_uploader_upload (G_TYPE_CHECK_INSTANCE_CAST (uploader, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader), _publishing_piwigo_piwigo_publisher_on_upload_status_updated_spit_publishing_progress_callback, self);
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_batch_uploader_unref0 (uploader);
#line 834 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishables = (_vala_array_free (publishables, publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 6241 "PiwigoPublishing.c"
}


/**
     * Event triggered when the batch uploader reports that at least one of the
     * network transactions encapsulating uploads has completed successfully
     */
static void publishing_piwigo_piwigo_publisher_on_upload_complete (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportBatchUploader* uploader, gint num_published) {
	PublishingRESTSupportBatchUploader* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportBatchUploader* _tmp2_;
	guint _tmp3_;
#line 860 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 860 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 861 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:861: EVENT: on_upload_complete");
#line 862 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = uploader;
#line 862 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp1_, NULL, FALSE);
#line 862 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 863 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = uploader;
#line 863 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp3_, NULL, FALSE);
#line 863 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 867 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_success_pane (self);
#line 6274 "PiwigoPublishing.c"
}


/**
     * Event triggered when the batch uploader reports that at least one of the
     * network transactions encapsulating uploads has caused a network error
     */
static void publishing_piwigo_piwigo_publisher_on_upload_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportBatchUploader* uploader, GError* err) {
	PublishingRESTSupportBatchUploader* _tmp0_;
	guint _tmp1_;
	PublishingRESTSupportBatchUploader* _tmp2_;
	guint _tmp3_;
	GError* _tmp4_;
#line 874 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 874 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_BATCH_UPLOADER (uploader));
#line 878 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:878: EVENT: on_upload_error");
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = uploader;
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("upload-complete", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp1_, NULL, FALSE);
#line 879 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_upload_complete_publishing_rest_support_batch_uploader_upload_complete, self);
#line 880 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = uploader;
#line 880 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_parse_name ("upload-error", PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, &_tmp3_, NULL, FALSE);
#line 880 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_handlers_disconnect_matched (_tmp2_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp3_, 0, NULL, (GCallback) _publishing_piwigo_piwigo_publisher_on_upload_error_publishing_rest_support_batch_uploader_upload_error, self);
#line 882 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = err;
#line 882 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp4_);
#line 6310 "PiwigoPublishing.c"
}


/**
     * Event triggered when upload progresses and the status needs to be updated.
     */
static void publishing_piwigo_piwigo_publisher_on_upload_status_updated (PublishingPiwigoPiwigoPublisher* self, gint file_number, gdouble completed_fraction) {
	gboolean _tmp0_;
	gdouble _tmp1_;
	SpitPublishingProgressCallback _tmp2_;
	void* _tmp2__target;
	SpitPublishingProgressCallback _tmp3_;
	void* _tmp3__target;
	gint _tmp4_;
	gdouble _tmp5_;
#line 888 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = spit_publishing_publisher_is_running (G_TYPE_CHECK_INSTANCE_CAST (self, SPIT_PUBLISHING_TYPE_PUBLISHER, SpitPublishingPublisher));
#line 889 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp0_) {
#line 890 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 6334 "PiwigoPublishing.c"
	}
#line 892 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = completed_fraction;
#line 892 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:892: EVENT: uploader reports upload %.2f percent" \
" complete.", 100.0 * _tmp1_);
#line 894 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->progress_reporter;
#line 894 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2__target = self->priv->progress_reporter_target;
#line 894 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_assert (_tmp2_ != NULL, "progress_reporter != null");
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = self->priv->progress_reporter;
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3__target = self->priv->progress_reporter_target;
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = file_number;
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = completed_fraction;
#line 896 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ (_tmp4_, _tmp5_, _tmp3__target);
#line 6356 "PiwigoPublishing.c"
}


/**
     * Action to display the success pane in the publishing dialog.
     */
static void publishing_piwigo_piwigo_publisher_do_show_success_pane (PublishingPiwigoPiwigoPublisher* self) {
	SpitPublishingPluginHost* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
#line 902 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 903 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:903: ACTION: installing success pane");
#line 905 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 905 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_service_locked (_tmp0_, FALSE);
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->host;
#line 906 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_success_pane (_tmp1_);
#line 6378 "PiwigoPublishing.c"
}


/**
     * Helper event to handle network errors.
     */
static void publishing_piwigo_piwigo_publisher_on_network_error (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* bad_txn, GError* err) {
	GError* _tmp0_;
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 912 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (bad_txn));
#line 916 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:916: EVENT: on_network_error");
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = err;
#line 917 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_error (self, _tmp0_);
#line 6397 "PiwigoPublishing.c"
}


/**
     * Action to display an error to the user.
     */
static void publishing_piwigo_piwigo_publisher_do_show_error (PublishingPiwigoPiwigoPublisher* self, GError* e) {
	gchar* error_type = NULL;
	gchar* _tmp0_;
	GError* _tmp1_;
	const gchar* _tmp16_;
	GError* _tmp17_;
	const gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 924 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:924: ACTION: do_show_error");
#line 925 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = g_strdup ("UNKNOWN");
#line 925 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	error_type = _tmp0_;
#line 926 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = e;
#line 926 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_error_matches (_tmp1_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_NO_ANSWER)) {
#line 927 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_piwigo_publisher_do_show_authentication_pane (self, PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_URL);
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (error_type);
#line 928 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return;
#line 6431 "PiwigoPublishing.c"
	} else {
		GError* _tmp2_;
#line 929 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp2_ = e;
#line 929 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (g_error_matches (_tmp2_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_COMMUNICATION_FAILED)) {
#line 6438 "PiwigoPublishing.c"
			gchar* _tmp3_;
#line 930 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp3_ = g_strdup ("COMMUNICATION_FAILED");
#line 930 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (error_type);
#line 930 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			error_type = _tmp3_;
#line 6446 "PiwigoPublishing.c"
		} else {
			GError* _tmp4_;
#line 931 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp4_ = e;
#line 931 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (g_error_matches (_tmp4_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_PROTOCOL_ERROR)) {
#line 6453 "PiwigoPublishing.c"
				gchar* _tmp5_;
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp5_ = g_strdup ("PROTOCOL_ERROR");
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_g_free0 (error_type);
#line 932 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				error_type = _tmp5_;
#line 6461 "PiwigoPublishing.c"
			} else {
				GError* _tmp6_;
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp6_ = e;
#line 933 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (g_error_matches (_tmp6_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_SERVICE_ERROR)) {
#line 6468 "PiwigoPublishing.c"
					gchar* _tmp7_;
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp7_ = g_strdup ("SERVICE_ERROR");
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (error_type);
#line 934 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					error_type = _tmp7_;
#line 6476 "PiwigoPublishing.c"
				} else {
					GError* _tmp8_;
#line 935 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp8_ = e;
#line 935 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (g_error_matches (_tmp8_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_MALFORMED_RESPONSE)) {
#line 6483 "PiwigoPublishing.c"
						gchar* _tmp9_;
#line 936 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp9_ = g_strdup ("MALFORMED_RESPONSE");
#line 936 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_g_free0 (error_type);
#line 936 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						error_type = _tmp9_;
#line 6491 "PiwigoPublishing.c"
					} else {
						GError* _tmp10_;
#line 937 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp10_ = e;
#line 937 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						if (g_error_matches (_tmp10_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_LOCAL_FILE_ERROR)) {
#line 6498 "PiwigoPublishing.c"
							gchar* _tmp11_;
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_tmp11_ = g_strdup ("LOCAL_FILE_ERROR");
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_g_free0 (error_type);
#line 938 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							error_type = _tmp11_;
#line 6506 "PiwigoPublishing.c"
						} else {
							GError* _tmp12_;
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_tmp12_ = e;
#line 939 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							if (g_error_matches (_tmp12_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_EXPIRED_SESSION)) {
#line 6513 "PiwigoPublishing.c"
								gchar* _tmp13_;
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp13_ = g_strdup ("EXPIRED_SESSION");
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_g_free0 (error_type);
#line 940 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								error_type = _tmp13_;
#line 6521 "PiwigoPublishing.c"
							} else {
								GError* _tmp14_;
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								_tmp14_ = e;
#line 941 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
								if (g_error_matches (_tmp14_, SPIT_PUBLISHING_PUBLISHING_ERROR, SPIT_PUBLISHING_PUBLISHING_ERROR_SSL_FAILED)) {
#line 6528 "PiwigoPublishing.c"
									gchar* _tmp15_;
#line 942 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
									_tmp15_ = g_strdup ("SECURE_CONNECTION_FAILED");
#line 942 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
									_g_free0 (error_type);
#line 942 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
									error_type = _tmp15_;
#line 6536 "PiwigoPublishing.c"
								}
							}
						}
					}
				}
			}
		}
	}
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = error_type;
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = e;
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = _tmp17_->message;
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = g_strdup_printf ("Unhandled error: type=%s; message='%s'", _tmp16_, _tmp18_);
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = _tmp19_;
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:945: %s", _tmp20_);
#line 945 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp20_);
#line 946 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_do_show_error_message (self, _ ("An error message occurred when publishing to Piwigo. Please try again."));
#line 923 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (error_type);
#line 6563 "PiwigoPublishing.c"
}


/**
     * Action to display an error message to the user.
     */
static void publishing_piwigo_piwigo_publisher_do_show_error_message (PublishingPiwigoPiwigoPublisher* self, const gchar* message) {
	SpitPublishingPluginHost* _tmp0_;
	const gchar* _tmp1_;
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self));
#line 952 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (message != NULL);
#line 953 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:953: ACTION: do_show_error_message");
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->host;
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = message;
#line 954 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_install_static_message_pane (_tmp0_, _tmp1_, SPIT_PUBLISHING_PLUGIN_HOST_BUTTON_MODE_CLOSE);
#line 6585 "PiwigoPublishing.c"
}


/**
     * Retrieves session ID from a REST Transaction received
     *
     * This helper method extracts the pwg_id out of the Set-Cookie header if
     * present in the received transaction.
     *
     * @param txn the received transaction
     * @return the value of pwg_id if present or null if not found
     */
static SoupCookie* _vala_SoupCookie_copy (SoupCookie* self) {
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return g_boxed_copy (soup_cookie_get_type (), self);
#line 6601 "PiwigoPublishing.c"
}


static gpointer __vala_SoupCookie_copy0 (gpointer self) {
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self ? _vala_SoupCookie_copy (self) : NULL;
#line 6608 "PiwigoPublishing.c"
}


static void _vala_SoupCookie_free (SoupCookie* self) {
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_boxed_free (soup_cookie_get_type (), self);
#line 6615 "PiwigoPublishing.c"
}


static void __vala_SoupCookie_free0_ (gpointer var) {
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(var == NULL) ? NULL : (var = (_vala_SoupCookie_free (var), NULL));
#line 6622 "PiwigoPublishing.c"
}


static void _g_slist_free___vala_SoupCookie_free0_ (GSList* self) {
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_slist_foreach (self, (GFunc) __vala_SoupCookie_free0_, NULL);
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_slist_free (self);
#line 6631 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_piwigo_publisher_get_pwg_id_from_transaction (PublishingPiwigoPiwigoPublisher* self, PublishingRESTSupportTransaction* txn) {
	gchar* result = NULL;
	gchar* pwg_id = NULL;
	PublishingRESTSupportTransaction* _tmp0_;
	SoupMessage* _tmp1_;
	SoupMessage* _tmp2_;
	GSList* _tmp3_;
	GSList* _tmp4_;
#line 969 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (self), NULL);
#line 969 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_TRANSACTION (txn), NULL);
#line 970 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	pwg_id = NULL;
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = txn;
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishing_rest_support_transaction_get_message (_tmp0_);
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = _tmp1_;
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = soup_cookies_from_response (_tmp2_);
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_;
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp2_);
#line 6661 "PiwigoPublishing.c"
	{
		GSList* cookie_collection = NULL;
		GSList* cookie_it = NULL;
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		cookie_collection = _tmp4_;
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		for (cookie_it = cookie_collection; cookie_it != NULL; cookie_it = cookie_it->next) {
#line 6669 "PiwigoPublishing.c"
			SoupCookie* _tmp5_;
			SoupCookie* cookie = NULL;
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp5_ = __vala_SoupCookie_copy0 ((SoupCookie*) cookie_it->data);
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			cookie = _tmp5_;
#line 6676 "PiwigoPublishing.c"
			{
				SoupCookie* _tmp6_;
				const gchar* _tmp7_;
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp6_ = cookie;
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp7_ = soup_cookie_get_name (_tmp6_);
#line 973 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (g_strcmp0 (_tmp7_, "pwg_id") == 0) {
#line 6686 "PiwigoPublishing.c"
					SoupCookie* _tmp8_;
					const gchar* _tmp9_;
					gchar* _tmp10_;
					const gchar* _tmp11_;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp8_ = cookie;
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp9_ = soup_cookie_get_value (_tmp8_);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp10_ = g_strdup (_tmp9_);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (pwg_id);
#line 976 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					pwg_id = _tmp10_;
#line 977 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp11_ = pwg_id;
#line 977 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					g_debug ("PiwigoPublishing.vala:977: Found pwg_id %s", _tmp11_);
#line 6705 "PiwigoPublishing.c"
				}
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				__vala_SoupCookie_free0 (cookie);
#line 6709 "PiwigoPublishing.c"
			}
		}
#line 972 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		__g_slist_free___vala_SoupCookie_free0_0 (cookie_collection);
#line 6714 "PiwigoPublishing.c"
	}
#line 981 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = pwg_id;
#line 981 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 6720 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_class_init (PublishingPiwigoPiwigoPublisherClass * klass) {
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_parent_class = g_type_class_peek_parent (klass);
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPiwigoPiwigoPublisherPrivate));
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_piwigo_piwigo_publisher_finalize;
#line 6731 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_spit_publishing_publisher_interface_init (SpitPublishingPublisherIface * iface) {
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_piwigo_publisher_spit_publishing_publisher_parent_iface = g_type_interface_peek_parent (iface);
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->get_service = (SpitPublishingService* (*) (SpitPublishingPublisher *)) publishing_piwigo_piwigo_publisher_real_get_service;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->is_running = (gboolean (*) (SpitPublishingPublisher *)) publishing_piwigo_piwigo_publisher_real_is_running;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->start = (void (*) (SpitPublishingPublisher *)) publishing_piwigo_piwigo_publisher_real_start;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	iface->stop = (void (*) (SpitPublishingPublisher *)) publishing_piwigo_piwigo_publisher_real_stop;
#line 6746 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_instance_init (PublishingPiwigoPiwigoPublisher * self) {
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv = PUBLISHING_PIWIGO_PIWIGO_PUBLISHER_GET_PRIVATE (self);
#line 128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->running = FALSE;
#line 129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->strip_metadata = FALSE;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->categories = NULL;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->categories_length1 = 0;
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->_categories_size_ = self->priv->categories_length1;
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->parameters = NULL;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target = self;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 6771 "PiwigoPublishing.c"
}


static void publishing_piwigo_piwigo_publisher_finalize (GObject * obj) {
	PublishingPiwigoPiwigoPublisher * self;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, PublishingPiwigoPiwigoPublisher);
#line 126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->service);
#line 127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->host);
#line 130 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_session_unref0 (self->priv->session);
#line 131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->categories = (_vala_array_free (self->priv->categories, self->priv->categories_length1, (GDestroyNotify) publishing_piwigo_category_unref), NULL);
#line 132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (self->priv->parameters);
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(self->priv->progress_reporter_target_destroy_notify == NULL) ? NULL : (self->priv->progress_reporter_target_destroy_notify (self->priv->progress_reporter_target), NULL);
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter = NULL;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target = NULL;
#line 133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->progress_reporter_target_destroy_notify = NULL;
#line 125 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (publishing_piwigo_piwigo_publisher_parent_class)->finalize (obj);
#line 6799 "PiwigoPublishing.c"
}


GType publishing_piwigo_piwigo_publisher_get_type (void) {
	static volatile gsize publishing_piwigo_piwigo_publisher_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_piwigo_publisher_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoPiwigoPublisherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_piwigo_publisher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoPiwigoPublisher), 0, (GInstanceInitFunc) publishing_piwigo_piwigo_publisher_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_publisher_info = { (GInterfaceInitFunc) publishing_piwigo_piwigo_publisher_spit_publishing_publisher_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_piwigo_piwigo_publisher_type_id;
		publishing_piwigo_piwigo_publisher_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingPiwigoPiwigoPublisher", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_piwigo_piwigo_publisher_type_id, SPIT_PUBLISHING_TYPE_PUBLISHER, &spit_publishing_publisher_info);
		g_once_init_leave (&publishing_piwigo_piwigo_publisher_type_id__volatile, publishing_piwigo_piwigo_publisher_type_id);
	}
	return publishing_piwigo_piwigo_publisher_type_id__volatile;
}


PublishingPiwigoUploader* publishing_piwigo_uploader_construct (GType object_type, PublishingPiwigoSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingPiwigoPublishingParameters* parameters) {
	PublishingPiwigoUploader* self = NULL;
	PublishingPiwigoSession* _tmp0_;
	SpitPublishingPublishable** _tmp1_;
	gint _tmp1__length1;
	PublishingPiwigoPublishingParameters* _tmp2_;
	PublishingPiwigoPublishingParameters* _tmp3_;
#line 990 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 990 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishables;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1__length1 = publishables_length1;
#line 992 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoUploader*) publishing_rest_support_batch_uploader_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, _tmp1__length1);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = parameters;
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _publishing_piwigo_publishing_parameters_ref0 (_tmp2_);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (self->priv->parameters);
#line 994 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->parameters = _tmp3_;
#line 990 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 6846 "PiwigoPublishing.c"
}


PublishingPiwigoUploader* publishing_piwigo_uploader_new (PublishingPiwigoSession* session, SpitPublishingPublishable** publishables, int publishables_length1, PublishingPiwigoPublishingParameters* parameters) {
#line 990 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_uploader_construct (PUBLISHING_PIWIGO_TYPE_UPLOADER, session, publishables, publishables_length1, parameters);
#line 6853 "PiwigoPublishing.c"
}


static PublishingRESTSupportTransaction* publishing_piwigo_uploader_real_create_transaction (PublishingRESTSupportBatchUploader* base, SpitPublishingPublishable* publishable) {
	PublishingPiwigoUploader * self;
	PublishingRESTSupportTransaction* result = NULL;
	PublishingRESTSupportSession* _tmp0_;
	PublishingPiwigoSession* _tmp1_;
	PublishingPiwigoPublishingParameters* _tmp2_;
	SpitPublishingPublishable* _tmp3_;
	PublishingPiwigoImagesAddTransaction* _tmp4_;
	PublishingRESTSupportTransaction* _tmp5_;
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_UPLOADER, PublishingPiwigoUploader);
#line 997 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = publishing_rest_support_batch_uploader_get_session (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, PublishingRESTSupportBatchUploader));
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSession);
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->parameters;
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishable;
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = publishing_piwigo_images_add_transaction_new (_tmp1_, _tmp2_, _tmp3_);
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction);
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_rest_support_session_unref0 (_tmp1_);
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp5_;
#line 999 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 6888 "PiwigoPublishing.c"
}


static void publishing_piwigo_uploader_class_init (PublishingPiwigoUploaderClass * klass) {
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_uploader_parent_class = g_type_class_peek_parent (klass);
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->finalize = publishing_piwigo_uploader_finalize;
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPiwigoUploaderPrivate));
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingRESTSupportBatchUploaderClass *) klass)->create_transaction = (PublishingRESTSupportTransaction* (*) (PublishingRESTSupportBatchUploader *, SpitPublishingPublishable*)) publishing_piwigo_uploader_real_create_transaction;
#line 6901 "PiwigoPublishing.c"
}


static void publishing_piwigo_uploader_instance_init (PublishingPiwigoUploader * self) {
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv = PUBLISHING_PIWIGO_UPLOADER_GET_PRIVATE (self);
#line 6908 "PiwigoPublishing.c"
}


static void publishing_piwigo_uploader_finalize (PublishingRESTSupportBatchUploader * obj) {
	PublishingPiwigoUploader * self;
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_UPLOADER, PublishingPiwigoUploader);
#line 988 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (self->priv->parameters);
#line 987 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	PUBLISHING_REST_SUPPORT_BATCH_UPLOADER_CLASS (publishing_piwigo_uploader_parent_class)->finalize (obj);
#line 6920 "PiwigoPublishing.c"
}


GType publishing_piwigo_uploader_get_type (void) {
	static volatile gsize publishing_piwigo_uploader_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_uploader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoUploaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_uploader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoUploader), 0, (GInstanceInitFunc) publishing_piwigo_uploader_instance_init, NULL };
		GType publishing_piwigo_uploader_type_id;
		publishing_piwigo_uploader_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_BATCH_UPLOADER, "PublishingPiwigoUploader", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_uploader_type_id__volatile, publishing_piwigo_uploader_type_id);
	}
	return publishing_piwigo_uploader_type_id__volatile;
}


PublishingPiwigoSSLErrorPane* publishing_piwigo_ssl_error_pane_construct (GType object_type, PublishingPiwigoSessionLoginTransaction* transaction, const gchar* host) {
	PublishingPiwigoSSLErrorPane * self = NULL;
	GTlsCertificate* cert = NULL;
	gchar* text = NULL;
	PublishingPiwigoSessionLoginTransaction* _tmp0_;
	GTlsCertificate* _tmp1_ = NULL;
	gchar* _tmp2_;
	const gchar* _tmp3_;
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION_LOGIN_TRANSACTION (transaction), NULL);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (host != NULL, NULL);
#line 1016 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = transaction;
#line 1016 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_rest_support_transaction_detailed_error_from_tls_flags (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_tmp1_);
#line 1016 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (cert);
#line 1016 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	cert = _tmp1_;
#line 1016 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	text = _tmp2_;
#line 1017 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = host;
#line 1017 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSSLErrorPane*) g_object_new (object_type, "resource-path", PLUGIN_RESOURCE_PATH "/piwigo_ssl_failure_pane.ui", "default-id", "default", "cert", cert, "error-text", text, "host", _tmp3_, NULL);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (text);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (cert);
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 6968 "PiwigoPublishing.c"
}


PublishingPiwigoSSLErrorPane* publishing_piwigo_ssl_error_pane_new (PublishingPiwigoSessionLoginTransaction* transaction, const gchar* host) {
#line 1013 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_ssl_error_pane_construct (PUBLISHING_PIWIGO_TYPE_SSL_ERROR_PANE, transaction, host);
#line 6975 "PiwigoPublishing.c"
}


static void __lambda5_ (PublishingPiwigoSSLErrorPane* self) {
	GcrSimpleCertificate* simple_cert = NULL;
	GTlsCertificate* _tmp0_;
	GByteArray* _tmp1_;
	GByteArray* _tmp2_;
	GByteArray* _tmp3_;
	guint8* _tmp4_;
	gint _tmp4__length1;
	GcrSimpleCertificate* _tmp5_;
	GcrSimpleCertificate* _tmp6_;
	GcrCertificateWidget* widget = NULL;
	GcrSimpleCertificate* _tmp7_;
	GcrCertificateWidget* _tmp8_;
	gboolean use_header = FALSE;
	GtkSettings* _tmp9_;
	GtkDialogFlags flags = 0;
	gboolean _tmp10_;
	GtkDialog* dialog = NULL;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	GtkDialogFlags _tmp17_;
	GtkDialog* _tmp18_;
	GtkDialog* _tmp19_;
	GtkBox* _tmp20_;
	GcrCertificateWidget* _tmp21_;
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_cert;
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_get (_tmp0_, "certificate", &_tmp1_, NULL);
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = _tmp1_;
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _tmp2_;
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_->data;
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4__length1 = (gint) _tmp3_->len;
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = (GcrSimpleCertificate*) gcr_simple_certificate_new (_tmp4_, _tmp4__length1);
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _tmp5_;
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_byte_array_unref0 (_tmp3_);
#line 1038 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	simple_cert = _tmp6_;
#line 1039 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = simple_cert;
#line 1039 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = gcr_certificate_widget_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gcr_certificate_get_type (), GcrCertificate));
#line 1039 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_ref_sink (_tmp8_);
#line 1039 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	widget = _tmp8_;
#line 1040 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	use_header = TRUE;
#line 1041 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = gtk_settings_get_default ();
#line 1041 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 1042 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	flags = (GtkDialogFlags) 0;
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = use_header;
#line 1043 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp10_) {
#line 7047 "PiwigoPublishing.c"
		GtkDialogFlags _tmp11_;
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = flags;
#line 1044 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		flags = _tmp11_ | GTK_DIALOG_USE_HEADER_BAR;
#line 7053 "PiwigoPublishing.c"
	}
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = publishing_piwigo_ssl_error_pane_get_host (self);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = _tmp12_;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = _tmp13_;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = g_strdup_printf (_ ("Certificate of %s"), _tmp14_);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = _tmp15_;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = flags;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = (GtkDialog*) gtk_dialog_new_with_buttons (_tmp16_, NULL, _tmp17_, _ ("_OK"), GTK_RESPONSE_OK, NULL);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_ref_sink (_tmp18_);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = _tmp18_;
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp16_);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp14_);
#line 1047 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	dialog = _tmp19_;
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = (GtkBox*) gtk_dialog_get_content_area (dialog);
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp21_ = widget;
#line 1052 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_widget_get_type (), GtkWidget));
#line 1053 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_dialog_set_default_response (dialog, (gint) GTK_RESPONSE_OK);
#line 1054 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_window_set_default_size (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_window_get_type (), GtkWindow), 640, -1);
#line 1055 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 1056 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_dialog_run (dialog);
#line 1057 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (dialog, gtk_widget_get_type (), GtkWidget));
#line 1037 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (dialog);
#line 1037 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (widget);
#line 1037 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (simple_cert);
#line 7101 "PiwigoPublishing.c"
}


static void ___lambda5__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1037 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	__lambda5_ ((PublishingPiwigoSSLErrorPane*) self);
#line 7108 "PiwigoPublishing.c"
}


static void __lambda6_ (PublishingPiwigoSSLErrorPane* self) {
#line 1061 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_emit (self, publishing_piwigo_ssl_error_pane_signals[PUBLISHING_PIWIGO_SSL_ERROR_PANE_PROCEED_SIGNAL], 0);
#line 7115 "PiwigoPublishing.c"
}


static void ___lambda6__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1061 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	__lambda6_ ((PublishingPiwigoSSLErrorPane*) self);
#line 7122 "PiwigoPublishing.c"
}


static void publishing_piwigo_ssl_error_pane_real_constructed (GObject* base) {
	PublishingPiwigoSSLErrorPane * self;
	GtkLabel* label = NULL;
	GtkBuilder* _tmp0_;
	GtkBuilder* _tmp1_;
	GObject* _tmp2_;
	GtkLabel* _tmp3_;
	GtkLabel* _tmp4_;
	GtkLabel* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	GtkLabel* _tmp11_;
	GtkBuilder* _tmp12_;
	GtkBuilder* _tmp13_;
	GObject* _tmp14_;
	GtkLabel* _tmp15_;
	GtkLabel* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GtkButton* info = NULL;
	GtkBuilder* _tmp20_;
	GtkBuilder* _tmp21_;
	GObject* _tmp22_;
	GtkButton* _tmp23_;
	GtkButton* _tmp24_;
	GtkButton* proceed = NULL;
	GtkBuilder* _tmp25_;
	GtkBuilder* _tmp26_;
	GObject* _tmp27_;
	GtkButton* _tmp28_;
	GtkButton* _tmp29_;
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_SSL_ERROR_PANE, PublishingPiwigoSSLErrorPane);
#line 1026 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (publishing_piwigo_ssl_error_pane_parent_class)->constructed (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane), G_TYPE_OBJECT, GObject));
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = shotwell_plugins_common_builder_pane_get_builder (G_TYPE_CHECK_INSTANCE_CAST (self, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane));
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _tmp0_;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = gtk_builder_get_object (_tmp1_, "main_text");
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp2_) : NULL);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_;
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp1_);
#line 1028 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	label = _tmp4_;
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = label;
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_piwigo_ssl_error_pane_get_host (self);
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = _tmp6_;
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = _tmp7_;
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = g_strdup_printf (_ ("This does not look like the real <b>%s</b>. Attackers might be trying " \
"to steal or alter information going to or from this site (for example," \
" private messages, credit card information, or passwords)."), _tmp8_);
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = _tmp9_;
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_label_set_text (_tmp5_, _tmp10_);
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp10_);
#line 1030 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp8_);
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = label;
#line 1031 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_label_set_use_markup (_tmp11_, TRUE);
#line 1033 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = shotwell_plugins_common_builder_pane_get_builder (G_TYPE_CHECK_INSTANCE_CAST (self, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane));
#line 1033 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = _tmp12_;
#line 1033 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = gtk_builder_get_object (_tmp13_, "ssl_errors");
#line 1033 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp14_) : NULL);
#line 1033 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (label);
#line 1033 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	label = _tmp15_;
#line 1033 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp13_);
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = label;
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = publishing_piwigo_ssl_error_pane_get_error_text (self);
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = _tmp17_;
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = _tmp18_;
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_label_set_text (_tmp16_, _tmp19_);
#line 1034 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp19_);
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = shotwell_plugins_common_builder_pane_get_builder (G_TYPE_CHECK_INSTANCE_CAST (self, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane));
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp21_ = _tmp20_;
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp22_ = gtk_builder_get_object (_tmp21_, "default");
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp23_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, gtk_button_get_type ()) ? ((GtkButton*) _tmp22_) : NULL);
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp24_ = _tmp23_;
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp21_);
#line 1036 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	info = _tmp24_;
#line 1037 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (info, "clicked", (GCallback) ___lambda5__gtk_button_clicked, self, 0);
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp25_ = shotwell_plugins_common_builder_pane_get_builder (G_TYPE_CHECK_INSTANCE_CAST (self, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane));
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp26_ = _tmp25_;
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp27_ = gtk_builder_get_object (_tmp26_, "proceed_button");
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp28_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, gtk_button_get_type ()) ? ((GtkButton*) _tmp27_) : NULL);
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp29_ = _tmp28_;
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp26_);
#line 1060 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	proceed = _tmp29_;
#line 1061 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (proceed, "clicked", (GCallback) ___lambda6__gtk_button_clicked, self, 0);
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (proceed);
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (info);
#line 1025 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (label);
#line 7265 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_ssl_error_pane_get_host (PublishingPiwigoSSLErrorPane* self) {
	gchar* result;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SSL_ERROR_PANE (self), NULL);
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_host;
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 7283 "PiwigoPublishing.c"
}


static void publishing_piwigo_ssl_error_pane_set_host (PublishingPiwigoSSLErrorPane* self, const gchar* value) {
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_SSL_ERROR_PANE (self));
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_strcmp0 (value, publishing_piwigo_ssl_error_pane_get_host (self)) != 0) {
#line 7292 "PiwigoPublishing.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = value;
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (self->priv->_host);
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_host = _tmp1_;
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_notify ((GObject *) self, "host");
#line 7305 "PiwigoPublishing.c"
	}
}


static GTlsCertificate* publishing_piwigo_ssl_error_pane_get_cert (PublishingPiwigoSSLErrorPane* self) {
	GTlsCertificate* result;
	GTlsCertificate* _tmp0_;
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SSL_ERROR_PANE (self), NULL);
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_cert;
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 7321 "PiwigoPublishing.c"
}


static void publishing_piwigo_ssl_error_pane_set_cert (PublishingPiwigoSSLErrorPane* self, GTlsCertificate* value) {
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_SSL_ERROR_PANE (self));
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (publishing_piwigo_ssl_error_pane_get_cert (self) != value) {
#line 7330 "PiwigoPublishing.c"
		GTlsCertificate* _tmp0_;
		GTlsCertificate* _tmp1_;
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = value;
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->_cert);
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_cert = _tmp1_;
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_notify ((GObject *) self, "cert");
#line 7343 "PiwigoPublishing.c"
	}
}


gchar* publishing_piwigo_ssl_error_pane_get_error_text (PublishingPiwigoSSLErrorPane* self) {
	gchar* result;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SSL_ERROR_PANE (self), NULL);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_error_text;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 7362 "PiwigoPublishing.c"
}


static void publishing_piwigo_ssl_error_pane_set_error_text (PublishingPiwigoSSLErrorPane* self, const gchar* value) {
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_SSL_ERROR_PANE (self));
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_strcmp0 (value, publishing_piwigo_ssl_error_pane_get_error_text (self)) != 0) {
#line 7371 "PiwigoPublishing.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = value;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (self->priv->_error_text);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_error_text = _tmp1_;
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_notify ((GObject *) self, "error-text");
#line 7384 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_ssl_error_pane_class_init (PublishingPiwigoSSLErrorPaneClass * klass) {
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_ssl_error_pane_parent_class = g_type_class_peek_parent (klass);
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPiwigoSSLErrorPanePrivate));
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((GObjectClass *) klass)->constructed = (void (*) (GObject *)) publishing_piwigo_ssl_error_pane_real_constructed;
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_publishing_piwigo_ssl_error_pane_get_property;
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_publishing_piwigo_ssl_error_pane_set_property;
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_piwigo_ssl_error_pane_finalize;
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_PIWIGO_SSL_ERROR_PANE_HOST_PROPERTY, g_param_spec_string ("host", "host", "host", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_PIWIGO_SSL_ERROR_PANE_CERT_PROPERTY, g_param_spec_object ("cert", "cert", "cert", g_tls_certificate_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_PIWIGO_SSL_ERROR_PANE_ERROR_TEXT_PROPERTY, g_param_spec_string ("error-text", "error-text", "error-text", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_ssl_error_pane_signals[PUBLISHING_PIWIGO_SSL_ERROR_PANE_PROCEED_SIGNAL] = g_signal_new ("proceed", PUBLISHING_PIWIGO_TYPE_SSL_ERROR_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 7410 "PiwigoPublishing.c"
}


static void publishing_piwigo_ssl_error_pane_instance_init (PublishingPiwigoSSLErrorPane * self) {
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv = PUBLISHING_PIWIGO_SSL_ERROR_PANE_GET_PRIVATE (self);
#line 7417 "PiwigoPublishing.c"
}


static void publishing_piwigo_ssl_error_pane_finalize (GObject * obj) {
	PublishingPiwigoSSLErrorPane * self;
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_SSL_ERROR_PANE, PublishingPiwigoSSLErrorPane);
#line 1009 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->_host);
#line 1010 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->_cert);
#line 1011 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->_error_text);
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (publishing_piwigo_ssl_error_pane_parent_class)->finalize (obj);
#line 7433 "PiwigoPublishing.c"
}


GType publishing_piwigo_ssl_error_pane_get_type (void) {
	static volatile gsize publishing_piwigo_ssl_error_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_ssl_error_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoSSLErrorPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_ssl_error_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoSSLErrorPane), 0, (GInstanceInitFunc) publishing_piwigo_ssl_error_pane_instance_init, NULL };
		GType publishing_piwigo_ssl_error_pane_type_id;
		publishing_piwigo_ssl_error_pane_type_id = g_type_register_static (SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, "PublishingPiwigoSSLErrorPane", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_ssl_error_pane_type_id__volatile, publishing_piwigo_ssl_error_pane_type_id);
	}
	return publishing_piwigo_ssl_error_pane_type_id__volatile;
}


static void _vala_publishing_piwigo_ssl_error_pane_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	PublishingPiwigoSSLErrorPane * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PUBLISHING_PIWIGO_TYPE_SSL_ERROR_PANE, PublishingPiwigoSSLErrorPane);
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	switch (property_id) {
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_SSL_ERROR_PANE_HOST_PROPERTY:
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_value_take_string (value, publishing_piwigo_ssl_error_pane_get_host (self));
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_SSL_ERROR_PANE_CERT_PROPERTY:
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_value_set_object (value, publishing_piwigo_ssl_error_pane_get_cert (self));
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_SSL_ERROR_PANE_ERROR_TEXT_PROPERTY:
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_value_take_string (value, publishing_piwigo_ssl_error_pane_get_error_text (self));
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 7472 "PiwigoPublishing.c"
		default:
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 7478 "PiwigoPublishing.c"
	}
}


static void _vala_publishing_piwigo_ssl_error_pane_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	PublishingPiwigoSSLErrorPane * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PUBLISHING_PIWIGO_TYPE_SSL_ERROR_PANE, PublishingPiwigoSSLErrorPane);
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	switch (property_id) {
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_SSL_ERROR_PANE_HOST_PROPERTY:
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_ssl_error_pane_set_host (self, g_value_get_string (value));
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_SSL_ERROR_PANE_CERT_PROPERTY:
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_ssl_error_pane_set_cert (self, g_value_get_object (value));
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_SSL_ERROR_PANE_ERROR_TEXT_PROPERTY:
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_ssl_error_pane_set_error_text (self, g_value_get_string (value));
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 7506 "PiwigoPublishing.c"
		default:
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1006 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 7512 "PiwigoPublishing.c"
	}
}


GType publishing_piwigo_authentication_pane_mode_get_type (void) {
	static volatile gsize publishing_piwigo_authentication_pane_mode_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_authentication_pane_mode_type_id__volatile)) {
		static const GEnumValue values[] = {{PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_INTRO, "PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_INTRO", "intro"}, {PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_URL, "PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_URL", "failed-retry-url"}, {PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER, "PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER", "failed-retry-user"}, {0, NULL, NULL}};
		GType publishing_piwigo_authentication_pane_mode_type_id;
		publishing_piwigo_authentication_pane_mode_type_id = g_enum_register_static ("PublishingPiwigoAuthenticationPaneMode", values);
		g_once_init_leave (&publishing_piwigo_authentication_pane_mode_type_id__volatile, publishing_piwigo_authentication_pane_mode_type_id);
	}
	return publishing_piwigo_authentication_pane_mode_type_id__volatile;
}


PublishingPiwigoAuthenticationPane* publishing_piwigo_authentication_pane_construct (GType object_type, PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoAuthenticationPaneMode mode) {
	PublishingPiwigoAuthenticationPane * self = NULL;
	PublishingPiwigoAuthenticationPaneMode _tmp0_;
	PublishingPiwigoPiwigoPublisher* _tmp1_;
#line 1091 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (publisher), NULL);
#line 1092 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = mode;
#line 1092 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publisher;
#line 1092 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoAuthenticationPane*) g_object_new (object_type, "resource-path", PLUGIN_RESOURCE_PATH "/piwigo_authentication_pane.ui", "connect-signals", TRUE, "default-id", "login_button", "mode", _tmp0_, "publisher", _tmp1_, NULL);
#line 1091 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 7543 "PiwigoPublishing.c"
}


PublishingPiwigoAuthenticationPane* publishing_piwigo_authentication_pane_new (PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoAuthenticationPaneMode mode) {
#line 1091 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_authentication_pane_construct (PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, publisher, mode);
#line 7550 "PiwigoPublishing.c"
}


static void _publishing_piwigo_authentication_pane_on_user_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 1142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_on_user_changed ((PublishingPiwigoAuthenticationPane*) self);
#line 7557 "PiwigoPublishing.c"
}


static void _publishing_piwigo_authentication_pane_on_url_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 1143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_on_url_changed ((PublishingPiwigoAuthenticationPane*) self);
#line 7564 "PiwigoPublishing.c"
}


static void _publishing_piwigo_authentication_pane_on_password_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_on_password_changed ((PublishingPiwigoAuthenticationPane*) self);
#line 7571 "PiwigoPublishing.c"
}


static void _publishing_piwigo_authentication_pane_on_login_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_on_login_button_clicked ((PublishingPiwigoAuthenticationPane*) self);
#line 7578 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_real_constructed (GObject* base) {
	PublishingPiwigoAuthenticationPane * self;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_;
	GtkLabel* message_label = NULL;
	GtkBuilder* _tmp1_;
	GObject* _tmp2_;
	GtkLabel* _tmp3_;
	PublishingPiwigoAuthenticationPaneMode _tmp4_;
	GtkBuilder* _tmp15_;
	GObject* _tmp16_;
	GtkEntry* _tmp17_;
	gchar* persistent_url = NULL;
	PublishingPiwigoPiwigoPublisher* _tmp18_;
	gchar* _tmp19_;
	const gchar* _tmp20_;
	GtkBuilder* _tmp23_;
	GObject* _tmp24_;
	GtkEntry* _tmp25_;
	gchar* persistent_username = NULL;
	PublishingPiwigoPiwigoPublisher* _tmp26_;
	gchar* _tmp27_;
	const gchar* _tmp28_;
	GtkBuilder* _tmp31_;
	GObject* _tmp32_;
	GtkEntry* _tmp33_;
	gchar* persistent_password = NULL;
	PublishingPiwigoPiwigoPublisher* _tmp34_;
	gchar* _tmp35_;
	const gchar* _tmp36_;
	GtkBuilder* _tmp39_;
	GObject* _tmp40_;
	GtkSwitch* _tmp41_;
	GtkSwitch* _tmp42_;
	PublishingPiwigoPiwigoPublisher* _tmp43_;
	gboolean _tmp44_;
	GtkBuilder* _tmp45_;
	GObject* _tmp46_;
	GtkButton* _tmp47_;
	GtkEntry* _tmp48_;
	GtkEntry* _tmp49_;
	GtkEntry* _tmp50_;
	GtkButton* _tmp51_;
	PublishingPiwigoPiwigoPublisher* _tmp52_;
	SpitPublishingPluginHost* _tmp53_;
	SpitPublishingPluginHost* _tmp54_;
	GtkButton* _tmp55_;
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPane);
#line 1101 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (publishing_piwigo_authentication_pane_parent_class)->constructed (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane), G_TYPE_OBJECT, GObject));
#line 1103 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = shotwell_plugins_common_builder_pane_get_builder (G_TYPE_CHECK_INSTANCE_CAST (self, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane));
#line 1103 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	builder = _tmp0_;
#line 1104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = builder;
#line 1104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = gtk_builder_get_object (_tmp1_, "message_label");
#line 1104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp2_) : NULL);
#line 1104 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	message_label = _tmp3_;
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->_mode;
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	switch (_tmp4_) {
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_INTRO:
#line 7651 "PiwigoPublishing.c"
		{
			GtkLabel* _tmp5_;
			const gchar* _tmp6_;
#line 1107 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp5_ = message_label;
#line 1107 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp6_ = publishing_piwigo_authentication_pane_INTRO_MESSAGE;
#line 1107 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			gtk_label_set_text (_tmp5_, _tmp6_);
#line 1108 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			break;
#line 7663 "PiwigoPublishing.c"
		}
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_URL:
#line 7667 "PiwigoPublishing.c"
		{
			GtkLabel* _tmp7_;
			const gchar* _tmp8_;
			gchar* _tmp9_;
			gchar* _tmp10_;
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp7_ = message_label;
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp8_ = publishing_piwigo_authentication_pane_FAILED_RETRY_URL_MESSAGE;
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp9_ = g_strdup_printf ("<b>%s</b>\n\n%s", _ ("Invalid URL"), _tmp8_);
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp10_ = _tmp9_;
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			gtk_label_set_markup (_tmp7_, _tmp10_);
#line 1111 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (_tmp10_);
#line 1113 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			break;
#line 7687 "PiwigoPublishing.c"
		}
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_FAILED_RETRY_USER:
#line 7691 "PiwigoPublishing.c"
		{
			GtkLabel* _tmp11_;
			const gchar* _tmp12_;
			gchar* _tmp13_;
			gchar* _tmp14_;
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp11_ = message_label;
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp12_ = publishing_piwigo_authentication_pane_FAILED_RETRY_USER_MESSAGE;
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp13_ = g_strdup_printf ("<b>%s</b>\n\n%s", _ ("Invalid User Name or Password"), _tmp12_);
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp14_ = _tmp13_;
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			gtk_label_set_markup (_tmp11_, _tmp14_);
#line 1116 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (_tmp14_);
#line 1118 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			break;
#line 7711 "PiwigoPublishing.c"
		}
		default:
#line 1105 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 7716 "PiwigoPublishing.c"
	}
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = builder;
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = gtk_builder_get_object (_tmp15_, "url_entry");
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp16_) : NULL);
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->url_entry);
#line 1121 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->url_entry = _tmp17_;
#line 1122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = self->priv->_publisher;
#line 1122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = publishing_piwigo_piwigo_publisher_get_persistent_url (_tmp18_);
#line 1122 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	persistent_url = _tmp19_;
#line 1123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = persistent_url;
#line 1123 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp20_ != NULL) {
#line 7738 "PiwigoPublishing.c"
		GtkEntry* _tmp21_;
		const gchar* _tmp22_;
#line 1124 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp21_ = self->priv->url_entry;
#line 1124 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp22_ = persistent_url;
#line 1124 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_entry_set_text (_tmp21_, _tmp22_);
#line 7747 "PiwigoPublishing.c"
	}
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp23_ = builder;
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp24_ = gtk_builder_get_object (_tmp23_, "username_entry");
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp25_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp24_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp24_) : NULL);
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 1126 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->username_entry = _tmp25_;
#line 1127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp26_ = self->priv->_publisher;
#line 1127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp27_ = publishing_piwigo_piwigo_publisher_get_persistent_username (_tmp26_);
#line 1127 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	persistent_username = _tmp27_;
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp28_ = persistent_username;
#line 1128 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp28_ != NULL) {
#line 7769 "PiwigoPublishing.c"
		GtkEntry* _tmp29_;
		const gchar* _tmp30_;
#line 1129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp29_ = self->priv->username_entry;
#line 1129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp30_ = persistent_username;
#line 1129 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_entry_set_text (_tmp29_, _tmp30_);
#line 7778 "PiwigoPublishing.c"
	}
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp31_ = builder;
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp32_ = gtk_builder_get_object (_tmp31_, "password_entry");
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp33_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp32_) : NULL);
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 1131 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->password_entry = _tmp33_;
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp34_ = self->priv->_publisher;
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp35_ = publishing_piwigo_piwigo_publisher_get_persistent_password (_tmp34_);
#line 1132 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	persistent_password = _tmp35_;
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp36_ = persistent_password;
#line 1133 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp36_ != NULL) {
#line 7800 "PiwigoPublishing.c"
		GtkEntry* _tmp37_;
		const gchar* _tmp38_;
#line 1134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp37_ = self->priv->password_entry;
#line 1134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp38_ = persistent_password;
#line 1134 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_entry_set_text (_tmp37_, _tmp38_);
#line 7809 "PiwigoPublishing.c"
	}
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp39_ = builder;
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp40_ = gtk_builder_get_object (_tmp39_, "remember_password_checkbutton");
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp41_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, gtk_switch_get_type ()) ? ((GtkSwitch*) _tmp40_) : NULL);
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->remember_password_checkbutton);
#line 1136 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->remember_password_checkbutton = _tmp41_;
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp42_ = self->priv->remember_password_checkbutton;
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp43_ = self->priv->_publisher;
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp44_ = publishing_piwigo_piwigo_publisher_get_remember_password (_tmp43_);
#line 1138 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_switch_set_active (_tmp42_, _tmp44_);
#line 1140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp45_ = builder;
#line 1140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp46_ = gtk_builder_get_object (_tmp45_, "login_button");
#line 1140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp47_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp46_, gtk_button_get_type ()) ? ((GtkButton*) _tmp46_) : NULL);
#line 1140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->login_button);
#line 1140 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->login_button = _tmp47_;
#line 1142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp48_ = self->priv->username_entry;
#line 1142 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_piwigo_authentication_pane_on_user_changed_gtk_editable_changed, self, 0);
#line 1143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp49_ = self->priv->url_entry;
#line 1143 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_piwigo_authentication_pane_on_url_changed_gtk_editable_changed, self, 0);
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp50_ = self->priv->password_entry;
#line 1144 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_piwigo_authentication_pane_on_password_changed_gtk_editable_changed, self, 0);
#line 1145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp51_ = self->priv->login_button;
#line 1145 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (_tmp51_, "clicked", (GCallback) _publishing_piwigo_authentication_pane_on_login_button_clicked_gtk_button_clicked, self, 0);
#line 1147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp52_ = self->priv->_publisher;
#line 1147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp53_ = publishing_piwigo_piwigo_publisher_get_host (_tmp52_);
#line 1147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp54_ = _tmp53_;
#line 1147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp55_ = self->priv->login_button;
#line 1147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	spit_publishing_plugin_host_set_dialog_default_widget (_tmp54_, G_TYPE_CHECK_INSTANCE_CAST (_tmp55_, gtk_widget_get_type (), GtkWidget));
#line 1147 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp54_);
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (persistent_password);
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (persistent_username);
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (persistent_url);
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (message_label);
#line 1100 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (builder);
#line 7877 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_on_login_button_clicked (PublishingPiwigoAuthenticationPane* self) {
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	GtkEntry* _tmp2_;
	const gchar* _tmp3_;
	GtkEntry* _tmp4_;
	const gchar* _tmp5_;
	GtkSwitch* _tmp6_;
	gboolean _tmp7_;
#line 1150 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self));
#line 1151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->url_entry;
#line 1151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 1151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->username_entry;
#line 1151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = gtk_entry_get_text (_tmp2_);
#line 1151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->password_entry;
#line 1151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = gtk_entry_get_text (_tmp4_);
#line 1151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = self->priv->remember_password_checkbutton;
#line 1151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = gtk_switch_get_active (_tmp6_);
#line 1151 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_emit (self, publishing_piwigo_authentication_pane_signals[PUBLISHING_PIWIGO_AUTHENTICATION_PANE_LOGIN_SIGNAL], 0, _tmp1_, _tmp3_, _tmp5_, _tmp7_);
#line 7910 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_on_url_changed (PublishingPiwigoAuthenticationPane* self) {
#line 1155 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self));
#line 1156 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_update_login_button_sensitivity (self);
#line 7919 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_on_user_changed (PublishingPiwigoAuthenticationPane* self) {
#line 1159 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self));
#line 1160 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_update_login_button_sensitivity (self);
#line 7928 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_on_password_changed (PublishingPiwigoAuthenticationPane* self) {
#line 1163 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self));
#line 1164 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_update_login_button_sensitivity (self);
#line 7937 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_update_login_button_sensitivity (PublishingPiwigoAuthenticationPane* self) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GtkEntry* _tmp2_;
	guint _tmp3_;
	guint _tmp4_;
	GtkButton* _tmp11_;
#line 1167 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self));
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->url_entry;
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = gtk_entry_get_text_length (_tmp2_);
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_;
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp4_ != ((guint) 0)) {
#line 7958 "PiwigoPublishing.c"
		GtkEntry* _tmp5_;
		guint _tmp6_;
		guint _tmp7_;
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = self->priv->username_entry;
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = gtk_entry_get_text_length (_tmp5_);
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = _tmp6_;
#line 1169 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = _tmp7_ != ((guint) 0);
#line 7970 "PiwigoPublishing.c"
	} else {
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = FALSE;
#line 7974 "PiwigoPublishing.c"
	}
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp1_) {
#line 7978 "PiwigoPublishing.c"
		GtkEntry* _tmp8_;
		guint _tmp9_;
		guint _tmp10_;
#line 1170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = self->priv->password_entry;
#line 1170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = gtk_entry_get_text_length (_tmp8_);
#line 1170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = _tmp9_;
#line 1170 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = _tmp10_ != ((guint) 0);
#line 7990 "PiwigoPublishing.c"
	} else {
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = FALSE;
#line 7994 "PiwigoPublishing.c"
	}
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = self->priv->login_button;
#line 1168 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, gtk_widget_get_type (), GtkWidget), _tmp0_);
#line 8000 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_real_on_pane_installed (ShotwellPluginsCommonBuilderPane* base) {
	PublishingPiwigoAuthenticationPane * self;
	GtkEntry* _tmp0_;
	GtkEntry* _tmp1_;
	GtkButton* _tmp2_;
#line 1173 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPane);
#line 1174 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_CLASS (publishing_piwigo_authentication_pane_parent_class)->on_pane_installed (G_TYPE_CHECK_INSTANCE_CAST (self, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane));
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->url_entry;
#line 1176 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->password_entry;
#line 1177 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_entry_set_activates_default (_tmp1_, TRUE);
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->login_button;
#line 1178 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_can_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1179 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_update_login_button_sensitivity (self);
#line 8027 "PiwigoPublishing.c"
}


PublishingPiwigoAuthenticationPaneMode publishing_piwigo_authentication_pane_get_mode (PublishingPiwigoAuthenticationPane* self) {
	PublishingPiwigoAuthenticationPaneMode result;
	PublishingPiwigoAuthenticationPaneMode _tmp0_;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self), 0);
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_mode;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 8042 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_set_mode (PublishingPiwigoAuthenticationPane* self, PublishingPiwigoAuthenticationPaneMode value) {
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self));
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (publishing_piwigo_authentication_pane_get_mode (self) != value) {
#line 8051 "PiwigoPublishing.c"
		PublishingPiwigoAuthenticationPaneMode _tmp0_;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = value;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_mode = _tmp0_;
#line 1076 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_notify ((GObject *) self, "mode");
#line 8059 "PiwigoPublishing.c"
	}
}


PublishingPiwigoPiwigoPublisher* publishing_piwigo_authentication_pane_get_publisher (PublishingPiwigoAuthenticationPane* self) {
	PublishingPiwigoPiwigoPublisher* result;
	PublishingPiwigoPiwigoPublisher* _tmp0_;
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self), NULL);
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_publisher;
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 8075 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_set_publisher (PublishingPiwigoAuthenticationPane* self, PublishingPiwigoPiwigoPublisher* value) {
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_AUTHENTICATION_PANE (self));
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (publishing_piwigo_authentication_pane_get_publisher (self) != value) {
#line 8084 "PiwigoPublishing.c"
		PublishingPiwigoPiwigoPublisher* _tmp0_;
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = value;
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_publisher = _tmp0_;
#line 1077 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_notify ((GObject *) self, "publisher");
#line 8092 "PiwigoPublishing.c"
	}
}


static void g_cclosure_user_marshal_VOID__STRING_STRING_STRING_BOOLEAN (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN) (gpointer data1, const char* arg_1, const char* arg_2, const char* arg_3, gboolean arg_4, gpointer data2);
	register GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (n_param_values == 5);
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data1 = closure->data;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data2 = param_values->data[0].v_pointer;
#line 8112 "PiwigoPublishing.c"
	} else {
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data1 = param_values->data[0].v_pointer;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data2 = closure->data;
#line 8118 "PiwigoPublishing.c"
	}
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	callback = (GMarshalFunc_VOID__STRING_STRING_STRING_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	callback (data1, g_value_get_string (param_values + 1), g_value_get_string (param_values + 2), g_value_get_string (param_values + 3), g_value_get_boolean (param_values + 4), data2);
#line 8124 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_class_init (PublishingPiwigoAuthenticationPaneClass * klass) {
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_parent_class = g_type_class_peek_parent (klass);
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPiwigoAuthenticationPanePrivate));
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((GObjectClass *) klass)->constructed = (void (*) (GObject *)) publishing_piwigo_authentication_pane_real_constructed;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((ShotwellPluginsCommonBuilderPaneClass *) klass)->on_pane_installed = (void (*) (ShotwellPluginsCommonBuilderPane *)) publishing_piwigo_authentication_pane_real_on_pane_installed;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_publishing_piwigo_authentication_pane_get_property;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_publishing_piwigo_authentication_pane_set_property;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_piwigo_authentication_pane_finalize;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_PROPERTY, g_param_spec_enum ("mode", "mode", "mode", PUBLISHING_PIWIGO_AUTHENTICATION_PANE_TYPE_MODE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_PIWIGO_AUTHENTICATION_PANE_PUBLISHER_PROPERTY, g_param_spec_object ("publisher", "publisher", "publisher", PUBLISHING_PIWIGO_TYPE_PIWIGO_PUBLISHER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_signals[PUBLISHING_PIWIGO_AUTHENTICATION_PANE_LOGIN_SIGNAL] = g_signal_new ("login", PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__STRING_STRING_STRING_BOOLEAN, G_TYPE_NONE, 4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN);
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = g_strdup (_ ("Enter the URL of your Piwigo photo library as well as the username and" \
" password associated with your Piwigo account for that library."));
#line 1079 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_INTRO_MESSAGE = _tmp0_;
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_ ("Shotwell cannot contact your Piwigo photo library. Please verify the U" \
"RL you entered"));
#line 1080 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_FAILED_RETRY_URL_MESSAGE = _tmp1_;
#line 1081 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = g_strdup (_ ("Username and/or password invalid. Please try again"));
#line 1081 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_authentication_pane_FAILED_RETRY_USER_MESSAGE = _tmp2_;
#line 8164 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_instance_init (PublishingPiwigoAuthenticationPane * self) {
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv = PUBLISHING_PIWIGO_AUTHENTICATION_PANE_GET_PRIVATE (self);
#line 8171 "PiwigoPublishing.c"
}


static void publishing_piwigo_authentication_pane_finalize (GObject * obj) {
	PublishingPiwigoAuthenticationPane * self;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPane);
#line 1083 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->url_entry);
#line 1084 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 1085 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 1086 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->remember_password_checkbutton);
#line 1087 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->login_button);
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (publishing_piwigo_authentication_pane_parent_class)->finalize (obj);
#line 8191 "PiwigoPublishing.c"
}


/**
 * The authentication pane used when asking service URL, user name and password
 * from the user.
 */
GType publishing_piwigo_authentication_pane_get_type (void) {
	static volatile gsize publishing_piwigo_authentication_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_authentication_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoAuthenticationPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_authentication_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoAuthenticationPane), 0, (GInstanceInitFunc) publishing_piwigo_authentication_pane_instance_init, NULL };
		GType publishing_piwigo_authentication_pane_type_id;
		publishing_piwigo_authentication_pane_type_id = g_type_register_static (SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, "PublishingPiwigoAuthenticationPane", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_authentication_pane_type_id__volatile, publishing_piwigo_authentication_pane_type_id);
	}
	return publishing_piwigo_authentication_pane_type_id__volatile;
}


static void _vala_publishing_piwigo_authentication_pane_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	PublishingPiwigoAuthenticationPane * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPane);
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	switch (property_id) {
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_PROPERTY:
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_value_set_enum (value, publishing_piwigo_authentication_pane_get_mode (self));
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_AUTHENTICATION_PANE_PUBLISHER_PROPERTY:
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_value_set_object (value, publishing_piwigo_authentication_pane_get_publisher (self));
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 8228 "PiwigoPublishing.c"
		default:
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 8234 "PiwigoPublishing.c"
	}
}


static void _vala_publishing_piwigo_authentication_pane_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	PublishingPiwigoAuthenticationPane * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PUBLISHING_PIWIGO_TYPE_AUTHENTICATION_PANE, PublishingPiwigoAuthenticationPane);
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	switch (property_id) {
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_AUTHENTICATION_PANE_MODE_PROPERTY:
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_authentication_pane_set_mode (self, g_value_get_enum (value));
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_AUTHENTICATION_PANE_PUBLISHER_PROPERTY:
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_authentication_pane_set_publisher (self, g_value_get_object (value));
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 8256 "PiwigoPublishing.c"
		default:
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1069 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 8262 "PiwigoPublishing.c"
	}
}


static gpointer _publishing_piwigo_category_ref0 (gpointer self) {
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self ? publishing_piwigo_category_ref (self) : NULL;
#line 8270 "PiwigoPublishing.c"
}


static PublishingPiwigoCategory** _vala_array_dup11 (PublishingPiwigoCategory** self, int length) {
	PublishingPiwigoCategory** result;
	int i;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = g_new0 (PublishingPiwigoCategory*, length + 1);
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	for (i = 0; i < length; i++) {
#line 8281 "PiwigoPublishing.c"
		PublishingPiwigoCategory* _tmp0_;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = _publishing_piwigo_category_ref0 (self[i]);
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		result[i] = _tmp0_;
#line 8287 "PiwigoPublishing.c"
	}
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 8291 "PiwigoPublishing.c"
}


static gboolean _publishing_piwigo_category_equal_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = publishing_piwigo_category_equal ((PublishingPiwigoCategory*) a, (PublishingPiwigoCategory*) b);
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 8300 "PiwigoPublishing.c"
}


PublishingPiwigoPublishingOptionsPane* publishing_piwigo_publishing_options_pane_construct (GType object_type, PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoCategory** categories, int categories_length1, gint last_category, gint last_permission_level, gint last_photo_size, gboolean last_title_as_comment, gboolean last_no_upload_tags, gboolean strip_metadata_enabled) {
	PublishingPiwigoPublishingOptionsPane * self = NULL;
	gint _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	PublishingPiwigoCategory** _tmp6_;
	gint _tmp6__length1;
	PublishingPiwigoCategory** _tmp7_;
	gint _tmp7__length1;
	GeeArrayList* _tmp8_;
	GeeArrayList* _tmp9_;
	PublishingPiwigoPiwigoPublisher* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (publisher), NULL);
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = last_category;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = last_permission_level;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = last_photo_size;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = last_title_as_comment;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = last_no_upload_tags;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = strip_metadata_enabled;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = categories;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6__length1 = categories_length1;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = (_tmp6_ != NULL) ? _vala_array_dup11 (_tmp6_, _tmp6__length1) : ((gpointer) _tmp6_);
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7__length1 = _tmp6__length1;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = gee_array_list_new_wrap (PUBLISHING_PIWIGO_TYPE_CATEGORY, (GBoxedCopyFunc) publishing_piwigo_category_ref, (GDestroyNotify) publishing_piwigo_category_unref, _tmp7_, _tmp7__length1, _publishing_piwigo_category_equal_gee_equal_data_func, NULL, NULL);
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = _tmp8_;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = publisher;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = publishing_piwigo_publishing_options_pane_get_common_comment_if_possible (_tmp10_);
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = _tmp11_;
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoPublishingOptionsPane*) g_object_new (object_type, "resource-path", PLUGIN_RESOURCE_PATH "/piwigo_publishing_options_pane.ui", "connect-signals", TRUE, "default-id", "publish_button", "last-category", _tmp0_, "last-permission-level", _tmp1_, "last-photo-size", _tmp2_, "last-title-as-comment", _tmp3_, "last-no-upload-tags", _tmp4_, "strip-metadata-enabled", _tmp5_, "existing-categories", _tmp9_, "default-comment", _tmp12_, NULL);
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp12_);
#line 1229 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp9_);
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 8361 "PiwigoPublishing.c"
}


PublishingPiwigoPublishingOptionsPane* publishing_piwigo_publishing_options_pane_new (PublishingPiwigoPiwigoPublisher* publisher, PublishingPiwigoCategory** categories, int categories_length1, gint last_category, gint last_permission_level, gint last_photo_size, gboolean last_title_as_comment, gboolean last_no_upload_tags, gboolean strip_metadata_enabled) {
#line 1221 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_publishing_options_pane_construct (PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, publisher, categories, categories_length1, last_category, last_permission_level, last_photo_size, last_title_as_comment, last_no_upload_tags, strip_metadata_enabled);
#line 8368 "PiwigoPublishing.c"
}


static void _publishing_piwigo_publishing_options_pane_on_logout_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_on_logout_button_clicked ((PublishingPiwigoPublishingOptionsPane*) self);
#line 8375 "PiwigoPublishing.c"
}


static void _publishing_piwigo_publishing_options_pane_on_publish_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_on_publish_button_clicked ((PublishingPiwigoPublishingOptionsPane*) self);
#line 8382 "PiwigoPublishing.c"
}


static void _publishing_piwigo_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1277 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_on_use_existing_radio_clicked ((PublishingPiwigoPublishingOptionsPane*) self);
#line 8389 "PiwigoPublishing.c"
}


static void _publishing_piwigo_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 1278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_on_create_new_radio_clicked ((PublishingPiwigoPublishingOptionsPane*) self);
#line 8396 "PiwigoPublishing.c"
}


static void _publishing_piwigo_publishing_options_pane_on_new_category_entry_changed_gtk_editable_changed (GtkEditable* _sender, gpointer self) {
#line 1279 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_on_new_category_entry_changed ((PublishingPiwigoPublishingOptionsPane*) self);
#line 8403 "PiwigoPublishing.c"
}


static void _publishing_piwigo_publishing_options_pane_on_existing_combo_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 1280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_on_existing_combo_changed ((PublishingPiwigoPublishingOptionsPane*) self);
#line 8410 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_real_constructed (GObject* base) {
	PublishingPiwigoPublishingOptionsPane * self;
	GtkBuilder* builder = NULL;
	GtkBuilder* _tmp0_;
	GObject* _tmp1_;
	GtkRadioButton* _tmp2_;
	GObject* _tmp3_;
	GtkRadioButton* _tmp4_;
	GObject* _tmp5_;
	GtkComboBoxText* _tmp6_;
	GObject* _tmp7_;
	GtkEntry* _tmp8_;
	GObject* _tmp9_;
	GtkLabel* _tmp10_;
	GObject* _tmp11_;
	GtkComboBoxText* _tmp12_;
	GObject* _tmp13_;
	GtkTextView* _tmp14_;
	GtkTextView* _tmp15_;
	GtkTextBuffer* _tmp16_;
	GtkTextBuffer* _tmp17_;
	GObject* _tmp18_;
	GtkLabel* _tmp19_;
	GObject* _tmp20_;
	GtkComboBoxText* _tmp21_;
	GObject* _tmp22_;
	GtkComboBoxText* _tmp23_;
	GObject* _tmp24_;
	GtkCheckButton* _tmp25_;
	GtkCheckButton* _tmp26_;
	gboolean _tmp27_;
	GObject* _tmp28_;
	GtkCheckButton* _tmp29_;
	GtkCheckButton* _tmp30_;
	gboolean _tmp31_;
	GObject* _tmp32_;
	GtkCheckButton* _tmp33_;
	GtkCheckButton* _tmp34_;
	gboolean _tmp35_;
	GObject* _tmp36_;
	GtkButton* _tmp37_;
	GtkButton* _tmp38_;
	GObject* _tmp39_;
	GtkButton* _tmp40_;
	GtkButton* _tmp41_;
	GtkRadioButton* _tmp42_;
	GtkRadioButton* _tmp43_;
	GtkEntry* _tmp44_;
	GtkComboBoxText* _tmp45_;
	gint _tmp46_;
	PublishingPiwigoPermissionLevel** _tmp47_;
	gint _tmp48_;
	PublishingPiwigoSizeEntry** _tmp49_;
	GtkTextView* _tmp50_;
	GtkTextBuffer* _tmp51_;
	GtkTextBuffer* _tmp52_;
	const gchar* _tmp53_;
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPane);
#line 1245 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (publishing_piwigo_publishing_options_pane_parent_class)->constructed (G_TYPE_CHECK_INSTANCE_CAST (G_TYPE_CHECK_INSTANCE_CAST (self, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane), G_TYPE_OBJECT, GObject));
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = shotwell_plugins_common_builder_pane_get_builder (G_TYPE_CHECK_INSTANCE_CAST (self, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane));
#line 1246 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	builder = _tmp0_;
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = gtk_builder_get_object (builder, "use_existing_radio");
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_radio_button_get_type ()) ? ((GtkRadioButton*) _tmp1_) : NULL);
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->use_existing_radio);
#line 1248 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->use_existing_radio = _tmp2_;
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = gtk_builder_get_object (builder, "create_new_radio");
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, gtk_radio_button_get_type ()) ? ((GtkRadioButton*) _tmp3_) : NULL);
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->create_new_radio);
#line 1249 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->create_new_radio = _tmp4_;
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = gtk_builder_get_object (builder, "existing_categories_combo");
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp5_) : NULL);
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->existing_categories_combo);
#line 1250 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->existing_categories_combo = _tmp6_;
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = gtk_builder_get_object (builder, "new_category_entry");
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, gtk_entry_get_type ()) ? ((GtkEntry*) _tmp7_) : NULL);
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->new_category_entry);
#line 1251 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->new_category_entry = _tmp8_;
#line 1252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = gtk_builder_get_object (builder, "within_existing_label");
#line 1252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp9_) : NULL);
#line 1252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->within_existing_label);
#line 1252 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->within_existing_label = _tmp10_;
#line 1253 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = gtk_builder_get_object (builder, "within_existing_combo");
#line 1253 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp11_) : NULL);
#line 1253 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->within_existing_combo);
#line 1253 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->within_existing_combo = _tmp12_;
#line 1255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = gtk_builder_get_object (builder, "album_comment");
#line 1255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp13_, gtk_text_view_get_type ()) ? ((GtkTextView*) _tmp13_) : NULL);
#line 1255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->album_comment);
#line 1255 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->album_comment = _tmp14_;
#line 1256 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = self->priv->album_comment;
#line 1256 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = gtk_text_buffer_new (NULL);
#line 1256 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = _tmp16_;
#line 1256 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_text_view_set_buffer (_tmp15_, _tmp17_);
#line 1256 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp17_);
#line 1257 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = gtk_builder_get_object (builder, "album_comment_label");
#line 1257 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp18_) : NULL);
#line 1257 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->album_comment_label);
#line 1257 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->album_comment_label = _tmp19_;
#line 1259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = gtk_builder_get_object (builder, "perms_combo");
#line 1259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp21_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp20_) : NULL);
#line 1259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->perms_combo);
#line 1259 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->perms_combo = _tmp21_;
#line 1260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp22_ = gtk_builder_get_object (builder, "size_combo");
#line 1260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp23_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, gtk_combo_box_text_get_type ()) ? ((GtkComboBoxText*) _tmp22_) : NULL);
#line 1260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->size_combo);
#line 1260 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->size_combo = _tmp23_;
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp24_ = gtk_builder_get_object (builder, "strip_metadata_check");
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp25_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp24_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp24_) : NULL);
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 1262 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->strip_metadata_check = _tmp25_;
#line 1263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp26_ = self->priv->strip_metadata_check;
#line 1263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp27_ = self->priv->_strip_metadata_enabled;
#line 1263 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp27_);
#line 1265 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp28_ = gtk_builder_get_object (builder, "title_as_comment_check");
#line 1265 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp29_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp28_) : NULL);
#line 1265 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->title_as_comment_check);
#line 1265 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->title_as_comment_check = _tmp29_;
#line 1266 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp30_ = self->priv->title_as_comment_check;
#line 1266 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp31_ = self->priv->_last_title_as_comment;
#line 1266 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp30_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp31_);
#line 1268 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp32_ = gtk_builder_get_object (builder, "no_upload_tags_check");
#line 1268 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp33_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, gtk_check_button_get_type ()) ? ((GtkCheckButton*) _tmp32_) : NULL);
#line 1268 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->no_upload_tags_check);
#line 1268 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->no_upload_tags_check = _tmp33_;
#line 1269 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp34_ = self->priv->no_upload_tags_check;
#line 1269 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp35_ = self->priv->_last_no_upload_tags;
#line 1269 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp34_, gtk_toggle_button_get_type (), GtkToggleButton), _tmp35_);
#line 1271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp36_ = gtk_builder_get_object (builder, "logout_button");
#line 1271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp37_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, gtk_button_get_type ()) ? ((GtkButton*) _tmp36_) : NULL);
#line 1271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 1271 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->logout_button = _tmp37_;
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp38_ = self->priv->logout_button;
#line 1272 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (_tmp38_, "clicked", (GCallback) _publishing_piwigo_publishing_options_pane_on_logout_button_clicked_gtk_button_clicked, self, 0);
#line 1274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp39_ = gtk_builder_get_object (builder, "publish_button");
#line 1274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp40_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, gtk_button_get_type ()) ? ((GtkButton*) _tmp39_) : NULL);
#line 1274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 1274 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->publish_button = _tmp40_;
#line 1275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp41_ = self->priv->publish_button;
#line 1275 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (_tmp41_, "clicked", (GCallback) _publishing_piwigo_publishing_options_pane_on_publish_button_clicked_gtk_button_clicked, self, 0);
#line 1277 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp42_ = self->priv->use_existing_radio;
#line 1277 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp42_, gtk_button_get_type (), GtkButton), "clicked", (GCallback) _publishing_piwigo_publishing_options_pane_on_use_existing_radio_clicked_gtk_button_clicked, self, 0);
#line 1278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp43_ = self->priv->create_new_radio;
#line 1278 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, gtk_button_get_type (), GtkButton), "clicked", (GCallback) _publishing_piwigo_publishing_options_pane_on_create_new_radio_clicked_gtk_button_clicked, self, 0);
#line 1279 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp44_ = self->priv->new_category_entry;
#line 1279 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp44_, GTK_TYPE_EDITABLE, GtkEditable), "changed", (GCallback) _publishing_piwigo_publishing_options_pane_on_new_category_entry_changed_gtk_editable_changed, self, 0);
#line 1280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp45_ = self->priv->within_existing_combo;
#line 1280 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, gtk_combo_box_get_type (), GtkComboBox), "changed", (GCallback) _publishing_piwigo_publishing_options_pane_on_existing_combo_changed_gtk_combo_box_changed, self, 0);
#line 1282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp47_ = publishing_piwigo_publishing_options_pane_create_perm_levels (self, &_tmp46_);
#line 1282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->perm_levels = (_vala_array_free (self->priv->perm_levels, self->priv->perm_levels_length1, (GDestroyNotify) publishing_piwigo_permission_level_unref), NULL);
#line 1282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->perm_levels = _tmp47_;
#line 1282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->perm_levels_length1 = _tmp46_;
#line 1282 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->_perm_levels_size_ = self->priv->perm_levels_length1;
#line 1283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp49_ = publishing_piwigo_publishing_options_pane_create_sizes (self, &_tmp48_);
#line 1283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->photo_sizes = (_vala_array_free (self->priv->photo_sizes, self->priv->photo_sizes_length1, (GDestroyNotify) publishing_piwigo_size_entry_unref), NULL);
#line 1283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->photo_sizes = _tmp49_;
#line 1283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->photo_sizes_length1 = _tmp48_;
#line 1283 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->_photo_sizes_size_ = self->priv->photo_sizes_length1;
#line 1284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp50_ = self->priv->album_comment;
#line 1284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp51_ = gtk_text_view_get_buffer (_tmp50_);
#line 1284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp52_ = _tmp51_;
#line 1284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp53_ = self->priv->_default_comment;
#line 1284 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_text_buffer_set_text (_tmp52_, _tmp53_, -1);
#line 1244 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (builder);
#line 8683 "PiwigoPublishing.c"
}


static void _vala_array_add36 (PublishingPiwigoPermissionLevel** * array, int* length, int* size, PublishingPiwigoPermissionLevel* value) {
#line 1290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoPermissionLevel*, *array, (*size) + 1);
#line 8694 "PiwigoPublishing.c"
	}
#line 1290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8700 "PiwigoPublishing.c"
}


static void _vala_array_add37 (PublishingPiwigoPermissionLevel** * array, int* length, int* size, PublishingPiwigoPermissionLevel* value) {
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoPermissionLevel*, *array, (*size) + 1);
#line 8711 "PiwigoPublishing.c"
	}
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8717 "PiwigoPublishing.c"
}


static void _vala_array_add38 (PublishingPiwigoPermissionLevel** * array, int* length, int* size, PublishingPiwigoPermissionLevel* value) {
#line 1292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoPermissionLevel*, *array, (*size) + 1);
#line 8728 "PiwigoPublishing.c"
	}
#line 1292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8734 "PiwigoPublishing.c"
}


static void _vala_array_add39 (PublishingPiwigoPermissionLevel** * array, int* length, int* size, PublishingPiwigoPermissionLevel* value) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoPermissionLevel*, *array, (*size) + 1);
#line 8745 "PiwigoPublishing.c"
	}
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8751 "PiwigoPublishing.c"
}


static void _vala_array_add40 (PublishingPiwigoPermissionLevel** * array, int* length, int* size, PublishingPiwigoPermissionLevel* value) {
#line 1294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoPermissionLevel*, *array, (*size) + 1);
#line 8762 "PiwigoPublishing.c"
	}
#line 1294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8768 "PiwigoPublishing.c"
}


static PublishingPiwigoPermissionLevel** publishing_piwigo_publishing_options_pane_create_perm_levels (PublishingPiwigoPublishingOptionsPane* self, int* result_length1) {
	PublishingPiwigoPermissionLevel** result = NULL;
	PublishingPiwigoPermissionLevel** _result_ = NULL;
	PublishingPiwigoPermissionLevel** _tmp0_;
	gint _result__length1;
	gint __result__size_;
	PublishingPiwigoPermissionLevel** _tmp1_;
	gint _tmp1__length1;
	PublishingPiwigoPermissionLevel* _tmp2_;
	PublishingPiwigoPermissionLevel** _tmp3_;
	gint _tmp3__length1;
	PublishingPiwigoPermissionLevel* _tmp4_;
	PublishingPiwigoPermissionLevel** _tmp5_;
	gint _tmp5__length1;
	PublishingPiwigoPermissionLevel* _tmp6_;
	PublishingPiwigoPermissionLevel** _tmp7_;
	gint _tmp7__length1;
	PublishingPiwigoPermissionLevel* _tmp8_;
	PublishingPiwigoPermissionLevel** _tmp9_;
	gint _tmp9__length1;
	PublishingPiwigoPermissionLevel* _tmp10_;
	PublishingPiwigoPermissionLevel** _tmp11_;
	gint _tmp11__length1;
#line 1287 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 1288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = g_new0 (PublishingPiwigoPermissionLevel*, 0 + 1);
#line 1288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result_ = _tmp0_;
#line 1288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result__length1 = 0;
#line 1288 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	__result__size_ = _result__length1;
#line 1290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _result_;
#line 1290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1__length1 = _result__length1;
#line 1290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_piwigo_permission_level_new (0, _ ("Everyone"));
#line 1290 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add36 (&_result_, &_result__length1, &__result__size_, _tmp2_);
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _result_;
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3__length1 = _result__length1;
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = publishing_piwigo_permission_level_new (1, _ ("Admins, Family, Friends, Contacts"));
#line 1291 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add37 (&_result_, &_result__length1, &__result__size_, _tmp4_);
#line 1292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = _result_;
#line 1292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5__length1 = _result__length1;
#line 1292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_piwigo_permission_level_new (2, _ ("Admins, Family, Friends"));
#line 1292 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add38 (&_result_, &_result__length1, &__result__size_, _tmp6_);
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = _result_;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7__length1 = _result__length1;
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = publishing_piwigo_permission_level_new (4, _ ("Admins, Family"));
#line 1293 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add39 (&_result_, &_result__length1, &__result__size_, _tmp8_);
#line 1294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = _result_;
#line 1294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9__length1 = _result__length1;
#line 1294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = publishing_piwigo_permission_level_new (8, _ ("Admins"));
#line 1294 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add40 (&_result_, &_result__length1, &__result__size_, _tmp10_);
#line 1296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = _result_;
#line 1296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11__length1 = _result__length1;
#line 1296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (result_length1) {
#line 1296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*result_length1 = _tmp11__length1;
#line 8853 "PiwigoPublishing.c"
	}
#line 1296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp11_;
#line 1296 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 8859 "PiwigoPublishing.c"
}


static void _vala_array_add41 (PublishingPiwigoSizeEntry** * array, int* length, int* size, PublishingPiwigoSizeEntry* value) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoSizeEntry*, *array, (*size) + 1);
#line 8870 "PiwigoPublishing.c"
	}
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8876 "PiwigoPublishing.c"
}


static void _vala_array_add42 (PublishingPiwigoSizeEntry** * array, int* length, int* size, PublishingPiwigoSizeEntry* value) {
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoSizeEntry*, *array, (*size) + 1);
#line 8887 "PiwigoPublishing.c"
	}
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8893 "PiwigoPublishing.c"
}


static void _vala_array_add43 (PublishingPiwigoSizeEntry** * array, int* length, int* size, PublishingPiwigoSizeEntry* value) {
#line 1304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoSizeEntry*, *array, (*size) + 1);
#line 8904 "PiwigoPublishing.c"
	}
#line 1304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8910 "PiwigoPublishing.c"
}


static void _vala_array_add44 (PublishingPiwigoSizeEntry** * array, int* length, int* size, PublishingPiwigoSizeEntry* value) {
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoSizeEntry*, *array, (*size) + 1);
#line 8921 "PiwigoPublishing.c"
	}
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8927 "PiwigoPublishing.c"
}


static void _vala_array_add45 (PublishingPiwigoSizeEntry** * array, int* length, int* size, PublishingPiwigoSizeEntry* value) {
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if ((*length) == (*size)) {
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*array = g_renew (PublishingPiwigoSizeEntry*, *array, (*size) + 1);
#line 8938 "PiwigoPublishing.c"
	}
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[(*length)++] = value;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	(*array)[*length] = NULL;
#line 8944 "PiwigoPublishing.c"
}


static PublishingPiwigoSizeEntry** publishing_piwigo_publishing_options_pane_create_sizes (PublishingPiwigoPublishingOptionsPane* self, int* result_length1) {
	PublishingPiwigoSizeEntry** result = NULL;
	PublishingPiwigoSizeEntry** _result_ = NULL;
	PublishingPiwigoSizeEntry** _tmp0_;
	gint _result__length1;
	gint __result__size_;
	PublishingPiwigoSizeEntry** _tmp1_;
	gint _tmp1__length1;
	PublishingPiwigoSizeEntry* _tmp2_;
	PublishingPiwigoSizeEntry** _tmp3_;
	gint _tmp3__length1;
	PublishingPiwigoSizeEntry* _tmp4_;
	PublishingPiwigoSizeEntry** _tmp5_;
	gint _tmp5__length1;
	PublishingPiwigoSizeEntry* _tmp6_;
	PublishingPiwigoSizeEntry** _tmp7_;
	gint _tmp7__length1;
	PublishingPiwigoSizeEntry* _tmp8_;
	PublishingPiwigoSizeEntry** _tmp9_;
	gint _tmp9__length1;
	PublishingPiwigoSizeEntry* _tmp10_;
	PublishingPiwigoSizeEntry** _tmp11_;
	gint _tmp11__length1;
#line 1299 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = g_new0 (PublishingPiwigoSizeEntry*, 0 + 1);
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result_ = _tmp0_;
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result__length1 = 0;
#line 1300 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	__result__size_ = _result__length1;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = _result_;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1__length1 = _result__length1;
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_piwigo_size_entry_new (500, _ ("500 × 375 pixels"));
#line 1302 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add41 (&_result_, &_result__length1, &__result__size_, _tmp2_);
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _result_;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3__length1 = _result__length1;
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = publishing_piwigo_size_entry_new (1024, _ ("1024 × 768 pixels"));
#line 1303 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add42 (&_result_, &_result__length1, &__result__size_, _tmp4_);
#line 1304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = _result_;
#line 1304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5__length1 = _result__length1;
#line 1304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_piwigo_size_entry_new (2048, _ ("2048 × 1536 pixels"));
#line 1304 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add43 (&_result_, &_result__length1, &__result__size_, _tmp6_);
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = _result_;
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7__length1 = _result__length1;
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = publishing_piwigo_size_entry_new (4096, _ ("4096 × 3072 pixels"));
#line 1305 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add44 (&_result_, &_result__length1, &__result__size_, _tmp8_);
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = _result_;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9__length1 = _result__length1;
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = publishing_piwigo_size_entry_new (PUBLISHING_PIWIGO_ORIGINAL_SIZE, _ ("Original size"));
#line 1306 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_vala_array_add45 (&_result_, &_result__length1, &__result__size_, _tmp10_);
#line 1308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = _result_;
#line 1308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11__length1 = _result__length1;
#line 1308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (result_length1) {
#line 1308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		*result_length1 = _tmp11__length1;
#line 9029 "PiwigoPublishing.c"
	}
#line 1308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp11_;
#line 1308 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 9035 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_on_logout_button_clicked (PublishingPiwigoPublishingOptionsPane* self) {
#line 1311 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1312 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_emit (self, publishing_piwigo_publishing_options_pane_signals[PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL], 0);
#line 9044 "PiwigoPublishing.c"
}


static gpointer _publishing_piwigo_permission_level_ref0 (gpointer self) {
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self ? publishing_piwigo_permission_level_ref (self) : NULL;
#line 9051 "PiwigoPublishing.c"
}


static gpointer _publishing_piwigo_size_entry_ref0 (gpointer self) {
#line 1318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self ? publishing_piwigo_size_entry_ref (self) : NULL;
#line 9058 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_on_publish_button_clicked (PublishingPiwigoPublishingOptionsPane* self) {
	PublishingPiwigoPublishingParameters* params = NULL;
	PublishingPiwigoPublishingParameters* _tmp0_;
	PublishingPiwigoPublishingParameters* _tmp1_;
	PublishingPiwigoPermissionLevel** _tmp2_;
	gint _tmp2__length1;
	GtkComboBoxText* _tmp3_;
	gint _tmp4_;
	PublishingPiwigoPermissionLevel* _tmp5_;
	PublishingPiwigoPermissionLevel* _tmp6_;
	PublishingPiwigoPublishingParameters* _tmp7_;
	PublishingPiwigoSizeEntry** _tmp8_;
	gint _tmp8__length1;
	GtkComboBoxText* _tmp9_;
	gint _tmp10_;
	PublishingPiwigoSizeEntry* _tmp11_;
	PublishingPiwigoSizeEntry* _tmp12_;
	PublishingPiwigoPublishingParameters* _tmp13_;
	GtkCheckButton* _tmp14_;
	gboolean _tmp15_;
	PublishingPiwigoPublishingParameters* _tmp16_;
	GtkCheckButton* _tmp17_;
	gboolean _tmp18_;
	GtkRadioButton* _tmp19_;
	gboolean _tmp20_;
	PublishingPiwigoPublishingParameters* _tmp53_;
	GtkCheckButton* _tmp54_;
	gboolean _tmp55_;
#line 1315 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = publishing_piwigo_publishing_parameters_new ();
#line 1316 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	params = _tmp0_;
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = params;
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->perm_levels;
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2__length1 = self->priv->perm_levels_length1;
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = self->priv->perms_combo;
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_combo_box_get_type (), GtkComboBox));
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = _tmp2_[_tmp4_];
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _publishing_piwigo_permission_level_ref0 (_tmp5_);
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_permission_level_unref0 (_tmp1_->perm_level);
#line 1317 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_->perm_level = _tmp6_;
#line 1318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = params;
#line 1318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = self->priv->photo_sizes;
#line 1318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8__length1 = self->priv->photo_sizes_length1;
#line 1318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp9_ = self->priv->size_combo;
#line 1318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp10_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_combo_box_get_type (), GtkComboBox));
#line 1318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp11_ = _tmp8_[_tmp10_];
#line 1318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = _publishing_piwigo_size_entry_ref0 (_tmp11_);
#line 1318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_size_entry_unref0 (_tmp7_->photo_size);
#line 1318 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_->photo_size = _tmp12_;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = params;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = self->priv->title_as_comment_check;
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1319 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_->title_as_comment = _tmp15_;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = params;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = self->priv->no_upload_tags_check;
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1320 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_->no_upload_tags = _tmp18_;
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = self->priv->create_new_radio;
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp20_) {
#line 9154 "PiwigoPublishing.c"
		gchar* uploadcomment = NULL;
		GtkTextView* _tmp21_;
		GtkTextBuffer* _tmp22_;
		GtkTextBuffer* _tmp23_;
		gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gint a = 0;
		GtkComboBoxText* _tmp29_;
		gint _tmp30_;
		gint _tmp31_;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp21_ = self->priv->album_comment;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp22_ = gtk_text_view_get_buffer (_tmp21_);
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp23_ = _tmp22_;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_get (_tmp23_, "text", &_tmp24_, NULL);
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp25_ = _tmp24_;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp26_ = _tmp25_;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp27_ = string_strip (_tmp26_);
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp28_ = _tmp27_;
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp26_);
#line 1322 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		uploadcomment = _tmp28_;
#line 1323 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp29_ = self->priv->within_existing_combo;
#line 1323 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp30_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, gtk_combo_box_get_type (), GtkComboBox));
#line 1323 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		a = _tmp30_;
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp31_ = a;
#line 1324 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp31_ == 0) {
#line 9198 "PiwigoPublishing.c"
			PublishingPiwigoPublishingParameters* _tmp32_;
			GtkEntry* _tmp33_;
			const gchar* _tmp34_;
			const gchar* _tmp35_;
			PublishingPiwigoCategory* _tmp36_;
#line 1325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp32_ = params;
#line 1325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp33_ = self->priv->new_category_entry;
#line 1325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp34_ = gtk_entry_get_text (_tmp33_);
#line 1325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp35_ = uploadcomment;
#line 1325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp36_ = publishing_piwigo_category_new_local (_tmp34_, 0, _tmp35_);
#line 1325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_piwigo_category_unref0 (_tmp32_->category);
#line 1325 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp32_->category = _tmp36_;
#line 9218 "PiwigoPublishing.c"
		} else {
			gint _tmp37_;
			PublishingPiwigoPublishingParameters* _tmp38_;
			GtkEntry* _tmp39_;
			const gchar* _tmp40_;
			GeeList* _tmp41_;
			gint _tmp42_;
			gpointer _tmp43_;
			PublishingPiwigoCategory* _tmp44_;
			gint _tmp45_;
			const gchar* _tmp46_;
			PublishingPiwigoCategory* _tmp47_;
#line 1329 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp37_ = a;
#line 1329 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			a = _tmp37_ - 1;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp38_ = params;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp39_ = self->priv->new_category_entry;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp40_ = gtk_entry_get_text (_tmp39_);
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp41_ = self->priv->_existing_categories;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp42_ = a;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp43_ = gee_list_get (_tmp41_, _tmp42_);
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp44_ = (PublishingPiwigoCategory*) _tmp43_;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp45_ = _tmp44_->id;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp46_ = uploadcomment;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp47_ = publishing_piwigo_category_new_local (_tmp40_, _tmp45_, _tmp46_);
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_piwigo_category_unref0 (_tmp38_->category);
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp38_->category = _tmp47_;
#line 1330 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_piwigo_category_unref0 (_tmp44_);
#line 9261 "PiwigoPublishing.c"
		}
#line 1321 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (uploadcomment);
#line 9265 "PiwigoPublishing.c"
	} else {
		PublishingPiwigoPublishingParameters* _tmp48_;
		GeeList* _tmp49_;
		GtkComboBoxText* _tmp50_;
		gint _tmp51_;
		gpointer _tmp52_;
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp48_ = params;
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp49_ = self->priv->_existing_categories;
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp50_ = self->priv->existing_categories_combo;
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp51_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, gtk_combo_box_get_type (), GtkComboBox));
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp52_ = gee_list_get (_tmp49_, _tmp51_);
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_piwigo_category_unref0 (_tmp48_->category);
#line 1334 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp48_->category = (PublishingPiwigoCategory*) _tmp52_;
#line 9286 "PiwigoPublishing.c"
	}
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp53_ = params;
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp54_ = self->priv->strip_metadata_check;
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp55_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1336 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_signal_emit (self, publishing_piwigo_publishing_options_pane_signals[PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL], 0, _tmp53_, _tmp55_);
#line 1315 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (params);
#line 9298 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_on_use_existing_radio_clicked (PublishingPiwigoPublishingOptionsPane* self) {
	GtkComboBoxText* _tmp0_;
	GtkEntry* _tmp1_;
	GtkLabel* _tmp2_;
	GtkComboBoxText* _tmp3_;
	GtkComboBoxText* _tmp4_;
	GtkLabel* _tmp5_;
	GtkTextView* _tmp6_;
#line 1340 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->existing_categories_combo;
#line 1341 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1342 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->new_category_entry;
#line 1342 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->within_existing_label;
#line 1343 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = self->priv->within_existing_combo;
#line 1344 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->existing_categories_combo;
#line 1345 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget));
#line 1346 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = self->priv->album_comment_label;
#line 1346 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = self->priv->album_comment;
#line 1347 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1348 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (self);
#line 9342 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_on_create_new_radio_clicked (PublishingPiwigoPublishingOptionsPane* self) {
	GtkEntry* _tmp0_;
	GtkLabel* _tmp1_;
	GtkComboBoxText* _tmp2_;
	GtkLabel* _tmp3_;
	GtkTextView* _tmp4_;
	GtkComboBoxText* _tmp5_;
	GtkEntry* _tmp6_;
#line 1351 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->new_category_entry;
#line 1352 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = self->priv->within_existing_label;
#line 1353 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1354 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->within_existing_combo;
#line 1354 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = self->priv->album_comment_label;
#line 1355 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = self->priv->album_comment;
#line 1356 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1357 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = self->priv->existing_categories_combo;
#line 1357 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = self->priv->new_category_entry;
#line 1358 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, gtk_widget_get_type (), GtkWidget));
#line 1359 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (self);
#line 9386 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_on_new_category_entry_changed (PublishingPiwigoPublishingOptionsPane* self) {
#line 1362 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1363 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (self);
#line 9395 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_on_existing_combo_changed (PublishingPiwigoPublishingOptionsPane* self) {
#line 1366 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1367 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (self);
#line 9404 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (PublishingPiwigoPublishingOptionsPane* self) {
	gchar* category_name = NULL;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gint a = 0;
	GtkComboBoxText* _tmp3_;
	gint _tmp4_;
	gchar* search_name = NULL;
	gint _tmp5_;
	gboolean _tmp18_ = FALSE;
	GtkRadioButton* _tmp19_;
	gboolean _tmp20_;
	GtkButton* _tmp25_;
#line 1370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->new_category_entry;
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = string_strip (_tmp1_);
#line 1371 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	category_name = _tmp2_;
#line 1372 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = self->priv->within_existing_combo;
#line 1372 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = gtk_combo_box_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, gtk_combo_box_get_type (), GtkComboBox));
#line 1372 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	a = _tmp4_;
#line 1374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = a;
#line 1374 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp5_ <= 0) {
#line 9442 "PiwigoPublishing.c"
		const gchar* _tmp6_;
		gchar* _tmp7_;
#line 1375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = category_name;
#line 1375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = g_strconcat ("/ ", _tmp6_, NULL);
#line 1375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (search_name);
#line 1375 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		search_name = _tmp7_;
#line 9453 "PiwigoPublishing.c"
	} else {
		gint _tmp8_;
		GeeList* _tmp9_;
		gint _tmp10_;
		gpointer _tmp11_;
		PublishingPiwigoCategory* _tmp12_;
		const gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		const gchar* _tmp16_;
		gchar* _tmp17_;
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = a;
#line 1377 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		a = _tmp8_ - 1;
#line 1378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = self->priv->_existing_categories;
#line 1378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = a;
#line 1378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = gee_list_get (_tmp9_, _tmp10_);
#line 1378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp12_ = (PublishingPiwigoCategory*) _tmp11_;
#line 1378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp13_ = _tmp12_->display_name;
#line 1378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp14_ = g_strconcat (_tmp13_, "/ ", NULL);
#line 1378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp15_ = _tmp14_;
#line 1378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp16_ = category_name;
#line 1378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp17_ = g_strconcat (_tmp15_, _tmp16_, NULL);
#line 1378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (search_name);
#line 1378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		search_name = _tmp17_;
#line 1378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp15_);
#line 1378 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_publishing_piwigo_category_unref0 (_tmp12_);
#line 9495 "PiwigoPublishing.c"
	}
#line 1382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = self->priv->create_new_radio;
#line 1382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp20_ = gtk_toggle_button_get_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_toggle_button_get_type (), GtkToggleButton));
#line 1382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp20_) {
#line 9503 "PiwigoPublishing.c"
		gboolean _tmp21_ = FALSE;
		const gchar* _tmp22_;
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp22_ = category_name;
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (g_strcmp0 (_tmp22_, "") == 0) {
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp21_ = TRUE;
#line 9512 "PiwigoPublishing.c"
		} else {
			const gchar* _tmp23_;
			gboolean _tmp24_;
#line 1385 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp23_ = search_name;
#line 1385 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp24_ = publishing_piwigo_publishing_options_pane_category_already_exists (self, _tmp23_);
#line 1385 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp21_ = _tmp24_;
#line 9522 "PiwigoPublishing.c"
		}
#line 1384 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp18_ = _tmp21_;
#line 9526 "PiwigoPublishing.c"
	} else {
#line 1382 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp18_ = FALSE;
#line 9530 "PiwigoPublishing.c"
	}
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp25_ = self->priv->publish_button;
#line 1380 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, gtk_widget_get_type (), GtkWidget), !_tmp18_);
#line 1370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (search_name);
#line 1370 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (category_name);
#line 9540 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_real_on_pane_installed (ShotwellPluginsCommonBuilderPane* base) {
	PublishingPiwigoPublishingOptionsPane * self;
	GtkButton* _tmp0_;
#line 1391 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPane);
#line 1392 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	SHOTWELL_PLUGINS_COMMON_BUILDER_PANE_CLASS (publishing_piwigo_publishing_options_pane_parent_class)->on_pane_installed (G_TYPE_CHECK_INSTANCE_CAST (self, SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, ShotwellPluginsCommonBuilderPane));
#line 1394 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_create_categories_combo (self);
#line 1395 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_create_within_categories_combo (self);
#line 1396 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_create_permissions_combo (self);
#line 1397 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_create_size_combo (self);
#line 1399 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->publish_button;
#line 1399 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_can_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1400 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_update_publish_button_sensitivity (self);
#line 9565 "PiwigoPublishing.c"
}


static gchar* publishing_piwigo_publishing_options_pane_get_common_comment_if_possible (PublishingPiwigoPiwigoPublisher* publisher) {
	gchar* result = NULL;
	SpitPublishingPublishable** publishables = NULL;
	PublishingPiwigoPiwigoPublisher* _tmp0_;
	SpitPublishingPluginHost* _tmp1_;
	SpitPublishingPluginHost* _tmp2_;
	gint _tmp3_;
	SpitPublishingPublishable** _tmp4_;
	SpitPublishingPublishable** _tmp5_;
	gint _tmp5__length1;
	gint publishables_length1;
	gint _publishables_size_;
	gchar* common = NULL;
	gchar* _tmp6_;
	gboolean isfirst = FALSE;
	SpitPublishingPublishable** _tmp7_;
	gint _tmp7__length1;
	const gchar* _tmp19_;
#line 1403 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PIWIGO_PUBLISHER (publisher), NULL);
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = publisher;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishing_piwigo_piwigo_publisher_get_host (_tmp0_);
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = _tmp1_;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = spit_publishing_plugin_host_get_publishables (_tmp2_, &_tmp3_);
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = _tmp4_;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5__length1 = _tmp3_;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp2_);
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishables = _tmp5_;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishables_length1 = _tmp5__length1;
#line 1406 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishables_size_ = publishables_length1;
#line 1407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = g_strdup ("");
#line 1407 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	common = _tmp6_;
#line 1408 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	isfirst = TRUE;
#line 1409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = publishables;
#line 1409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7__length1 = publishables_length1;
#line 1409 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp7_ != NULL) {
#line 9621 "PiwigoPublishing.c"
		SpitPublishingPublishable** _tmp8_;
		gint _tmp8__length1;
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = publishables;
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8__length1 = publishables_length1;
#line 9628 "PiwigoPublishing.c"
		{
			SpitPublishingPublishable** pub_collection = NULL;
			gint pub_collection_length1 = 0;
			gint _pub_collection_size_ = 0;
			gint pub_it = 0;
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			pub_collection = _tmp8_;
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			pub_collection_length1 = _tmp8__length1;
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			for (pub_it = 0; pub_it < _tmp8__length1; pub_it = pub_it + 1) {
#line 9640 "PiwigoPublishing.c"
				SpitPublishingPublishable* _tmp9_;
				SpitPublishingPublishable* pub = NULL;
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp9_ = _g_object_ref0 (pub_collection[pub_it]);
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				pub = _tmp9_;
#line 9647 "PiwigoPublishing.c"
				{
					gchar* cur = NULL;
					SpitPublishingPublishable* _tmp10_;
					gchar* _tmp11_;
					const gchar* _tmp12_;
					gboolean _tmp13_;
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp10_ = pub;
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp11_ = spit_publishing_publishable_get_param_string (_tmp10_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_EVENTCOMMENT);
#line 1411 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					cur = _tmp11_;
#line 1413 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp12_ = cur;
#line 1413 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (_tmp12_ == NULL) {
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_g_free0 (cur);
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_g_object_unref0 (pub);
#line 1414 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						continue;
#line 9670 "PiwigoPublishing.c"
					}
#line 1417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp13_ = isfirst;
#line 1417 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					if (_tmp13_) {
#line 9676 "PiwigoPublishing.c"
						const gchar* _tmp14_;
						gchar* _tmp15_;
#line 1418 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp14_ = cur;
#line 1418 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp15_ = g_strdup (_tmp14_);
#line 1418 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_g_free0 (common);
#line 1418 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						common = _tmp15_;
#line 1419 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						isfirst = FALSE;
#line 9689 "PiwigoPublishing.c"
					} else {
						const gchar* _tmp16_;
						const gchar* _tmp17_;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp16_ = cur;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						_tmp17_ = common;
#line 1421 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
						if (g_strcmp0 (_tmp16_, _tmp17_) != 0) {
#line 9699 "PiwigoPublishing.c"
							gchar* _tmp18_;
#line 1422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_tmp18_ = g_strdup ("");
#line 1422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_g_free0 (common);
#line 1422 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							common = _tmp18_;
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_g_free0 (cur);
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							_g_object_unref0 (pub);
#line 1423 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
							break;
#line 9713 "PiwigoPublishing.c"
						}
					}
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_free0 (cur);
#line 1410 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_g_object_unref0 (pub);
#line 9720 "PiwigoPublishing.c"
				}
			}
		}
	}
#line 1428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = common;
#line 1428 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:1428: PiwigoConnector: found common event commen" \
"t %s\n", _tmp19_);
#line 1429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = common;
#line 1429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishables = (_vala_array_free (publishables, publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 1429 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 9735 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_create_categories_combo (PublishingPiwigoPublishingOptionsPane* self) {
	GeeList* _tmp14_;
	gboolean _tmp15_;
	gboolean _tmp16_;
	const gchar* _tmp30_;
	gboolean _tmp31_;
#line 1432 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 9747 "PiwigoPublishing.c"
	{
		GeeList* _cat_list = NULL;
		GeeList* _tmp0_;
		GeeList* _tmp1_;
		gint _cat_size = 0;
		GeeList* _tmp2_;
		gint _tmp3_;
		gint _tmp4_;
		gint _cat_index = 0;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = self->priv->_existing_categories;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_cat_list = _tmp1_;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp2_ = _cat_list;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = _tmp3_;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_cat_size = _tmp4_;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_cat_index = -1;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		while (TRUE) {
#line 9775 "PiwigoPublishing.c"
			gint _tmp5_;
			gint _tmp6_;
			gint _tmp7_;
			PublishingPiwigoCategory* cat = NULL;
			GeeList* _tmp8_;
			gint _tmp9_;
			gpointer _tmp10_;
			GtkComboBoxText* _tmp11_;
			PublishingPiwigoCategory* _tmp12_;
			const gchar* _tmp13_;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp5_ = _cat_index;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_cat_index = _tmp5_ + 1;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp6_ = _cat_index;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp7_ = _cat_size;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (!(_tmp6_ < _tmp7_)) {
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				break;
#line 9798 "PiwigoPublishing.c"
			}
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp8_ = _cat_list;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp9_ = _cat_index;
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp10_ = gee_list_get (_tmp8_, _tmp9_);
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			cat = (PublishingPiwigoCategory*) _tmp10_;
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp11_ = self->priv->existing_categories_combo;
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp12_ = cat;
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp13_ = _tmp12_->display_name;
#line 1434 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			gtk_combo_box_text_append_text (_tmp11_, _tmp13_);
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_piwigo_category_unref0 (cat);
#line 9818 "PiwigoPublishing.c"
		}
#line 1433 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (_cat_list);
#line 9822 "PiwigoPublishing.c"
	}
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = self->priv->_existing_categories;
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = gee_collection_get_is_empty (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = _tmp15_;
#line 1436 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp16_) {
#line 9832 "PiwigoPublishing.c"
		GtkComboBoxText* _tmp17_;
		GtkRadioButton* _tmp18_;
		GtkRadioButton* _tmp19_;
		GtkTextView* _tmp20_;
		GtkLabel* _tmp21_;
		GtkEntry* _tmp22_;
#line 1438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp17_ = self->priv->existing_categories_combo;
#line 1438 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp18_ = self->priv->use_existing_radio;
#line 1439 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp19_ = self->priv->create_new_radio;
#line 1440 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_toggle_button_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, gtk_toggle_button_get_type (), GtkToggleButton), TRUE);
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp20_ = self->priv->album_comment;
#line 1441 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp21_ = self->priv->album_comment_label;
#line 1442 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 1443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp22_ = self->priv->new_category_entry;
#line 1443 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_grab_focus (G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, gtk_widget_get_type (), GtkWidget));
#line 9863 "PiwigoPublishing.c"
	} else {
		gint last_category_index = 0;
		gint _tmp23_;
		gint _tmp24_;
		GtkComboBoxText* _tmp25_;
		gint _tmp26_;
		GtkEntry* _tmp27_;
		GtkTextView* _tmp28_;
		GtkLabel* _tmp29_;
#line 1445 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp23_ = self->priv->_last_category;
#line 1445 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp24_ = publishing_piwigo_publishing_options_pane_find_category_index (self, _tmp23_);
#line 1445 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		last_category_index = _tmp24_;
#line 1446 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp25_ = self->priv->existing_categories_combo;
#line 1446 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp26_ = last_category_index;
#line 1446 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp25_, gtk_combo_box_get_type (), GtkComboBox), _tmp26_);
#line 1447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp27_ = self->priv->new_category_entry;
#line 1447 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp28_ = self->priv->album_comment;
#line 1448 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp29_ = self->priv->album_comment_label;
#line 1449 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 9897 "PiwigoPublishing.c"
	}
#line 1451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp30_ = publishing_piwigo_publishing_options_pane_DEFAULT_CATEGORY_NAME;
#line 1451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp31_ = publishing_piwigo_publishing_options_pane_category_already_exists (self, _tmp30_);
#line 1451 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp31_) {
#line 9905 "PiwigoPublishing.c"
		GtkEntry* _tmp32_;
		const gchar* _tmp33_;
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp32_ = self->priv->new_category_entry;
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp33_ = publishing_piwigo_publishing_options_pane_DEFAULT_CATEGORY_NAME;
#line 1452 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_entry_set_text (_tmp32_, _tmp33_);
#line 9914 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_publishing_options_pane_create_within_categories_combo (PublishingPiwigoPublishingOptionsPane* self) {
	GtkComboBoxText* _tmp0_;
	GtkLabel* _tmp15_;
	GtkComboBoxText* _tmp16_;
	GtkComboBoxText* _tmp17_;
#line 1455 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1457 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->within_existing_combo;
#line 1457 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_combo_box_text_append_text (_tmp0_, "/ ");
#line 9930 "PiwigoPublishing.c"
	{
		GeeList* _cat_list = NULL;
		GeeList* _tmp1_;
		GeeList* _tmp2_;
		gint _cat_size = 0;
		GeeList* _tmp3_;
		gint _tmp4_;
		gint _tmp5_;
		gint _cat_index = 0;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = self->priv->_existing_categories;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp2_ = _g_object_ref0 (_tmp1_);
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_cat_list = _tmp2_;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = _cat_list;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = _tmp4_;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_cat_size = _tmp5_;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_cat_index = -1;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		while (TRUE) {
#line 9958 "PiwigoPublishing.c"
			gint _tmp6_;
			gint _tmp7_;
			gint _tmp8_;
			PublishingPiwigoCategory* cat = NULL;
			GeeList* _tmp9_;
			gint _tmp10_;
			gpointer _tmp11_;
			GtkComboBoxText* _tmp12_;
			PublishingPiwigoCategory* _tmp13_;
			const gchar* _tmp14_;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp6_ = _cat_index;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_cat_index = _tmp6_ + 1;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp7_ = _cat_index;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp8_ = _cat_size;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (!(_tmp7_ < _tmp8_)) {
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				break;
#line 9981 "PiwigoPublishing.c"
			}
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp9_ = _cat_list;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp10_ = _cat_index;
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp11_ = gee_list_get (_tmp9_, _tmp10_);
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			cat = (PublishingPiwigoCategory*) _tmp11_;
#line 1459 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp12_ = self->priv->within_existing_combo;
#line 1459 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp13_ = cat;
#line 1459 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp14_ = _tmp13_->display_name;
#line 1459 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			gtk_combo_box_text_append_text (_tmp12_, _tmp14_);
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_piwigo_category_unref0 (cat);
#line 10001 "PiwigoPublishing.c"
		}
#line 1458 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (_cat_list);
#line 10005 "PiwigoPublishing.c"
	}
#line 1462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = self->priv->within_existing_label;
#line 1462 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 1463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = self->priv->within_existing_combo;
#line 1463 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = self->priv->within_existing_combo;
#line 1464 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 10019 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_create_permissions_combo (PublishingPiwigoPublishingOptionsPane* self) {
	PublishingPiwigoPermissionLevel** _tmp0_;
	gint _tmp0__length1;
	gint last_permission_level_index = 0;
	gint _tmp5_;
	gint _tmp6_;
	gint _tmp7_;
#line 1467 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->perm_levels;
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0__length1 = self->priv->perm_levels_length1;
#line 10036 "PiwigoPublishing.c"
	{
		PublishingPiwigoPermissionLevel** perm_collection = NULL;
		gint perm_collection_length1 = 0;
		gint _perm_collection_size_ = 0;
		gint perm_it = 0;
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		perm_collection = _tmp0_;
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		perm_collection_length1 = _tmp0__length1;
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		for (perm_it = 0; perm_it < _tmp0__length1; perm_it = perm_it + 1) {
#line 10048 "PiwigoPublishing.c"
			PublishingPiwigoPermissionLevel* _tmp1_;
			PublishingPiwigoPermissionLevel* perm = NULL;
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp1_ = _publishing_piwigo_permission_level_ref0 (perm_collection[perm_it]);
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			perm = _tmp1_;
#line 10055 "PiwigoPublishing.c"
			{
				GtkComboBoxText* _tmp2_;
				PublishingPiwigoPermissionLevel* _tmp3_;
				const gchar* _tmp4_;
#line 1469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp2_ = self->priv->perms_combo;
#line 1469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3_ = perm;
#line 1469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4_ = _tmp3_->name;
#line 1469 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				gtk_combo_box_text_append_text (_tmp2_, _tmp4_);
#line 1468 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_piwigo_permission_level_unref0 (perm);
#line 10070 "PiwigoPublishing.c"
			}
		}
	}
#line 1471 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = self->priv->_last_permission_level;
#line 1471 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_piwigo_publishing_options_pane_find_permission_level_index (self, _tmp5_);
#line 1471 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	last_permission_level_index = _tmp6_;
#line 1472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = last_permission_level_index;
#line 1472 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp7_ < 0) {
#line 10084 "PiwigoPublishing.c"
		GtkComboBoxText* _tmp8_;
#line 1473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = self->priv->perms_combo;
#line 1473 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_combo_box_get_type (), GtkComboBox), 0);
#line 10090 "PiwigoPublishing.c"
	} else {
		GtkComboBoxText* _tmp9_;
		gint _tmp10_;
#line 1475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = self->priv->perms_combo;
#line 1475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = last_permission_level_index;
#line 1475 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_combo_box_get_type (), GtkComboBox), _tmp10_);
#line 10100 "PiwigoPublishing.c"
	}
}


static void publishing_piwigo_publishing_options_pane_create_size_combo (PublishingPiwigoPublishingOptionsPane* self) {
	PublishingPiwigoSizeEntry** _tmp0_;
	gint _tmp0__length1;
	gint last_size_index = 0;
	gint _tmp5_;
	gint _tmp6_;
	gint _tmp7_;
#line 1479 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1480 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->photo_sizes;
#line 1480 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0__length1 = self->priv->photo_sizes_length1;
#line 10118 "PiwigoPublishing.c"
	{
		PublishingPiwigoSizeEntry** size_collection = NULL;
		gint size_collection_length1 = 0;
		gint _size_collection_size_ = 0;
		gint size_it = 0;
#line 1480 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		size_collection = _tmp0_;
#line 1480 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		size_collection_length1 = _tmp0__length1;
#line 1480 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		for (size_it = 0; size_it < _tmp0__length1; size_it = size_it + 1) {
#line 10130 "PiwigoPublishing.c"
			PublishingPiwigoSizeEntry* _tmp1_;
			PublishingPiwigoSizeEntry* size = NULL;
#line 1480 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp1_ = _publishing_piwigo_size_entry_ref0 (size_collection[size_it]);
#line 1480 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			size = _tmp1_;
#line 10137 "PiwigoPublishing.c"
			{
				GtkComboBoxText* _tmp2_;
				PublishingPiwigoSizeEntry* _tmp3_;
				const gchar* _tmp4_;
#line 1481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp2_ = self->priv->size_combo;
#line 1481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3_ = size;
#line 1481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4_ = _tmp3_->name;
#line 1481 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				gtk_combo_box_text_append_text (_tmp2_, _tmp4_);
#line 1480 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_piwigo_size_entry_unref0 (size);
#line 10152 "PiwigoPublishing.c"
			}
		}
	}
#line 1483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = self->priv->_last_photo_size;
#line 1483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_piwigo_publishing_options_pane_find_size_index (self, _tmp5_);
#line 1483 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	last_size_index = _tmp6_;
#line 1484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = last_size_index;
#line 1484 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp7_ < 0) {
#line 10166 "PiwigoPublishing.c"
		GtkComboBoxText* _tmp8_;
		gint _tmp9_;
#line 1485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = self->priv->size_combo;
#line 1485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = publishing_piwigo_publishing_options_pane_find_size_index (self, PUBLISHING_PIWIGO_ORIGINAL_SIZE);
#line 1485 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, gtk_combo_box_get_type (), GtkComboBox), _tmp9_);
#line 10175 "PiwigoPublishing.c"
	} else {
		GtkComboBoxText* _tmp10_;
		gint _tmp11_;
#line 1487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = self->priv->size_combo;
#line 1487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = last_size_index;
#line 1487 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		gtk_combo_box_set_active (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_combo_box_get_type (), GtkComboBox), _tmp11_);
#line 10185 "PiwigoPublishing.c"
	}
}


static gint publishing_piwigo_publishing_options_pane_find_category_index (PublishingPiwigoPublishingOptionsPane* self, gint category_id) {
	gint result = 0;
	gint _result_ = 0;
#line 1491 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), 0);
#line 1492 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result_ = 0;
#line 10197 "PiwigoPublishing.c"
	{
		gint i = 0;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		i = 0;
#line 10202 "PiwigoPublishing.c"
		{
			gboolean _tmp0_ = FALSE;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp0_ = TRUE;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			while (TRUE) {
#line 10209 "PiwigoPublishing.c"
				gint _tmp2_;
				GeeList* _tmp3_;
				gint _tmp4_;
				gint _tmp5_;
				GeeList* _tmp6_;
				gint _tmp7_;
				gpointer _tmp8_;
				PublishingPiwigoCategory* _tmp9_;
				gint _tmp10_;
				gint _tmp11_;
				gboolean _tmp12_;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!_tmp0_) {
#line 10223 "PiwigoPublishing.c"
					gint _tmp1_;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp1_ = i;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					i = _tmp1_ + 1;
#line 10229 "PiwigoPublishing.c"
				}
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp0_ = FALSE;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp2_ = i;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3_ = self->priv->_existing_categories;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp5_ = _tmp4_;
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!(_tmp2_ < _tmp5_)) {
#line 1493 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 10245 "PiwigoPublishing.c"
				}
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp6_ = self->priv->_existing_categories;
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp7_ = i;
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp8_ = gee_list_get (_tmp6_, _tmp7_);
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp9_ = (PublishingPiwigoCategory*) _tmp8_;
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp10_ = _tmp9_->id;
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp11_ = category_id;
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp12_ = _tmp10_ == _tmp11_;
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_piwigo_category_unref0 (_tmp9_);
#line 1494 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_tmp12_) {
#line 10265 "PiwigoPublishing.c"
					gint _tmp13_;
#line 1495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp13_ = i;
#line 1495 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_result_ = _tmp13_;
#line 1496 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 10273 "PiwigoPublishing.c"
				}
			}
		}
	}
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _result_;
#line 1499 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10282 "PiwigoPublishing.c"
}


static gint publishing_piwigo_publishing_options_pane_find_permission_level_index (PublishingPiwigoPublishingOptionsPane* self, gint permission_level_id) {
	gint result = 0;
	gint _result_ = 0;
#line 1502 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), 0);
#line 1503 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result_ = -1;
#line 10293 "PiwigoPublishing.c"
	{
		gint i = 0;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		i = 0;
#line 10298 "PiwigoPublishing.c"
		{
			gboolean _tmp0_ = FALSE;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp0_ = TRUE;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			while (TRUE) {
#line 10305 "PiwigoPublishing.c"
				gint _tmp2_;
				PublishingPiwigoPermissionLevel** _tmp3_;
				gint _tmp3__length1;
				PublishingPiwigoPermissionLevel** _tmp4_;
				gint _tmp4__length1;
				gint _tmp5_;
				PublishingPiwigoPermissionLevel* _tmp6_;
				gint _tmp7_;
				gint _tmp8_;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!_tmp0_) {
#line 10317 "PiwigoPublishing.c"
					gint _tmp1_;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp1_ = i;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					i = _tmp1_ + 1;
#line 10323 "PiwigoPublishing.c"
				}
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp0_ = FALSE;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp2_ = i;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3_ = self->priv->perm_levels;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3__length1 = self->priv->perm_levels_length1;
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!(_tmp2_ < _tmp3__length1)) {
#line 1504 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 10337 "PiwigoPublishing.c"
				}
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4_ = self->priv->perm_levels;
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4__length1 = self->priv->perm_levels_length1;
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp5_ = i;
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp6_ = _tmp4_[_tmp5_];
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp7_ = _tmp6_->id;
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp8_ = permission_level_id;
#line 1505 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_tmp7_ == _tmp8_) {
#line 10353 "PiwigoPublishing.c"
					gint _tmp9_;
#line 1506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp9_ = i;
#line 1506 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_result_ = _tmp9_;
#line 1507 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 10361 "PiwigoPublishing.c"
				}
			}
		}
	}
#line 1510 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _result_;
#line 1510 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10370 "PiwigoPublishing.c"
}


static gint publishing_piwigo_publishing_options_pane_find_size_index (PublishingPiwigoPublishingOptionsPane* self, gint size_id) {
	gint result = 0;
	gint _result_ = 0;
#line 1513 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), 0);
#line 1514 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result_ = -1;
#line 10381 "PiwigoPublishing.c"
	{
		gint i = 0;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		i = 0;
#line 10386 "PiwigoPublishing.c"
		{
			gboolean _tmp0_ = FALSE;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp0_ = TRUE;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			while (TRUE) {
#line 10393 "PiwigoPublishing.c"
				gint _tmp2_;
				PublishingPiwigoSizeEntry** _tmp3_;
				gint _tmp3__length1;
				PublishingPiwigoSizeEntry** _tmp4_;
				gint _tmp4__length1;
				gint _tmp5_;
				PublishingPiwigoSizeEntry* _tmp6_;
				gint _tmp7_;
				gint _tmp8_;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!_tmp0_) {
#line 10405 "PiwigoPublishing.c"
					gint _tmp1_;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp1_ = i;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					i = _tmp1_ + 1;
#line 10411 "PiwigoPublishing.c"
				}
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp0_ = FALSE;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp2_ = i;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3_ = self->priv->photo_sizes;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp3__length1 = self->priv->photo_sizes_length1;
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (!(_tmp2_ < _tmp3__length1)) {
#line 1515 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 10425 "PiwigoPublishing.c"
				}
#line 1516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4_ = self->priv->photo_sizes;
#line 1516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp4__length1 = self->priv->photo_sizes_length1;
#line 1516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp5_ = i;
#line 1516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp6_ = _tmp4_[_tmp5_];
#line 1516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp7_ = _tmp6_->id;
#line 1516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp8_ = size_id;
#line 1516 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				if (_tmp7_ == _tmp8_) {
#line 10441 "PiwigoPublishing.c"
					gint _tmp9_;
#line 1517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_tmp9_ = i;
#line 1517 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					_result_ = _tmp9_;
#line 1518 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
					break;
#line 10449 "PiwigoPublishing.c"
				}
			}
		}
	}
#line 1521 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _result_;
#line 1521 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10458 "PiwigoPublishing.c"
}


static gboolean publishing_piwigo_publishing_options_pane_category_already_exists (PublishingPiwigoPublishingOptionsPane* self, const gchar* category_name) {
	gboolean result = FALSE;
	gboolean _result_ = FALSE;
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), FALSE);
#line 1524 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (category_name != NULL, FALSE);
#line 1525 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_result_ = FALSE;
#line 10471 "PiwigoPublishing.c"
	{
		GeeList* _category_list = NULL;
		GeeList* _tmp0_;
		GeeList* _tmp1_;
		gint _category_size = 0;
		GeeList* _tmp2_;
		gint _tmp3_;
		gint _tmp4_;
		gint _category_index = 0;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = self->priv->_existing_categories;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_category_list = _tmp1_;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp2_ = _category_list;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection));
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = _tmp3_;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_category_size = _tmp4_;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_category_index = -1;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		while (TRUE) {
#line 10499 "PiwigoPublishing.c"
			gint _tmp5_;
			gint _tmp6_;
			gint _tmp7_;
			PublishingPiwigoCategory* category = NULL;
			GeeList* _tmp8_;
			gint _tmp9_;
			gpointer _tmp10_;
			PublishingPiwigoCategory* _tmp11_;
			const gchar* _tmp12_;
			gchar* _tmp13_;
			gchar* _tmp14_;
			const gchar* _tmp15_;
			gboolean _tmp16_;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp5_ = _category_index;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_category_index = _tmp5_ + 1;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp6_ = _category_index;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp7_ = _category_size;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (!(_tmp6_ < _tmp7_)) {
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				break;
#line 10525 "PiwigoPublishing.c"
			}
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp8_ = _category_list;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp9_ = _category_index;
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp10_ = gee_list_get (_tmp8_, _tmp9_);
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			category = (PublishingPiwigoCategory*) _tmp10_;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp11_ = category;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp12_ = _tmp11_->display_name;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp13_ = string_strip (_tmp12_);
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp14_ = _tmp13_;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp15_ = category_name;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp16_ = g_strcmp0 (_tmp14_, _tmp15_) == 0;
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (_tmp14_);
#line 1527 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_tmp16_) {
#line 1528 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_result_ = TRUE;
#line 1529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_piwigo_category_unref0 (category);
#line 1529 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				break;
#line 10557 "PiwigoPublishing.c"
			}
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_publishing_piwigo_category_unref0 (category);
#line 10561 "PiwigoPublishing.c"
		}
#line 1526 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (_category_list);
#line 10565 "PiwigoPublishing.c"
	}
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _result_;
#line 1532 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10571 "PiwigoPublishing.c"
}


static gint publishing_piwigo_publishing_options_pane_get_last_category (PublishingPiwigoPublishingOptionsPane* self) {
	gint result;
	gint _tmp0_;
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), 0);
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_last_category;
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10586 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_set_last_category (PublishingPiwigoPublishingOptionsPane* self, gint value) {
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (publishing_piwigo_publishing_options_pane_get_last_category (self) != value) {
#line 10595 "PiwigoPublishing.c"
		gint _tmp0_;
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = value;
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_last_category = _tmp0_;
#line 1209 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_notify ((GObject *) self, "last-category");
#line 10603 "PiwigoPublishing.c"
	}
}


static gint publishing_piwigo_publishing_options_pane_get_last_permission_level (PublishingPiwigoPublishingOptionsPane* self) {
	gint result;
	gint _tmp0_;
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), 0);
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_last_permission_level;
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10619 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_set_last_permission_level (PublishingPiwigoPublishingOptionsPane* self, gint value) {
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (publishing_piwigo_publishing_options_pane_get_last_permission_level (self) != value) {
#line 10628 "PiwigoPublishing.c"
		gint _tmp0_;
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = value;
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_last_permission_level = _tmp0_;
#line 1210 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_notify ((GObject *) self, "last-permission-level");
#line 10636 "PiwigoPublishing.c"
	}
}


static gint publishing_piwigo_publishing_options_pane_get_last_photo_size (PublishingPiwigoPublishingOptionsPane* self) {
	gint result;
	gint _tmp0_;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), 0);
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_last_photo_size;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10652 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_set_last_photo_size (PublishingPiwigoPublishingOptionsPane* self, gint value) {
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (publishing_piwigo_publishing_options_pane_get_last_photo_size (self) != value) {
#line 10661 "PiwigoPublishing.c"
		gint _tmp0_;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = value;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_last_photo_size = _tmp0_;
#line 1211 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_notify ((GObject *) self, "last-photo-size");
#line 10669 "PiwigoPublishing.c"
	}
}


static gboolean publishing_piwigo_publishing_options_pane_get_last_title_as_comment (PublishingPiwigoPublishingOptionsPane* self) {
	gboolean result;
	gboolean _tmp0_;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), FALSE);
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_last_title_as_comment;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10685 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_set_last_title_as_comment (PublishingPiwigoPublishingOptionsPane* self, gboolean value) {
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (publishing_piwigo_publishing_options_pane_get_last_title_as_comment (self) != value) {
#line 10694 "PiwigoPublishing.c"
		gboolean _tmp0_;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = value;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_last_title_as_comment = _tmp0_;
#line 1212 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_notify ((GObject *) self, "last-title-as-comment");
#line 10702 "PiwigoPublishing.c"
	}
}


static gboolean publishing_piwigo_publishing_options_pane_get_last_no_upload_tags (PublishingPiwigoPublishingOptionsPane* self) {
	gboolean result;
	gboolean _tmp0_;
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), FALSE);
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_last_no_upload_tags;
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10718 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_set_last_no_upload_tags (PublishingPiwigoPublishingOptionsPane* self, gboolean value) {
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (publishing_piwigo_publishing_options_pane_get_last_no_upload_tags (self) != value) {
#line 10727 "PiwigoPublishing.c"
		gboolean _tmp0_;
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = value;
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_last_no_upload_tags = _tmp0_;
#line 1213 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_notify ((GObject *) self, "last-no-upload-tags");
#line 10735 "PiwigoPublishing.c"
	}
}


static gboolean publishing_piwigo_publishing_options_pane_get_strip_metadata_enabled (PublishingPiwigoPublishingOptionsPane* self) {
	gboolean result;
	gboolean _tmp0_;
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), FALSE);
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_strip_metadata_enabled;
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10751 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_set_strip_metadata_enabled (PublishingPiwigoPublishingOptionsPane* self, gboolean value) {
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (publishing_piwigo_publishing_options_pane_get_strip_metadata_enabled (self) != value) {
#line 10760 "PiwigoPublishing.c"
		gboolean _tmp0_;
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = value;
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_strip_metadata_enabled = _tmp0_;
#line 1214 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_notify ((GObject *) self, "strip-metadata-enabled");
#line 10768 "PiwigoPublishing.c"
	}
}


static GeeList* publishing_piwigo_publishing_options_pane_get_existing_categories (PublishingPiwigoPublishingOptionsPane* self) {
	GeeList* result;
	GeeList* _tmp0_;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_existing_categories;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10784 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_set_existing_categories (PublishingPiwigoPublishingOptionsPane* self, GeeList* value) {
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (publishing_piwigo_publishing_options_pane_get_existing_categories (self) != value) {
#line 10793 "PiwigoPublishing.c"
		GeeList* _tmp0_;
		GeeList* _tmp1_;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = value;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_object_unref0 (self->priv->_existing_categories);
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_existing_categories = _tmp1_;
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_notify ((GObject *) self, "existing-categories");
#line 10806 "PiwigoPublishing.c"
	}
}


static const gchar* publishing_piwigo_publishing_options_pane_get_default_comment (PublishingPiwigoPublishingOptionsPane* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self), NULL);
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->_default_comment;
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 10822 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_set_default_comment (PublishingPiwigoPublishingOptionsPane* self, const gchar* value) {
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_OPTIONS_PANE (self));
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_strcmp0 (value, publishing_piwigo_publishing_options_pane_get_default_comment (self)) != 0) {
#line 10831 "PiwigoPublishing.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = value;
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (self->priv->_default_comment);
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		self->priv->_default_comment = _tmp1_;
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_object_notify ((GObject *) self, "default-comment");
#line 10844 "PiwigoPublishing.c"
	}
}


static void g_cclosure_user_marshal_VOID__PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_BOOLEAN (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_BOOLEAN) (gpointer data1, gpointer arg_1, gboolean arg_2, gpointer data2);
	register GMarshalFunc_VOID__PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_BOOLEAN callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (n_param_values == 3);
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data1 = closure->data;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data2 = param_values->data[0].v_pointer;
#line 10864 "PiwigoPublishing.c"
	} else {
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data1 = param_values->data[0].v_pointer;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		data2 = closure->data;
#line 10870 "PiwigoPublishing.c"
	}
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	callback = (GMarshalFunc_VOID__PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	callback (data1, publishing_piwigo_value_get_publishing_parameters (param_values + 1), g_value_get_boolean (param_values + 2), data2);
#line 10876 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_class_init (PublishingPiwigoPublishingOptionsPaneClass * klass) {
	gchar* _tmp0_;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_parent_class = g_type_class_peek_parent (klass);
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPiwigoPublishingOptionsPanePrivate));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((GObjectClass *) klass)->constructed = (void (*) (GObject *)) publishing_piwigo_publishing_options_pane_real_constructed;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((ShotwellPluginsCommonBuilderPaneClass *) klass)->on_pane_installed = (void (*) (ShotwellPluginsCommonBuilderPane *)) publishing_piwigo_publishing_options_pane_real_on_pane_installed;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_publishing_piwigo_publishing_options_pane_get_property;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_publishing_piwigo_publishing_options_pane_set_property;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_piwigo_publishing_options_pane_finalize;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_CATEGORY_PROPERTY, g_param_spec_int ("last-category", "last-category", "last-category", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_PERMISSION_LEVEL_PROPERTY, g_param_spec_int ("last-permission-level", "last-permission-level", "last-permission-level", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_PHOTO_SIZE_PROPERTY, g_param_spec_int ("last-photo-size", "last-photo-size", "last-photo-size", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_TITLE_AS_COMMENT_PROPERTY, g_param_spec_boolean ("last-title-as-comment", "last-title-as-comment", "last-title-as-comment", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_NO_UPLOAD_TAGS_PROPERTY, g_param_spec_boolean ("last-no-upload-tags", "last-no-upload-tags", "last-no-upload-tags", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_STRIP_METADATA_ENABLED_PROPERTY, g_param_spec_boolean ("strip-metadata-enabled", "strip-metadata-enabled", "strip-metadata-enabled", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_EXISTING_CATEGORIES_PROPERTY, g_param_spec_object ("existing-categories", "existing-categories", "existing-categories", GEE_TYPE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_DEFAULT_COMMENT_PROPERTY, g_param_spec_string ("default-comment", "default-comment", "default-comment", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_signals[PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_PUBLISH_SIGNAL] = g_signal_new ("publish", PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__PUBLISHING_PIWIGO_PUBLISHING_PARAMETERS_BOOLEAN, G_TYPE_NONE, 2, PUBLISHING_PIWIGO_TYPE_PUBLISHING_PARAMETERS, G_TYPE_BOOLEAN);
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_signals[PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LOGOUT_SIGNAL] = g_signal_new ("logout", PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 1188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = g_strdup (_ ("Shotwell Connect"));
#line 1188 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_publishing_options_pane_DEFAULT_CATEGORY_NAME = _tmp0_;
#line 10920 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_instance_init (PublishingPiwigoPublishingOptionsPane * self) {
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv = PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_GET_PRIVATE (self);
#line 1198 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->strip_metadata_check = NULL;
#line 1199 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->title_as_comment_check = NULL;
#line 1200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->no_upload_tags_check = NULL;
#line 10933 "PiwigoPublishing.c"
}


static void publishing_piwigo_publishing_options_pane_finalize (GObject * obj) {
	PublishingPiwigoPublishingOptionsPane * self;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPane);
#line 1190 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->use_existing_radio);
#line 1191 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->create_new_radio);
#line 1192 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->existing_categories_combo);
#line 1193 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->new_category_entry);
#line 1194 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->within_existing_label);
#line 1195 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->within_existing_combo);
#line 1196 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->perms_combo);
#line 1197 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->size_combo);
#line 1198 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->strip_metadata_check);
#line 1199 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->title_as_comment_check);
#line 1200 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->no_upload_tags_check);
#line 1201 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->logout_button);
#line 1202 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->publish_button);
#line 1203 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->album_comment);
#line 1204 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->album_comment_label);
#line 1206 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->perm_levels = (_vala_array_free (self->priv->perm_levels, self->priv->perm_levels_length1, (GDestroyNotify) publishing_piwigo_permission_level_unref), NULL);
#line 1207 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->photo_sizes = (_vala_array_free (self->priv->photo_sizes, self->priv->photo_sizes_length1, (GDestroyNotify) publishing_piwigo_size_entry_unref), NULL);
#line 1215 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (self->priv->_existing_categories);
#line 1216 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->_default_comment);
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	G_OBJECT_CLASS (publishing_piwigo_publishing_options_pane_parent_class)->finalize (obj);
#line 10981 "PiwigoPublishing.c"
}


/**
 * The publishing options pane.
 */
GType publishing_piwigo_publishing_options_pane_get_type (void) {
	static volatile gsize publishing_piwigo_publishing_options_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_publishing_options_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoPublishingOptionsPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_publishing_options_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoPublishingOptionsPane), 0, (GInstanceInitFunc) publishing_piwigo_publishing_options_pane_instance_init, NULL };
		GType publishing_piwigo_publishing_options_pane_type_id;
		publishing_piwigo_publishing_options_pane_type_id = g_type_register_static (SHOTWELL_PLUGINS_COMMON_TYPE_BUILDER_PANE, "PublishingPiwigoPublishingOptionsPane", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_publishing_options_pane_type_id__volatile, publishing_piwigo_publishing_options_pane_type_id);
	}
	return publishing_piwigo_publishing_options_pane_type_id__volatile;
}


static void _vala_publishing_piwigo_publishing_options_pane_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	PublishingPiwigoPublishingOptionsPane * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPane);
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	switch (property_id) {
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_CATEGORY_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_value_set_int (value, publishing_piwigo_publishing_options_pane_get_last_category (self));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_PERMISSION_LEVEL_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_value_set_int (value, publishing_piwigo_publishing_options_pane_get_last_permission_level (self));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_PHOTO_SIZE_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_value_set_int (value, publishing_piwigo_publishing_options_pane_get_last_photo_size (self));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_TITLE_AS_COMMENT_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_value_set_boolean (value, publishing_piwigo_publishing_options_pane_get_last_title_as_comment (self));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_NO_UPLOAD_TAGS_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_value_set_boolean (value, publishing_piwigo_publishing_options_pane_get_last_no_upload_tags (self));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_STRIP_METADATA_ENABLED_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_value_set_boolean (value, publishing_piwigo_publishing_options_pane_get_strip_metadata_enabled (self));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_EXISTING_CATEGORIES_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_value_set_object (value, publishing_piwigo_publishing_options_pane_get_existing_categories (self));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_DEFAULT_COMMENT_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_value_set_string (value, publishing_piwigo_publishing_options_pane_get_default_comment (self));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 11053 "PiwigoPublishing.c"
		default:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 11059 "PiwigoPublishing.c"
	}
}


static void _vala_publishing_piwigo_publishing_options_pane_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	PublishingPiwigoPublishingOptionsPane * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, PUBLISHING_PIWIGO_TYPE_PUBLISHING_OPTIONS_PANE, PublishingPiwigoPublishingOptionsPane);
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	switch (property_id) {
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_CATEGORY_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_options_pane_set_last_category (self, g_value_get_int (value));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_PERMISSION_LEVEL_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_options_pane_set_last_permission_level (self, g_value_get_int (value));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_PHOTO_SIZE_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_options_pane_set_last_photo_size (self, g_value_get_int (value));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_TITLE_AS_COMMENT_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_options_pane_set_last_title_as_comment (self, g_value_get_boolean (value));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_LAST_NO_UPLOAD_TAGS_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_options_pane_set_last_no_upload_tags (self, g_value_get_boolean (value));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_STRIP_METADATA_ENABLED_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_options_pane_set_strip_metadata_enabled (self, g_value_get_boolean (value));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_EXISTING_CATEGORIES_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_options_pane_set_existing_categories (self, g_value_get_object (value));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		case PUBLISHING_PIWIGO_PUBLISHING_OPTIONS_PANE_DEFAULT_COMMENT_PROPERTY:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_piwigo_publishing_options_pane_set_default_comment (self, g_value_get_string (value));
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 11117 "PiwigoPublishing.c"
		default:
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 1186 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		break;
#line 11123 "PiwigoPublishing.c"
	}
}


PublishingPiwigoSession* publishing_piwigo_session_construct (GType object_type) {
	PublishingPiwigoSession* self = NULL;
#line 1548 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSession*) publishing_rest_support_session_construct (object_type, "");
#line 1547 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 11134 "PiwigoPublishing.c"
}


PublishingPiwigoSession* publishing_piwigo_session_new (void) {
#line 1547 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_session_construct (PUBLISHING_PIWIGO_TYPE_SESSION);
#line 11141 "PiwigoPublishing.c"
}


static gboolean publishing_piwigo_session_real_is_authenticated (PublishingRESTSupportSession* base) {
	PublishingPiwigoSession * self;
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	const gchar* _tmp2_;
#line 1551 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSession);
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = self->priv->pwg_id;
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp2_ != NULL) {
#line 11157 "PiwigoPublishing.c"
		const gchar* _tmp3_;
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = self->priv->pwg_url;
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = _tmp3_ != NULL;
#line 11163 "PiwigoPublishing.c"
	} else {
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp1_ = FALSE;
#line 11167 "PiwigoPublishing.c"
	}
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp1_) {
#line 11171 "PiwigoPublishing.c"
		const gchar* _tmp4_;
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = self->priv->username;
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = _tmp4_ != NULL;
#line 11177 "PiwigoPublishing.c"
	} else {
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp0_ = FALSE;
#line 11181 "PiwigoPublishing.c"
	}
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp0_;
#line 1552 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 11187 "PiwigoPublishing.c"
}


void publishing_piwigo_session_authenticate (PublishingPiwigoSession* self, const gchar* url, const gchar* username, const gchar* id) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_SESSION (self));
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (url != NULL);
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (username != NULL);
#line 1555 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (id != NULL);
#line 1556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = url;
#line 1556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_url);
#line 1556 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_url = _tmp1_;
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = username;
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->username);
#line 1557 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->username = _tmp3_;
#line 1558 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = id;
#line 1558 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = g_strdup (_tmp4_);
#line 1558 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_id);
#line 1558 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_id = _tmp5_;
#line 11230 "PiwigoPublishing.c"
}


void publishing_piwigo_session_deauthenticate (PublishingPiwigoSession* self) {
#line 1561 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_SESSION (self));
#line 1562 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_url);
#line 1562 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_url = NULL;
#line 1563 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_id);
#line 1563 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_id = NULL;
#line 1564 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->username);
#line 1564 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->username = NULL;
#line 11249 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_session_get_username (PublishingPiwigoSession* self) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1567 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (self), NULL);
#line 1568 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->username;
#line 1568 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1568 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 1568 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 11267 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_session_get_pwg_url (PublishingPiwigoSession* self) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1571 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (self), NULL);
#line 1572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->pwg_url;
#line 1572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 1572 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 11285 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_session_get_pwg_id (PublishingPiwigoSession* self) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1575 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (self), NULL);
#line 1576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = self->priv->pwg_id;
#line 1576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp1_;
#line 1576 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 11303 "PiwigoPublishing.c"
}


void publishing_piwigo_session_set_pwg_id (PublishingPiwigoSession* self, const gchar* id) {
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (PUBLISHING_PIWIGO_IS_SESSION (self));
#line 1579 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_if_fail (id != NULL);
#line 1580 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = id;
#line 1580 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 1580 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_id);
#line 1580 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_id = _tmp1_;
#line 11322 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_class_init (PublishingPiwigoSessionClass * klass) {
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_session_parent_class = g_type_class_peek_parent (klass);
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingRESTSupportSessionClass *) klass)->finalize = publishing_piwigo_session_finalize;
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPiwigoSessionPrivate));
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingRESTSupportSessionClass *) klass)->is_authenticated = (gboolean (*) (PublishingRESTSupportSession *)) publishing_piwigo_session_real_is_authenticated;
#line 11335 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_instance_init (PublishingPiwigoSession * self) {
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv = PUBLISHING_PIWIGO_SESSION_GET_PRIVATE (self);
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_url = NULL;
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->pwg_id = NULL;
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->username = NULL;
#line 11348 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_finalize (PublishingRESTSupportSession * obj) {
	PublishingPiwigoSession * self;
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_SESSION, PublishingPiwigoSession);
#line 1543 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_url);
#line 1544 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->pwg_id);
#line 1545 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (self->priv->username);
#line 1542 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	PUBLISHING_REST_SUPPORT_SESSION_CLASS (publishing_piwigo_session_parent_class)->finalize (obj);
#line 11364 "PiwigoPublishing.c"
}


/**
 * Session class that keeps track of the authentication status and of the
 * user token pwg_id.
 */
GType publishing_piwigo_session_get_type (void) {
	static volatile gsize publishing_piwigo_session_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_session_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoSessionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_session_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoSession), 0, (GInstanceInitFunc) publishing_piwigo_session_instance_init, NULL };
		GType publishing_piwigo_session_type_id;
		publishing_piwigo_session_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_SESSION, "PublishingPiwigoSession", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_session_type_id__volatile, publishing_piwigo_session_type_id);
	}
	return publishing_piwigo_session_type_id__volatile;
}


PublishingPiwigoTransaction* publishing_piwigo_transaction_construct (GType object_type, PublishingPiwigoSession* session) {
	PublishingPiwigoTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_;
	PublishingPiwigoSession* _tmp1_;
	gboolean _tmp2_;
#line 1593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1594 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoTransaction*) publishing_rest_support_transaction_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1595 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = session;
#line 1595 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1595 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp2_) {
#line 11401 "PiwigoPublishing.c"
		PublishingPiwigoSession* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = session;
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = publishing_piwigo_session_get_pwg_id (_tmp3_);
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = _tmp4_;
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = g_strconcat ("pwg_id=", _tmp5_, NULL);
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = _tmp6_;
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "Cookie", _tmp7_);
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp7_);
#line 1596 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp5_);
#line 11423 "PiwigoPublishing.c"
	}
#line 1593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 11427 "PiwigoPublishing.c"
}


PublishingPiwigoTransaction* publishing_piwigo_transaction_new (PublishingPiwigoSession* session) {
#line 1593 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_transaction_construct (PUBLISHING_PIWIGO_TYPE_TRANSACTION, session);
#line 11434 "PiwigoPublishing.c"
}


PublishingPiwigoTransaction* publishing_piwigo_transaction_construct_authenticated (GType object_type, PublishingPiwigoSession* session) {
	PublishingPiwigoTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_;
	PublishingPiwigoSession* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	PublishingPiwigoSession* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
#line 1600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = session;
#line 1601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_piwigo_session_get_pwg_url (_tmp1_);
#line 1601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _tmp2_;
#line 1601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp3_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1601 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp3_);
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = session;
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = publishing_piwigo_session_get_pwg_id (_tmp4_);
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _tmp5_;
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = g_strconcat ("pwg_id=", _tmp6_, NULL);
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = _tmp7_;
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "Cookie", _tmp8_);
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp8_);
#line 1602 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp6_);
#line 1600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 11481 "PiwigoPublishing.c"
}


PublishingPiwigoTransaction* publishing_piwigo_transaction_new_authenticated (PublishingPiwigoSession* session) {
#line 1600 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_transaction_construct_authenticated (PUBLISHING_PIWIGO_TYPE_TRANSACTION, session);
#line 11488 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_transaction_validate_xml (PublishingRESTSupportXmlDocument* doc) {
	gchar* result = NULL;
	xmlNode* root = NULL;
	PublishingRESTSupportXmlDocument* _tmp0_;
	xmlNode* _tmp1_;
	gchar* status = NULL;
	xmlNode* _tmp2_;
	gchar* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp6_;
	xmlNode* errcode = NULL;
	xmlNode* _tmp12_;
	gchar* _tmp13_;
	gchar* _tmp14_;
	xmlNode* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError * _inner_error_ = NULL;
#line 1605 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_XML_DOCUMENT (doc), NULL);
#line 1606 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = doc;
#line 1606 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishing_rest_support_xml_document_get_root_node (_tmp0_);
#line 1606 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	root = _tmp1_;
#line 1607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = root;
#line 1607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = (gchar*) xmlGetProp (_tmp2_, (xmlChar*) "stat");
#line 1607 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	status = _tmp3_;
#line 1610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = status;
#line 1610 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp4_ == NULL) {
#line 11530 "PiwigoPublishing.c"
		gchar* _tmp5_;
#line 1611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = g_strdup ("No status property in root node");
#line 1611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		result = _tmp5_;
#line 1611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (status);
#line 1611 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return result;
#line 11540 "PiwigoPublishing.c"
	}
#line 1613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = status;
#line 1613 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_strcmp0 (_tmp6_, "ok") == 0) {
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		result = NULL;
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (status);
#line 1614 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return result;
#line 11552 "PiwigoPublishing.c"
	}
	{
		xmlNode* _tmp7_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp8_;
		xmlNode* _tmp9_;
		xmlNode* _tmp10_;
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = doc;
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = root;
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = publishing_rest_support_xml_document_get_named_child (_tmp8_, _tmp9_, "err", &_inner_error_);
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = _tmp10_;
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 11571 "PiwigoPublishing.c"
				goto __catch35_spit_publishing_publishing_error;
			}
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_g_free0 (status);
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return NULL;
#line 11582 "PiwigoPublishing.c"
		}
#line 1618 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		errcode = _tmp7_;
#line 11586 "PiwigoPublishing.c"
	}
	goto __finally35;
	__catch35_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		gchar* _tmp11_;
#line 1617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 1617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 1620 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = g_strdup ("No error code specified");
#line 1620 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		result = _tmp11_;
#line 1620 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 1620 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (status);
#line 1620 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return result;
#line 11607 "PiwigoPublishing.c"
	}
	__finally35:
#line 1617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (status);
#line 1617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 1617 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return NULL;
#line 11620 "PiwigoPublishing.c"
	}
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = errcode;
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = (gchar*) xmlGetProp (_tmp12_, (xmlChar*) "msg");
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = _tmp13_;
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp15_ = errcode;
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = (gchar*) xmlGetProp (_tmp15_, (xmlChar*) "code");
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = _tmp16_;
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = g_strdup_printf ("%s (error code %s)", _tmp14_, _tmp17_);
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp19_ = _tmp18_;
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp17_);
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp14_);
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp19_;
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (status);
#line 1623 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 11648 "PiwigoPublishing.c"
}


gchar* publishing_piwigo_transaction_get_error_code (PublishingRESTSupportXmlDocument* doc) {
	gchar* result = NULL;
	xmlNode* root = NULL;
	PublishingRESTSupportXmlDocument* _tmp0_;
	xmlNode* _tmp1_;
	xmlNode* errcode = NULL;
	xmlNode* _tmp7_;
	gchar* _tmp8_;
	GError * _inner_error_ = NULL;
#line 1626 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_REST_SUPPORT_IS_XML_DOCUMENT (doc), NULL);
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = doc;
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishing_rest_support_xml_document_get_root_node (_tmp0_);
#line 1627 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	root = _tmp1_;
#line 11669 "PiwigoPublishing.c"
	{
		xmlNode* _tmp2_ = NULL;
		PublishingRESTSupportXmlDocument* _tmp3_;
		xmlNode* _tmp4_;
		xmlNode* _tmp5_;
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = doc;
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = root;
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = publishing_rest_support_xml_document_get_named_child (_tmp3_, _tmp4_, "err", &_inner_error_);
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp2_ = _tmp5_;
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_inner_error_->domain == SPIT_PUBLISHING_PUBLISHING_ERROR) {
#line 11687 "PiwigoPublishing.c"
				goto __catch36_spit_publishing_publishing_error;
			}
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			g_clear_error (&_inner_error_);
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			return NULL;
#line 11696 "PiwigoPublishing.c"
		}
#line 1630 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		errcode = _tmp2_;
#line 11700 "PiwigoPublishing.c"
	}
	goto __finally36;
	__catch36_spit_publishing_publishing_error:
	{
		GError* err = NULL;
		gchar* _tmp6_;
#line 1629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		err = _inner_error_;
#line 1629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_inner_error_ = NULL;
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp6_ = g_strdup ("0");
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		result = _tmp6_;
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_error_free0 (err);
#line 1632 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return result;
#line 11719 "PiwigoPublishing.c"
	}
	__finally36:
#line 1629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		g_clear_error (&_inner_error_);
#line 1629 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		return NULL;
#line 11730 "PiwigoPublishing.c"
	}
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp7_ = errcode;
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp8_ = (gchar*) xmlGetProp (_tmp7_, (xmlChar*) "code");
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	result = _tmp8_;
#line 1634 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return result;
#line 11740 "PiwigoPublishing.c"
}


static void publishing_piwigo_transaction_class_init (PublishingPiwigoTransactionClass * klass) {
#line 1592 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_transaction_parent_class = g_type_class_peek_parent (klass);
#line 11747 "PiwigoPublishing.c"
}


static void publishing_piwigo_transaction_instance_init (PublishingPiwigoTransaction * self) {
}


/**
 * Generic REST transaction class.
 *
 * This class implements the generic logic for all REST transactions used
 * by the Piwigo publishing plugin. In particular, it ensures that if the
 * session has been authenticated, the pwg_id token is included in the
 * transaction header.
 */
GType publishing_piwigo_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoTransaction), 0, (GInstanceInitFunc) publishing_piwigo_transaction_instance_init, NULL };
		GType publishing_piwigo_transaction_type_id;
		publishing_piwigo_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, "PublishingPiwigoTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_transaction_type_id__volatile, publishing_piwigo_transaction_type_id);
	}
	return publishing_piwigo_transaction_type_id__volatile;
}


PublishingPiwigoSessionLoginTransaction* publishing_piwigo_session_login_transaction_construct (GType object_type, PublishingPiwigoSession* session, const gchar* url, const gchar* username, const gchar* password) {
	PublishingPiwigoSessionLoginTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (username != NULL, NULL);
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (password != NULL, NULL);
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = url;
#line 1643 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSessionLoginTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1645 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.session.login");
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = username;
#line 1646 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "username", _tmp2_);
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = password;
#line 1647 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "password", _tmp3_);
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 11807 "PiwigoPublishing.c"
}


PublishingPiwigoSessionLoginTransaction* publishing_piwigo_session_login_transaction_new (PublishingPiwigoSession* session, const gchar* url, const gchar* username, const gchar* password) {
#line 1642 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_session_login_transaction_construct (PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION, session, url, username, password);
#line 11814 "PiwigoPublishing.c"
}


static gpointer _publishing_rest_support_argument_ref0 (gpointer self) {
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self ? publishing_rest_support_argument_ref (self) : NULL;
#line 11821 "PiwigoPublishing.c"
}


PublishingPiwigoSessionLoginTransaction* publishing_piwigo_session_login_transaction_construct_from_other (GType object_type, PublishingPiwigoSession* session, PublishingPiwigoTransaction* other) {
	PublishingPiwigoSessionLoginTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_;
	PublishingPiwigoTransaction* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	PublishingPiwigoTransaction* _tmp4_;
	gint _tmp5_;
	PublishingRESTSupportArgument** _tmp6_;
#line 1650 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1650 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_TRANSACTION (other), NULL);
#line 1651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = other;
#line 1651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = publishing_rest_support_transaction_get_endpoint_url (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction));
#line 1651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = _tmp2_;
#line 1651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSessionLoginTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp3_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1651 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp3_);
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = other;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_rest_support_transaction_get_arguments (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), &_tmp5_);
#line 11854 "PiwigoPublishing.c"
	{
		PublishingRESTSupportArgument** argument_collection = NULL;
		gint argument_collection_length1 = 0;
		gint _argument_collection_size_ = 0;
		gint argument_it = 0;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		argument_collection = _tmp6_;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		argument_collection_length1 = _tmp5_;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		for (argument_it = 0; argument_it < _tmp5_; argument_it = argument_it + 1) {
#line 11866 "PiwigoPublishing.c"
			PublishingRESTSupportArgument* _tmp7_;
			PublishingRESTSupportArgument* argument = NULL;
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp7_ = _publishing_rest_support_argument_ref0 (argument_collection[argument_it]);
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			argument = _tmp7_;
#line 11873 "PiwigoPublishing.c"
			{
				PublishingRESTSupportArgument* _tmp8_;
				const gchar* _tmp9_;
				PublishingRESTSupportArgument* _tmp10_;
				const gchar* _tmp11_;
#line 1654 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp8_ = argument;
#line 1654 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp9_ = _tmp8_->key;
#line 1654 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp10_ = argument;
#line 1654 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp11_ = _tmp10_->value;
#line 1654 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), _tmp9_, _tmp11_);
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_publishing_rest_support_argument_unref0 (argument);
#line 11891 "PiwigoPublishing.c"
			}
		}
#line 1653 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		argument_collection = (_vala_array_free (argument_collection, argument_collection_length1, (GDestroyNotify) publishing_rest_support_argument_unref), NULL);
#line 11896 "PiwigoPublishing.c"
	}
#line 1650 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 11900 "PiwigoPublishing.c"
}


PublishingPiwigoSessionLoginTransaction* publishing_piwigo_session_login_transaction_new_from_other (PublishingPiwigoSession* session, PublishingPiwigoTransaction* other) {
#line 1650 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_session_login_transaction_construct_from_other (PUBLISHING_PIWIGO_TYPE_SESSION_LOGIN_TRANSACTION, session, other);
#line 11907 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_login_transaction_class_init (PublishingPiwigoSessionLoginTransactionClass * klass) {
#line 1641 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_session_login_transaction_parent_class = g_type_class_peek_parent (klass);
#line 11914 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_login_transaction_instance_init (PublishingPiwigoSessionLoginTransaction * self) {
}


/**
 * Transaction used to implement the network login interaction.
 */
GType publishing_piwigo_session_login_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_session_login_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_session_login_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoSessionLoginTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_session_login_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoSessionLoginTransaction), 0, (GInstanceInitFunc) publishing_piwigo_session_login_transaction_instance_init, NULL };
		GType publishing_piwigo_session_login_transaction_type_id;
		publishing_piwigo_session_login_transaction_type_id = g_type_register_static (PUBLISHING_PIWIGO_TYPE_TRANSACTION, "PublishingPiwigoSessionLoginTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_session_login_transaction_type_id__volatile, publishing_piwigo_session_login_transaction_type_id);
	}
	return publishing_piwigo_session_login_transaction_type_id__volatile;
}


PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_construct_unauthenticated (GType object_type, PublishingPiwigoSession* session, const gchar* url, const gchar* pwg_id) {
	PublishingPiwigoSessionGetStatusTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_;
	const gchar* _tmp1_;
	PublishingPiwigoSession* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (url != NULL, NULL);
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (pwg_id != NULL, NULL);
#line 1664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = url;
#line 1664 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSessionGetStatusTransaction*) publishing_rest_support_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, PUBLISHING_REST_SUPPORT_HTTP_METHOD_POST);
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = session;
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishing_piwigo_session_get_pwg_id (_tmp2_);
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_;
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = g_strconcat ("pwg_id=", _tmp4_, NULL);
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = _tmp5_;
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "Cookie", _tmp6_);
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp6_);
#line 1665 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp4_);
#line 1667 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.session.getStatus");
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 11978 "PiwigoPublishing.c"
}


PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_new_unauthenticated (PublishingPiwigoSession* session, const gchar* url, const gchar* pwg_id) {
#line 1663 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_session_get_status_transaction_construct_unauthenticated (PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION, session, url, pwg_id);
#line 11985 "PiwigoPublishing.c"
}


PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_construct (GType object_type, PublishingPiwigoSession* session) {
	PublishingPiwigoSessionGetStatusTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_;
#line 1670 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1671 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSessionGetStatusTransaction*) publishing_piwigo_transaction_construct_authenticated (object_type, _tmp0_);
#line 1673 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.session.getStatus");
#line 1670 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 12002 "PiwigoPublishing.c"
}


PublishingPiwigoSessionGetStatusTransaction* publishing_piwigo_session_get_status_transaction_new (PublishingPiwigoSession* session) {
#line 1670 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_session_get_status_transaction_construct (PUBLISHING_PIWIGO_TYPE_SESSION_GET_STATUS_TRANSACTION, session);
#line 12009 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_get_status_transaction_class_init (PublishingPiwigoSessionGetStatusTransactionClass * klass) {
#line 1662 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_session_get_status_transaction_parent_class = g_type_class_peek_parent (klass);
#line 12016 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_get_status_transaction_instance_init (PublishingPiwigoSessionGetStatusTransaction * self) {
}


/**
 * Transaction used to implement the get status interaction.
 */
GType publishing_piwigo_session_get_status_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_session_get_status_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_session_get_status_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoSessionGetStatusTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_session_get_status_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoSessionGetStatusTransaction), 0, (GInstanceInitFunc) publishing_piwigo_session_get_status_transaction_instance_init, NULL };
		GType publishing_piwigo_session_get_status_transaction_type_id;
		publishing_piwigo_session_get_status_transaction_type_id = g_type_register_static (PUBLISHING_PIWIGO_TYPE_TRANSACTION, "PublishingPiwigoSessionGetStatusTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_session_get_status_transaction_type_id__volatile, publishing_piwigo_session_get_status_transaction_type_id);
	}
	return publishing_piwigo_session_get_status_transaction_type_id__volatile;
}


PublishingPiwigoCategoriesGetListTransaction* publishing_piwigo_categories_get_list_transaction_construct (GType object_type, PublishingPiwigoSession* session) {
	PublishingPiwigoCategoriesGetListTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_;
#line 1681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1682 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1682 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoCategoriesGetListTransaction*) publishing_piwigo_transaction_construct_authenticated (object_type, _tmp0_);
#line 1684 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.categories.getList");
#line 1685 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "recursive", "true");
#line 1681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 12054 "PiwigoPublishing.c"
}


PublishingPiwigoCategoriesGetListTransaction* publishing_piwigo_categories_get_list_transaction_new (PublishingPiwigoSession* session) {
#line 1681 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_categories_get_list_transaction_construct (PUBLISHING_PIWIGO_TYPE_CATEGORIES_GET_LIST_TRANSACTION, session);
#line 12061 "PiwigoPublishing.c"
}


static void publishing_piwigo_categories_get_list_transaction_class_init (PublishingPiwigoCategoriesGetListTransactionClass * klass) {
#line 1680 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_categories_get_list_transaction_parent_class = g_type_class_peek_parent (klass);
#line 12068 "PiwigoPublishing.c"
}


static void publishing_piwigo_categories_get_list_transaction_instance_init (PublishingPiwigoCategoriesGetListTransaction * self) {
}


/**
 * Transaction used to implement the fetch categories interaction.
 */
GType publishing_piwigo_categories_get_list_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_categories_get_list_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_categories_get_list_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoCategoriesGetListTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_categories_get_list_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoCategoriesGetListTransaction), 0, (GInstanceInitFunc) publishing_piwigo_categories_get_list_transaction_instance_init, NULL };
		GType publishing_piwigo_categories_get_list_transaction_type_id;
		publishing_piwigo_categories_get_list_transaction_type_id = g_type_register_static (PUBLISHING_PIWIGO_TYPE_TRANSACTION, "PublishingPiwigoCategoriesGetListTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_categories_get_list_transaction_type_id__volatile, publishing_piwigo_categories_get_list_transaction_type_id);
	}
	return publishing_piwigo_categories_get_list_transaction_type_id__volatile;
}


PublishingPiwigoSessionLogoutTransaction* publishing_piwigo_session_logout_transaction_construct (GType object_type, PublishingPiwigoSession* session) {
	PublishingPiwigoSessionLogoutTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_;
#line 1690 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1691 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoSessionLogoutTransaction*) publishing_piwigo_transaction_construct_authenticated (object_type, _tmp0_);
#line 1693 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.session.logout");
#line 1690 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 12104 "PiwigoPublishing.c"
}


PublishingPiwigoSessionLogoutTransaction* publishing_piwigo_session_logout_transaction_new (PublishingPiwigoSession* session) {
#line 1690 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_session_logout_transaction_construct (PUBLISHING_PIWIGO_TYPE_SESSION_LOGOUT_TRANSACTION, session);
#line 12111 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_logout_transaction_class_init (PublishingPiwigoSessionLogoutTransactionClass * klass) {
#line 1689 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_session_logout_transaction_parent_class = g_type_class_peek_parent (klass);
#line 12118 "PiwigoPublishing.c"
}


static void publishing_piwigo_session_logout_transaction_instance_init (PublishingPiwigoSessionLogoutTransaction * self) {
}


GType publishing_piwigo_session_logout_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_session_logout_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_session_logout_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoSessionLogoutTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_session_logout_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoSessionLogoutTransaction), 0, (GInstanceInitFunc) publishing_piwigo_session_logout_transaction_instance_init, NULL };
		GType publishing_piwigo_session_logout_transaction_type_id;
		publishing_piwigo_session_logout_transaction_type_id = g_type_register_static (PUBLISHING_PIWIGO_TYPE_TRANSACTION, "PublishingPiwigoSessionLogoutTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_session_logout_transaction_type_id__volatile, publishing_piwigo_session_logout_transaction_type_id);
	}
	return publishing_piwigo_session_logout_transaction_type_id__volatile;
}


PublishingPiwigoCategoriesAddTransaction* publishing_piwigo_categories_add_transaction_construct (GType object_type, PublishingPiwigoSession* session, const gchar* category, gint parent_id, const gchar* comment) {
	PublishingPiwigoCategoriesAddTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_;
	const gchar* _tmp1_;
	gint _tmp2_;
	const gchar* _tmp6_;
#line 1698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (category != NULL, NULL);
#line 1699 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1699 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoCategoriesAddTransaction*) publishing_piwigo_transaction_construct_authenticated (object_type, _tmp0_);
#line 1701 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.categories.add");
#line 1702 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = category;
#line 1702 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "name", _tmp1_);
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = parent_id;
#line 1704 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp2_ != 0) {
#line 12162 "PiwigoPublishing.c"
		gint _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp3_ = parent_id;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp4_ = g_strdup_printf ("%i", _tmp3_);
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp5_ = _tmp4_;
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "parent", _tmp5_);
#line 1705 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp5_);
#line 12176 "PiwigoPublishing.c"
	}
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = comment;
#line 1708 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (g_strcmp0 (_tmp6_, "") != 0) {
#line 12182 "PiwigoPublishing.c"
		const gchar* _tmp7_;
#line 1709 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = comment;
#line 1709 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "comment", _tmp7_);
#line 12188 "PiwigoPublishing.c"
	}
#line 1698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 12192 "PiwigoPublishing.c"
}


PublishingPiwigoCategoriesAddTransaction* publishing_piwigo_categories_add_transaction_new (PublishingPiwigoSession* session, const gchar* category, gint parent_id, const gchar* comment) {
#line 1698 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_categories_add_transaction_construct (PUBLISHING_PIWIGO_TYPE_CATEGORIES_ADD_TRANSACTION, session, category, parent_id, comment);
#line 12199 "PiwigoPublishing.c"
}


static void publishing_piwigo_categories_add_transaction_class_init (PublishingPiwigoCategoriesAddTransactionClass * klass) {
#line 1697 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_categories_add_transaction_parent_class = g_type_class_peek_parent (klass);
#line 12206 "PiwigoPublishing.c"
}


static void publishing_piwigo_categories_add_transaction_instance_init (PublishingPiwigoCategoriesAddTransaction * self) {
}


GType publishing_piwigo_categories_add_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_categories_add_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_categories_add_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoCategoriesAddTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_categories_add_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoCategoriesAddTransaction), 0, (GInstanceInitFunc) publishing_piwigo_categories_add_transaction_instance_init, NULL };
		GType publishing_piwigo_categories_add_transaction_type_id;
		publishing_piwigo_categories_add_transaction_type_id = g_type_register_static (PUBLISHING_PIWIGO_TYPE_TRANSACTION, "PublishingPiwigoCategoriesAddTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_categories_add_transaction_type_id__volatile, publishing_piwigo_categories_add_transaction_type_id);
	}
	return publishing_piwigo_categories_add_transaction_type_id__volatile;
}


static gchar* _vala_g_strjoinv (const gchar* separator, gchar** str_array, int str_array_length1) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gchar** _tmp3_;
	gint _tmp3__length1;
#line 1078 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp0_ = separator;
#line 1078 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp0_ == NULL) {
#line 1079 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		separator = "";
#line 12239 "PiwigoPublishing.c"
	}
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3_ = str_array;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	_tmp3__length1 = str_array_length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp2_ = TRUE;
#line 12249 "PiwigoPublishing.c"
	} else {
		gchar** _tmp4_;
		gint _tmp4__length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4_ = str_array;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp4__length1 = str_array_length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp2_ = _tmp4__length1 > 0;
#line 12259 "PiwigoPublishing.c"
	}
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp2_) {
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp1_ = TRUE;
#line 12265 "PiwigoPublishing.c"
	} else {
		gboolean _tmp5_ = FALSE;
		gchar** _tmp6_;
		gint _tmp6__length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6_ = str_array;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp6__length1 = str_array_length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		if (_tmp6__length1 == -1) {
#line 12276 "PiwigoPublishing.c"
			gchar** _tmp7_;
			gint _tmp7__length1;
			const gchar* _tmp8_;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp7_ = str_array;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp7__length1 = str_array_length1;
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp8_ = _tmp7_[0];
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp5_ = _tmp8_ != NULL;
#line 12288 "PiwigoPublishing.c"
		} else {
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp5_ = FALSE;
#line 12292 "PiwigoPublishing.c"
		}
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp1_ = _tmp5_;
#line 12296 "PiwigoPublishing.c"
	}
#line 1081 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
	if (_tmp1_) {
#line 12300 "PiwigoPublishing.c"
		gint i = 0;
		gsize len = 0UL;
		gint _tmp31_;
		gint _tmp33_;
		gint _tmp34_;
		gsize _tmp35_;
		const gchar* _tmp36_;
		gint _tmp37_;
		gint _tmp38_;
		gint _tmp39_;
		const gchar* res = NULL;
		gsize _tmp40_;
		void* _tmp41_;
		void* ptr = NULL;
		const gchar* _tmp42_;
		gchar** _tmp43_;
		gint _tmp43__length1;
		const gchar* _tmp44_;
		void* _tmp45_;
		const gchar* _tmp62_;
#line 1083 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		len = (gsize) 1;
#line 12323 "PiwigoPublishing.c"
		{
			gboolean _tmp9_ = FALSE;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			i = 0;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp9_ = TRUE;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 12332 "PiwigoPublishing.c"
				gboolean _tmp11_ = FALSE;
				gboolean _tmp12_ = FALSE;
				gchar** _tmp13_;
				gint _tmp13__length1;
				gint _tmp21_ = 0;
				gchar** _tmp22_;
				gint _tmp22__length1;
				gint _tmp23_;
				const gchar* _tmp24_;
				gsize _tmp30_;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (!_tmp9_) {
#line 12345 "PiwigoPublishing.c"
					gint _tmp10_;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp10_ = i;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					i = _tmp10_ + 1;
#line 12351 "PiwigoPublishing.c"
				}
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp9_ = FALSE;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp13_ = str_array;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp13__length1 = str_array_length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (_tmp13__length1 != -1) {
#line 12361 "PiwigoPublishing.c"
					gint _tmp14_;
					gchar** _tmp15_;
					gint _tmp15__length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp14_ = i;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp15_ = str_array;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp15__length1 = str_array_length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp12_ = _tmp14_ < _tmp15__length1;
#line 12373 "PiwigoPublishing.c"
				} else {
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp12_ = FALSE;
#line 12377 "PiwigoPublishing.c"
				}
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (_tmp12_) {
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp11_ = TRUE;
#line 12383 "PiwigoPublishing.c"
				} else {
					gboolean _tmp16_ = FALSE;
					gchar** _tmp17_;
					gint _tmp17__length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp17_ = str_array;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp17__length1 = str_array_length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					if (_tmp17__length1 == -1) {
#line 12394 "PiwigoPublishing.c"
						gchar** _tmp18_;
						gint _tmp18__length1;
						gint _tmp19_;
						const gchar* _tmp20_;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp18_ = str_array;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp18__length1 = str_array_length1;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp19_ = i;
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp20_ = _tmp18_[_tmp19_];
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp16_ = _tmp20_ != NULL;
#line 12409 "PiwigoPublishing.c"
					} else {
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
						_tmp16_ = FALSE;
#line 12413 "PiwigoPublishing.c"
					}
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp11_ = _tmp16_;
#line 12417 "PiwigoPublishing.c"
				}
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (!_tmp11_) {
#line 1084 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					break;
#line 12423 "PiwigoPublishing.c"
				}
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp22_ = str_array;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp22__length1 = str_array_length1;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp23_ = i;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp24_ = _tmp22_[_tmp23_];
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (_tmp24_ != NULL) {
#line 12435 "PiwigoPublishing.c"
					gchar** _tmp25_;
					gint _tmp25__length1;
					gint _tmp26_;
					const gchar* _tmp27_;
					gint _tmp28_;
					gint _tmp29_;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp25_ = str_array;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp25__length1 = str_array_length1;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp26_ = i;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp27_ = _tmp25_[_tmp26_];
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp28_ = strlen ((const gchar*) _tmp27_);
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp29_ = _tmp28_;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp21_ = _tmp29_;
#line 12456 "PiwigoPublishing.c"
				} else {
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp21_ = 0;
#line 12460 "PiwigoPublishing.c"
				}
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp30_ = len;
#line 1085 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				len = _tmp30_ + _tmp21_;
#line 12466 "PiwigoPublishing.c"
			}
		}
#line 1087 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp31_ = i;
#line 1087 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		if (_tmp31_ == 0) {
#line 12473 "PiwigoPublishing.c"
			gchar* _tmp32_;
#line 1088 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp32_ = g_strdup ("");
#line 1088 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			result = _tmp32_;
#line 1088 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			return result;
#line 12481 "PiwigoPublishing.c"
		}
#line 1090 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp33_ = i;
#line 1090 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		str_array_length1 = _tmp33_;
#line 1090 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp34_ = str_array_length1;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp35_ = len;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp36_ = separator;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp37_ = strlen ((const gchar*) _tmp36_);
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp38_ = _tmp37_;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp39_ = i;
#line 1091 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		len = _tmp35_ + (_tmp38_ * (_tmp39_ - 1));
#line 1093 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp40_ = len;
#line 1093 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp41_ = g_malloc (_tmp40_);
#line 1093 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		res = _tmp41_;
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp42_ = res;
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp43_ = str_array;
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp43__length1 = str_array_length1;
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp44_ = _tmp43_[0];
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp45_ = g_stpcpy ((void*) _tmp42_, (const gchar*) _tmp44_);
#line 1094 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		ptr = _tmp45_;
#line 12519 "PiwigoPublishing.c"
		{
			gboolean _tmp46_ = FALSE;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			i = 1;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			_tmp46_ = TRUE;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
			while (TRUE) {
#line 12528 "PiwigoPublishing.c"
				gint _tmp48_;
				gchar** _tmp49_;
				gint _tmp49__length1;
				void* _tmp50_;
				const gchar* _tmp51_;
				void* _tmp52_;
				const gchar* _tmp53_ = NULL;
				gchar** _tmp54_;
				gint _tmp54__length1;
				gint _tmp55_;
				const gchar* _tmp56_;
				void* _tmp60_;
				void* _tmp61_;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (!_tmp46_) {
#line 12544 "PiwigoPublishing.c"
					gint _tmp47_;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp47_ = i;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					i = _tmp47_ + 1;
#line 12550 "PiwigoPublishing.c"
				}
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp46_ = FALSE;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp48_ = i;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp49_ = str_array;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp49__length1 = str_array_length1;
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (!(_tmp48_ < _tmp49__length1)) {
#line 1095 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					break;
#line 12564 "PiwigoPublishing.c"
				}
#line 1096 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp50_ = ptr;
#line 1096 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp51_ = separator;
#line 1096 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp52_ = g_stpcpy (_tmp50_, (const gchar*) _tmp51_);
#line 1096 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				ptr = _tmp52_;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp54_ = str_array;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp54__length1 = str_array_length1;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp55_ = i;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp56_ = _tmp54_[_tmp55_];
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				if (_tmp56_ != NULL) {
#line 12584 "PiwigoPublishing.c"
					gchar** _tmp57_;
					gint _tmp57__length1;
					gint _tmp58_;
					const gchar* _tmp59_;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp57_ = str_array;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp57__length1 = str_array_length1;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp58_ = i;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp59_ = _tmp57_[_tmp58_];
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp53_ = (const gchar*) _tmp59_;
#line 12599 "PiwigoPublishing.c"
				} else {
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
					_tmp53_ = "";
#line 12603 "PiwigoPublishing.c"
				}
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp60_ = ptr;
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				_tmp61_ = g_stpcpy (_tmp60_, _tmp53_);
#line 1097 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
				ptr = _tmp61_;
#line 12611 "PiwigoPublishing.c"
			}
		}
#line 1100 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp62_ = res;
#line 1100 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		res = NULL;
#line 1100 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = (gchar*) _tmp62_;
#line 1100 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 12622 "PiwigoPublishing.c"
	} else {
		gchar* _tmp63_;
#line 1102 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		_tmp63_ = g_strdup ("");
#line 1102 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		result = _tmp63_;
#line 1102 "/usr/share/vala-0.36/vapi/glib-2.0.vapi"
		return result;
#line 12631 "PiwigoPublishing.c"
	}
}


static void _g_free0_ (gpointer var) {
#line 1774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	var = (g_free (var), NULL);
#line 12639 "PiwigoPublishing.c"
}


PublishingPiwigoImagesAddTransaction* publishing_piwigo_images_add_transaction_construct (GType object_type, PublishingPiwigoSession* session, PublishingPiwigoPublishingParameters* parameters, SpitPublishingPublishable* publishable) {
	PublishingPiwigoImagesAddTransaction* self = NULL;
	PublishingPiwigoSession* _tmp0_;
	SpitPublishingPublishable* _tmp1_;
	PublishingPiwigoSession* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	PublishingPiwigoSession* _tmp5_;
	gboolean _tmp6_;
	PublishingPiwigoPublishingParameters* _tmp12_;
	PublishingPiwigoPublishingParameters* _tmp13_;
	gchar** keywords = NULL;
	SpitPublishingPublishable* _tmp14_;
	gint _tmp15_;
	gchar** _tmp16_;
	gint keywords_length1;
	gint _keywords_size_;
	gchar* tags = NULL;
	gchar* _tmp17_;
	gchar** _tmp18_;
	gint _tmp18__length1;
	SpitPublishingPublishable* _tmp21_;
	GFile* _tmp22_;
	GFile* _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	PublishingPiwigoPublishingParameters* _tmp26_;
	PublishingPiwigoCategory* _tmp27_;
	gint _tmp28_;
	PublishingPiwigoPublishingParameters* _tmp29_;
	PublishingPiwigoPermissionLevel* _tmp30_;
	gint _tmp31_;
	gchar* name = NULL;
	SpitPublishingPublishable* _tmp32_;
	gchar* _tmp33_;
	gchar* comment = NULL;
	SpitPublishingPublishable* _tmp34_;
	gchar* _tmp35_;
	gboolean _tmp36_ = FALSE;
	const gchar* _tmp37_;
	PublishingPiwigoPublishingParameters* _tmp55_;
	PublishingPiwigoCategory* _tmp56_;
	gint _tmp57_;
	gchar* _tmp58_;
	gchar* _tmp59_;
	PublishingPiwigoPublishingParameters* _tmp60_;
	PublishingPiwigoPermissionLevel* _tmp61_;
	gint _tmp62_;
	gchar* _tmp63_;
	gchar* _tmp64_;
	PublishingPiwigoPublishingParameters* _tmp65_;
	gboolean _tmp66_;
	GHashTable* disposition_table = NULL;
	GHashFunc _tmp69_;
	GEqualFunc _tmp70_;
	GHashTable* _tmp71_;
	gchar* basename = NULL;
	SpitPublishingPublishable* _tmp72_;
	gchar* _tmp73_;
	gboolean _tmp74_ = FALSE;
	const gchar* _tmp75_;
	gchar* _tmp76_;
	gchar* _tmp77_;
	gboolean _tmp78_;
	gboolean _tmp79_;
	GHashTable* _tmp86_;
	gchar* _tmp87_;
	const gchar* _tmp88_;
	gchar* _tmp89_;
	GHashTable* _tmp90_;
	gchar* _tmp91_;
	gchar* _tmp92_;
	GHashTable* _tmp93_;
#line 1717 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_SESSION (session), NULL);
#line 1717 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (PUBLISHING_PIWIGO_IS_PUBLISHING_PARAMETERS (parameters), NULL);
#line 1717 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_return_val_if_fail (SPIT_PUBLISHING_IS_PUBLISHABLE (publishable), NULL);
#line 1718 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp0_ = session;
#line 1718 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp1_ = publishable;
#line 1718 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp2_ = session;
#line 1718 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp3_ = publishing_piwigo_session_get_pwg_url (_tmp2_);
#line 1718 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp4_ = _tmp3_;
#line 1718 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = (PublishingPiwigoImagesAddTransaction*) publishing_rest_support_upload_transaction_construct_with_endpoint_url (object_type, G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession), _tmp1_, _tmp4_);
#line 1718 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp4_);
#line 1719 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp5_ = session;
#line 1719 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp6_ = publishing_rest_support_session_is_authenticated (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, PUBLISHING_REST_SUPPORT_TYPE_SESSION, PublishingRESTSupportSession));
#line 1719 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp6_) {
#line 12742 "PiwigoPublishing.c"
		PublishingPiwigoSession* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
#line 1720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp7_ = session;
#line 1720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp8_ = publishing_piwigo_session_get_pwg_id (_tmp7_);
#line 1720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp9_ = _tmp8_;
#line 1720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp10_ = g_strconcat ("pwg_id=", _tmp9_, NULL);
#line 1720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp11_ = _tmp10_;
#line 1720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_add_header (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "Cookie", _tmp11_);
#line 1720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp11_);
#line 1720 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp9_);
#line 12764 "PiwigoPublishing.c"
	}
#line 1722 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp12_ = parameters;
#line 1722 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp13_ = _publishing_piwigo_publishing_parameters_ref0 (_tmp12_);
#line 1722 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (self->priv->parameters);
#line 1722 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->parameters = _tmp13_;
#line 1724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp14_ = publishable;
#line 1724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp16_ = spit_publishing_publishable_get_publishing_keywords (_tmp14_, &_tmp15_);
#line 1724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	keywords = _tmp16_;
#line 1724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	keywords_length1 = _tmp15_;
#line 1724 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_keywords_size_ = keywords_length1;
#line 1725 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp17_ = g_strdup ("");
#line 1725 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	tags = _tmp17_;
#line 1726 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18_ = keywords;
#line 1726 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp18__length1 = keywords_length1;
#line 1726 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp18_ != NULL) {
#line 12794 "PiwigoPublishing.c"
		gchar** _tmp19_;
		gint _tmp19__length1;
		gchar* _tmp20_;
#line 1727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp19_ = keywords;
#line 1727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp19__length1 = keywords_length1;
#line 1727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp20_ = _vala_g_strjoinv (",", _tmp19_, _tmp19__length1);
#line 1727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (tags);
#line 1727 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		tags = _tmp20_;
#line 12808 "PiwigoPublishing.c"
	}
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp21_ = publishable;
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp22_ = spit_publishing_publishable_get_serialized_file (_tmp21_);
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp23_ = _tmp22_;
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp24_ = g_file_get_basename (_tmp23_);
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp25_ = _tmp24_;
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp26_ = parameters;
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp27_ = _tmp26_->category;
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp28_ = _tmp27_->id;
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp29_ = parameters;
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp30_ = _tmp29_->perm_level;
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp31_ = _tmp30_->id;
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_debug ("PiwigoPublishing.vala:1730: PiwigoConnector: Uploading photo %s to cat" \
"egory id %d with perm level %d", _tmp25_, _tmp28_, _tmp31_);
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp25_);
#line 1730 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_object_unref0 (_tmp23_);
#line 1733 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp32_ = publishable;
#line 1733 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp33_ = spit_publishing_publishable_get_publishing_name (_tmp32_);
#line 1733 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	name = _tmp33_;
#line 1734 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp34_ = publishable;
#line 1734 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp35_ = spit_publishing_publishable_get_param_string (_tmp34_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_COMMENT);
#line 1734 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	comment = _tmp35_;
#line 1736 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp37_ = name;
#line 1736 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp37_ == NULL) {
#line 1736 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp36_ = TRUE;
#line 12856 "PiwigoPublishing.c"
	} else {
		const gchar* _tmp38_;
#line 1736 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp38_ = name;
#line 1736 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp36_ = g_strcmp0 (_tmp38_, "") == 0;
#line 12863 "PiwigoPublishing.c"
	}
#line 1736 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp36_) {
#line 12867 "PiwigoPublishing.c"
		SpitPublishingPublishable* _tmp39_;
		gchar* _tmp40_;
		const gchar* _tmp41_;
		gboolean _tmp42_ = FALSE;
		const gchar* _tmp43_;
#line 1737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp39_ = publishable;
#line 1737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp40_ = spit_publishing_publishable_get_param_string (_tmp39_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 1737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (name);
#line 1737 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		name = _tmp40_;
#line 1739 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp41_ = name;
#line 1739 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "name", _tmp41_);
#line 1740 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp43_ = comment;
#line 1740 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp43_ != NULL) {
#line 12889 "PiwigoPublishing.c"
			const gchar* _tmp44_;
#line 1740 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp44_ = comment;
#line 1740 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp42_ = g_strcmp0 (_tmp44_, "") != 0;
#line 12895 "PiwigoPublishing.c"
		} else {
#line 1740 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp42_ = FALSE;
#line 12899 "PiwigoPublishing.c"
		}
#line 1740 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp42_) {
#line 12903 "PiwigoPublishing.c"
			const gchar* _tmp45_;
#line 1741 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp45_ = comment;
#line 1741 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "comment", _tmp45_);
#line 12909 "PiwigoPublishing.c"
		}
	} else {
		gboolean _tmp46_ = FALSE;
		const gchar* _tmp47_;
#line 1745 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp47_ = comment;
#line 1745 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp47_ != NULL) {
#line 12918 "PiwigoPublishing.c"
			const gchar* _tmp48_;
#line 1745 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp48_ = comment;
#line 1745 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp46_ = g_strcmp0 (_tmp48_, "") != 0;
#line 12924 "PiwigoPublishing.c"
		} else {
#line 1745 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp46_ = FALSE;
#line 12928 "PiwigoPublishing.c"
		}
#line 1745 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (_tmp46_) {
#line 12932 "PiwigoPublishing.c"
			const gchar* _tmp49_;
			const gchar* _tmp50_;
#line 1746 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp49_ = name;
#line 1746 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "name", _tmp49_);
#line 1747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp50_ = comment;
#line 1747 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "comment", _tmp50_);
#line 12943 "PiwigoPublishing.c"
		} else {
			PublishingPiwigoPublishingParameters* _tmp51_;
			gboolean _tmp52_;
#line 1752 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp51_ = parameters;
#line 1752 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp52_ = _tmp51_->title_as_comment;
#line 1752 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			if (_tmp52_) {
#line 12953 "PiwigoPublishing.c"
				const gchar* _tmp53_;
#line 1753 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp53_ = name;
#line 1753 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "comment", _tmp53_);
#line 12959 "PiwigoPublishing.c"
			} else {
				const gchar* _tmp54_;
#line 1755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				_tmp54_ = name;
#line 1755 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
				publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "name", _tmp54_);
#line 12966 "PiwigoPublishing.c"
			}
		}
	}
#line 1759 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "method", "pwg.images.addSimple");
#line 1760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp55_ = parameters;
#line 1760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp56_ = _tmp55_->category;
#line 1760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp57_ = _tmp56_->id;
#line 1760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp58_ = g_strdup_printf ("%i", _tmp57_);
#line 1760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp59_ = _tmp58_;
#line 1760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "category", _tmp59_);
#line 1760 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp59_);
#line 1761 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp60_ = parameters;
#line 1761 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp61_ = _tmp60_->perm_level;
#line 1761 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp62_ = _tmp61_->id;
#line 1761 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp63_ = g_strdup_printf ("%i", _tmp62_);
#line 1761 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp64_ = _tmp63_;
#line 1761 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "level", _tmp64_);
#line 1761 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp64_);
#line 1762 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp65_ = parameters;
#line 1762 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp66_ = _tmp65_->no_upload_tags;
#line 1762 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (!_tmp66_) {
#line 13006 "PiwigoPublishing.c"
		const gchar* _tmp67_;
#line 1763 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp67_ = tags;
#line 1763 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		if (g_strcmp0 (_tmp67_, "") != 0) {
#line 13012 "PiwigoPublishing.c"
			const gchar* _tmp68_;
#line 1764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			_tmp68_ = tags;
#line 1764 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
			publishing_rest_support_transaction_add_argument (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_TRANSACTION, PublishingRESTSupportTransaction), "tags", _tmp68_);
#line 13018 "PiwigoPublishing.c"
		}
	}
#line 1774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp69_ = g_str_hash;
#line 1774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp70_ = g_str_equal;
#line 1774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp71_ = g_hash_table_new_full (_tmp69_, _tmp70_, _g_free0_, _g_free0_);
#line 1774 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	disposition_table = _tmp71_;
#line 1776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp72_ = publishable;
#line 1776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp73_ = spit_publishing_publishable_get_param_string (_tmp72_, SPIT_PUBLISHING_PUBLISHABLE_PARAM_STRING_BASENAME);
#line 1776 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	basename = _tmp73_;
#line 1777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp75_ = basename;
#line 1777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp76_ = g_utf8_strdown (_tmp75_, (gssize) -1);
#line 1777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp77_ = _tmp76_;
#line 1777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp78_ = g_str_has_suffix (_tmp77_, ".jpeg");
#line 1777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp79_ = !_tmp78_;
#line 1777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (_tmp77_);
#line 1777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp79_) {
#line 13049 "PiwigoPublishing.c"
		const gchar* _tmp80_;
		gchar* _tmp81_;
		gchar* _tmp82_;
		gboolean _tmp83_;
#line 1778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp80_ = basename;
#line 1778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp81_ = g_utf8_strdown (_tmp80_, (gssize) -1);
#line 1778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp82_ = _tmp81_;
#line 1778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp83_ = g_str_has_suffix (_tmp82_, ".jpg");
#line 1778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp74_ = !_tmp83_;
#line 1778 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (_tmp82_);
#line 13066 "PiwigoPublishing.c"
	} else {
#line 1777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp74_ = FALSE;
#line 13070 "PiwigoPublishing.c"
	}
#line 1777 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	if (_tmp74_) {
#line 13074 "PiwigoPublishing.c"
		const gchar* _tmp84_;
		gchar* _tmp85_;
#line 1779 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp84_ = basename;
#line 1779 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_tmp85_ = g_strconcat (_tmp84_, ".jpg", NULL);
#line 1779 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		_g_free0 (basename);
#line 1779 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
		basename = _tmp85_;
#line 13085 "PiwigoPublishing.c"
	}
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp86_ = disposition_table;
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp87_ = g_strdup ("filename");
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp88_ = basename;
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp89_ = soup_uri_encode (_tmp88_, NULL);
#line 1781 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_hash_table_insert (_tmp86_, _tmp87_, _tmp89_);
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp90_ = disposition_table;
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp91_ = g_strdup ("name");
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp92_ = g_strdup ("image");
#line 1782 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_hash_table_insert (_tmp90_, _tmp91_, _tmp92_);
#line 1784 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_tmp93_ = disposition_table;
#line 1784 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_rest_support_upload_transaction_set_binary_disposition_table (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, PublishingRESTSupportUploadTransaction), _tmp93_);
#line 1717 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (basename);
#line 1717 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_hash_table_unref0 (disposition_table);
#line 1717 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (comment);
#line 1717 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (name);
#line 1717 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_g_free0 (tags);
#line 1717 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	keywords = (_vala_array_free (keywords, keywords_length1, (GDestroyNotify) g_free), NULL);
#line 1717 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return self;
#line 13123 "PiwigoPublishing.c"
}


PublishingPiwigoImagesAddTransaction* publishing_piwigo_images_add_transaction_new (PublishingPiwigoSession* session, PublishingPiwigoPublishingParameters* parameters, SpitPublishingPublishable* publishable) {
#line 1717 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	return publishing_piwigo_images_add_transaction_construct (PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION, session, parameters, publishable);
#line 13130 "PiwigoPublishing.c"
}


static void publishing_piwigo_images_add_transaction_class_init (PublishingPiwigoImagesAddTransactionClass * klass) {
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	publishing_piwigo_images_add_transaction_parent_class = g_type_class_peek_parent (klass);
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	((PublishingRESTSupportTransactionClass *) klass)->finalize = publishing_piwigo_images_add_transaction_finalize;
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	g_type_class_add_private (klass, sizeof (PublishingPiwigoImagesAddTransactionPrivate));
#line 13141 "PiwigoPublishing.c"
}


static void publishing_piwigo_images_add_transaction_instance_init (PublishingPiwigoImagesAddTransaction * self) {
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv = PUBLISHING_PIWIGO_IMAGES_ADD_TRANSACTION_GET_PRIVATE (self);
#line 1715 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self->priv->parameters = NULL;
#line 13150 "PiwigoPublishing.c"
}


static void publishing_piwigo_images_add_transaction_finalize (PublishingRESTSupportTransaction * obj) {
	PublishingPiwigoImagesAddTransaction * self;
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_PIWIGO_TYPE_IMAGES_ADD_TRANSACTION, PublishingPiwigoImagesAddTransaction);
#line 1715 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	_publishing_piwigo_publishing_parameters_unref0 (self->priv->parameters);
#line 1714 "/home/jens/Source/shotwell/plugins/shotwell-publishing/PiwigoPublishing.vala"
	PUBLISHING_REST_SUPPORT_TRANSACTION_CLASS (publishing_piwigo_images_add_transaction_parent_class)->finalize (obj);
#line 13162 "PiwigoPublishing.c"
}


GType publishing_piwigo_images_add_transaction_get_type (void) {
	static volatile gsize publishing_piwigo_images_add_transaction_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_piwigo_images_add_transaction_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingPiwigoImagesAddTransactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_piwigo_images_add_transaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingPiwigoImagesAddTransaction), 0, (GInstanceInitFunc) publishing_piwigo_images_add_transaction_instance_init, NULL };
		GType publishing_piwigo_images_add_transaction_type_id;
		publishing_piwigo_images_add_transaction_type_id = g_type_register_static (PUBLISHING_REST_SUPPORT_TYPE_UPLOAD_TRANSACTION, "PublishingPiwigoImagesAddTransaction", &g_define_type_info, 0);
		g_once_init_leave (&publishing_piwigo_images_add_transaction_type_id__volatile, publishing_piwigo_images_add_transaction_type_id);
	}
	return publishing_piwigo_images_add_transaction_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



